@@ -6,7 +6,7 @@
  * \author Urs Fleisch
  * \date 10 Aug 2013
  *
- * Copyright (C) 2013-2014  Urs Fleisch
+ * Copyright (C) 2013-2018  Urs Fleisch
  *
  * This file is part of Kid3.
  *
@@ -24,8 +24,7 @@
  * along with this program.  If not, see <http://www.gnu.org/licenses/>.
  */
 
-#ifndef ABSTRACTCLI_H
-#define ABSTRACTCLI_H
+#pragma once
 
 #include <QObject>
 
@@ -38,7 +37,13 @@ public:
   /**
    * Destructor.
    */
-  virtual ~AbstractCliIO();
+  virtual ~AbstractCliIO() override;
+
+  /**
+   * Can be reimplemented for cleanup, e.g. restoring the terminal.
+   * Is called from the destructor.
+   */
+  virtual void cleanup();
 
   /**
    * Write a line to standard output.
@@ -97,12 +102,12 @@ public:
    * @param io I/O handler
    * @param parent parent object
    */
-  explicit AbstractCli(AbstractCliIO* io, QObject* parent = 0);
+  explicit AbstractCli(AbstractCliIO* io, QObject* parent = nullptr);
 
   /**
    * Destructor.
    */
-  virtual ~AbstractCli();
+  virtual ~AbstractCli() override = default;
 
   /**
    * Write a line to standard output.
@@ -162,6 +167,5 @@ private slots:
 private:
   AbstractCliIO* m_io;
   int m_returnCode;
+  bool m_terminating;
 };
-
-#endif // ABSTRACTCLI_H
