@@ -6,7 +6,7 @@
  * \author Urs Fleisch
  * \date 11 Aug 2013
  *
- * Copyright (C) 2013  Urs Fleisch
+ * Copyright (C) 2013-2018  Urs Fleisch
  *
  * This file is part of Kid3.
  *
@@ -33,6 +33,7 @@
 #include "kid3application.h"
 #include "fileproxymodel.h"
 #include "frametablemodel.h"
+#include "filefilter.h"
 #include "importconfig.h"
 #include "exportconfig.h"
 #include "filterconfig.h"
@@ -44,8 +45,12 @@
 #include "dirrenamer.h"
 #include "audioplayer.h"
 
+namespace {
+
 /** Default command timeout in milliseconds. */
-static const int DEFAULT_TIMEOUT_MS = 3000;
+const int DEFAULT_TIMEOUT_MS = 3000;
+
+}
 
 /**
  * Constructor.
@@ -56,16 +61,9 @@ static const int DEFAULT_TIMEOUT_MS = 3000;
  */
 CliCommand::CliCommand(Kid3Cli* processor,
                        const QString& name, const QString& help,
-                       const QString& argspec) :
-  QObject(processor), m_processor(processor), m_name(name), m_help(help),
-  m_argspec(argspec), m_timerId(0), m_timeoutMs(DEFAULT_TIMEOUT_MS), m_result(0)
-{
-}
-
-/**
- * Destructor.
- */
-CliCommand::~CliCommand()
+                       const QString& argspec)
+  : QObject(processor), m_processor(processor), m_name(name), m_help(help),
+    m_argspec(argspec), m_timerId(0), m_timeoutMs(DEFAULT_TIMEOUT_MS), m_result(0)
 {
 }
 
@@ -123,7 +121,7 @@ void CliCommand::terminate() {
  */
 void CliCommand::connectResultSignal()
 {
-  QTimer::singleShot(0, this, SLOT(terminate()));
+  QTimer::singleShot(0, this, &CliCommand::terminate);
 }
 
 /**
@@ -185,9 +183,9 @@ void CliCommand::showUsage()
 
 
 
-HelpCommand::HelpCommand(Kid3Cli* processor) :
-  CliCommand(processor, QLatin1String("help"), tr("Help"),
-             QLatin1String("[S]\nS = ") + tr("Command name"))
+HelpCommand::HelpCommand(Kid3Cli* processor)
+  : CliCommand(processor, QLatin1String("help"), tr("Help"),
+               QLatin1String("[S]\nS = ") + tr("Command name"))
 {
 }
 
@@ -197,10 +195,10 @@ void HelpCommand::startCommand()
 }
 
 
-TimeoutCommand::TimeoutCommand(Kid3Cli* processor) :
-  CliCommand(processor, QLatin1String("timeout"), tr("Overwrite timeout"),
-             QLatin1String("[S]\nS = \"default\" | \"off\" | ") + tr("Time") +
-             QLatin1String(" [ms]"))
+TimeoutCommand::TimeoutCommand(Kid3Cli* processor)
+  : CliCommand(processor, QLatin1String("timeout"), tr("Overwrite timeout"),
+               QLatin1String("[S]\nS = \"default\" | \"off\" | ") + tr("Time") +
+               QLatin1String(" [ms]"))
 {
 }
 
@@ -236,9 +234,9 @@ void TimeoutCommand::startCommand()
 }
 
 
-QuitCommand::QuitCommand(Kid3Cli* processor) :
-  CliCommand(processor, QLatin1String("exit"), tr("Quit application"),
-             QLatin1String("[S]\nS = \"force\""))
+QuitCommand::QuitCommand(Kid3Cli* processor)
+  : CliCommand(processor, QLatin1String("exit"), tr("Quit application"),
+               QLatin1String("[S]\nS = \"force\""))
 {
 }
 
@@ -252,7 +250,7 @@ void QuitCommand::startCommand()
       return;
     }
   }
-  disconnect(this, SIGNAL(finished()), cli(), SLOT(onCommandFinished()));
+  disconnect(this, &CliCommand::finished, cli(), &Kid3Cli::onCommandFinished);
   cli()->terminate();
 }
 
@@ -262,9 +260,9 @@ void QuitCommand::connectResultSignal()
 }
 
 
-CdCommand::CdCommand(Kid3Cli* processor) :
-  CliCommand(processor, QLatin1String("cd"), tr("Change directory"),
-             QLatin1String("[P]"))
+CdCommand::CdCommand(Kid3Cli* processor)
+  : CliCommand(processor, QLatin1String("cd"), tr("Change directory"),
+               QLatin1String("[P]"))
 {
 }
 
@@ -276,7 +274,7 @@ void CdCommand::startCommand()
   } else {
     paths.append(QDir::homePath());
   }
-  if (!cli()->openDirectory(cli()->expandWildcards(paths))) {
+  if (!cli()->openDirectory(Kid3Cli::expandWildcards(paths))) {
     setError(tr("%1 does not exist").arg(paths.join(QLatin1String(", "))));
     terminate();
   }
@@ -284,20 +282,20 @@ void CdCommand::startCommand()
 
 void CdCommand::connectResultSignal()
 {
-  connect(cli()->app(), SIGNAL(directoryOpened()),
-    this, SLOT(terminate()));
+  connect(cli()->app(), &Kid3Application::directoryOpened,
+    this, &CdCommand::terminate);
 }
 
 void CdCommand::disconnectResultSignal()
 {
-  disconnect(cli()->app(), SIGNAL(directoryOpened()),
-    this, SLOT(terminate()));
+  disconnect(cli()->app(), &Kid3Application::directoryOpened,
+    this, &CdCommand::terminate);
 }
 
 
-PwdCommand::PwdCommand(Kid3Cli* processor) :
-  CliCommand(processor, QLatin1String("pwd"),
-             tr("Print the filename of the current working directory"))
+PwdCommand::PwdCommand(Kid3Cli* processor)
+  : CliCommand(processor, QLatin1String("pwd"),
+               tr("Print the filename of the current working directory"))
 {
 }
 
@@ -306,14 +304,14 @@ void PwdCommand::startCommand()
   QString path = cli()->app()->getDirPath();
   if (path.isNull()) {
     path = QDir::currentPath();
-    cli()->app()->openDirectory(QStringList() << path);
+    cli()->app()->openDirectory({path});
   }
   cli()->writeLine(path);
 }
 
 
-LsCommand::LsCommand(Kid3Cli* processor) :
-  CliCommand(processor, QLatin1String("ls"), tr("Directory list"))
+LsCommand::LsCommand(Kid3Cli* processor)
+  : CliCommand(processor, QLatin1String("ls"), tr("Directory list"))
 {
   setTimeout(10000);
 }
@@ -324,8 +322,8 @@ void LsCommand::startCommand()
 }
 
 
-SaveCommand::SaveCommand(Kid3Cli* processor) :
-  CliCommand(processor, QLatin1String("save"), tr("Saves the changed files"))
+SaveCommand::SaveCommand(Kid3Cli* processor)
+  : CliCommand(processor, QLatin1String("save"), tr("Saves the changed files"))
 {
 }
 
@@ -341,10 +339,10 @@ void SaveCommand::startCommand()
 }
 
 
-SelectCommand::SelectCommand(Kid3Cli* processor) :
-  CliCommand(processor, QLatin1String("select"), tr("Select file"),
-             QLatin1String("[P|S]\n"
-             "S = \"all\" | \"none\" | \"first\" | \"previous\" | \"next\""))
+SelectCommand::SelectCommand(Kid3Cli* processor)
+  : CliCommand(processor, QLatin1String("select"), tr("Select file"),
+               QLatin1String("[P|S]\n"
+                "S = \"all\" | \"none\" | \"first\" | \"previous\" | \"next\""))
 {
 }
 
@@ -364,7 +362,7 @@ void SelectCommand::startCommand()
       setResult(cli()->app()->nextFile(true) ? 0 : 1);
     } else {
       QStringList paths = args().mid(1);
-      if (!cli()->selectFile(cli()->expandWildcards(paths))) {
+      if (!cli()->selectFile(Kid3Cli::expandWildcards(paths))) {
         setError(tr("%1 not found").arg(paths.join(QLatin1String(", "))));
       }
     }
@@ -374,9 +372,9 @@ void SelectCommand::startCommand()
 }
 
 
-TagCommand::TagCommand(Kid3Cli* processor) :
-  CliCommand(processor, QLatin1String("tag"), tr("Select tag"),
-             QLatin1String("[T]"))
+TagCommand::TagCommand(Kid3Cli* processor)
+  : CliCommand(processor, QLatin1String("tag"), tr("Select tag"),
+               QLatin1String("[T]"))
 {
 }
 
@@ -391,9 +389,9 @@ void TagCommand::startCommand()
 }
 
 
-GetCommand::GetCommand(Kid3Cli* processor) :
-  CliCommand(processor, QLatin1String("get"), tr("Get tag frame"),
-             QLatin1String("[N|S] [T]\nS = \"all\""))
+GetCommand::GetCommand(Kid3Cli* processor)
+  : CliCommand(processor, QLatin1String("get"), tr("Get tag frame"),
+               QLatin1String("[N|S] [T]\nS = \"all\""))
 {
 }
 
@@ -407,7 +405,7 @@ void GetCommand::startCommand()
   if (name == QLatin1String("all")) {
     cli()->writeFileInformation(tagMask);
   } else {
-    foreach (Frame::TagNumber tagNr, Frame::tagNumbersFromMask(tagMask)) {
+    for (Frame::TagNumber tagNr : Frame::tagNumbersFromMask(tagMask)) {
       QString value = cli()->app()->getFrame(Frame::tagVersionFromNumber(tagNr),
                                              name);
       if (!(tagNr == Frame::Tag_1 ? value.isEmpty() : value.isNull())) {
@@ -419,9 +417,9 @@ void GetCommand::startCommand()
 }
 
 
-SetCommand::SetCommand(Kid3Cli* processor) :
-  CliCommand(processor, QLatin1String("set"), tr("Set tag frame"),
-             QLatin1String("N V [T]"))
+SetCommand::SetCommand(Kid3Cli* processor)
+  : CliCommand(processor, QLatin1String("set"), tr("Set tag frame"),
+               QLatin1String("N V [T]"))
 {
 }
 
@@ -438,7 +436,7 @@ void SetCommand::startCommand()
         cli()->updateSelection();
       }
     } else if (!value.isEmpty()) {
-      setError(tr("Could not set \"%1\" for %2").arg(value).arg(name));
+      setError(tr("Could not set \"%1\" for %2").arg(value, name));
     }
   } else {
     showUsage();
@@ -446,9 +444,9 @@ void SetCommand::startCommand()
 }
 
 
-RevertCommand::RevertCommand(Kid3Cli* processor) :
-  CliCommand(processor, QLatin1String("revert"),
-             tr("Revert"))
+RevertCommand::RevertCommand(Kid3Cli* processor)
+  : CliCommand(processor, QLatin1String("revert"),
+               tr("Revert"))
 {
 }
 
@@ -458,13 +456,13 @@ void RevertCommand::startCommand()
 }
 
 
-ImportCommand::ImportCommand(Kid3Cli* processor) :
-  CliCommand(processor, QLatin1String("import"),
-             tr("Import from file"),
-             QLatin1String("P S [T]\nP S = ") +
-             tr("File path") + QLatin1Char(' ') + tr("Format name") +
-             QLatin1String(" | tags ") + tr("Source") + QLatin1Char(' ') +
-             tr("Extraction"))
+ImportCommand::ImportCommand(Kid3Cli* processor)
+  : CliCommand(processor, QLatin1String("import"),
+               tr("Import from file"),
+               QLatin1String("P S [T]\nP S = ") +
+               tr("File path") + QLatin1Char(' ') + tr("Format name") +
+               QLatin1String(" | tags ") + tr("Source") + QLatin1Char(' ') +
+               tr("Extraction"))
 {
 }
 
@@ -505,10 +503,10 @@ void ImportCommand::startCommand()
 }
 
 
-BatchImportCommand::BatchImportCommand(Kid3Cli* processor) :
-  CliCommand(processor, QLatin1String("autoimport"),
-             tr("Automatic import"), QLatin1String("[S] [T]\nS = ") +
-             tr("Profile name"))
+BatchImportCommand::BatchImportCommand(Kid3Cli* processor)
+  : CliCommand(processor, QLatin1String("autoimport"),
+               tr("Automatic import"), QLatin1String("[S] [T]\nS = ") +
+               tr("Profile name"))
 {
   setTimeout(60000);
 }
@@ -535,19 +533,19 @@ void BatchImportCommand::startCommand()
 void BatchImportCommand::connectResultSignal()
 {
   BatchImporter* importer = cli()->app()->getBatchImporter();
-  connect(importer, SIGNAL(reportImportEvent(int,QString)),
-          this, SLOT(onReportImportEvent(int,QString)));
-  connect(importer, SIGNAL(finished()),
-          this, SLOT(terminate()));
+  connect(importer, &BatchImporter::reportImportEvent,
+          this, &BatchImportCommand::onReportImportEvent);
+  connect(importer, &BatchImporter::finished,
+          this, &BatchImportCommand::terminate);
 }
 
 void BatchImportCommand::disconnectResultSignal()
 {
   BatchImporter* importer = cli()->app()->getBatchImporter();
-  disconnect(importer, SIGNAL(reportImportEvent(int,QString)),
-             this, SLOT(onReportImportEvent(int,QString)));
-  disconnect(importer, SIGNAL(finished()),
-             this, SLOT(terminate()));
+  disconnect(importer, &BatchImporter::reportImportEvent,
+             this, &BatchImportCommand::onReportImportEvent);
+  disconnect(importer, &BatchImporter::finished,
+             this, &BatchImportCommand::terminate);
 }
 
 void BatchImportCommand::onReportImportEvent(int type, const QString& text)
@@ -593,10 +591,10 @@ void BatchImportCommand::onReportImportEvent(int type, const QString& text)
 }
 
 
-AlbumArtCommand::AlbumArtCommand(Kid3Cli* processor) :
-  CliCommand(processor, QLatin1String("albumart"),
-             tr("Download album cover artwork"),
-             QLatin1String("U [S]\nS = \"all\""))
+AlbumArtCommand::AlbumArtCommand(Kid3Cli* processor)
+  : CliCommand(processor, QLatin1String("albumart"),
+               tr("Download album cover artwork"),
+               QLatin1String("U [S]\nS = \"all\""))
 {
   setTimeout(10000);
 }
@@ -617,16 +615,16 @@ void AlbumArtCommand::startCommand()
 void AlbumArtCommand::connectResultSignal()
 {
   DownloadClient* downloadClient = cli()->app()->getDownloadClient();
-  connect(downloadClient, SIGNAL(downloadFinished(QByteArray,QString,QString)),
-          this, SLOT(onDownloadFinished(QByteArray,QString,QString)));
+  connect(downloadClient, &DownloadClient::downloadFinished,
+          this, &AlbumArtCommand::onDownloadFinished);
 }
 
 void AlbumArtCommand::disconnectResultSignal()
 {
   DownloadClient* downloadClient = cli()->app()->getDownloadClient();
   disconnect(downloadClient,
-             SIGNAL(downloadFinished(QByteArray,QString,QString)),
-             this, SLOT(onDownloadFinished(QByteArray,QString,QString)));
+             &DownloadClient::downloadFinished,
+             this, &AlbumArtCommand::onDownloadFinished);
 }
 
 void AlbumArtCommand::onDownloadFinished(
@@ -637,10 +635,10 @@ void AlbumArtCommand::onDownloadFinished(
 }
 
 
-ExportCommand::ExportCommand(Kid3Cli* processor) :
-  CliCommand(processor, QLatin1String("export"),
-             tr("Export to file"),
-             QLatin1String("P S [T]\nS = ") + tr("Format name"))
+ExportCommand::ExportCommand(Kid3Cli* processor)
+  : CliCommand(processor, QLatin1String("export"),
+               tr("Export to file"),
+               QLatin1String("P S [T]\nS = ") + tr("Format name"))
 {
 }
 
@@ -676,8 +674,8 @@ void ExportCommand::startCommand()
 }
 
 
-PlaylistCommand::PlaylistCommand(Kid3Cli* processor) :
-  CliCommand(processor, QLatin1String("playlist"), tr("Create playlist"))
+PlaylistCommand::PlaylistCommand(Kid3Cli* processor)
+  : CliCommand(processor, QLatin1String("playlist"), tr("Create playlist"))
 {
 }
 
@@ -689,9 +687,9 @@ void PlaylistCommand::startCommand()
 }
 
 
-FilenameFormatCommand::FilenameFormatCommand(Kid3Cli* processor) :
-  CliCommand(processor, QLatin1String("filenameformat"),
-             tr("Apply filename format"))
+FilenameFormatCommand::FilenameFormatCommand(Kid3Cli* processor)
+  : CliCommand(processor, QLatin1String("filenameformat"),
+               tr("Apply filename format"))
 {
 }
 
@@ -701,8 +699,8 @@ void FilenameFormatCommand::startCommand()
 }
 
 
-TagFormatCommand::TagFormatCommand(Kid3Cli* processor) :
-  CliCommand(processor, QLatin1String("tagformat"), tr("Apply tag format"))
+TagFormatCommand::TagFormatCommand(Kid3Cli* processor)
+  : CliCommand(processor, QLatin1String("tagformat"), tr("Apply tag format"))
 {
 }
 
@@ -712,9 +710,9 @@ void TagFormatCommand::startCommand()
 }
 
 
-TextEncodingCommand::TextEncodingCommand(Kid3Cli* processor) :
-  CliCommand(processor, QLatin1String("textencoding"),
-             tr("Apply text encoding"))
+TextEncodingCommand::TextEncodingCommand(Kid3Cli* processor)
+  : CliCommand(processor, QLatin1String("textencoding"),
+               tr("Apply text encoding"))
 {
 }
 
@@ -724,10 +722,10 @@ void TextEncodingCommand::startCommand()
 }
 
 
-RenameDirectoryCommand::RenameDirectoryCommand(Kid3Cli* processor) :
-  CliCommand(processor, QLatin1String("renamedir"), tr("Rename directory"),
+RenameDirectoryCommand::RenameDirectoryCommand(Kid3Cli* processor)
+  : CliCommand(processor, QLatin1String("renamedir"), tr("Rename directory"),
        QLatin1String("[F] [S] [T]\nS = \"create\" | \"rename\" | \"dryrun\"")),
-  m_dryRun(false)
+    m_dryRun(false)
 {
 }
 
@@ -771,19 +769,19 @@ void RenameDirectoryCommand::startCommand()
 void RenameDirectoryCommand::connectResultSignal()
 {
   DirRenamer* renamer = cli()->app()->getDirRenamer();
-  connect(renamer, SIGNAL(actionScheduled(QStringList)),
-          this, SLOT(onActionScheduled(QStringList)));
-  connect(cli()->app(), SIGNAL(renameActionsScheduled()),
-          this, SLOT(onRenameActionsScheduled()));
+  connect(renamer, &DirRenamer::actionScheduled,
+          this, &RenameDirectoryCommand::onActionScheduled);
+  connect(cli()->app(), &Kid3Application::renameActionsScheduled,
+          this, &RenameDirectoryCommand::onRenameActionsScheduled);
 }
 
 void RenameDirectoryCommand::disconnectResultSignal()
 {
   DirRenamer* renamer = cli()->app()->getDirRenamer();
-  disconnect(renamer, SIGNAL(actionScheduled(QStringList)),
-             this, SLOT(onActionScheduled(QStringList)));
-  disconnect(cli()->app(), SIGNAL(renameActionsScheduled()),
-             this, SLOT(onRenameActionsScheduled()));
+  disconnect(renamer, &DirRenamer::actionScheduled,
+             this, &RenameDirectoryCommand::onActionScheduled);
+  disconnect(cli()->app(), &Kid3Application::renameActionsScheduled,
+             this, &RenameDirectoryCommand::onRenameActionsScheduled);
 }
 
 void RenameDirectoryCommand::onActionScheduled(const QStringList& actionStrs)
@@ -814,9 +812,9 @@ void RenameDirectoryCommand::onRenameActionsScheduled()
 }
 
 
-NumberTracksCommand::NumberTracksCommand(Kid3Cli* processor) :
-  CliCommand(processor, QLatin1String("numbertracks"), tr("Number tracks"),
-             QLatin1String("[S] [T]\nS = ") + tr("Track number"))
+NumberTracksCommand::NumberTracksCommand(Kid3Cli* processor)
+  : CliCommand(processor, QLatin1String("numbertracks"), tr("Number tracks"),
+               QLatin1String("[S] [T]\nS = ") + tr("Track number"))
 {
 }
 
@@ -839,9 +837,9 @@ void NumberTracksCommand::startCommand()
 }
 
 
-FilterCommand::FilterCommand(Kid3Cli* processor) :
-  CliCommand(processor, QLatin1String("filter"), tr("Filter"),
-             QLatin1String("F|S\nS = ") + tr("Filter name"))
+FilterCommand::FilterCommand(Kid3Cli* processor)
+  : CliCommand(processor, QLatin1String("filter"), tr("Filter"),
+               QLatin1String("F|S\nS = ") + tr("Filter name"))
 {
   setTimeout(60000);
 }
@@ -876,15 +874,15 @@ void FilterCommand::startCommand()
 
 void FilterCommand::connectResultSignal()
 {
-  connect(cli()->app(), SIGNAL(fileFiltered(int,QString,int,int)),
-          this, SLOT(onFileFiltered(int,QString)));
+  connect(cli()->app(), &Kid3Application::fileFiltered,
+          this, &FilterCommand::onFileFiltered);
 }
 
 void FilterCommand::disconnectResultSignal()
 {
   cli()->app()->abortFilter();
-  disconnect(cli()->app(), SIGNAL(fileFiltered(int,QString,int,int)),
-             this, SLOT(onFileFiltered(int,QString)));
+  disconnect(cli()->app(), &Kid3Application::fileFiltered,
+             this, &FilterCommand::onFileFiltered);
 }
 
 void FilterCommand::onFileFiltered(int type, const QString& fileName)
@@ -923,8 +921,8 @@ void FilterCommand::onFileFiltered(int type, const QString& fileName)
 }
 
 
-ToId3v24Command::ToId3v24Command(Kid3Cli* processor) :
-  CliCommand(processor, QLatin1String("to24"), tr("Convert ID3v2.3 to ID3v2.4"))
+ToId3v24Command::ToId3v24Command(Kid3Cli* processor)
+  : CliCommand(processor, QLatin1String("to24"), tr("Convert ID3v2.3 to ID3v2.4"))
 {
 }
 
@@ -934,8 +932,8 @@ void ToId3v24Command::startCommand()
 }
 
 
-ToId3v23Command::ToId3v23Command(Kid3Cli* processor) :
-  CliCommand(processor, QLatin1String("to23"), tr("Convert ID3v2.4 to ID3v2.3"))
+ToId3v23Command::ToId3v23Command(Kid3Cli* processor)
+  : CliCommand(processor, QLatin1String("to23"), tr("Convert ID3v2.4 to ID3v2.3"))
 {
 }
 
@@ -945,9 +943,9 @@ void ToId3v23Command::startCommand()
 }
 
 
-TagToFilenameCommand::TagToFilenameCommand(Kid3Cli* processor) :
-  CliCommand(processor, QLatin1String("fromtag"), tr("Filename from tag"),
-             QLatin1String("[F] [T]"))
+TagToFilenameCommand::TagToFilenameCommand(Kid3Cli* processor)
+  : CliCommand(processor, QLatin1String("fromtag"), tr("Filename from tag"),
+               QLatin1String("[F] [T]"))
 {
 }
 
@@ -975,9 +973,9 @@ void TagToFilenameCommand::startCommand()
 }
 
 
-FilenameToTagCommand::FilenameToTagCommand(Kid3Cli* processor) :
-  CliCommand(processor, QLatin1String("totag"), tr("Tag from filename"),
-             QLatin1String("[F] [T]"))
+FilenameToTagCommand::FilenameToTagCommand(Kid3Cli* processor)
+  : CliCommand(processor, QLatin1String("totag"), tr("Tag from filename"),
+               QLatin1String("[F] [T]"))
 {
 }
 
@@ -1005,9 +1003,9 @@ void FilenameToTagCommand::startCommand()
 }
 
 
-TagToOtherTagCommand::TagToOtherTagCommand(Kid3Cli* processor) :
-  CliCommand(processor, QLatin1String("syncto"), tr("Tag to other tag"),
-             QLatin1String("T"))
+TagToOtherTagCommand::TagToOtherTagCommand(Kid3Cli* processor)
+  : CliCommand(processor, QLatin1String("syncto"), tr("Tag to other tag"),
+               QLatin1String("T"))
 {
 }
 
@@ -1022,9 +1020,9 @@ void TagToOtherTagCommand::startCommand()
 }
 
 
-CopyCommand::CopyCommand(Kid3Cli* processor) :
-  CliCommand(processor, QLatin1String("copy"), tr("Copy"),
-             QLatin1String("[T]"))
+CopyCommand::CopyCommand(Kid3Cli* processor)
+  : CliCommand(processor, QLatin1String("copy"), tr("Copy"),
+               QLatin1String("[T]"))
 {
 }
 
@@ -1035,9 +1033,9 @@ void CopyCommand::startCommand()
 }
 
 
-PasteCommand::PasteCommand(Kid3Cli* processor) :
-  CliCommand(processor, QLatin1String("paste"), tr("Paste"),
-             QLatin1String("[T]"))
+PasteCommand::PasteCommand(Kid3Cli* processor)
+  : CliCommand(processor, QLatin1String("paste"), tr("Paste"),
+               QLatin1String("[T]"))
 {
 }
 
@@ -1048,9 +1046,9 @@ void PasteCommand::startCommand()
 }
 
 
-RemoveCommand::RemoveCommand(Kid3Cli* processor) :
-  CliCommand(processor, QLatin1String("remove"), tr("Remove"),
-             QLatin1String("[T]"))
+RemoveCommand::RemoveCommand(Kid3Cli* processor)
+  : CliCommand(processor, QLatin1String("remove"), tr("Remove"),
+               QLatin1String("[T]"))
 {
 }
 
@@ -1061,17 +1059,16 @@ void RemoveCommand::startCommand()
 }
 
 
-#if defined HAVE_PHONON || QT_VERSION >= 0x050000
-PlayCommand::PlayCommand(Kid3Cli* processor) :
-  CliCommand(processor, QLatin1String("play"), tr("Play"),
-             QLatin1String("[S]\n"
-             "S = \"pause\" | \"stop\" | \"previous\" | \"next\""))
+PlayCommand::PlayCommand(Kid3Cli* processor)
+  : CliCommand(processor, QLatin1String("play"), tr("Play"),
+               QLatin1String("[S]\n"
+               "S = \"pause\" | \"stop\" | \"previous\" | \"next\""))
 {
 }
 
 void PlayCommand::startCommand()
 {
-  AudioPlayer* player = 0;
+  AudioPlayer* player = nullptr;
   QString param;
   if (args().size() > 1) {
     param = args().at(1);
@@ -1097,4 +1094,3 @@ void PlayCommand::startCommand()
     cli()->app()->playAudio();
   }
 }
-#endif
