@@ -44,30 +44,29 @@
 class Kid3CliCompleter : public ReadlineCompleter {
 public:
   explicit Kid3CliCompleter(const QList<CliCommand*>& cmds);
-  virtual ~Kid3CliCompleter();
+  virtual ~Kid3CliCompleter() override = default;
 
-  virtual QList<QByteArray> getCommandList() const;
-  virtual QList<QByteArray> getParameterList() const;
-  virtual bool updateParameterList(const char* buffer);
+  virtual QList<QByteArray> getCommandList() const override;
+  virtual QList<QByteArray> getParameterList() const override;
+  virtual bool updateParameterList(const char* buffer) override;
 
 private:
+  Q_DISABLE_COPY(Kid3CliCompleter)
+
   const QList<CliCommand*>& m_cmds;
   QList<QByteArray> m_commands;
   QList<QByteArray> m_parameters;
 };
 
-Kid3CliCompleter::Kid3CliCompleter(const QList<CliCommand*>& cmds) :
-  m_cmds(cmds)
+Kid3CliCompleter::Kid3CliCompleter(const QList<CliCommand*>& cmds)
+  : m_cmds(cmds)
 {
-  foreach (const CliCommand* cmd, cmds) {
+  m_commands.reserve(cmds.size());
+  for (const CliCommand* cmd : cmds) {
     m_commands.append(cmd->name().toLocal8Bit());
   }
 }
 
-Kid3CliCompleter::~Kid3CliCompleter()
-{
-}
-
 QList<QByteArray> Kid3CliCompleter::getCommandList() const
 {
   return m_commands;
@@ -91,7 +90,7 @@ bool Kid3CliCompleter::updateParameterList(const char* buffer)
 
   QString argSpec;
   if (isFirstParameter) {
-    foreach (const CliCommand* cmd, m_cmds) {
+    for (const CliCommand* cmd : m_cmds) {
       if (cmdName == cmd->name()) {
         argSpec = cmd->argumentSpecification();
         break;
@@ -103,8 +102,8 @@ bool Kid3CliCompleter::updateParameterList(const char* buffer)
   if (!argSpec.isEmpty()) {
     QStringList argSpecs = argSpec.split(QLatin1Char('\n'));
     if (!argSpecs.isEmpty()) {
-      QString argTypes = argSpecs.first().
-          remove(QLatin1Char('[')).remove(QLatin1Char(']'));
+      QString argTypes = argSpecs.first().remove(QLatin1Char('['))
+                                         .remove(QLatin1Char(']'));
       if (!argTypes.isEmpty()) {
         char argType = argTypes.at(0).toLatin1();
         switch (argType) {
@@ -120,11 +119,12 @@ bool Kid3CliCompleter::updateParameterList(const char* buffer)
           // frame name
           static QList<QByteArray> frameNames;
           if (frameNames.isEmpty()) {
+            frameNames.reserve(Frame::FT_LastFrame - Frame::FT_FirstFrame + 1);
             for (int k = Frame::FT_FirstFrame; k <= Frame::FT_LastFrame; ++k) {
               frameNames.append(
-                    Frame::ExtendedType(static_cast<Frame::Type>(k),
-                                        QLatin1String("")).
-                    getName().toLower().remove(QLatin1Char(' ')).toLocal8Bit());
+                    Frame::ExtendedType(
+                      static_cast<Frame::Type>(k), QLatin1String(""))
+                    .getName().toLower().remove(QLatin1Char(' ')).toLocal8Bit());
             }
           }
           m_parameters = frameNames;
@@ -132,13 +132,13 @@ bool Kid3CliCompleter::updateParameterList(const char* buffer)
         }
         case 'S':
           // specific command
-          if (argSpecs.size() > 0) {
+          if (argSpecs.size() > 1) {
             const QString& valuesStr = argSpecs.at(1);
             int valuesIdx = valuesStr.indexOf(QLatin1String("S = \""));
             if (valuesIdx != -1) {
-              QStringList values =
+              const QStringList values =
                   valuesStr.mid(valuesIdx + 4).split(QLatin1String(" | "));
-              foreach (const QString& value, values) {
+              for (const QString& value : values) {
                 if (value.startsWith(QLatin1Char('"')) &&
                     value.endsWith(QLatin1Char('"'))) {
                   m_parameters.append(
@@ -224,7 +224,6 @@ QStringList splitArgs(const QString& str)
     } while (!c.isSpace());
     params.append(param);
   }
-  return QStringList();
 }
 
 }
@@ -275,18 +274,15 @@ Kid3Cli::Kid3Cli(Kid3Application* app,
          << new CopyCommand(this)
          << new PasteCommand(this)
          << new RemoveCommand(this)
-#if defined HAVE_PHONON || QT_VERSION >= 0x050000
-         << new PlayCommand(this)
-#endif
-         ;
-  connect(m_app, SIGNAL(fileSelectionUpdateRequested()),
-          this, SLOT(updateSelectedFiles()));
-  connect(m_app, SIGNAL(selectedFilesUpdated()),
-          this, SLOT(updateSelection()));
-  connect(m_app, SIGNAL(selectedFilesChanged(QItemSelection,QItemSelection)),
-          this, SLOT(updateSelection()));
+         << new PlayCommand(this);
+  connect(m_app, &Kid3Application::fileSelectionUpdateRequested,
+          this, &Kid3Cli::updateSelectedFiles);
+  connect(m_app, &Kid3Application::selectedFilesUpdated,
+          this, &Kid3Cli::updateSelection);
+  connect(m_app, &Kid3Application::selectedFilesChanged,
+          this, &Kid3Cli::updateSelection);
 #ifdef HAVE_READLINE
-  m_completer = new Kid3CliCompleter(m_cmds);
+  m_completer.reset(new Kid3CliCompleter(m_cmds));
   m_completer->install();
 #endif
 }
@@ -296,9 +292,7 @@ Kid3Cli::Kid3Cli(Kid3Application* app,
  */
 Kid3Cli::~Kid3Cli()
 {
-#ifdef HAVE_READLINE
-  delete m_completer;
-#endif
+  // Must not be inline because of forwared declared QScopedPointer.
 }
 
 /**
@@ -309,14 +303,12 @@ Kid3Cli::~Kid3Cli()
 CliCommand* Kid3Cli::commandForArgs(const QString& line)
 {
   if (line.isEmpty())
-    return 0;
+    return nullptr;
 
   QStringList args = splitArgs(line);
   if (!args.isEmpty()) {
     const QString& name = args.at(0);
-    for (QList<CliCommand*>::iterator it = m_cmds.begin();
-         it != m_cmds.end();
-         ++it) {
+    for (auto it = m_cmds.begin(); it != m_cmds.end(); ++it) { // clazy:exclude=detaching-member
       CliCommand* cmd = *it;
       if (name == cmd->name()) {
         cmd->setArgs(args);
@@ -324,7 +316,7 @@ CliCommand* Kid3Cli::commandForArgs(const QString& line)
       }
     }
   }
-  return 0;
+  return nullptr;
 }
 
 /**
@@ -358,9 +350,7 @@ void Kid3Cli::writeHelp(const QString& cmdName)
   }
   QList<QStringList> cmdStrs;
   int maxLength = 0;
-  for (QList<CliCommand*>::const_iterator it = m_cmds.constBegin();
-       it != m_cmds.constEnd();
-       ++it) {
+  for (auto it = m_cmds.constBegin(); it != m_cmds.constEnd(); ++it) {
     const CliCommand* cmd = *it;
     QString cmdStr = cmd->name();
     if (cmdName.isEmpty() || cmdName == cmdStr) {
@@ -373,7 +363,8 @@ void Kid3Cli::writeHelp(const QString& cmdName)
       maxLength = qMax(cmdStr.size(), maxLength);
     }
   }
-  foreach (QStringList strs, cmdStrs) {
+  const auto constCmdStrs = cmdStrs;
+  for (QStringList strs : constCmdStrs) {
     QString cmdStr = strs.takeFirst();
     cmdStr += QString(maxLength - cmdStr.size() + 2, QLatin1Char(' '));
     cmdStr += strs.takeFirst();
@@ -420,7 +411,7 @@ bool Kid3Cli::openDirectory(const QStringList& paths)
 QStringList Kid3Cli::expandWildcards(const QStringList& paths)
 {
   QStringList expandedPaths;
-  foreach (const QString& path, paths) {
+  for (const QString& path : paths) {
     QStringList expandedPath;
     int wcIdx = path.indexOf(QRegExp(QLatin1String("[?*]")));
     if (wcIdx != -1) {
@@ -436,18 +427,18 @@ QStringList Kid3Cli::expandWildcards(const QStringList& paths)
       if (!wildcardPart.isEmpty()) {
         QDir dir(partBefore);
         if (!dir.exists(wildcardPart)) {
-          QStringList entries = dir.entryList(QStringList() << wildcardPart,
+          const QStringList entries = dir.entryList({wildcardPart},
                                     QDir::AllEntries | QDir::NoDotAndDotDot);
           if (!entries.isEmpty()) {
-            foreach (const QString& entry, entries) {
-              expandedPath.append(partBefore + entry + partAfter);
+            for (const QString& entry : entries) {
+              expandedPath.append(partBefore + entry + partAfter); // clazy:exclude=reserve-candidates
             }
           }
         }
       }
     }
     if (expandedPath.isEmpty()) {
-      expandedPaths.append(path);
+      expandedPaths.append(path); // clazy:exclude=reserve-candidates
     } else {
       expandedPaths.append(expandedPath);
     }
@@ -464,7 +455,7 @@ bool Kid3Cli::selectFile(const QStringList& paths)
 {
   bool ok = true;
   FileProxyModel* model = m_app->getFileProxyModel();
-  foreach (const QString& fileName, paths) {
+  for (const QString& fileName : paths) {
     QModelIndex index = model->index(fileName);
     if (index.isValid()) {
       m_app->getFileSelectionModel()->setCurrentIndex(
@@ -545,8 +536,8 @@ void Kid3Cli::writeFileInformation(int tagMask)
         QString value =
             ft->index(row, FrameTableModel::CI_Value).data().toString();
         if (!(tagNr == Frame::Tag_1 ? value.isEmpty() : value.isNull())) {
-          bool changed = ft->index(row, FrameTableModel::CI_Enable).
-              data(Qt::BackgroundColorRole).value<QBrush>() != Qt::NoBrush;
+          bool changed = ft->index(row, FrameTableModel::CI_Enable)
+              .data(Qt::BackgroundColorRole).value<QBrush>() != Qt::NoBrush;
           QString line = changed ? QLatin1String("*") : QLatin1String(" ");
           line += QLatin1Char(' ');
           line += name;
@@ -636,7 +627,8 @@ void Kid3Cli::printFileProxyModel(const FileProxyModel* model,
       indexesWithChildren.append(idx);
     }
     writeLine(propsStr + indentStr + nameStr);
-    foreach (const QModelIndex& idx, indexesWithChildren) {
+    const auto idxs = indexesWithChildren;
+    for (const QModelIndex& idx : idxs) {
       printFileProxyModel(model, idx, indent + 2);
     }
   }
@@ -656,7 +648,7 @@ void Kid3Cli::readLine(const QString& line)
   flushStandardOutput();
   CliCommand* cmd = commandForArgs(line);
   if (cmd) {
-    connect(cmd, SIGNAL(finished()), this, SLOT(onCommandFinished()));
+    connect(cmd, &CliCommand::finished, this, &Kid3Cli::onCommandFinished);
     cmd->execute();
   } else {
     writeErrorLine(tr("Unknown command '%1'. Type 'help' for help.").arg(line));
@@ -668,8 +660,8 @@ void Kid3Cli::readLine(const QString& line)
  * Called when a command is finished.
  */
 void Kid3Cli::onCommandFinished() {
-  if (CliCommand* cmd = qobject_cast<CliCommand*>(sender())) {
-    disconnect(cmd, SIGNAL(finished()), this, SLOT(onCommandFinished()));
+  if (auto cmd = qobject_cast<CliCommand*>(sender())) {
+    disconnect(cmd, &CliCommand::finished, this, &Kid3Cli::onCommandFinished);
     if (cmd->hasError()) {
       QString msg(cmd->getErrorMessage());
       if (!msg.startsWith(QLatin1Char('_'))) {
@@ -685,8 +677,8 @@ void Kid3Cli::onCommandFinished() {
  * Called when an argument command is finished.
  */
 void Kid3Cli::onArgCommandFinished() {
-  if (CliCommand* cmd = qobject_cast<CliCommand*>(sender())) {
-    disconnect(cmd, SIGNAL(finished()), this, SLOT(onArgCommandFinished()));
+  if (auto cmd = qobject_cast<CliCommand*>(sender())) {
+    disconnect(cmd, &CliCommand::finished, this, &Kid3Cli::onArgCommandFinished);
     if (!cmd->hasError()) {
       cmd->clear();
       executeNextArgCommand();
@@ -704,10 +696,10 @@ void Kid3Cli::onArgCommandFinished() {
 
 bool Kid3Cli::parseOptions()
 {
-  QStringList args = m_args.mid(1);
+  const QStringList args = m_args.mid(1);
   QStringList paths;
   bool isCommand = false;
-  foreach (const QString& arg, args) {
+  for (const QString& arg : args) {
     if (isCommand) {
       m_argCommands.append(arg);
       isCommand = false;
@@ -730,8 +722,9 @@ bool Kid3Cli::parseOptions()
   if (paths.isEmpty()) {
     paths.append(QDir::currentPath());
   }
-  connect(m_app, SIGNAL(directoryOpened()),
-    this, SLOT(onInitialDirectoryOpened()));
+  m_app->readConfig();
+  connect(m_app, &Kid3Application::directoryOpened,
+    this, &Kid3Cli::onInitialDirectoryOpened);
   if (!openDirectory(expandWildcards(paths))) {
     writeErrorLine(tr("%1 does not exist").arg(paths.join(QLatin1String(", "))));
   }
@@ -744,8 +737,8 @@ bool Kid3Cli::parseOptions()
  */
 void Kid3Cli::onInitialDirectoryOpened()
 {
-  disconnect(m_app, SIGNAL(directoryOpened()),
-    this, SLOT(onInitialDirectoryOpened()));
+  disconnect(m_app, &Kid3Application::directoryOpened,
+    this, &Kid3Cli::onInitialDirectoryOpened);
   if (!m_argCommands.isEmpty()) {
     if (!m_app->getRootIndex().isValid()) {
       // Do not execute commands if directory could not be opened.
@@ -774,7 +767,7 @@ void Kid3Cli::executeNextArgCommand()
   QString line = m_argCommands.takeFirst();
   CliCommand* cmd = commandForArgs(line);
   if (cmd) {
-    connect(cmd, SIGNAL(finished()), this, SLOT(onArgCommandFinished()));
+    connect(cmd, &CliCommand::finished, this, &Kid3Cli::onArgCommandFinished);
     cmd->execute();
   } else {
     writeErrorLine(tr("Unknown command '%1', -h for help.").arg(line));
