@@ -6,7 +6,7 @@
  * \author Urs Fleisch
  * \date 10 Aug 2013
  *
- * Copyright (C) 2013  Urs Fleisch
+ * Copyright (C) 2013-2018  Urs Fleisch
  *
  * This file is part of Kid3.
  *
@@ -47,9 +47,9 @@
  * Constructor.
  * @param prompt command line prompt
  */
-StandardIOHandler::StandardIOHandler(const char* prompt) :
-  m_prompt(prompt), m_conInThread(0),
-  m_cout(stdout, QIODevice::WriteOnly), m_cerr(stderr, QIODevice::WriteOnly)
+StandardIOHandler::StandardIOHandler(const char* prompt)
+  : m_prompt(prompt), m_conInThread(nullptr),
+    m_cout(stdout, QIODevice::WriteOnly), m_cerr(stderr, QIODevice::WriteOnly)
 {
 #ifdef Q_OS_WIN32
   DWORD mode;
@@ -58,9 +58,9 @@ StandardIOHandler::StandardIOHandler(const char* prompt) :
 }
 
 /**
- * Destructor.
+ * Restore terminal on cleanup.
  */
-StandardIOHandler::~StandardIOHandler()
+void StandardIOHandler::cleanup()
 {
 #ifdef HAVE_READLINE
   ::rl_cleanup_after_signal();
@@ -75,12 +75,9 @@ void StandardIOHandler::start()
   m_conInThread = new QThread;
   m_conInThread->setObjectName(QLatin1String("conInThread"));
 
-  connect(m_conInThread, SIGNAL(started()), this, SLOT(blockingReadLine()));
-  connect(m_conInThread, SIGNAL(finished()), this, SLOT(deleteLater()));
-  connect(m_conInThread, SIGNAL(finished()), m_conInThread, SLOT(deleteLater()));
-#if QT_VERSION < 0x050000
-  connect(m_conInThread, SIGNAL(terminated()), m_conInThread, SLOT(deleteLater()));
-#endif
+  connect(m_conInThread, &QThread::started, this, &StandardIOHandler::blockingReadLine);
+  connect(m_conInThread, &QThread::finished, this, &QObject::deleteLater);
+  connect(m_conInThread, &QThread::finished, m_conInThread, &QObject::deleteLater);
   moveToThread(m_conInThread);
 
   m_conInThread->start();
@@ -114,7 +111,12 @@ void StandardIOHandler::blockingReadLine()
 {
 #ifdef HAVE_READLINE
   char* lineRead = ::readline(m_prompt);
-  if (lineRead && *lineRead) {
+  if (!lineRead) {
+    // EOF
+    emit lineReady(QString());
+    return;
+  }
+  if (*lineRead) {
     ::add_history(lineRead);
   }
   QString line = QString::fromLocal8Bit(lineRead);
