@@ -6,7 +6,7 @@
  * \author Urs Fleisch
  * \date 10 Aug 2013
  *
- * Copyright (C) 2013-2014  Urs Fleisch
+ * Copyright (C) 2013-2018  Urs Fleisch
  *
  * This file is part of Kid3.
  *
@@ -24,8 +24,7 @@
  * along with this program.  If not, see <http://www.gnu.org/licenses/>.
  */
 
-#ifndef STANDARDIOHANDLER_H
-#define STANDARDIOHANDLER_H
+#pragma once
 
 #include "abstractcli.h"
 #include <QTextStream>
@@ -45,24 +44,29 @@ public:
   /**
    * Destructor.
    */
-  virtual ~StandardIOHandler();
+  virtual ~StandardIOHandler() override = default;
+
+  /**
+   * Restore terminal on cleanup.
+   */
+  virtual void cleanup() override;
 
   /**
    * Write a line to standard output.
    * @param line line to write
    */
-  virtual void writeLine(const QString& line);
+  virtual void writeLine(const QString& line) override;
 
   /**
    * Write a line to standard error.
    * @param line line to write
    */
-  virtual void writeErrorLine(const QString& line);
+  virtual void writeErrorLine(const QString& line) override;
 
   /**
    * Flush the standard output.
    */
-  virtual void flushStandardOutput();
+  virtual void flushStandardOutput() override;
 
   /**
    * Read the next line.
@@ -70,7 +74,7 @@ public:
    * input in the read thread.
    * When the line is ready, lineReady() is emitted.
    */
-  virtual void readLine();
+  virtual void readLine() override;
 
 public slots:
   /**
@@ -78,13 +82,13 @@ public slots:
    * This will start a read thread. lineReady() is emitted when the first
    * line is ready. To request subsequent lines, readLine() has to be called.
    */
-  virtual void start();
+  virtual void start() override;
 
   /**
    * Stop processing.
    * This will stop the read thread and finally delete this object.
    */
-  virtual void stop();
+  virtual void stop() override;
 
 private slots:
   /**
@@ -103,5 +107,3 @@ private:
   bool m_consoleMode;
 #endif
 };
-
-#endif // STANDARDIOHANDLER_H
