@@ -6,7 +6,7 @@
  * \author Urs Fleisch
  * \date 9 Jan 2003
  *
- * Copyright (C) 2003-2017  Urs Fleisch
+ * Copyright (C) 2003-2018  Urs Fleisch
  *
  * This file is part of Kid3.
  *
@@ -25,7 +25,7 @@
  */
 
 #include "kdemainwindow.h"
-#if QT_VERSION >= 0x050000
+#include <kconfigwidgets_version.h>
 #include <KConfig>
 #include <KToggleAction>
 #include <KStandardAction>
@@ -37,31 +37,6 @@
 #include <QApplication>
 #include <QUrl>
 #include <QAction>
-
-#define KUrl QUrl
-#define KAction QAction
-#define KShortcut QKeySequence
-#define KIcon QIcon::fromTheme
-#define KSharedConfig_openConfig KSharedConfig::openConfig
-
-#else
-#include <kapplication.h>
-#include <kurl.h>
-#include <kconfig.h>
-#include <kaction.h>
-#include <ktoggleaction.h>
-#include <kstandardaction.h>
-#include <kshortcutsdialog.h>
-#include <krecentfilesaction.h>
-#include <kactioncollection.h>
-#include <kedittoolbar.h>
-#include <kconfigskeleton.h>
-
-/** Create object for configuration file. */
-#define KSharedConfig_openConfig KGlobal::config
-
-#endif
-#include <QAction>
 #include "config.h"
 #include "kid3form.h"
 #include "filelist.h"
@@ -81,22 +56,15 @@
  * @param parent parent widget
  */
 KdeMainWindow::KdeMainWindow(IPlatformTools* platformTools,
-                             Kid3Application* app, QWidget* parent) :
-  KXmlGuiWindow(parent),
-  BaseMainWindow(this, platformTools, app),
-  m_platformTools(platformTools), m_fileOpenRecent(0),
-  m_settingsAutoHideTags(0), m_settingsShowHidePicture(0)
+                             Kid3Application* app, QWidget* parent)
+  : KXmlGuiWindow(parent),
+    BaseMainWindow(this, platformTools, app),
+    m_platformTools(platformTools), m_fileOpenRecent(nullptr),
+    m_settingsAutoHideTags(nullptr), m_settingsShowHidePicture(nullptr)
 {
   init();
 }
 
-/**
- * Destructor.
- */
-KdeMainWindow::~KdeMainWindow()
-{
-}
-
 /** Only defined for generation of translation files */
 #define MAIN_TOOLBAR_FOR_PO QT_TRANSLATE_NOOP("@default", "Main Toolbar")
 
@@ -106,288 +74,360 @@ KdeMainWindow::~KdeMainWindow()
 void KdeMainWindow::initActions()
 {
   KActionCollection* collection = actionCollection();
-  KAction* action = KStandardAction::open(
-      impl(), SLOT(slotFileOpen()), collection);
-  action->setStatusTip(tr("Open files"));
-  m_fileOpenRecent = KStandardAction::openRecent(
-      this,
-#if QT_VERSION >= 0x050000
-        SLOT(slotFileOpenRecentUrl(QUrl)),
+#if KCONFIGWIDGETS_VERSION >= 0x051700
+  QAction* action = KStandardAction::open(
+      impl(), &BaseMainWindowImpl::slotFileOpen, collection);
 #else
-        SLOT(slotFileOpenRecentUrl(KUrl)),
+  QAction* action = KStandardAction::open(
+      impl(), SLOT(slotFileOpen()), collection);
+#endif
+  action->setStatusTip(tr("Open files"));
+#if KCONFIGWIDGETS_VERSION >= 0x051700
+  m_fileOpenRecent = KStandardAction::openRecent(
+      this, &KdeMainWindow::slotFileOpenRecentUrl, collection);
+#else
+  m_fileOpenRecent = KStandardAction::openRecent(
+      this, SLOT(slotFileOpenRecentUrl(QUrl)), collection);
 #endif
-      collection);
   m_fileOpenRecent->setStatusTip(tr("Opens a recently used directory"));
+#if KCONFIGWIDGETS_VERSION >= 0x051700
+  action = KStandardAction::revert(
+      app(), &Kid3Application::revertFileModifications, collection);
+#else
   action = KStandardAction::revert(
       app(), SLOT(revertFileModifications()), collection);
+#endif
   action->setStatusTip(
       tr("Reverts the changes of all or the selected files"));
-#if QT_VERSION >= 0x050000
   collection->setDefaultShortcuts(action,
                           KStandardShortcut::shortcut(KStandardShortcut::Undo));
+#if KCONFIGWIDGETS_VERSION >= 0x051700
+  action = KStandardAction::save(
+      impl(), &BaseMainWindowImpl::slotFileSave, collection);
 #else
-  action->setShortcut(KStandardShortcut::shortcut(KStandardShortcut::Undo));
-#endif
   action = KStandardAction::save(
       impl(), SLOT(slotFileSave()), collection);
+#endif
   action->setStatusTip(tr("Saves the changed files"));
+#if KCONFIGWIDGETS_VERSION >= 0x051700
+  action = KStandardAction::quit(
+      impl(), &BaseMainWindowImpl::slotFileQuit, collection);
+#else
   action = KStandardAction::quit(
       impl(), SLOT(slotFileQuit()), collection);
+#endif
   action->setStatusTip(tr("Quits the application"));
+#if KCONFIGWIDGETS_VERSION >= 0x051700
+  action = KStandardAction::selectAll(
+      form(), &Kid3Form::selectAllFiles, collection);
+#else
   action = KStandardAction::selectAll(
       form(), SLOT(selectAllFiles()), collection);
+#endif
   action->setStatusTip(tr("Select all files"));
-  action->setShortcut(KShortcut(QLatin1String("Alt+Shift+A")));
+  action->setShortcut(QKeySequence(QLatin1String("Alt+Shift+A")));
+#if KCONFIGWIDGETS_VERSION >= 0x051700
+  action = KStandardAction::deselect(
+      form(), &Kid3Form::deselectAllFiles, collection);
+#else
   action = KStandardAction::deselect(
       form(), SLOT(deselectAllFiles()), collection);
+#endif
   action->setStatusTip(tr("Deselect all files"));
+#if KCONFIGWIDGETS_VERSION >= 0x051700
+  action = KStandardAction::find(
+      impl(), &BaseMainWindowImpl::find, collection);
+#else
   action = KStandardAction::find(
       impl(), SLOT(find()), collection);
+#endif
   action->setStatusTip(tr("Find"));
+#if KCONFIGWIDGETS_VERSION >= 0x051700
+  action = KStandardAction::replace(
+      impl(), &BaseMainWindowImpl::findReplace, collection);
+#else
   action = KStandardAction::replace(
       impl(), SLOT(findReplace()), collection);
+#endif
   action->setStatusTip(tr("Find and replace"));
   setStandardToolBarMenuEnabled(true);
   createStandardStatusBarAction();
+#if KCONFIGWIDGETS_VERSION >= 0x051700
+  action = KStandardAction::keyBindings(
+    this, &KdeMainWindow::slotSettingsShortcuts, collection);
+#else
   action = KStandardAction::keyBindings(
     this, SLOT(slotSettingsShortcuts()), collection);
+#endif
   action->setStatusTip(tr("Configure Shortcuts"));
+#if KCONFIGWIDGETS_VERSION >= 0x051700
+  action = KStandardAction::configureToolbars(
+    this, &KdeMainWindow::slotSettingsToolbars, collection);
+#else
   action = KStandardAction::configureToolbars(
     this, SLOT(slotSettingsToolbars()), collection);
+#endif
   action->setStatusTip(tr("Configure Toolbars"));
+#if KCONFIGWIDGETS_VERSION >= 0x051700
+  action = KStandardAction::preferences(
+      this, &KdeMainWindow::slotSettingsConfigure, collection);
+#else
   action = KStandardAction::preferences(
       this, SLOT(slotSettingsConfigure()), collection);
+#endif
   action->setStatusTip(tr("Preferences dialog"));
 
-  action = new KAction(KIcon(QLatin1String("document-open")),
+  action = new QAction(QIcon::fromTheme(QLatin1String("document-open")),
                        tr("O&pen Directory..."), this);
   action->setStatusTip(tr("Opens a directory"));
-  action->setShortcut(KShortcut(QLatin1String("Ctrl+D")));
+  action->setShortcut(QKeySequence(QLatin1String("Ctrl+D")));
   collection->addAction(QLatin1String("open_directory"), action);
-  connect(action, SIGNAL(triggered()), impl(), SLOT(slotFileOpenDirectory()));
-  action = new KAction(KIcon(QLatin1String("document-import")),
+  connect(action, &QAction::triggered,
+          impl(), &BaseMainWindowImpl::slotFileOpenDirectory);
+
+  action = new QAction(QIcon::fromTheme(QLatin1String("view-refresh")),
+                       tr("Re&load"), this);
+  action->setStatusTip(tr("Reload directory"));
+  action->setShortcut(QKeySequence::Refresh);
+  collection->addAction(QLatin1String("reload"), action);
+  connect(action, &QAction::triggered,
+          impl(), &BaseMainWindowImpl::slotFileReload);
+
+  action = new QAction(tr("Unload"), this);
+  collection->addAction(QLatin1String("unload"), action);
+  connect(action, &QAction::triggered, app(), &Kid3Application::unloadAllTags);
+
+  action = new QAction(QIcon::fromTheme(QLatin1String("document-import")),
                        tr("&Import..."), this);
   action->setStatusTip(tr("Import from file or clipboard"));
   action->setData(-1);
   collection->addAction(QLatin1String("import"), action);
-  connect(action, SIGNAL(triggered()), impl(), SLOT(slotImport()));
+  connect(action, &QAction::triggered, impl(), &BaseMainWindowImpl::slotImport);
 
   int importerIdx = 0;
-  foreach (const ServerImporter* si, app()->getServerImporters()) {
+  const auto sis = app()->getServerImporters();
+  for (const ServerImporter* si : sis) {
     QString serverName(QCoreApplication::translate("@default", si->name()));
-    QString actionName = QString::fromLatin1(si->name()).toLower().
-        remove(QLatin1Char(' '));
+    QString actionName = QString::fromLatin1(si->name()).toLower()
+        .remove(QLatin1Char(' '));
     int dotPos = actionName.indexOf(QLatin1Char('.'));
     if (dotPos != -1)
       actionName.truncate(dotPos);
     actionName = QLatin1String("import_") + actionName;
-    action = new KAction(tr("Import from %1...").arg(serverName), this);
+    action = new QAction(tr("Import from %1...").arg(serverName), this);
     action->setData(importerIdx);
     action->setStatusTip(tr("Import from %1").arg(serverName));
     collection->addAction(actionName, action);
-    connect(action, SIGNAL(triggered()), impl(), SLOT(slotImport()));
+    connect(action, &QAction::triggered, impl(), &BaseMainWindowImpl::slotImport);
     ++importerIdx;
   }
 
-  foreach (const ServerTrackImporter* si, app()->getServerTrackImporters()) {
+  const auto stis = app()->getServerTrackImporters();
+  for (const ServerTrackImporter* si : stis) {
     QString serverName(QCoreApplication::translate("@default", si->name()));
-    QString actionName = QString::fromLatin1(si->name()).toLower().
-        remove(QLatin1Char(' '));
+    QString actionName = QString::fromLatin1(si->name()).toLower()
+        .remove(QLatin1Char(' '));
     int dotPos = actionName.indexOf(QLatin1Char('.'));
     if (dotPos != -1)
       actionName.truncate(dotPos);
     actionName = QLatin1String("import_") + actionName;
-    action = new KAction(tr("Import from %1...").arg(serverName), this);
+    action = new QAction(tr("Import from %1...").arg(serverName), this);
     action->setStatusTip(tr("Import from %1").arg(serverName));
     action->setData(importerIdx);
     collection->addAction(actionName, action);
-    connect(action, SIGNAL(triggered()), impl(), SLOT(slotImport()));
+    connect(action, &QAction::triggered, impl(), &BaseMainWindowImpl::slotImport);
     ++importerIdx;
   }
 
-  action = new KAction(tr("Automatic I&mport..."), this);
+  action = new QAction(tr("Automatic I&mport..."), this);
   action->setStatusTip(tr("Automatic import"));
   collection->addAction(QLatin1String("batch_import"), action);
-  connect(action, SIGNAL(triggered()), impl(), SLOT(slotBatchImport()));
+  connect(action, &QAction::triggered, impl(), &BaseMainWindowImpl::slotBatchImport);
 
-  action = new KAction(tr("&Browse Cover Art..."), this);
+  action = new QAction(tr("&Browse Cover Art..."), this);
   action->setStatusTip(tr("Browse album cover artwork"));
   collection->addAction(QLatin1String("browse_cover_art"), action);
-  connect(action, SIGNAL(triggered()), impl(), SLOT(slotBrowseCoverArt()));
-  action = new KAction(KIcon(QLatin1String("document-export")), tr("&Export..."), this);
+  connect(action, &QAction::triggered, impl(), &BaseMainWindowImpl::slotBrowseCoverArt);
+  action = new QAction(QIcon::fromTheme(QLatin1String("document-export")),
+                       tr("&Export..."), this);
   action->setStatusTip(tr("Export to file or clipboard"));
   collection->addAction(QLatin1String("export"), action);
-  connect(action, SIGNAL(triggered()), impl(), SLOT(slotExport()));
-  action = new KAction(KIcon(QLatin1String("view-media-playlist")), tr("&Create Playlist..."), this);
+  connect(action, &QAction::triggered, impl(), &BaseMainWindowImpl::slotExport);
+  action = new QAction(QIcon::fromTheme(QLatin1String("view-media-playlist")),
+                       tr("&Create Playlist..."), this);
   action->setStatusTip(tr("Create M3U Playlist"));
   collection->addAction(QLatin1String("create_playlist"), action);
-  connect(action, SIGNAL(triggered()), impl(), SLOT(slotPlaylistDialog()));
-  action = new KAction(tr("Apply &Filename Format"), this);
+  connect(action, &QAction::triggered, impl(), &BaseMainWindowImpl::slotPlaylistDialog);
+  action = new QAction(tr("Apply &Filename Format"), this);
   action->setStatusTip(tr("Apply Filename Format"));
   collection->addAction(QLatin1String("apply_filename_format"), action);
-  connect(action, SIGNAL(triggered()), app(), SLOT(applyFilenameFormat()));
-  action = new KAction(tr("Apply &Tag Format"), this);
+  connect(action, &QAction::triggered, app(), &Kid3Application::applyFilenameFormat);
+  action = new QAction(tr("Apply &Tag Format"), this);
   action->setStatusTip(tr("Apply Tag Format"));
   collection->addAction(QLatin1String("apply_id3_format"), action);
-  connect(action, SIGNAL(triggered()), app(), SLOT(applyTagFormat()));
-  action = new KAction(tr("Apply Text &Encoding"), this);
+  connect(action, &QAction::triggered, app(), &Kid3Application::applyTagFormat);
+  action = new QAction(tr("Apply Text &Encoding"), this);
   action->setStatusTip(tr("Apply Text Encoding"));
   collection->addAction(QLatin1String("apply_text_encoding"), action);
-  connect(action, SIGNAL(triggered()), app(), SLOT(applyTextEncoding()));
-  action = new KAction(tr("&Rename Directory..."), this);
+  connect(action, &QAction::triggered, app(), &Kid3Application::applyTextEncoding);
+  action = new QAction(tr("&Rename Directory..."), this);
   action->setStatusTip(tr("Rename Directory"));
   collection->addAction(QLatin1String("rename_directory"), action);
-  connect(action, SIGNAL(triggered()), impl(), SLOT(slotRenameDirectory()));
-  action = new KAction(tr("&Number Tracks..."), this);
+  connect(action, &QAction::triggered, impl(), &BaseMainWindowImpl::slotRenameDirectory);
+  action = new QAction(tr("&Number Tracks..."), this);
   action->setStatusTip(tr("Number Tracks"));
   collection->addAction(QLatin1String("number_tracks"), action);
-  connect(action, SIGNAL(triggered()), impl(), SLOT(slotNumberTracks()));
-  action = new KAction(tr("F&ilter..."), this);
+  connect(action, &QAction::triggered, impl(), &BaseMainWindowImpl::slotNumberTracks);
+  action = new QAction(tr("F&ilter..."), this);
   action->setStatusTip(tr("Filter"));
   collection->addAction(QLatin1String("filter"), action);
-  connect(action, SIGNAL(triggered()), impl(), SLOT(slotFilter()));
+  connect(action, &QAction::triggered, impl(), &BaseMainWindowImpl::slotFilter);
   const TagConfig& tagCfg = TagConfig::instance();
   if (tagCfg.taggedFileFeatures() & TaggedFile::TF_ID3v24) {
-    action = new KAction(tr("Convert ID3v2.3 to ID3v2.&4"), this);
+    action = new QAction(tr("Convert ID3v2.3 to ID3v2.&4"), this);
     action->setStatusTip(tr("Convert ID3v2.3 to ID3v2.4"));
     collection->addAction(QLatin1String("convert_to_id3v24"), action);
-    connect(action, SIGNAL(triggered()), app(), SLOT(convertToId3v24()));
+    connect(action, &QAction::triggered, app(), &Kid3Application::convertToId3v24);
     if (tagCfg.taggedFileFeatures() & TaggedFile::TF_ID3v23) {
-      action = new KAction(tr("Convert ID3v2.4 to ID3v2.&3"), this);
+      action = new QAction(tr("Convert ID3v2.4 to ID3v2.&3"), this);
       action->setStatusTip(tr("Convert ID3v2.4 to ID3v2.3"));
       collection->addAction(QLatin1String("convert_to_id3v23"), action);
-      connect(action, SIGNAL(triggered()), app(), SLOT(convertToId3v23()));
+      connect(action, &QAction::triggered, app(), &Kid3Application::convertToId3v23);
     }
   }
-#if defined HAVE_PHONON || QT_VERSION >= 0x050000
-  action = new KAction(KIcon(QLatin1String("media-playback-start")), tr("&Play"), this);
+  action = new QAction(QIcon::fromTheme(QLatin1String("media-playback-start")),
+                       tr("&Play"), this);
   action->setStatusTip(tr("Play"));
   collection->addAction(QLatin1String("play"), action);
-  connect(action, SIGNAL(triggered()), app(), SLOT(playAudio()));
-#endif
+  connect(action, &QAction::triggered, app(), &Kid3Application::playAudio);
   m_settingsShowHidePicture = new KToggleAction(tr("Show &Picture"), this);
   m_settingsShowHidePicture->setStatusTip(tr("Show Picture"));
   m_settingsShowHidePicture->setCheckable(true);
   collection->addAction(QLatin1String("hide_picture"), m_settingsShowHidePicture);
-  connect(m_settingsShowHidePicture, SIGNAL(triggered()), impl(), SLOT(slotSettingsShowHidePicture()));
+  connect(m_settingsShowHidePicture, &QAction::triggered,
+          impl(), &BaseMainWindowImpl::slotSettingsShowHidePicture);
   m_settingsAutoHideTags = new KToggleAction(tr("Auto &Hide Tags"), this);
   m_settingsAutoHideTags->setStatusTip(tr("Auto Hide Tags"));
   m_settingsAutoHideTags->setCheckable(true);
   collection->addAction(QLatin1String("auto_hide_tags"), m_settingsAutoHideTags);
-  connect(m_settingsAutoHideTags, SIGNAL(triggered()), impl(), SLOT(slotSettingsAutoHideTags()));
-  action = new KAction(tr("Select All in &Directory"), this);
+  connect(m_settingsAutoHideTags, &QAction::triggered,
+          impl(), &BaseMainWindowImpl::slotSettingsAutoHideTags);
+  action = new QAction(tr("Select All in &Directory"), this);
   action->setStatusTip(tr("Select all files in the current directory"));
   collection->addAction(QLatin1String("select_all_in_directory"), action);
-  connect(action, SIGNAL(triggered()), app(), SLOT(selectAllInDirectory()));
-  action = new KAction(KIcon(QLatin1String("go-previous")), tr("&Previous File"), this);
+  connect(action, &QAction::triggered, app(), &Kid3Application::selectAllInDirectory);
+  action = new QAction(QIcon::fromTheme(QLatin1String("go-previous")),
+                       tr("&Previous File"), this);
   action->setStatusTip(tr("Select previous file"));
-#if QT_VERSION >= 0x050000
   collection->setDefaultShortcuts(action,
                          KStandardShortcut::shortcut(KStandardShortcut::Prior));
-#else
-  action->setShortcut(KShortcut(QLatin1String("Alt+Up")));
-#endif
   collection->addAction(QLatin1String("previous_file"), action);
-  connect(action, SIGNAL(triggered()), form(), SLOT(previousFile()));
-  action = new KAction(KIcon(QLatin1String("go-next")), tr("&Next File"), this);
+  connect(action, &QAction::triggered, form(), &Kid3Form::selectPreviousTaggedFile);
+  action = new QAction(QIcon::fromTheme(QLatin1String("go-next")),
+                       tr("&Next File"), this);
   action->setStatusTip(tr("Select next file"));
-#if QT_VERSION >= 0x050000
   collection->setDefaultShortcuts(action,
                          KStandardShortcut::shortcut(KStandardShortcut::Next));
-#else
-  action->setShortcut(KShortcut(QLatin1String("Alt+Down")));
-#endif
   collection->addAction(QLatin1String("next_file"), action);
-  connect(action, SIGNAL(triggered()), form(), SLOT(nextFile()));
+  connect(action, &QAction::triggered, form(), &Kid3Form::selectNextTaggedFile);
   FOR_ALL_TAGS(tagNr) {
-    Frame::TagNumber otherTagNr = tagNr == Frame::Tag_1 ? Frame::Tag_2 :
-          tagNr == Frame::Tag_2 ? Frame::Tag_1 : Frame::Tag_NumValues;
+    Frame::TagNumber otherTagNr = tagNr == Frame::Tag_1
+        ? Frame::Tag_2
+        : tagNr == Frame::Tag_2 ? Frame::Tag_1 : Frame::Tag_NumValues;
     QString tagStr = Frame::tagNumberToString(tagNr);
     Kid3ApplicationTagContext* appTag = app()->tag(tagNr);
     Kid3FormTagContext* formTag = form()->tag(tagNr);
     QString actionPrefix = tr("Tag %1").arg(tagStr) +
         QLatin1String(": ");
-    action = new KAction(tr("Filename") + QLatin1String(": ") +
+    action = new QAction(tr("Filename") + QLatin1String(": ") +
                          tr("From Tag %1").arg(tagStr), this);
     collection->addAction(QLatin1String("filename_from_v") + tagStr, action);
-    connect(action, SIGNAL(triggered()), appTag, SLOT(getFilenameFromTags()));
+    connect(action, &QAction::triggered,
+            appTag, &Kid3ApplicationTagContext::getFilenameFromTags);
     tagStr = QLatin1Char('v') + tagStr + QLatin1Char('_');
-    action = new KAction(actionPrefix + tr("From Filename"), this);
+    action = new QAction(actionPrefix + tr("From Filename"), this);
     collection->addAction(tagStr + QLatin1String("from_filename"), action);
-    connect(action, SIGNAL(triggered()), appTag, SLOT(getTagsFromFilename()));
+    connect(action, &QAction::triggered,
+            appTag, &Kid3ApplicationTagContext::getTagsFromFilename);
     if (otherTagNr < Frame::Tag_NumValues) {
       QString otherTagStr = Frame::tagNumberToString(otherTagNr);
-      action = new KAction(actionPrefix + tr("From Tag %1").arg(otherTagStr),
+      action = new QAction(actionPrefix + tr("From Tag %1").arg(otherTagStr),
                            this);
       collection->addAction(tagStr + QLatin1String("from_v") + otherTagStr,
                             action);
-      connect(action, SIGNAL(triggered()), appTag, SLOT(copyToOtherTag()));
+      connect(action, &QAction::triggered,
+              appTag, &Kid3ApplicationTagContext::copyToOtherTag);
     }
-    action = new KAction(actionPrefix + tr("Copy"), this);
+    action = new QAction(actionPrefix + tr("Copy"), this);
     collection->addAction(tagStr + QLatin1String("copy"), action);
-    connect(action, SIGNAL(triggered()), appTag, SLOT(copyTags()));
-    action = new KAction(actionPrefix + tr("Paste"), this);
+    connect(action, &QAction::triggered,
+            appTag, &Kid3ApplicationTagContext::copyTags);
+    action = new QAction(actionPrefix + tr("Paste"), this);
     collection->addAction(tagStr + QLatin1String("paste"), action);
-    connect(action, SIGNAL(triggered()), appTag, SLOT(pasteTags()));
-    action = new KAction(actionPrefix + tr("Remove"), this);
+    connect(action, &QAction::triggered,
+            appTag, &Kid3ApplicationTagContext::pasteTags);
+    action = new QAction(actionPrefix + tr("Remove"), this);
     collection->addAction(tagStr + QLatin1String("remove"), action);
-    connect(action, SIGNAL(triggered()), appTag, SLOT(removeTags()));
-    action = new KAction(actionPrefix + tr("Focus"), this);
+    connect(action, &QAction::triggered,
+            appTag, &Kid3ApplicationTagContext::removeTags);
+    action = new QAction(actionPrefix + tr("Focus"), this);
     collection->addAction(tagStr + QLatin1String("focus"), action);
-    connect(action, SIGNAL(triggered()), formTag, SLOT(setFocusTag()));
+    connect(action, &QAction::triggered,
+            formTag, &Kid3FormTagContext::setFocusTag);
     if (tagNr != Frame::Tag_Id3v1) {
       actionPrefix += tr("Frames:") + QLatin1Char(' ');
-      action = new KAction(actionPrefix + tr("Edit"), this);
+      action = new QAction(actionPrefix + tr("Edit"), this);
       collection->addAction(tagStr + QLatin1String("frames_edit"), action);
-      connect(action, SIGNAL(triggered()), appTag, SLOT(editFrame()));
-      action = new KAction(actionPrefix + tr("Add"), this);
+      connect(action, &QAction::triggered,
+              appTag, &Kid3ApplicationTagContext::editFrame);
+      action = new QAction(actionPrefix + tr("Add"), this);
       collection->addAction(tagStr + QLatin1String("frames_add"), action);
-      connect(action, SIGNAL(triggered()), appTag, SLOT(addFrame()));
-      action = new KAction(actionPrefix + tr("Delete"), this);
+      connect(action, &QAction::triggered,
+              appTag, &Kid3ApplicationTagContext::addFrame);
+      action = new QAction(actionPrefix + tr("Delete"), this);
       collection->addAction(tagStr + QLatin1String("frames_delete"), action);
-      connect(action, SIGNAL(triggered()), appTag, SLOT(deleteFrame()));
+      connect(action, &QAction::triggered,
+              appTag, &Kid3ApplicationTagContext::deleteFrame);
     }
   }
 
-  action = new KAction(tr("Filename") + QLatin1String(": ") + tr("Focus"),
+  action = new QAction(tr("Filename") + QLatin1String(": ") + tr("Focus"),
                        this);
   collection->addAction(QLatin1String("filename_focus"), action);
-  connect(action, SIGNAL(triggered()), form(), SLOT(setFocusFilename()));
+  connect(action, &QAction::triggered, form(), &Kid3Form::setFocusFilename);
 
-  action = new KAction(tr("File List") + QLatin1String(": ") + tr("Focus"),
+  action = new QAction(tr("File List") + QLatin1String(": ") + tr("Focus"),
                        this);
   collection->addAction(QLatin1String("filelist_focus"), action);
-  connect(action, SIGNAL(triggered()), form(), SLOT(setFocusFileList()));
-  action = new KAction(tr("&Rename"), this);
+  connect(action, &QAction::triggered, form(), &Kid3Form::setFocusFileList);
+  action = new QAction(tr("&Rename"), this);
   action->setShortcut(QKeySequence(Qt::Key_F2));
   action->setShortcutContext(Qt::WidgetShortcut);
-  connect(action, SIGNAL(triggered()), impl(), SLOT(renameFile()));
+  connect(action, &QAction::triggered, impl(), &BaseMainWindowImpl::renameFile);
   collection->addAction(QLatin1String("filelist_rename"), action);
   form()->getFileList()->setRenameAction(action);
-  action = new KAction(tr("&Move to Trash"), this);
+  action = new QAction(tr("&Move to Trash"), this);
   action->setShortcut(QKeySequence::Delete);
   action->setShortcutContext(Qt::WidgetShortcut);
-  connect(action, SIGNAL(triggered()), impl(), SLOT(deleteFile()));
+  connect(action, &QAction::triggered, impl(), &BaseMainWindowImpl::deleteFile);
   collection->addAction(QLatin1String("filelist_delete"), action);
   form()->getFileList()->setDeleteAction(action);
-  action = new KAction(tr("Directory List") + QLatin1String(": ") + tr("Focus"),
+  action = new QAction(tr("Directory List") + QLatin1String(": ") + tr("Focus"),
                        this);
   collection->addAction(QLatin1String("dirlist_focus"), action);
-  connect(action, SIGNAL(triggered()), form(), SLOT(setFocusDirList()));
+  connect(action, &QAction::triggered, form(), &Kid3Form::setFocusDirList);
 
   FileList* fileList = form()->getFileList();
-#if QT_VERSION >= 0x050000
   // Do not support user action keyboard shortcuts with KDE 4, it would only
   // print "Attempt to use QAction (..) with KXMLGUIFactory!" warnings.
-  connect(fileList, SIGNAL(userActionAdded(QString,QAction*)),
-          this, SLOT(onUserActionAdded(QString,QAction*)));
-  connect(fileList, SIGNAL(userActionRemoved(QString,QAction*)),
-          this, SLOT(onUserActionRemoved(QString,QAction*)));
-#endif
+  connect(fileList, &FileList::userActionAdded,
+          this, &KdeMainWindow::onUserActionAdded);
+  connect(fileList, &FileList::userActionRemoved,
+          this, &KdeMainWindow::onUserActionRemoved);
   fileList->initUserActions();
   const UserActionsConfig& userActionsCfg = UserActionsConfig::instance();
-  connect(&userActionsCfg, SIGNAL(contextMenuCommandsChanged()),
-          fileList, SLOT(initUserActions()));
+  connect(&userActionsCfg, &UserActionsConfig::contextMenuCommandsChanged,
+          fileList, &FileList::initUserActions);
 
   createGUI();
 }
@@ -399,7 +439,7 @@ void KdeMainWindow::initActions()
  */
 void KdeMainWindow::addDirectoryToRecentFiles(const QString& dirName)
 {
-  KUrl url;
+  QUrl url;
   url.setPath(dirName);
   m_fileOpenRecent->addUrl(url);
 }
@@ -412,7 +452,7 @@ void KdeMainWindow::readConfig()
   setAutoSaveSettings();
   m_settingsShowHidePicture->setChecked(!GuiConfig::instance().hidePicture());
   m_settingsAutoHideTags->setChecked(GuiConfig::instance().autoHideTags());
-  m_fileOpenRecent->loadEntries(KSharedConfig_openConfig()->group("Recent Files"));
+  m_fileOpenRecent->loadEntries(KSharedConfig::openConfig()->group("Recent Files"));
 }
 
 /**
@@ -420,7 +460,7 @@ void KdeMainWindow::readConfig()
  */
 void KdeMainWindow::saveConfig()
 {
-  m_fileOpenRecent->saveEntries(KSharedConfig_openConfig()->group("Recent Files"));
+  m_fileOpenRecent->saveEntries(KSharedConfig::openConfig()->group("Recent Files"));
 }
 
 /**
@@ -485,7 +525,7 @@ void KdeMainWindow::saveProperties(KConfigGroup& cfg)
  */
 void KdeMainWindow::readProperties(const KConfigGroup& cfg)
 {
-  app()->openDirectory(QStringList() << cfg.readEntry("dirname", ""));
+  app()->openDirectory({cfg.readEntry("dirname", "")});
 }
 
 /**
@@ -493,7 +533,7 @@ void KdeMainWindow::readProperties(const KConfigGroup& cfg)
  *
  * @param dir directory to open
  */
-void KdeMainWindow::slotFileOpenRecentUrl(const KUrl& url)
+void KdeMainWindow::slotFileOpenRecentUrl(const QUrl& url)
 {
   openRecentDirectory(url.path());
 }
@@ -526,7 +566,7 @@ void KdeMainWindow::slotSettingsConfigure()
 {
   QString caption(tr("Configure - Kid3"));
   KConfigSkeleton* configSkeleton = new KConfigSkeleton;
-  KdeConfigDialog* dialog = new KdeConfigDialog(m_platformTools, this, caption,
+  auto dialog = new KdeConfigDialog(m_platformTools, this, caption,
                                                 configSkeleton);
   dialog->setConfig();
   if (dialog->exec() == QDialog::Accepted) {
