@@ -6,7 +6,7 @@
  * \author Urs Fleisch
  * \date 9 Jan 2003
  *
- * Copyright (C) 2003-2011  Urs Fleisch
+ * Copyright (C) 2003-2018  Urs Fleisch
  *
  * This file is part of Kid3.
  *
@@ -24,15 +24,10 @@
  * along with this program.  If not, see <http://www.gnu.org/licenses/>.
  */
 
-#ifndef KDEMAINWINDOW_H
-#define KDEMAINWINDOW_H
+#pragma once
 
 #include <QtGlobal>
-#if QT_VERSION >= 0x050000
 #include <KXmlGuiWindow>
-#else
-#include <kxmlguiwindow.h>
-#endif
 #include "basemainwindow.h"
 
 class QAction;
@@ -55,46 +50,46 @@ public:
    * @param parent parent widget
    */
   explicit KdeMainWindow(IPlatformTools* platformTools,
-                         Kid3Application* app, QWidget* parent = 0);
+                         Kid3Application* app, QWidget* parent = nullptr);
 
   /**
    * Destructor.
    */
-  virtual ~KdeMainWindow();
+  virtual ~KdeMainWindow() override = default;
 
   /**
    * Init menu and toolbar actions.
    */
-  virtual void initActions();
+  virtual void initActions() override;
 
   /**
    * Add directory to recent files list.
    *
    * @param dirName path to directory
    */
-  virtual void addDirectoryToRecentFiles(const QString& dirName);
+  virtual void addDirectoryToRecentFiles(const QString& dirName) override;
 
   /**
    * Read settings from the configuration.
    */
-  virtual void readConfig();
+  virtual void readConfig() override;
 
   /**
    * Store geometry and recent files in settings.
    */
-  virtual void saveConfig();
+  virtual void saveConfig() override;
 
   /**
    * Get action for Settings/Auto Hide Tags.
    * @return action.
    */
-  virtual QAction* autoHideTagsAction();
+  virtual QAction* autoHideTagsAction() override;
 
   /**
    * Get action for Settings/Hide Picture.
    * @return action.
    */
-  virtual QAction* showHidePictureAction();
+  virtual QAction* showHidePictureAction() override;
 
   /**
    * Set main window caption.
@@ -102,7 +97,7 @@ public:
    * @param caption caption without application name
    * @param modified true if any file is modified
    */
-  virtual void setWindowCaption(const QString& caption, bool modified);
+  virtual void setWindowCaption(const QString& caption, bool modified) override;
 
 protected:
   /**
@@ -112,7 +107,7 @@ protected:
    *
    * @return FALSE if user canceled.
    */
-  virtual bool queryClose();
+  virtual bool queryClose() override;
 
   /**
    * Saves the window properties for each open window during session end
@@ -120,14 +115,14 @@ protected:
    *
    * @param cfg application configuration
    */
-  virtual void saveProperties(KConfigGroup& cfg);
+  virtual void saveProperties(KConfigGroup& cfg) override;
 
   /**
    * Reads the session config file and restores the application's state.
    *
    * @param cfg application configuration
    */
-  virtual void readProperties(const KConfigGroup& cfg);
+  virtual void readProperties(const KConfigGroup& cfg) override;
 
 private slots:
   /**
@@ -135,11 +130,7 @@ private slots:
    *
    * @param url URL of directory to open
    */
-#if QT_VERSION >= 0x050000
   void slotFileOpenRecentUrl(const QUrl& url);
-#else
-  void slotFileOpenRecentUrl(const KUrl& url);
-#endif
 
   /**
    * Shortcuts configuration.
@@ -177,5 +168,3 @@ private:
   KToggleAction* m_settingsAutoHideTags;
   KToggleAction* m_settingsShowHidePicture;
 };
-
-#endif /* KDEMAINWINDOW_H */
