@@ -6,7 +6,7 @@
  * \author Urs Fleisch
  * \date 30 Mar 2013
  *
- * Copyright (C) 2013  Urs Fleisch
+ * Copyright (C) 2013-2018  Urs Fleisch
  *
  * This file is part of Kid3.
  *
@@ -24,9 +24,9 @@
  * along with this program.  If not, see <http://www.gnu.org/licenses/>.
  */
 
-#ifndef KDEPLATFORMTOOLS_H
-#define KDEPLATFORMTOOLS_H
+#pragma once
 
+#include <QScopedPointer>
 #include "iplatformtools.h"
 
 class KConfig;
@@ -44,13 +44,13 @@ public:
   /**
    * Destructor.
    */
-  virtual ~KdePlatformTools();
+  virtual ~KdePlatformTools() override;
 
   /**
    * Get application settings.
    * @return settings instance.
    */
-  virtual ISettings* applicationSettings();
+  virtual ISettings* applicationSettings() override;
 
   /**
    * Move file or directory to trash.
@@ -59,21 +59,21 @@ public:
    *
    * @return true if ok.
    */
-  virtual bool moveToTrash(const QString& path) const;
+  virtual bool moveToTrash(const QString& path) const override;
 
   /**
    * Display help for a topic.
    *
    * @param anchor anchor in help document
    */
-  virtual void displayHelp(const QString& anchor);
+  virtual void displayHelp(const QString& anchor) override;
 
   /**
    * Get a themed icon by name.
    * @param name name of icon
    * @return icon.
    */
-  virtual QIcon iconFromTheme(const QString& name) const;
+  virtual QIcon iconFromTheme(const QString& name) const override;
 
   /**
    * Construct a name filter string suitable for file dialogs.
@@ -82,14 +82,14 @@ public:
    * @return name filter string.
    */
   virtual QString fileDialogNameFilter(
-      const QList<QPair<QString, QString> >& nameFilters) const;
+      const QList<QPair<QString, QString> >& nameFilters) const override;
 
   /**
    * Get file pattern part of m_nameFilter.
    * @param nameFilter name filter string
    * @return file patterns, e.g. "*.mp3".
    */
-  virtual QString getNameFilterPatterns(const QString& nameFilter) const;
+  virtual QString getNameFilterPatterns(const QString& nameFilter) const override;
 
   /**
    * Display error dialog with item list.
@@ -99,7 +99,7 @@ public:
    * @param caption caption
    */
   virtual void errorList(QWidget* parent, const QString& text,
-      const QStringList& strlist, const QString& caption);
+      const QStringList& strlist, const QString& caption) override;
 
   /**
    * Display warning dialog with yes, no, cancel buttons.
@@ -109,7 +109,7 @@ public:
    * @return QMessageBox::Yes, QMessageBox::No or QMessageBox::Cancel.
    */
   virtual int warningYesNoCancel(QWidget* parent, const QString& text,
-      const QString& caption);
+      const QString& caption) override;
 
   /**
    * Display warning dialog with item list.
@@ -120,7 +120,7 @@ public:
    * @return QMessageBox::Yes or QMessageBox::No.
    */
   virtual int warningYesNoList(QWidget* parent, const QString& text,
-      const QStringList& strlist, const QString& caption);
+      const QStringList& strlist, const QString& caption) override;
 
   /**
    * Display dialog to select an existing file.
@@ -133,7 +133,7 @@ public:
    */
   virtual QString getOpenFileName(QWidget* parent,
       const QString& caption, const QString& dir, const QString& filter,
-      QString* selectedFilter);
+      QString* selectedFilter) override;
 
   /**
    * Display dialog to select existing files.
@@ -146,7 +146,7 @@ public:
    */
   virtual QStringList getOpenFileNames(QWidget* parent,
       const QString& caption, const QString& dir, const QString& filter,
-      QString* selectedFilter);
+      QString* selectedFilter) override;
 
   /**
    * Display dialog to select a file to save.
@@ -159,7 +159,7 @@ public:
    */
   virtual QString getSaveFileName(QWidget* parent,
       const QString& caption, const QString& dir, const QString& filter,
-      QString* selectedFilter);
+      QString* selectedFilter) override;
 
   /**
    * Display dialog to select an existing directory.
@@ -169,7 +169,7 @@ public:
    * @return selected directory, empty if canceled.
    */
   virtual QString getExistingDirectory(QWidget* parent,
-      const QString& caption, const QString& startDir);
+      const QString& caption, const QString& startDir) override;
 
   /**
    * Display warning dialog.
@@ -179,7 +179,7 @@ public:
    * @param caption caption
    */
   virtual void warningDialog(QWidget* parent,
-      const QString& text, const QString& details, const QString& caption);
+      const QString& text, const QString& details, const QString& caption) override;
 
   /**
    * Display warning dialog with options to continue or cancel.
@@ -190,11 +190,9 @@ public:
    * @return true if continue was selected.
    */
   virtual bool warningContinueCancelList(QWidget* parent,
-      const QString& text, const QStringList& strlist, const QString& caption);
+      const QString& text, const QStringList& strlist, const QString& caption) override;
 
 private:
-  KConfig* m_settings;
-  ISettings* m_config;
+  QScopedPointer<KConfig> m_settings;
+  QScopedPointer<ISettings> m_config;
 };
-
-#endif // KDEPLATFORMTOOLS_H
