@@ -6,7 +6,7 @@
  * \author Urs Fleisch
  * \date 9 Jan 2003
  *
- * Copyright (C) 2003-2017  Urs Fleisch
+ * Copyright (C) 2003-2018  Urs Fleisch
  *
  * This file is part of Kid3.
  *
@@ -62,11 +62,12 @@
  * @param parent parent widget
  */
 Kid3MainWindow::Kid3MainWindow(IPlatformTools* platformTools,
-                               Kid3Application* app, QWidget* parent) :
-  QMainWindow(parent),
-  BaseMainWindow(this, platformTools, app),
-  m_platformTools(platformTools),
-  m_shortcutsModel(new ShortcutsModel(this))
+                               Kid3Application* app, QWidget* parent)
+  : QMainWindow(parent), BaseMainWindow(this, platformTools, app),
+    m_platformTools(platformTools),
+    m_fileOpenRecent(nullptr), m_shortcutsModel(new ShortcutsModel(this)),
+    m_viewToolBar(nullptr), m_viewStatusBar(nullptr),
+    m_settingsAutoHideTags(nullptr), m_settingsShowHidePicture(nullptr)
 {
 #if !defined Q_OS_WIN32 && defined CFG_DATAROOTDIR
   QString dataRootDir(QLatin1String(CFG_DATAROOTDIR));
@@ -86,15 +87,8 @@ Kid3MainWindow::Kid3MainWindow(IPlatformTools* platformTools,
   readFontAndStyleOptions();
   init();
 
-  connect(qApp, SIGNAL(commitDataRequest(QSessionManager&)),
-          this, SLOT(onCommitDataRequest(QSessionManager&)));
-}
-
-/**
- * Destructor.
- */
-Kid3MainWindow::~Kid3MainWindow()
-{
+  connect(qApp, &QGuiApplication::commitDataRequest,
+          this, &Kid3MainWindow::onCommitDataRequest);
 }
 
 /** Only defined for generation of translation files */
@@ -105,16 +99,16 @@ Kid3MainWindow::~Kid3MainWindow()
  */
 void Kid3MainWindow::initActions()
 {
-  QToolBar* toolBar = new QToolBar(this);
+  auto toolBar = new QToolBar(this);
   toolBar->setObjectName(QLatin1String("MainToolbar"));
-#if defined Q_OS_MAC && QT_VERSION >= 0x050000
+#ifdef Q_OS_MAC
   toolBar->setStyleSheet(QLatin1String("QToolButton { border: 0; }"));
 #endif
   QMenuBar* menubar = menuBar();
   QString menuTitle(tr("&File"));
   QMenu* fileMenu = menubar->addMenu(menuTitle);
 
-  QAction* fileOpen = new QAction(this);
+  auto fileOpen = new QAction(this);
   fileOpen->setStatusTip(tr("Open files"));
   fileOpen->setText(tr("&Open..."));
   fileOpen->setShortcut(QKeySequence::Open);
@@ -122,14 +116,14 @@ void Kid3MainWindow::initActions()
       QIcon(QLatin1String(":/images/document-open.png"))));
   fileOpen->setObjectName(QLatin1String("file_open"));
   m_shortcutsModel->registerAction(fileOpen, menuTitle);
-  connect(fileOpen, SIGNAL(triggered()),
-    impl(), SLOT(slotFileOpen()));
+  connect(fileOpen, &QAction::triggered,
+    impl(), &BaseMainWindowImpl::slotFileOpen);
   fileMenu->addAction(fileOpen);
   toolBar->addAction(fileOpen);
 
   m_fileOpenRecent = new RecentFilesMenu(fileMenu);
-  connect(m_fileOpenRecent, SIGNAL(loadFile(QString)),
-          this, SLOT(slotFileOpenRecentDirectory(QString)));
+  connect(m_fileOpenRecent, &RecentFilesMenu::loadFile,
+          this, &Kid3MainWindow::slotFileOpenRecentDirectory);
   m_fileOpenRecent->setStatusTip(tr("Opens a recently used directory"));
   m_fileOpenRecent->setTitle(tr("Open &Recent"));
   m_fileOpenRecent->setIcon(QIcon::fromTheme(
@@ -137,7 +131,7 @@ void Kid3MainWindow::initActions()
       QIcon(QLatin1String(":/images/document-open-recent.png"))));
   fileMenu->addMenu(m_fileOpenRecent);
 
-  QAction* fileOpenDirectory = new QAction(this);
+  auto fileOpenDirectory = new QAction(this);
   fileOpenDirectory->setStatusTip(tr("Opens a directory"));
   fileOpenDirectory->setText(tr("O&pen Directory..."));
   fileOpenDirectory->setShortcut(Qt::CTRL + Qt::Key_D);
@@ -145,12 +139,33 @@ void Kid3MainWindow::initActions()
       QIcon(QLatin1String(":/images/document-open.png"))));
   fileOpenDirectory->setObjectName(QLatin1String("open_directory"));
   m_shortcutsModel->registerAction(fileOpenDirectory, menuTitle);
-  connect(fileOpenDirectory, SIGNAL(triggered()),
-    impl(), SLOT(slotFileOpenDirectory()));
+  connect(fileOpenDirectory, &QAction::triggered,
+    impl(), &BaseMainWindowImpl::slotFileOpenDirectory);
   fileMenu->addAction(fileOpenDirectory);
+
+  auto fileReload = new QAction(this);
+  fileReload->setStatusTip(tr("Reload directory"));
+  fileReload->setText(tr("Re&load"));
+  fileReload->setShortcut(QKeySequence::Refresh);
+  fileReload->setIcon(QIcon::fromTheme(QLatin1String("view-refresh"),
+      QIcon(QLatin1String(":/images/view-refresh.png"))));
+  fileReload->setObjectName(QLatin1String("reload"));
+  m_shortcutsModel->registerAction(fileReload, menuTitle);
+  connect(fileReload, &QAction::triggered,
+    impl(), &BaseMainWindowImpl::slotFileReload);
+  fileMenu->addAction(fileReload);
+
+  auto fileUnload = new QAction(this);
+  fileUnload->setText(tr("Unload"));
+  fileUnload->setObjectName(QLatin1String("unload"));
+  m_shortcutsModel->registerAction(fileUnload, menuTitle);
+  connect(fileUnload, &QAction::triggered,
+          app(), &Kid3Application::unloadAllTags);
+  addAction(fileUnload);
+
   fileMenu->addSeparator();
 
-  QAction* fileSave = new QAction(this);
+  auto fileSave = new QAction(this);
   fileSave->setStatusTip(tr("Saves the changed files"));
   fileSave->setText(tr("&Save"));
   fileSave->setShortcut(QKeySequence::Save);
@@ -158,12 +173,12 @@ void Kid3MainWindow::initActions()
       QIcon(QLatin1String(":/images/document-save.png"))));
   fileSave->setObjectName(QLatin1String("file_save"));
   m_shortcutsModel->registerAction(fileSave, menuTitle);
-  connect(fileSave, SIGNAL(triggered()),
-    impl(), SLOT(slotFileSave()));
+  connect(fileSave, &QAction::triggered,
+    impl(), &BaseMainWindowImpl::slotFileSave);
   fileMenu->addAction(fileSave);
   toolBar->addAction(fileSave);
 
-  QAction* fileRevert = new QAction(this);
+  auto fileRevert = new QAction(this);
   fileRevert->setStatusTip(
       tr("Reverts the changes of all or the selected files"));
   fileRevert->setText(tr("Re&vert"));
@@ -172,13 +187,13 @@ void Kid3MainWindow::initActions()
       QIcon(QLatin1String(":/images/document-revert.png"))));
   fileRevert->setObjectName(QLatin1String("file_revert"));
   m_shortcutsModel->registerAction(fileRevert, menuTitle);
-  connect(fileRevert, SIGNAL(triggered()),
-          app(), SLOT(revertFileModifications()));
+  connect(fileRevert, &QAction::triggered,
+          app(), &Kid3Application::revertFileModifications);
   fileMenu->addAction(fileRevert);
   toolBar->addAction(fileRevert);
   fileMenu->addSeparator();
 
-  QAction* fileImport = new QAction(this);
+  auto fileImport = new QAction(this);
   fileImport->setData(-1);
   fileImport->setStatusTip(tr("Import from file or clipboard"));
   fileImport->setText(tr("&Import..."));
@@ -186,12 +201,13 @@ void Kid3MainWindow::initActions()
       QIcon(QLatin1String(":/images/document-import.png"))));
   fileImport->setObjectName(QLatin1String("import"));
   m_shortcutsModel->registerAction(fileImport, menuTitle);
-  connect(fileImport, SIGNAL(triggered()),
-    impl(), SLOT(slotImport()));
+  connect(fileImport, &QAction::triggered,
+    impl(), &BaseMainWindowImpl::slotImport);
   fileMenu->addAction(fileImport);
 
   int importerIdx = 0;
-  foreach (const ServerImporter* si, app()->getServerImporters()) {
+  const auto sis = app()->getServerImporters();
+  for (const ServerImporter* si : sis) {
     QString serverName(QCoreApplication::translate("@default", si->name()));
     QString actionName = QString::fromLatin1(
           si->name()).toLower().remove(QLatin1Char(' '));
@@ -199,19 +215,20 @@ void Kid3MainWindow::initActions()
     if (dotPos != -1)
       actionName.truncate(dotPos);
     actionName = QLatin1String("import_") + actionName;
-    QAction* fileImportServer = new QAction(this);
+    auto fileImportServer = new QAction(this);
     fileImportServer->setData(importerIdx);
     fileImportServer->setStatusTip(tr("Import from %1").arg(serverName));
     fileImportServer->setText(tr("Import from %1...").arg(serverName));
     fileImportServer->setObjectName(actionName);
     m_shortcutsModel->registerAction(fileImportServer, menuTitle);
-    connect(fileImportServer, SIGNAL(triggered()),
-      impl(), SLOT(slotImport()));
+    connect(fileImportServer, &QAction::triggered,
+      impl(), &BaseMainWindowImpl::slotImport);
     fileMenu->addAction(fileImportServer);
     ++importerIdx;
   }
 
-  foreach (const ServerTrackImporter* si, app()->getServerTrackImporters()) {
+  const auto stis = app()->getServerTrackImporters();
+  for (const ServerTrackImporter* si : stis) {
     QString serverName(QCoreApplication::translate("@default", si->name()));
     QString actionName = QString::fromLatin1(
           si->name()).toLower().remove(QLatin1Char(' '));
@@ -219,49 +236,49 @@ void Kid3MainWindow::initActions()
     if (dotPos != -1)
       actionName.truncate(dotPos);
     actionName = QLatin1String("import_") + actionName;
-    QAction* fileImportServer = new QAction(this);
+    auto fileImportServer = new QAction(this);
     fileImportServer->setData(importerIdx);
     fileImportServer->setStatusTip(tr("Import from %1").arg(serverName));
     fileImportServer->setText(tr("Import from %1...").arg(serverName));
     fileImportServer->setObjectName(actionName);
     m_shortcutsModel->registerAction(fileImportServer, menuTitle);
-    connect(fileImportServer, SIGNAL(triggered()),
-      impl(), SLOT(slotImport()));
+    connect(fileImportServer, &QAction::triggered,
+      impl(), &BaseMainWindowImpl::slotImport);
     fileMenu->addAction(fileImportServer);
     ++importerIdx;
   }
 
-  QAction* fileBatchImport = new QAction(this);
+  auto fileBatchImport = new QAction(this);
   fileBatchImport->setStatusTip(tr("Automatic import"));
   fileBatchImport->setText(tr("Automatic I&mport..."));
   fileBatchImport->setObjectName(QLatin1String("batch_import"));
   m_shortcutsModel->registerAction(fileBatchImport, menuTitle);
-  connect(fileBatchImport, SIGNAL(triggered()),
-    impl(), SLOT(slotBatchImport()));
+  connect(fileBatchImport, &QAction::triggered,
+    impl(), &BaseMainWindowImpl::slotBatchImport);
   fileMenu->addAction(fileBatchImport);
 
-  QAction* fileBrowseCoverArt = new QAction(this);
+  auto fileBrowseCoverArt = new QAction(this);
   fileBrowseCoverArt->setStatusTip(tr("Browse album cover artwork"));
   fileBrowseCoverArt->setText(tr("&Browse Cover Art..."));
   fileBrowseCoverArt->setObjectName(QLatin1String("browse_cover_art"));
   m_shortcutsModel->registerAction(fileBrowseCoverArt, menuTitle);
-  connect(fileBrowseCoverArt, SIGNAL(triggered()),
-    impl(), SLOT(slotBrowseCoverArt()));
+  connect(fileBrowseCoverArt, &QAction::triggered,
+    impl(), &BaseMainWindowImpl::slotBrowseCoverArt);
   fileMenu->addAction(fileBrowseCoverArt);
   fileMenu->addSeparator();
 
-  QAction* fileExport = new QAction(this);
+  auto fileExport = new QAction(this);
   fileExport->setStatusTip(tr("Export to file or clipboard"));
   fileExport->setText(tr("&Export..."));
   fileExport->setIcon(QIcon::fromTheme(QLatin1String("document-export"),
       QIcon(QLatin1String(":/images/document-export.png"))));
   fileExport->setObjectName(QLatin1String("export"));
   m_shortcutsModel->registerAction(fileExport, menuTitle);
-  connect(fileExport, SIGNAL(triggered()),
-    impl(), SLOT(slotExport()));
+  connect(fileExport, &QAction::triggered,
+    impl(), &BaseMainWindowImpl::slotExport);
   fileMenu->addAction(fileExport);
 
-  QAction* fileCreatePlaylist = new QAction(this);
+  auto fileCreatePlaylist = new QAction(this);
   fileCreatePlaylist->setStatusTip(tr("Create M3U Playlist"));
   fileCreatePlaylist->setText(tr("&Create Playlist..."));
   fileCreatePlaylist->setIcon(
@@ -269,13 +286,13 @@ void Kid3MainWindow::initActions()
             QIcon(QLatin1String(":/images/view-media-playlist.png"))));
   fileCreatePlaylist->setObjectName(QLatin1String("create_playlist"));
   m_shortcutsModel->registerAction(fileCreatePlaylist, menuTitle);
-  connect(fileCreatePlaylist, SIGNAL(triggered()),
-    impl(), SLOT(slotPlaylistDialog()));
+  connect(fileCreatePlaylist, &QAction::triggered,
+    impl(), &BaseMainWindowImpl::slotPlaylistDialog);
   fileMenu->addAction(fileCreatePlaylist);
   toolBar->addAction(fileCreatePlaylist);
   fileMenu->addSeparator();
 
-  QAction* fileQuit = new QAction(this);
+  auto fileQuit = new QAction(this);
   fileQuit->setStatusTip(tr("Quits the application"));
   fileQuit->setText(tr("&Quit"));
   fileQuit->setShortcut(Qt::CTRL + Qt::Key_Q);
@@ -284,13 +301,13 @@ void Kid3MainWindow::initActions()
   fileQuit->setMenuRole(QAction::QuitRole);
   fileQuit->setObjectName(QLatin1String("file_quit"));
   m_shortcutsModel->registerAction(fileQuit, menuTitle);
-  connect(fileQuit, SIGNAL(triggered()),
-    impl(), SLOT(slotFileQuit()));
+  connect(fileQuit, &QAction::triggered,
+    impl(), &BaseMainWindowImpl::slotFileQuit);
   fileMenu->addAction(fileQuit);
 
   menuTitle = tr("&Edit");
   QMenu* editMenu = menubar->addMenu(menuTitle);
-  QAction* editSelectAll = new QAction(this);
+  auto editSelectAll = new QAction(this);
   editSelectAll->setStatusTip(tr("Select all files"));
   editSelectAll->setText(tr("Select &All"));
   editSelectAll->setShortcut(Qt::ALT + Qt::Key_A);
@@ -302,31 +319,31 @@ void Kid3MainWindow::initActions()
 #endif
   editSelectAll->setObjectName(QLatin1String("edit_select_all"));
   m_shortcutsModel->registerAction(editSelectAll, menuTitle);
-  connect(editSelectAll, SIGNAL(triggered()),
-          form(), SLOT(selectAllFiles()));
+  connect(editSelectAll, &QAction::triggered,
+          form(), &Kid3Form::selectAllFiles);
   editMenu->addAction(editSelectAll);
 
-  QAction* editDeselect = new QAction(this);
+  auto editDeselect = new QAction(this);
   editDeselect->setStatusTip(tr("Deselect all files"));
   editDeselect->setText(tr("Dese&lect"));
   editDeselect->setShortcut(Qt::CTRL + Qt::SHIFT + Qt::Key_A);
   editDeselect->setObjectName(QLatin1String("edit_deselect"));
   m_shortcutsModel->registerAction(editDeselect, menuTitle);
-  connect(editDeselect, SIGNAL(triggered()),
-          form(), SLOT(deselectAllFiles()));
+  connect(editDeselect, &QAction::triggered,
+          form(), &Kid3Form::deselectAllFiles);
   editMenu->addAction(editDeselect);
 
-  QAction* editSelectAllInDir = new QAction(this);
+  auto editSelectAllInDir = new QAction(this);
   editSelectAllInDir->setStatusTip(
         tr("Select all files in the current directory"));
   editSelectAllInDir->setText(tr("Select All in &Directory"));
   editSelectAllInDir->setObjectName(QLatin1String("select_all_in_directory"));
   m_shortcutsModel->registerAction(editSelectAllInDir, menuTitle);
-  connect(editSelectAllInDir, SIGNAL(triggered()),
-    app(), SLOT(selectAllInDirectory()));
+  connect(editSelectAllInDir, &QAction::triggered,
+    app(), &Kid3Application::selectAllInDirectory);
   editMenu->addAction(editSelectAllInDir);
 
-  QAction* editPreviousFile = new QAction(this);
+  auto editPreviousFile = new QAction(this);
   editPreviousFile->setStatusTip(tr("Select previous file"));
   editPreviousFile->setText(tr("&Previous File"));
   editPreviousFile->setShortcut(Qt::ALT + Qt::Key_Up);
@@ -334,12 +351,12 @@ void Kid3MainWindow::initActions()
       QIcon(QLatin1String(":/images/go-previous.png"))));
   editPreviousFile->setObjectName(QLatin1String("previous_file"));
   m_shortcutsModel->registerAction(editPreviousFile, menuTitle);
-  connect(editPreviousFile, SIGNAL(triggered()),
-    form(), SLOT(previousFile()));
+  connect(editPreviousFile, &QAction::triggered,
+    form(), &Kid3Form::selectPreviousTaggedFile);
   editMenu->addAction(editPreviousFile);
   toolBar->addAction(editPreviousFile);
 
-  QAction* editNextFile = new QAction(this);
+  auto editNextFile = new QAction(this);
   editNextFile->setStatusTip(tr("Select next file"));
   editNextFile->setText(tr("&Next File"));
   editNextFile->setShortcut(Qt::ALT + Qt::Key_Down);
@@ -347,13 +364,13 @@ void Kid3MainWindow::initActions()
       QIcon(QLatin1String(":/images/go-next.png"))));
   editNextFile->setObjectName(QLatin1String("next_file"));
   m_shortcutsModel->registerAction(editNextFile, menuTitle);
-  connect(editNextFile, SIGNAL(triggered()),
-    form(), SLOT(nextFile()));
+  connect(editNextFile, &QAction::triggered,
+    form(), &Kid3Form::selectNextTaggedFile);
   editMenu->addAction(editNextFile);
   toolBar->addAction(editNextFile);
   editMenu->addSeparator();
 
-  QAction* editFind = new QAction(this);
+  auto editFind = new QAction(this);
   editFind->setStatusTip(tr("Find"));
   editFind->setText(tr("&Find..."));
   editFind->setShortcut(QKeySequence::Find);
@@ -363,11 +380,11 @@ void Kid3MainWindow::initActions()
 #endif
   editFind->setObjectName(QLatin1String("edit_find"));
   m_shortcutsModel->registerAction(editFind, menuTitle);
-  connect(editFind, SIGNAL(triggered()),
-    impl(), SLOT(find()));
+  connect(editFind, &QAction::triggered,
+    impl(), &BaseMainWindowImpl::find);
   editMenu->addAction(editFind);
 
-  QAction* editReplace = new QAction(this);
+  auto editReplace = new QAction(this);
   editReplace->setStatusTip(tr("Find and replace"));
   editReplace->setText(tr("&Replace..."));
   editReplace->setShortcut(QKeySequence::Replace);
@@ -377,105 +394,103 @@ void Kid3MainWindow::initActions()
 #endif
   editReplace->setObjectName(QLatin1String("edit_replace"));
   m_shortcutsModel->registerAction(editReplace, menuTitle);
-  connect(editReplace, SIGNAL(triggered()),
-    impl(), SLOT(findReplace()));
+  connect(editReplace, &QAction::triggered,
+    impl(), &BaseMainWindowImpl::findReplace);
   editMenu->addAction(editReplace);
 
   menuTitle = tr("&Tools");
   QMenu* toolsMenu = menubar->addMenu(menuTitle);
-  QAction* toolsApplyFilenameFormat = new QAction(this);
+  auto toolsApplyFilenameFormat = new QAction(this);
   toolsApplyFilenameFormat->setStatusTip(tr("Apply Filename Format"));
   toolsApplyFilenameFormat->setText(tr("Apply &Filename Format"));
   toolsApplyFilenameFormat->setObjectName(
         QLatin1String("apply_filename_format"));
   m_shortcutsModel->registerAction(toolsApplyFilenameFormat, menuTitle);
-  connect(toolsApplyFilenameFormat, SIGNAL(triggered()),
-    app(), SLOT(applyFilenameFormat()));
+  connect(toolsApplyFilenameFormat, &QAction::triggered,
+    app(), &Kid3Application::applyFilenameFormat);
   toolsMenu->addAction(toolsApplyFilenameFormat);
 
-  QAction* toolsApplyTagFormat = new QAction(this);
+  auto toolsApplyTagFormat = new QAction(this);
   toolsApplyTagFormat->setStatusTip(tr("Apply Tag Format"));
   toolsApplyTagFormat->setText(tr("Apply &Tag Format"));
   toolsApplyTagFormat->setObjectName(QLatin1String("apply_id3_format"));
   m_shortcutsModel->registerAction(toolsApplyTagFormat, menuTitle);
-  connect(toolsApplyTagFormat, SIGNAL(triggered()),
-    app(), SLOT(applyTagFormat()));
+  connect(toolsApplyTagFormat, &QAction::triggered,
+    app(), &Kid3Application::applyTagFormat);
   toolsMenu->addAction(toolsApplyTagFormat);
 
-  QAction* toolsApplyTextEncoding = new QAction(this);
+  auto toolsApplyTextEncoding = new QAction(this);
   toolsApplyTextEncoding->setStatusTip(tr("Apply Text Encoding"));
   toolsApplyTextEncoding->setText(tr("Apply Text &Encoding"));
   toolsApplyTextEncoding->setObjectName(QLatin1String("apply_text_encoding"));
   m_shortcutsModel->registerAction(toolsApplyTextEncoding, menuTitle);
-  connect(toolsApplyTextEncoding, SIGNAL(triggered()),
-    app(), SLOT(applyTextEncoding()));
+  connect(toolsApplyTextEncoding, &QAction::triggered,
+    app(), &Kid3Application::applyTextEncoding);
   toolsMenu->addAction(toolsApplyTextEncoding);
   toolsMenu->addSeparator();
 
-  QAction* toolsRenameDirectory = new QAction(this);
+  auto toolsRenameDirectory = new QAction(this);
   toolsRenameDirectory->setStatusTip(tr("Rename Directory"));
   toolsRenameDirectory->setText(tr("&Rename Directory..."));
   toolsRenameDirectory->setObjectName(QLatin1String("rename_directory"));
   m_shortcutsModel->registerAction(toolsRenameDirectory, menuTitle);
-  connect(toolsRenameDirectory, SIGNAL(triggered()),
-    impl(), SLOT(slotRenameDirectory()));
+  connect(toolsRenameDirectory, &QAction::triggered,
+    impl(), &BaseMainWindowImpl::slotRenameDirectory);
   toolsMenu->addAction(toolsRenameDirectory);
 
-  QAction* toolsNumberTracks = new QAction(this);
+  auto toolsNumberTracks = new QAction(this);
   toolsNumberTracks->setStatusTip(tr("Number Tracks"));
   toolsNumberTracks->setText(tr("&Number Tracks..."));
   toolsNumberTracks->setObjectName(QLatin1String("number_tracks"));
   m_shortcutsModel->registerAction(toolsNumberTracks, menuTitle);
-  connect(toolsNumberTracks, SIGNAL(triggered()),
-    impl(), SLOT(slotNumberTracks()));
+  connect(toolsNumberTracks, &QAction::triggered,
+    impl(), &BaseMainWindowImpl::slotNumberTracks);
   toolsMenu->addAction(toolsNumberTracks);
 
-  QAction* toolsFilter = new QAction(this);
+  auto toolsFilter = new QAction(this);
   toolsFilter->setStatusTip(tr("Filter"));
   toolsFilter->setText(tr("F&ilter..."));
   toolsFilter->setObjectName(QLatin1String("filter"));
   m_shortcutsModel->registerAction(toolsFilter, menuTitle);
-  connect(toolsFilter, SIGNAL(triggered()),
-    impl(), SLOT(slotFilter()));
+  connect(toolsFilter, &QAction::triggered,
+    impl(), &BaseMainWindowImpl::slotFilter);
   toolsMenu->addAction(toolsFilter);
   toolsMenu->addSeparator();
 
   const TagConfig& tagCfg = TagConfig::instance();
   if (tagCfg.taggedFileFeatures() & TaggedFile::TF_ID3v24) {
-    QAction* toolsConvertToId3v24 = new QAction(this);
+    auto toolsConvertToId3v24 = new QAction(this);
     toolsConvertToId3v24->setStatusTip(tr("Convert ID3v2.3 to ID3v2.4"));
     toolsConvertToId3v24->setText(tr("Convert ID3v2.3 to ID3v2.&4"));
     toolsConvertToId3v24->setObjectName(QLatin1String("convert_to_id3v24"));
     m_shortcutsModel->registerAction(toolsConvertToId3v24, menuTitle);
-    connect(toolsConvertToId3v24, SIGNAL(triggered()),
-      app(), SLOT(convertToId3v24()));
+    connect(toolsConvertToId3v24, &QAction::triggered,
+      app(), &Kid3Application::convertToId3v24);
     toolsMenu->addAction(toolsConvertToId3v24);
 
     if (tagCfg.taggedFileFeatures() & TaggedFile::TF_ID3v23) {
-      QAction* toolsConvertToId3v23 = new QAction(this);
+      auto toolsConvertToId3v23 = new QAction(this);
       toolsConvertToId3v23->setStatusTip(tr("Convert ID3v2.4 to ID3v2.3"));
       toolsConvertToId3v23->setText(tr("Convert ID3v2.4 to ID3v2.&3"));
       toolsConvertToId3v23->setObjectName(QLatin1String("convert_to_id3v23"));
       m_shortcutsModel->registerAction(toolsConvertToId3v23, menuTitle);
-      connect(toolsConvertToId3v23, SIGNAL(triggered()),
-        app(), SLOT(convertToId3v23()));
+      connect(toolsConvertToId3v23, &QAction::triggered,
+        app(), &Kid3Application::convertToId3v23);
       toolsMenu->addAction(toolsConvertToId3v23);
     }
   }
 
-#if defined HAVE_PHONON || QT_VERSION >= 0x050000
   toolsMenu->addSeparator();
-  QAction* toolsPlay = new QAction(this);
+  auto toolsPlay = new QAction(this);
   toolsPlay->setStatusTip(tr("Play"));
   toolsPlay->setText(tr("&Play"));
   toolsPlay->setIcon(QIcon(style()->standardIcon(QStyle::SP_MediaPlay)));
   toolsPlay->setObjectName(QLatin1String("play"));
   m_shortcutsModel->registerAction(toolsPlay, menuTitle);
-  connect(toolsPlay, SIGNAL(triggered()),
-    app(), SLOT(playAudio()));
+  connect(toolsPlay, &QAction::triggered,
+    app(), &Kid3Application::playAudio);
   toolsMenu->addAction(toolsPlay);
   toolBar->addAction(toolsPlay);
-#endif
 
   menuTitle = tr("&Settings");
   QMenu* settingsMenu = menubar->addMenu(menuTitle);
@@ -497,8 +512,8 @@ void Kid3MainWindow::initActions()
   m_viewStatusBar->setCheckable(true);
   m_viewStatusBar->setObjectName(QLatin1String("options_show_statusbar"));
   m_shortcutsModel->registerAction(m_viewStatusBar, menuTitle);
-  connect(m_viewStatusBar, SIGNAL(triggered()),
-    this, SLOT(slotViewStatusBar()));
+  connect(m_viewStatusBar, &QAction::triggered,
+    this, &Kid3MainWindow::slotViewStatusBar);
   settingsMenu->addAction(m_viewStatusBar);
 
   m_settingsShowHidePicture = new QAction(this);
@@ -507,8 +522,8 @@ void Kid3MainWindow::initActions()
   m_settingsShowHidePicture->setCheckable(true);
   m_settingsShowHidePicture->setObjectName(QLatin1String("hide_picture"));
   m_shortcutsModel->registerAction(m_settingsShowHidePicture, menuTitle);
-  connect(m_settingsShowHidePicture, SIGNAL(triggered()),
-    impl(), SLOT(slotSettingsShowHidePicture()));
+  connect(m_settingsShowHidePicture, &QAction::triggered,
+    impl(), &BaseMainWindowImpl::slotSettingsShowHidePicture);
   settingsMenu->addAction(m_settingsShowHidePicture);
 
   m_settingsAutoHideTags = new QAction(this);
@@ -517,11 +532,11 @@ void Kid3MainWindow::initActions()
   m_settingsAutoHideTags->setCheckable(true);
   m_settingsAutoHideTags->setObjectName(QLatin1String("auto_hide_tags"));
   m_shortcutsModel->registerAction(m_settingsAutoHideTags, menuTitle);
-  connect(m_settingsAutoHideTags, SIGNAL(triggered()),
-    impl(), SLOT(slotSettingsAutoHideTags()));
+  connect(m_settingsAutoHideTags, &QAction::triggered,
+    impl(), &BaseMainWindowImpl::slotSettingsAutoHideTags);
   settingsMenu->addAction(m_settingsAutoHideTags);
 
-  QAction* settingsConfigure = new QAction(this);
+  auto settingsConfigure = new QAction(this);
   settingsConfigure->setStatusTip(tr("Configure Kid3"));
   settingsConfigure->setText(tr("&Configure Kid3..."));
   settingsConfigure->setIcon(QIcon::fromTheme(
@@ -531,15 +546,15 @@ void Kid3MainWindow::initActions()
   settingsConfigure->setMenuRole(QAction::PreferencesRole);
   settingsConfigure->setObjectName(QLatin1String("options_configure"));
   m_shortcutsModel->registerAction(settingsConfigure, menuTitle);
-  connect(settingsConfigure, SIGNAL(triggered()),
-    this, SLOT(slotSettingsConfigure()));
+  connect(settingsConfigure, &QAction::triggered,
+    this, &Kid3MainWindow::slotSettingsConfigure);
   settingsMenu->addSeparator();
   settingsMenu->addAction(settingsConfigure);
   toolBar->addAction(settingsConfigure);
 
   menuTitle = tr("&Help");
   QMenu* helpMenu = menubar->addMenu(menuTitle);
-  QAction* helpHandbook = new QAction(this);
+  auto helpHandbook = new QAction(this);
   helpHandbook->setStatusTip(tr("Kid3 Handbook"));
   helpHandbook->setText(tr("Kid3 &Handbook"));
   helpHandbook->setIcon(QIcon::fromTheme(QLatin1String("help-contents"),
@@ -547,11 +562,11 @@ void Kid3MainWindow::initActions()
   helpHandbook->setShortcut(QKeySequence::HelpContents);
   helpHandbook->setObjectName(QLatin1String("help_contents"));
   m_shortcutsModel->registerAction(helpHandbook, menuTitle);
-  connect(helpHandbook, SIGNAL(triggered()),
-    this, SLOT(slotHelpHandbook()));
+  connect(helpHandbook, &QAction::triggered,
+    this, &Kid3MainWindow::slotHelpHandbook);
   helpMenu->addAction(helpHandbook);
 
-  QAction* helpAbout = new QAction(this);
+  auto helpAbout = new QAction(this);
   helpAbout->setStatusTip(tr("About Kid3"));
   helpAbout->setText(tr("&About Kid3"));
 #ifndef Q_OS_MAC
@@ -561,18 +576,18 @@ void Kid3MainWindow::initActions()
   helpAbout->setMenuRole(QAction::AboutRole);
   helpAbout->setObjectName(QLatin1String("help_about_app"));
   m_shortcutsModel->registerAction(helpAbout, menuTitle);
-  connect(helpAbout, SIGNAL(triggered()),
-    this, SLOT(slotHelpAbout()));
+  connect(helpAbout, &QAction::triggered,
+    this, &Kid3MainWindow::slotHelpAbout);
   helpMenu->addAction(helpAbout);
 
-  QAction* helpAboutQt = new QAction(this);
+  auto helpAboutQt = new QAction(this);
   helpAboutQt->setStatusTip(tr("About Qt"));
   helpAboutQt->setText(tr("About &Qt"));
   helpAboutQt->setMenuRole(QAction::AboutQtRole);
   helpAboutQt->setObjectName(QLatin1String("help_about_qt"));
   m_shortcutsModel->registerAction(helpAboutQt, menuTitle);
-  connect(helpAboutQt, SIGNAL(triggered()),
-    this, SLOT(slotHelpAboutQt()));
+  connect(helpAboutQt, &QAction::triggered,
+    this, &Kid3MainWindow::slotHelpAboutQt);
   helpMenu->addAction(helpAboutQt);
 
   addToolBar(toolBar);
@@ -582,14 +597,14 @@ void Kid3MainWindow::initActions()
   initFormActions();
 
   FileList* fileList = form()->getFileList();
-  connect(fileList, SIGNAL(userActionAdded(QString,QAction*)),
-          this, SLOT(onUserActionAdded(QString,QAction*)));
-  connect(fileList, SIGNAL(userActionRemoved(QString,QAction*)),
-          this, SLOT(onUserActionRemoved(QString,QAction*)));
+  connect(fileList, &FileList::userActionAdded,
+          this, &Kid3MainWindow::onUserActionAdded);
+  connect(fileList, &FileList::userActionRemoved,
+          this, &Kid3MainWindow::onUserActionRemoved);
   fileList->initUserActions();
   const UserActionsConfig& userActionsCfg = UserActionsConfig::instance();
-  connect(&userActionsCfg, SIGNAL(contextMenuCommandsChanged()),
-          fileList, SLOT(initUserActions()));
+  connect(&userActionsCfg, &UserActionsConfig::contextMenuCommandsChanged,
+          fileList, &FileList::initUserActions);
 }
 
 /**
@@ -600,81 +615,95 @@ void Kid3MainWindow::initFormActions()
   QString ctx(tr("Filename"));
   FOR_ALL_TAGS(tagNr) {
     QString tagStr = Frame::tagNumberToString(tagNr);
-    initAction(tr("From Tag %1").arg(tagStr),
-               QLatin1String("filename_from_v") + tagStr,
-               app()->tag(tagNr), SLOT(getFilenameFromTags()), ctx);
+    connect(addFormAction(tr("From Tag %1").arg(tagStr),
+                          QLatin1String("filename_from_v") + tagStr, ctx),
+            &QAction::triggered,
+            app()->tag(tagNr), &Kid3ApplicationTagContext::getFilenameFromTags);
   }
-  initAction(tr("Focus"), QLatin1String("filename_focus"),
-             form(), SLOT(setFocusFilename()), ctx);
+  connect(addFormAction(tr("Focus"), QLatin1String("filename_focus"), ctx),
+          &QAction::triggered,
+          form(), &Kid3Form::setFocusFilename);
   FOR_ALL_TAGS(tagNr) {
-    Frame::TagNumber otherTagNr = tagNr == Frame::Tag_1 ? Frame::Tag_2 :
-          tagNr == Frame::Tag_2 ? Frame::Tag_1 : Frame::Tag_NumValues;
+    Frame::TagNumber otherTagNr = tagNr == Frame::Tag_1
+        ? Frame::Tag_2
+        : tagNr == Frame::Tag_2 ? Frame::Tag_1 : Frame::Tag_NumValues;
     QString tagStr = Frame::tagNumberToString(tagNr);
     Kid3ApplicationTagContext* appTag = app()->tag(tagNr);
     Kid3FormTagContext* formTag = form()->tag(tagNr);
     ctx = tr("Tag %1").arg(tagStr);
     tagStr = QLatin1Char('v') + tagStr + QLatin1Char('_');
-    initAction(tr("From Filename"), tagStr + QLatin1String("from_filename"),
-               appTag, SLOT(getTagsFromFilename()), ctx);
+    connect(addFormAction(tr("From Filename"),
+                          tagStr + QLatin1String("from_filename"), ctx),
+            &QAction::triggered,
+            appTag, &Kid3ApplicationTagContext::getTagsFromFilename);
     if (otherTagNr < Frame::Tag_NumValues) {
       QString otherTagStr = Frame::tagNumberToString(otherTagNr);
-      initAction(tr("From Tag %1").arg(otherTagStr),
-                 tagStr + QLatin1String("from_v") + otherTagStr,
-                 appTag, SLOT(copyToOtherTag()), ctx);
+      connect(addFormAction(tr("From Tag %1").arg(otherTagStr),
+                            tagStr + QLatin1String("from_v") + otherTagStr, ctx),
+              &QAction::triggered,
+              appTag, &Kid3ApplicationTagContext::copyToOtherTag);
     }
-    initAction(tr("Copy"), tagStr + QLatin1String("copy"),
-               appTag, SLOT(copyTags()), ctx);
-    initAction(tr("Paste"), tagStr + QLatin1String("paste"),
-               appTag, SLOT(pasteTags()), ctx);
-    initAction(tr("Remove"), tagStr + QLatin1String("remove"),
-               appTag, SLOT(removeTags()), ctx);
+    connect(addFormAction(tr("Copy"), tagStr + QLatin1String("copy"), ctx),
+            &QAction::triggered,
+            appTag, &Kid3ApplicationTagContext::copyTags);
+    connect(addFormAction(tr("Paste"), tagStr + QLatin1String("paste"), ctx),
+            &QAction::triggered,
+            appTag, &Kid3ApplicationTagContext::pasteTags);
+    connect(addFormAction(tr("Remove"), tagStr + QLatin1String("remove"), ctx),
+            &QAction::triggered,
+            appTag, &Kid3ApplicationTagContext::removeTags);
     if (tagNr != Frame::Tag_Id3v1) {
-      initAction(tr("Edit"), tagStr + QLatin1String("frames_edit"),
-                 appTag, SLOT(editFrame()), ctx);
-      initAction(tr("Add"), tagStr + QLatin1String("frames_add"),
-                 appTag, SLOT(addFrame()), ctx);
-      initAction(tr("Delete"), tagStr + QLatin1String("frames_delete"),
-                 appTag, SLOT(deleteFrame()), ctx);
+      connect(addFormAction(tr("Edit"), tagStr + QLatin1String("frames_edit"), ctx),
+              &QAction::triggered,
+              appTag, &Kid3ApplicationTagContext::editFrame);
+      connect(addFormAction(tr("Add"), tagStr + QLatin1String("frames_add"), ctx),
+              &QAction::triggered,
+              appTag, &Kid3ApplicationTagContext::addFrame);
+      connect(addFormAction(tr("Delete"), tagStr + QLatin1String("frames_delete"), ctx),
+              &QAction::triggered,
+              appTag, &Kid3ApplicationTagContext::deleteFrame);
     }
-    initAction(tr("Focus"), tagStr + QLatin1String("focus"),
-               formTag, SLOT(setFocusTag()), ctx);
+    connect(addFormAction(tr("Focus"), tagStr + QLatin1String("focus"), ctx),
+            &QAction::triggered,
+            formTag, &Kid3FormTagContext::setFocusTag);
   }
   ctx = tr("File List");
-  initAction(tr("Focus"), QLatin1String("filelist_focus"),
-             form(), SLOT(setFocusFileList()), ctx);
+  connect(addFormAction(tr("Focus"), QLatin1String("filelist_focus"), ctx),
+          &QAction::triggered,
+          form(), &Kid3Form::setFocusFileList);
   QAction* renameAction = new QAction(tr("&Rename"), this);
   renameAction->setObjectName(QLatin1String("filelist_rename"));
   renameAction->setShortcut(QKeySequence(Qt::Key_F2));
   renameAction->setShortcutContext(Qt::WidgetShortcut);
-  connect(renameAction, SIGNAL(triggered()), impl(), SLOT(renameFile()));
+  connect(renameAction, &QAction::triggered, impl(), &BaseMainWindowImpl::renameFile);
   form()->getFileList()->setRenameAction(renameAction);
   m_shortcutsModel->registerAction(renameAction, ctx);
   QAction* deleteAction = new QAction(tr("&Move to Trash"), this);
   deleteAction->setObjectName(QLatin1String("filelist_delete"));
   deleteAction->setShortcut(QKeySequence::Delete);
   deleteAction->setShortcutContext(Qt::WidgetShortcut);
-  connect(deleteAction, SIGNAL(triggered()), impl(), SLOT(deleteFile()));
+  connect(deleteAction, &QAction::triggered, impl(), &BaseMainWindowImpl::deleteFile);
   form()->getFileList()->setDeleteAction(deleteAction);
   m_shortcutsModel->registerAction(deleteAction, ctx);
   ctx = tr("Directory List");
-  initAction(tr("Focus"), QLatin1String("dirlist_focus"),
-             form(), SLOT(setFocusDirList()), ctx);
+  connect(addFormAction(tr("Focus"), QLatin1String("dirlist_focus"), ctx),
+          &QAction::triggered,
+          form(), &Kid3Form::setFocusDirList);
 }
 
 /**
- * Init action of form.
+ * Add action of form.
  */
-void Kid3MainWindow::initAction(const QString& text, const QString& name,
-                                const QObject* receiver, const char* slot,
-                                const QString& context)
+QAction* Kid3MainWindow::addFormAction(const QString& text, const QString& name,
+                                       const QString& context)
 {
-  QAction* action = new QAction(form());
+  auto action = new QAction(form());
   action->setStatusTip(text);
   action->setText(text);
   action->setObjectName(name);
   m_shortcutsModel->registerAction(action, context);
-  connect(action, SIGNAL(triggered()), receiver, slot);
   addAction(action);
+  return action;
 }
 
 /**
@@ -860,7 +889,7 @@ void Kid3MainWindow::slotHelpAboutQt()
 void Kid3MainWindow::slotSettingsConfigure()
 {
   QString caption(tr("Configure - Kid3"));
-  ConfigDialog* dialog = new ConfigDialog(m_platformTools, this, caption,
+  auto dialog = new ConfigDialog(m_platformTools, this, caption,
                                           m_shortcutsModel);
   dialog->setConfig();
   if (dialog->exec() == QDialog::Accepted) {
