@@ -6,7 +6,7 @@
  * \author Urs Fleisch
  * \date 9 Jan 2003
  *
- * Copyright (C) 2003-2013  Urs Fleisch
+ * Copyright (C) 2003-2018  Urs Fleisch
  *
  * This file is part of Kid3.
  *
@@ -50,15 +50,13 @@ int main(int argc, char* argv[])
 {
   Q_INIT_RESOURCE(kid3);
 
-#if QT_VERSION >= 0x050100
   // Enable support for high resolution "@2x" images
   QCoreApplication::setAttribute(Qt::AA_UseHighDpiPixmaps);
-#endif
 #if QT_VERSION >= 0x050600
   QCoreApplication::setAttribute(Qt::AA_EnableHighDpiScaling);
 #endif
   Kid3QtApplication app(argc, argv);
-  app.setApplicationName(QLatin1String("Kid3"));
+  QCoreApplication::setApplicationName(QLatin1String("Kid3"));
 
   Utils::loadTranslation();
 
@@ -77,13 +75,14 @@ int main(int argc, char* argv[])
   }
 
   IPlatformTools* platformTools = new PlatformTools;
-  Kid3Application* kid3App = new Kid3Application(platformTools);
+  auto kid3App = new Kid3Application(platformTools);
 #ifdef HAVE_QTDBUS
   kid3App->activateDbusInterface();
 #endif
-  Kid3MainWindow* kid3 = new Kid3MainWindow(platformTools, kid3App);
+  auto kid3 = new Kid3MainWindow(platformTools, kid3App);
   kid3->setAttribute(Qt::WA_DeleteOnClose);
-  QObject::connect(&app, SIGNAL(openFileRequested(QStringList)), kid3App, SLOT(openDrop(QStringList)));
+  QObject::connect(&app, &Kid3QtApplication::openFileRequested,
+                   kid3App, &Kid3Application::openDrop);
   kid3->show();
   if (args.size() > 1) {
     kid3->confirmedOpenDirectory(args.mid(1));
@@ -93,7 +92,7 @@ int main(int argc, char* argv[])
     kid3->confirmedOpenDirectory(QStringList()
                                  << FileConfig::instance().lastOpenedFile());
   }
-  int rc = app.exec();
+  int rc = QApplication::exec();
   delete kid3App;
   delete platformTools;
   return rc;
