@@ -6,7 +6,7 @@
  * \author Urs Fleisch
  * \date 3 Jan 2013
  *
- * Copyright (C) 2013  Urs Fleisch
+ * Copyright (C) 2013-2018  Urs Fleisch
  *
  * This file is part of Kid3.
  *
@@ -27,6 +27,7 @@
 #include "batchimportconfig.h"
 #include <QString>
 #include "batchimportprofile.h"
+#include "isettings.h"
 #include "config.h"
 
 int BatchImportConfig::s_index = -1;
@@ -34,9 +35,9 @@ int BatchImportConfig::s_index = -1;
 /**
  * Constructor.
  */
-BatchImportConfig::BatchImportConfig() :
-  StoredConfig<BatchImportConfig>(QLatin1String("BatchImport")),
-  m_importDest(Frame::TagV2), m_profileIdx(0)
+BatchImportConfig::BatchImportConfig()
+  : StoredConfig<BatchImportConfig>(QLatin1String("BatchImport")),
+    m_importDest(Frame::TagV2), m_profileIdx(0)
 {
   /**
    * Preset profile expressions.
@@ -48,20 +49,14 @@ BatchImportConfig::BatchImportConfig() :
     QLatin1String("Cover Art") <<
     QLatin1String("Custom Profile");
   m_profileSources <<
-    QLatin1String("MusicBrainz Release:75:SAC;Discogs:75:SAC;Amazon:75:SAC;gnudb.org:75:S;TrackType.org:75:S") <<
+    QLatin1String("MusicBrainz Release:75:SAC;Discogs:75:SAC;Amazon:75:SAC;"
+                  "gnudb.org:75:S;TrackType.org:75:S") <<
     QLatin1String("MusicBrainz Release:75:SAC") <<
     QLatin1String("Discogs:75:SAC") <<
     QLatin1String("Amazon:75:C;Discogs:75:C;MusicBrainz Release:75:C") <<
     QLatin1String("");
 }
 
-/**
- * Destructor.
- */
-BatchImportConfig::~BatchImportConfig()
-{
-}
-
 /**
  * Persist configuration.
  *
@@ -104,9 +99,8 @@ void BatchImportConfig::readFromConfig(ISettings* config)
   while (sources.size() < numNames)
     sources.append(QLatin1String(""));
   /* Use defaults if no configuration found */
-  QStringList::const_iterator namesIt, sourcesIt;
-  for (namesIt = names.begin(), sourcesIt = sources.begin();
-       namesIt != names.end() && sourcesIt != sources.end();
+  for (auto namesIt = names.constBegin(), sourcesIt = sources.constBegin();
+       namesIt != names.constEnd() && sourcesIt != sources.constEnd();
        ++namesIt, ++sourcesIt) {
     int idx = m_profileNames.indexOf(*namesIt);
     if (idx >= 0) {
@@ -131,7 +125,7 @@ void BatchImportConfig::readFromConfig(ISettings* config)
 bool BatchImportConfig::getProfileByName(const QString& name,
                                          BatchImportProfile& profile) const
 {
-  for (QStringList::const_iterator namesIt = m_profileNames.constBegin(),
+  for (auto namesIt = m_profileNames.constBegin(),
        sourcesIt = m_profileSources.constBegin();
        namesIt != m_profileNames.constEnd() &&
        sourcesIt != m_profileSources.constEnd();
