@@ -6,7 +6,7 @@
  * \author Urs Fleisch
  * \date 09 Jul 2011
  *
- * Copyright (C) 2011-2013  Urs Fleisch
+ * Copyright (C) 2011-2018  Urs Fleisch
  *
  * This file is part of Kid3.
  *
@@ -26,6 +26,9 @@
 
 #include "configstore.h"
 #include "generalconfig.h"
+#include "isettings.h"
+
+namespace {
 
 /**
  * Current configuration file version.
@@ -33,14 +36,17 @@
  * 1: 3.1
  * 2: 3.2
  * 3: 3.3
+ * 4: 3.7
  */
-static const int CONFIG_VERSION = 3;
+const int CONFIG_VERSION = 4;
+
+}
 
 /** Version of configuration file read, -1 if not read yet. */
 int ConfigStore::s_configVersion = -1;
 
 
-ConfigStore* ConfigStore::s_self = 0;
+ConfigStore* ConfigStore::s_self = nullptr;
 
 /**
  * Constructor.
@@ -65,7 +71,8 @@ ConfigStore::~ConfigStore()
  */
 void ConfigStore::writeToConfig()
 {
-  foreach (GeneralConfig* cfg, m_configurations) {
+  const auto cfgs = m_configurations;
+  for (const GeneralConfig* cfg : cfgs) {
     cfg->writeToConfig(m_config);
   }
   m_config->beginGroup(QLatin1String("ConfigStore"));
