@@ -6,7 +6,7 @@
  * \author Urs Fleisch
  * \date 09 Jul 2011
  *
- * Copyright (C) 2011  Urs Fleisch
+ * Copyright (C) 2011-2018  Urs Fleisch
  *
  * This file is part of Kid3.
  *
@@ -24,8 +24,7 @@
  * along with this program.  If not, see <http://www.gnu.org/licenses/>.
  */
 
-#ifndef CONFIGSTORE_H
-#define CONFIGSTORE_H
+#pragma once
 
 #include <QObject>
 #include <QList>
@@ -48,7 +47,7 @@ public:
   /**
    * Destructor.
    */
-  ~ConfigStore();
+  virtual ~ConfigStore() override;
 
   /**
    * Persist all added configurations.
@@ -91,5 +90,3 @@ private:
   static ConfigStore* s_self;
   static int s_configVersion;
 };
-
-#endif // CONFIGSTORE_H
