@@ -6,7 +6,7 @@
  * \author Urs Fleisch
  * \date 29 Jun 2013
  *
- * Copyright (C) 2013-2017  Urs Fleisch
+ * Copyright (C) 2013-2018  Urs Fleisch
  *
  * This file is part of Kid3.
  *
@@ -26,27 +26,30 @@
 
 #include "fileconfig.h"
 #include <QCoreApplication>
+#include "isettings.h"
 
 int FileConfig::s_index = -1;
 
+namespace {
+
 /** Default to filename format list */
-static const char* defaultToFilenameFormats[] = {
+const char* defaultToFilenameFormats[] = {
   "%{track} %{title}",
   "%{track}. %{title}",
   "%{track} - %{artist} - %{title}",
   "%{track}. %{artist} - %{title}",
   "%{artist} - %{track} - %{title}",
   "%{artist} - %{album} - %{track} - %{title}",
-  "%{artist} - [%{year}] %{album} - %{track} - %{title}",
+ R"(%{artist} - %{"["year"] "}%{album} - %{track} - %{title})",
   "%{artist} - %{title}",
   "%{artist}-%{title}",
   "(%{artist}) %{title}",
   "%{artist}-%{title}-%{album}",
-  0
+  nullptr
 };
 
 /** Default from filename format list */
-static const char* defaultFromFilenameFormats[] = {
+const char* defaultFromFilenameFormats[] = {
   "%{artist} - %{album}/%{track} %{title}",
   "%{artist} - %{album}/%{track}. %{title}",
   "%{artist} - [%{year}] %{album}/%{track} %{title}",
@@ -68,33 +71,29 @@ static const char* defaultFromFilenameFormats[] = {
   "%{album}/%{artist}-%{title}",
   "%{album}/(%{artist}) %{title}",
   "%{artist}-%{title}-%{album}",
-  0
+  nullptr
 };
 
+}
+
 /**
  * Constructor.
  */
-FileConfig::FileConfig() :
-  StoredConfig<FileConfig>(QLatin1String("Files")),
-  m_nameFilter(QLatin1String("")),
-  m_formatText(QString::fromLatin1(defaultToFilenameFormats[0])),
-  m_formatItem(0),
-  m_formatFromFilenameText(QString::fromLatin1(defaultFromFilenameFormats[0])),
-  m_formatFromFilenameItem(0),
-  m_defaultCoverFileName(QLatin1String("folder.jpg")),
-  m_textEncoding(QLatin1String("System")),
-  m_preserveTime(false),
-  m_markChanges(true),
-  m_loadLastOpenedFile(true),
-  m_showHiddenFiles(false)
+FileConfig::FileConfig()
+  : StoredConfig<FileConfig>(QLatin1String("Files")),
+    m_nameFilter(QLatin1String("")),
+    m_formatText(QString::fromLatin1(defaultToFilenameFormats[0])),
+    m_formatFromFilenameText(QString::fromLatin1(defaultFromFilenameFormats[0])),
+    m_defaultCoverFileName(QLatin1String("folder.jpg")),
+    m_textEncoding(QLatin1String("System")),
+    m_preserveTime(false),
+    m_markChanges(true),
+    m_loadLastOpenedFile(true),
+    m_showHiddenFiles(false)
 {
+  initFormatListsIfEmpty();
 }
 
-/**
- * Destructor.
- */
-FileConfig::~FileConfig() {}
-
 /**
  * Persist configuration.
  *
@@ -107,10 +106,8 @@ void FileConfig::writeToConfig(ISettings* config) const
   config->setValue(QLatin1String("IncludeFolders"), QVariant(m_includeFolders));
   config->setValue(QLatin1String("ExcludeFolders"), QVariant(m_excludeFolders));
   config->setValue(QLatin1String("ShowHiddenFiles"), QVariant(m_showHiddenFiles));
-  config->setValue(QLatin1String("FormatItem"), QVariant(m_formatItem));
   config->setValue(QLatin1String("FormatItems"), QVariant(m_formatItems));
   config->setValue(QLatin1String("FormatText"), QVariant(m_formatText));
-  config->setValue(QLatin1String("FormatFromFilenameItem"), QVariant(m_formatFromFilenameItem));
   config->setValue(QLatin1String("FormatFromFilenameItems"), QVariant(m_formatFromFilenameItems));
   config->setValue(QLatin1String("FormatFromFilenameText"), QVariant(m_formatFromFilenameText));
   config->setValue(QLatin1String("PreserveTime"), QVariant(m_preserveTime));
@@ -133,44 +130,42 @@ void FileConfig::readFromConfig(ISettings* config)
   m_nameFilter =
       config->value(QLatin1String("NameFilter"), QLatin1String("")).toString();
   m_includeFolders =
-      config->value(QLatin1String("IncludeFolders"), m_includeFolders).toStringList();
+      config->value(QLatin1String("IncludeFolders"),
+                    m_includeFolders).toStringList();
   m_excludeFolders =
-      config->value(QLatin1String("ExcludeFolders"), m_excludeFolders).toStringList();
-  m_showHiddenFiles = config->value(QLatin1String("ShowHiddenFiles"), m_showHiddenFiles).toBool();
-  m_formatItem =
-      config->value(QLatin1String("FormatItem"), 0).toInt();
+      config->value(QLatin1String("ExcludeFolders"),
+                    m_excludeFolders).toStringList();
+  m_showHiddenFiles = config->value(QLatin1String("ShowHiddenFiles"),
+                                    m_showHiddenFiles).toBool();
   m_formatItems =
       config->value(QLatin1String("FormatItems"),
                     m_formatItems).toStringList();
-  m_formatFromFilenameItem =
-      config->value(QLatin1String("FormatFromFilenameItem"), 0).toInt();
   m_formatFromFilenameItems =
       config->value(QLatin1String("FormatFromFilenameItems"),
                     m_formatFromFilenameItems).toStringList();
-  m_preserveTime = config->value(QLatin1String("PreserveTime"), m_preserveTime).toBool();
-  m_markChanges = config->value(QLatin1String("MarkChanges"), m_markChanges).toBool();
+  m_preserveTime = config->value(QLatin1String("PreserveTime"),
+                                 m_preserveTime).toBool();
+  m_markChanges = config->value(QLatin1String("MarkChanges"),
+                                m_markChanges).toBool();
 
   m_formatText =
-      config->value(QLatin1String("FormatText"), QString::fromLatin1(defaultToFilenameFormats[0])).toString();
+      config->value(QLatin1String("FormatText"),
+                    QString::fromLatin1(defaultToFilenameFormats[0])).toString();
   m_formatFromFilenameText =
-      config->value(QLatin1String("FormatFromFilenameText"), QString::fromLatin1(defaultFromFilenameFormats[0])).toString();
-  m_loadLastOpenedFile = config->value(QLatin1String("LoadLastOpenedFile"), m_loadLastOpenedFile).toBool();
-  m_textEncoding = config->value(QLatin1String("TextEncoding"), QLatin1String("System")).toString();
-  m_lastOpenedFile = config->value(QLatin1String("LastOpenedFile"), m_lastOpenedFile).toString();
-  m_defaultCoverFileName = config->value(QLatin1String("DefaultCoverFileName"), m_defaultCoverFileName).toString();
+      config->value(QLatin1String("FormatFromFilenameText"),
+                    QString::fromLatin1(defaultFromFilenameFormats[0])).toString();
+  m_loadLastOpenedFile = config->value(QLatin1String("LoadLastOpenedFile"),
+                                       m_loadLastOpenedFile).toBool();
+  m_textEncoding = config->value(QLatin1String("TextEncoding"),
+                                 QLatin1String("System")).toString();
+  m_lastOpenedFile = config->value(QLatin1String("LastOpenedFile"),
+                                   m_lastOpenedFile).toString();
+  m_defaultCoverFileName = config->value(QLatin1String("DefaultCoverFileName"),
+                                         m_defaultCoverFileName).toString();
   config->endGroup();
 
-  if (m_formatItems.isEmpty()) {
-    for (const char** sl = defaultToFilenameFormats; *sl != 0; ++sl) {
-      m_formatItems += QString::fromLatin1(*sl);
-    }
-  }
-  if (m_formatFromFilenameItems.isEmpty()) {
-    for (const char** sl = defaultFromFilenameFormats; *sl != 0; ++sl) {
-      m_formatFromFilenameItems += QString::fromLatin1(*sl);
-    }
-  }
-  if (ConfigStore::getConfigVersion() < 2) {
+  initFormatListsIfEmpty();
+  if (ConfigStore::getConfigVersion() < 4) {
     // Reset file name filter if it is set to "All Supported Files" in order
     // to introduce newly supported file formats (e.g. *.dsf) when the
     // configuration version is increased.
@@ -181,6 +176,20 @@ void FileConfig::readFromConfig(ISettings* config)
   }
 }
 
+void FileConfig::initFormatListsIfEmpty()
+{
+  if (m_formatItems.size() <= 1) {
+    for (const char** sl = defaultToFilenameFormats; *sl != nullptr; ++sl) {
+      m_formatItems += QString::fromLatin1(*sl);
+    }
+  }
+  if (m_formatFromFilenameItems.size() <= 1) {
+    for (const char** sl = defaultFromFilenameFormats; *sl != nullptr; ++sl) {
+      m_formatFromFilenameItems += QString::fromLatin1(*sl);
+    }
+  }
+}
+
 void FileConfig::setNameFilter(const QString& nameFilter)
 {
   if (m_nameFilter != nameFilter) {
@@ -221,18 +230,11 @@ void FileConfig::setToFilenameFormat(const QString& formatText)
   }
 }
 
-void FileConfig::setToFilenameFormatIndex(int formatItem)
-{
-  if (m_formatItem != formatItem) {
-    m_formatItem = formatItem;
-    emit toFilenameFormatIndexChanged(m_formatItem);
-  }
-}
-
 void FileConfig::setToFilenameFormats(const QStringList& formatItems)
 {
   if (m_formatItems != formatItems) {
     m_formatItems = formatItems;
+    m_formatItems.removeDuplicates();
     emit toFilenameFormatsChanged(m_formatItems);
   }
 }
@@ -245,18 +247,11 @@ void FileConfig::setFromFilenameFormat(const QString& formatFromFilenameText)
   }
 }
 
-void FileConfig::setFromFilenameFormatIndex(int formatFromFilenameItem)
-{
-  if (m_formatFromFilenameItem != formatFromFilenameItem) {
-    m_formatFromFilenameItem = formatFromFilenameItem;
-    emit fromFilenameFormatIndexChanged(m_formatFromFilenameItem);
-  }
-}
-
 void FileConfig::setFromFilenameFormats(const QStringList& formatFromFilenameItems)
 {
   if (m_formatFromFilenameItems != formatFromFilenameItems) {
     m_formatFromFilenameItems = formatFromFilenameItems;
+    m_formatFromFilenameItems.removeDuplicates();
     emit fromFilenameFormatsChanged(m_formatFromFilenameItems);
   }
 }
