@@ -6,7 +6,7 @@
  * \author Urs Fleisch
  * \date 29 Jun 2013
  *
- * Copyright (C) 2013-2017  Urs Fleisch
+ * Copyright (C) 2013-2018  Urs Fleisch
  *
  * This file is part of Kid3.
  *
@@ -24,8 +24,7 @@
  * along with this program.  If not, see <http://www.gnu.org/licenses/>.
  */
 
-#ifndef FILECONFIG_H
-#define FILECONFIG_H
+#pragma once
 
 #include <QStringList>
 #include "generalconfig.h"
@@ -37,39 +36,50 @@
 class KID3_CORE_EXPORT FileConfig : public StoredConfig<FileConfig> {
   Q_OBJECT
   /** filter of file names to be opened */
-  Q_PROPERTY(QString nameFilter READ nameFilter WRITE setNameFilter NOTIFY nameFilterChanged)
+  Q_PROPERTY(QString nameFilter READ nameFilter WRITE setNameFilter
+             NOTIFY nameFilterChanged)
   /** patterns for folders to include in file list */
-  Q_PROPERTY(QStringList includeFolders READ includeFolders WRITE setIncludeFolders NOTIFY includeFoldersChanged)
+  Q_PROPERTY(QStringList includeFolders READ includeFolders
+             WRITE setIncludeFolders NOTIFY includeFoldersChanged)
   /** patterns for folders to exclude in file list */
-  Q_PROPERTY(QStringList excludeFolders READ excludeFolders WRITE setExcludeFolders NOTIFY excludeFoldersChanged)
+  Q_PROPERTY(QStringList excludeFolders READ excludeFolders
+             WRITE setExcludeFolders NOTIFY excludeFoldersChanged)
   /** true to show hidden files */
-  Q_PROPERTY(bool showHiddenFiles READ showHiddenFiles WRITE setShowHiddenFiles NOTIFY showHiddenFilesChanged)
+  Q_PROPERTY(bool showHiddenFiles READ showHiddenFiles WRITE setShowHiddenFiles
+             NOTIFY showHiddenFilesChanged)
   /** filename format */
-  Q_PROPERTY(QString toFilenameFormat READ toFilenameFormat WRITE setToFilenameFormat NOTIFY toFilenameFormatChanged)
-  /** index of filename format selected */
-  Q_PROPERTY(int toFilenameFormatIndex READ toFilenameFormatIndex WRITE setToFilenameFormatIndex NOTIFY toFilenameFormatIndexChanged)
+  Q_PROPERTY(QString toFilenameFormat READ toFilenameFormat
+             WRITE setToFilenameFormat NOTIFY toFilenameFormatChanged)
   /** filename formats */
-  Q_PROPERTY(QStringList toFilenameFormats READ toFilenameFormats WRITE setToFilenameFormats NOTIFY toFilenameFormatsChanged)
+  Q_PROPERTY(QStringList toFilenameFormats READ toFilenameFormats
+             WRITE setToFilenameFormats NOTIFY toFilenameFormatsChanged)
   /** from filename format */
-  Q_PROPERTY(QString fromFilenameFormat READ fromFilenameFormat WRITE setFromFilenameFormat NOTIFY fromFilenameFormatChanged)
-  /** index of from filename format selected */
-  Q_PROPERTY(int fromFilenameFormatIndex READ fromFilenameFormatIndex WRITE setFromFilenameFormatIndex NOTIFY fromFilenameFormatIndexChanged)
+  Q_PROPERTY(QString fromFilenameFormat READ fromFilenameFormat
+             WRITE setFromFilenameFormat NOTIFY fromFilenameFormatChanged)
   /** from filename formats */
-  Q_PROPERTY(QStringList fromFilenameFormats READ fromFilenameFormats WRITE setFromFilenameFormats NOTIFY fromFilenameFormatsChanged)
+  Q_PROPERTY(QStringList fromFilenameFormats READ fromFilenameFormats
+             WRITE setFromFilenameFormats NOTIFY fromFilenameFormatsChanged)
   /** default file name to save cover art */
-  Q_PROPERTY(QString defaultCoverFileName READ defaultCoverFileName WRITE setDefaultCoverFileName NOTIFY defaultCoverFileNameChanged)
+  Q_PROPERTY(QString defaultCoverFileName READ defaultCoverFileName
+             WRITE setDefaultCoverFileName NOTIFY defaultCoverFileNameChanged)
   /** path to last opened file */
-  Q_PROPERTY(QString lastOpenedFile READ lastOpenedFile WRITE setLastOpenedFile NOTIFY lastOpenedFileChanged)
+  Q_PROPERTY(QString lastOpenedFile READ lastOpenedFile WRITE setLastOpenedFile
+             NOTIFY lastOpenedFileChanged)
   /** text encoding used for exports and playlists */
-  Q_PROPERTY(QString textEncoding READ textEncoding WRITE setTextEncoding NOTIFY textEncodingChanged)
+  Q_PROPERTY(QString textEncoding READ textEncoding WRITE setTextEncoding
+             NOTIFY textEncodingChanged)
   /** text encoding used for exports and playlists */
-  Q_PROPERTY(int textEncodingIndex READ textEncodingIndex WRITE setTextEncodingIndex NOTIFY textEncodingChanged)
+  Q_PROPERTY(int textEncodingIndex READ textEncodingIndex
+             WRITE setTextEncodingIndex NOTIFY textEncodingChanged)
   /** true to preserve file time stamps */
-  Q_PROPERTY(bool preserveTime READ preserveTime WRITE setPreserveTime NOTIFY preserveTimeChanged)
+  Q_PROPERTY(bool preserveTime READ preserveTime WRITE setPreserveTime
+             NOTIFY preserveTimeChanged)
   /** true to mark changed fields */
-  Q_PROPERTY(bool markChanges READ markChanges WRITE setMarkChanges NOTIFY markChangesChanged)
+  Q_PROPERTY(bool markChanges READ markChanges WRITE setMarkChanges
+             NOTIFY markChangesChanged)
   /** true to open last opened file on startup */
-  Q_PROPERTY(bool loadLastOpenedFile READ loadLastOpenedFile WRITE setLoadLastOpenedFile NOTIFY loadLastOpenedFileChanged)
+  Q_PROPERTY(bool loadLastOpenedFile READ loadLastOpenedFile
+             WRITE setLoadLastOpenedFile NOTIFY loadLastOpenedFileChanged)
 
 public:
   /**
@@ -80,21 +90,21 @@ public:
   /**
    * Destructor.
    */
-  virtual ~FileConfig();
+  virtual ~FileConfig() override = default;
 
   /**
    * Persist configuration.
    *
    * @param config configuration
    */
-  virtual void writeToConfig(ISettings* config) const;
+  virtual void writeToConfig(ISettings* config) const override;
 
   /**
    * Read persisted configuration.
    *
    * @param config configuration
    */
-  virtual void readFromConfig(ISettings* config);
+  virtual void readFromConfig(ISettings* config) override;
 
   /** Get filter of file names to be opened. */
   QString nameFilter() const { return m_nameFilter; }
@@ -126,12 +136,6 @@ public:
   /** Set filename format. */
   void setToFilenameFormat(const QString& toFilenameFormat);
 
-  /** Get index of filename format selected. */
-  int toFilenameFormatIndex() const { return m_formatItem; }
-
-  /** Set index of filename format selected. */
-  void setToFilenameFormatIndex(int toFilenameFormatIndex);
-
   /** Get filename formats. */
   QStringList toFilenameFormats() const { return m_formatItems; }
 
@@ -144,12 +148,6 @@ public:
   /** Set from filename format. */
   void setFromFilenameFormat(const QString& fromFilenameFormat);
 
-  /** Get index of from filename format selected. */
-  int fromFilenameFormatIndex() const { return m_formatFromFilenameItem; }
-
-  /** Set index of from filename format selected. */
-  void setFromFilenameFormatIndex(int fromFilenameFormatIndex);
-
   /** Get from filename formats. */
   QStringList fromFilenameFormats() const {
     return m_formatFromFilenameItems;
@@ -216,18 +214,12 @@ signals:
   /** Emitted when @a formatText changed. */
   void toFilenameFormatChanged(const QString& toFilenameFormat);
 
-  /** Emitted when @a formatItem changed. */
-  void toFilenameFormatIndexChanged(int toFilenameFormatIndex);
-
   /** Emitted when @a formatItems changed. */
   void toFilenameFormatsChanged(const QStringList& toFilenameFormats);
 
   /** Emitted when @a formatFromFilenameText changed. */
   void fromFilenameFormatChanged(const QString& fromFilenameFormat);
 
-  /** Emitted when @a formatFromFilenameItem changed. */
-  void fromFilenameFormatIndexChanged(int fromFilenameFormatIndex);
-
   /** Emitted when @a formatFromFilenameItems changed. */
   void fromFilenameFormatsChanged(const QStringList& fromFilenameFormats);
 
@@ -252,14 +244,14 @@ signals:
 private:
   friend FileConfig& StoredConfig<FileConfig>::instance();
 
+  void initFormatListsIfEmpty();
+
   QString m_nameFilter;
   QStringList m_includeFolders;
   QStringList m_excludeFolders;
   QString m_formatText;
-  int m_formatItem;
   QStringList m_formatItems;
   QString m_formatFromFilenameText;
-  int m_formatFromFilenameItem;
   QStringList m_formatFromFilenameItems;
   QString m_defaultCoverFileName;
   QString m_lastOpenedFile;
@@ -272,5 +264,3 @@ private:
   /** Index in configuration storage */
   static int s_index;
 };
-
-#endif
