@@ -6,7 +6,7 @@
  * \author Urs Fleisch
  * \date 17 Sep 2003
  *
- * Copyright (C) 2003-2012  Urs Fleisch
+ * Copyright (C) 2003-2018  Urs Fleisch
  *
  * This file is part of Kid3.
  *
@@ -24,13 +24,12 @@
  * along with this program.  If not, see <http://www.gnu.org/licenses/>.
  */
 
-#ifndef FORMATCONFIG_H
-#define FORMATCONFIG_H
+#pragma once
 
-#include "config.h"
-#include "generalconfig.h"
-#include <QMap>
+#include <QScopedPointer>
+#include <QVariantMap>
 #include <QStringList>
+#include "generalconfig.h"
 #include "kid3api.h"
 
 class QString;
@@ -40,25 +39,32 @@ class FrameCollection;
 /**
  * Format configuration.
  */
-class KID3_CORE_EXPORT FormatConfig : public GeneralConfig
-{
+class KID3_CORE_EXPORT FormatConfig : public GeneralConfig {
   Q_OBJECT
   /** Mapping for string replacement */
-  Q_PROPERTY(QVariantMap strRepMap READ strRepVariantMap WRITE setStrRepVariantMap NOTIFY strRepMapChanged)
+  Q_PROPERTY(QVariantMap strRepMap READ strRepVariantMap
+             WRITE setStrRepVariantMap NOTIFY strRepMapChanged)
   /** Case conversion option */
-  Q_PROPERTY(int caseConversion READ caseConversion WRITE setCaseConversionInt NOTIFY caseConversionChanged)
+  Q_PROPERTY(int caseConversion READ caseConversion WRITE setCaseConversionInt
+             NOTIFY caseConversionChanged)
   /** name of locale to use for string conversions */
-  Q_PROPERTY(QString localeName READ localeName WRITE setLocaleName NOTIFY localeNameChanged)
+  Q_PROPERTY(QString localeName READ localeName WRITE setLocaleName
+             NOTIFY localeNameChanged)
   /** maximum length */
-  Q_PROPERTY(int maximumLength READ maximumLength WRITE setMaximumLength NOTIFY maximumLengthChanged)
+  Q_PROPERTY(int maximumLength READ maximumLength WRITE setMaximumLength
+             NOTIFY maximumLengthChanged)
   /** true to enable length restriction */
-  Q_PROPERTY(bool enableMaximumLength READ enableMaximumLength WRITE setEnableMaximumLength NOTIFY enableMaximumLengthChanged)
+  Q_PROPERTY(bool enableMaximumLength READ enableMaximumLength
+             WRITE setEnableMaximumLength NOTIFY enableMaximumLengthChanged)
   /** true to enable formating in line edits */
-  Q_PROPERTY(bool formatWhileEditing READ formatWhileEditing WRITE setFormatWhileEditing NOTIFY formatWhileEditingChanged)
+  Q_PROPERTY(bool formatWhileEditing READ formatWhileEditing
+             WRITE setFormatWhileEditing NOTIFY formatWhileEditingChanged)
   /** true if string replacement enabled */
-  Q_PROPERTY(bool strRepEnabled READ strRepEnabled WRITE setStrRepEnabled NOTIFY strRepEnabledChanged)
+  Q_PROPERTY(bool strRepEnabled READ strRepEnabled WRITE setStrRepEnabled
+             NOTIFY strRepEnabledChanged)
   /** true to enable data validation */
-  Q_PROPERTY(bool enableValidation READ enableValidation WRITE setEnableValidation NOTIFY enableValidationChanged)
+  Q_PROPERTY(bool enableValidation READ enableValidation
+             WRITE setEnableValidation NOTIFY enableValidationChanged)
   Q_ENUMS(CaseConversion)
 public:
   /** Case conversion options. */
@@ -81,7 +87,7 @@ public:
   /**
    * Destructor.
    */
-  virtual ~FormatConfig();
+  virtual ~FormatConfig() override;
 
   /**
    * Set specific properties for a filename format.
@@ -128,14 +134,14 @@ public:
    *
    * @param config KDE configuration
    */
-  virtual void writeToConfig(ISettings* config) const;
+  virtual void writeToConfig(ISettings* config) const override;
 
   /**
    * Read persisted configuration.
    *
    * @param config KDE configuration
    */
-  virtual void readFromConfig(ISettings* config);
+  virtual void readFromConfig(ISettings* config) override;
 
   /** Get mapping for string replacement. */
   QMap<QString, QString> strRepMap() const { return m_strRepMap; }
@@ -212,7 +218,7 @@ signals:
   void strRepMapChanged(const QMap<QString, QString>& strRepMap);
 
   /** Emitted when @a caseConversion changed. */
-  void caseConversionChanged(CaseConversion caseConversion);
+  void caseConversionChanged(FormatConfig::CaseConversion caseConversion);
 
   /** Emitted when @a localeName changed. */
   void localeNameChanged(const QString& localeName);
@@ -247,7 +253,7 @@ private:
   CaseConversion m_caseConversion;
   QString m_localeName;
   /** Locale to use for string conversions */
-  const QLocale* m_locale;
+  QScopedPointer<const QLocale> m_locale;
   int m_maximumLength;
   bool m_enableMaximumLength;
   /** true if it is a file formatter */
@@ -261,8 +267,8 @@ private:
 /**
  * FormatConfig subclass for stored filename format configuration instance.
  */
-class KID3_CORE_EXPORT FilenameFormatConfig :
-    public StoredConfig<FilenameFormatConfig, FormatConfig> {
+class KID3_CORE_EXPORT FilenameFormatConfig
+    : public StoredConfig<FilenameFormatConfig, FormatConfig> {
   Q_OBJECT
 public:
   /**
@@ -273,7 +279,7 @@ public:
   /**
    * Destructor.
    */
-  virtual ~FilenameFormatConfig();
+  virtual ~FilenameFormatConfig() override = default;
 
 private:
   friend FilenameFormatConfig&
@@ -287,8 +293,8 @@ private:
 /**
  * FormatConfig subclass for stored tag format configuration instance.
  */
-class KID3_CORE_EXPORT TagFormatConfig :
-    public StoredConfig<TagFormatConfig, FormatConfig> {
+class KID3_CORE_EXPORT TagFormatConfig
+    : public StoredConfig<TagFormatConfig, FormatConfig> {
   Q_OBJECT
 public:
   /**
@@ -299,7 +305,7 @@ public:
   /**
    * Destructor.
    */
-  virtual ~TagFormatConfig();
+  virtual ~TagFormatConfig() override = default;
 
 private:
   friend TagFormatConfig&
@@ -308,5 +314,3 @@ private:
   /** Index in configuration storage */
   static int s_index;
 };
-
-#endif
