@@ -6,7 +6,7 @@
  * \author Urs Fleisch
  * \date 09 Oct 2006
  *
- * Copyright (C) 2006-2013  Urs Fleisch
+ * Copyright (C) 2006-2018  Urs Fleisch
  *
  * This file is part of Kid3.
  *
@@ -26,6 +26,7 @@
 
 #include "serverimporterconfig.h"
 #include <QtGlobal>
+#include "isettings.h"
 
 /**
  * Constructor.
@@ -33,10 +34,10 @@
  *
  * @param grp         configuration group
  */
-ServerImporterConfig::ServerImporterConfig(const QString& grp) :
-  GeneralConfig(grp),
-  m_cgiPathUsed(true), m_additionalTagsUsed(false),
-  m_standardTags(true), m_additionalTags(true), m_coverArt(true)
+ServerImporterConfig::ServerImporterConfig(const QString& grp)
+  : GeneralConfig(grp),
+    m_cgiPathUsed(true), m_additionalTagsUsed(false),
+    m_standardTags(true), m_additionalTags(true), m_coverArt(true)
 {
 }
 
@@ -44,16 +45,11 @@ ServerImporterConfig::ServerImporterConfig(const QString& grp) :
  * Constructor.
  * Used to create temporary configuration.
  */
-ServerImporterConfig::ServerImporterConfig() :
-  GeneralConfig(QLatin1String("Temporary")),
-  m_cgiPathUsed(false),
-  m_additionalTagsUsed(false), m_standardTags(false), m_additionalTags(false),
-  m_coverArt(false) {}
-
-/**
- * Destructor.
- */
-ServerImporterConfig::~ServerImporterConfig() {}
+ServerImporterConfig::ServerImporterConfig()
+  : GeneralConfig(QLatin1String("Temporary")),
+    m_cgiPathUsed(false),
+    m_additionalTagsUsed(false), m_standardTags(false), m_additionalTags(false),
+    m_coverArt(false) {}
 
 /**
  * Persist configuration.
@@ -97,3 +93,67 @@ void ServerImporterConfig::readFromConfig(ISettings* config)
                                    m_windowGeometry).toByteArray();
   config->endGroup();
 }
+
+void ServerImporterConfig::setServer(const QString& server)
+{
+  if (m_server != server) {
+    m_server = server;
+    emit serverChanged(m_server);
+  }
+}
+
+void ServerImporterConfig::setCgiPath(const QString& cgiPath)
+{
+  if (m_cgiPath != cgiPath) {
+    m_cgiPath = cgiPath;
+    emit cgiPathChanged(m_cgiPath);
+  }
+}
+
+void ServerImporterConfig::setWindowGeometry(const QByteArray& windowGeometry)
+{
+  if (m_windowGeometry != windowGeometry) {
+    m_windowGeometry = windowGeometry;
+    emit windowGeometryChanged(m_windowGeometry);
+  }
+}
+
+void ServerImporterConfig::setCgiPathUsed(bool cgiPathUsed)
+{
+  if (m_cgiPathUsed != cgiPathUsed) {
+    m_cgiPathUsed = cgiPathUsed;
+    emit cgiPathUsedChanged(m_cgiPathUsed);
+  }
+}
+
+void ServerImporterConfig::setAdditionalTagsUsed(bool additionalTagsUsed)
+{
+  if (m_additionalTagsUsed != additionalTagsUsed) {
+    m_additionalTagsUsed = additionalTagsUsed;
+    emit additionalTagsUsedChanged(m_additionalTagsUsed);
+  }
+}
+
+void ServerImporterConfig::setStandardTags(bool standardTags)
+{
+  if (m_standardTags != standardTags) {
+    m_standardTags = standardTags;
+    emit standardTagsChanged(m_standardTags);
+  }
+}
+
+void ServerImporterConfig::setAdditionalTags(bool additionalTags)
+{
+  if (m_additionalTags != additionalTags) {
+    m_additionalTags = additionalTags;
+    emit additionalTagsChanged(m_additionalTags);
+  }
+}
+
+void ServerImporterConfig::setCoverArt(bool coverArt)
+{
+  if (m_coverArt != coverArt) {
+    m_coverArt = coverArt;
+    emit coverArtChanged(m_coverArt);
+  }
+}
