@@ -6,7 +6,7 @@
  * \author Urs Fleisch
  * \date 22 Jul 2011
  *
- * Copyright (C) 2011  Urs Fleisch
+ * Copyright (C) 2011-2018  Urs Fleisch
  *
  * This file is part of Kid3.
  *
@@ -24,8 +24,7 @@
  * along with this program.  If not, see <http://www.gnu.org/licenses/>.
  */
 
-#ifndef TEXTEXPORTER_H
-#define TEXTEXPORTER_H
+#pragma once
 
 #include <QObject>
 #include "trackdata.h"
@@ -40,12 +39,12 @@ public:
    * Constructor.
    * @param parent parent object
    */
-  explicit TextExporter(QObject* parent = 0);
+  explicit TextExporter(QObject* parent = nullptr);
 
   /**
    * Destructor.
    */
-  virtual ~TextExporter();
+  virtual ~TextExporter() override;
 
   /**
    * Set data to be exported.
@@ -60,7 +59,7 @@ public:
    * Reread the tags in the track data.
    * @param tagVersion tag version
    */
-  void readTagsInTrackData(TrackData::TagVersion tagVersion) {
+  void readTagsInTrackData(Frame::TagVersion tagVersion) {
     m_trackDataVector.readTags(tagVersion);
   }
 
@@ -105,5 +104,3 @@ private:
   ImportTrackDataVector m_trackDataVector;
   QString m_text;
 };
-
-#endif // TEXTEXPORTER_H
