@@ -6,7 +6,7 @@
  * \author Urs Fleisch
  * \date 3 Jan 2013
  *
- * Copyright (C) 2013  Urs Fleisch
+ * Copyright (C) 2013-2018  Urs Fleisch
  *
  * This file is part of Kid3.
  *
@@ -24,8 +24,7 @@
  * along with this program.  If not, see <http://www.gnu.org/licenses/>.
  */
 
-#ifndef BATCHIMPORTER_H
-#define BATCHIMPORTER_H
+#pragma once
 
 #include <QObject>
 #include "trackdata.h"
@@ -70,26 +69,26 @@ public:
   /**
    * Destructor.
    */
-  virtual ~BatchImporter();
+  virtual ~BatchImporter() override = default;
 
   /**
    * Check if operation is aborted.
    *
    * @return true if aborted.
    */
-  virtual bool isAborted() const;
+  virtual bool isAborted() const override;
 
   /**
    * Clear state which is reported by isAborted().
    */
-  virtual void clearAborted();
+  virtual void clearAborted() override;
 
   /**
    * Set importers.
    * @param importers available importers
    * @param trackDataModel track data model used by importers
    */
-  void setImporters(QList<ServerImporter*> importers,
+  void setImporters(const QList<ServerImporter*>& importers,
                     TrackDataModel* trackDataModel);
 
   /**
@@ -135,7 +134,7 @@ public slots:
   /**
    * Abort batch import.
    */
-  virtual void abort();
+  virtual void abort() override;
 
 private slots:
   void onFindFinished(const QByteArray& searchStr);
@@ -180,5 +179,3 @@ private:
   QString m_currentAlbum;
   FrameFilter m_frameFilter;
 };
-
-#endif // BATCHIMPORTER_H
