@@ -6,7 +6,7 @@
  * \author Urs Fleisch
  * \date 30 Dec 2008
  *
- * Copyright (C) 2008-2017  Urs Fleisch
+ * Copyright (C) 2008-2018  Urs Fleisch
  *
  * This file is part of Kid3.
  *
@@ -24,27 +24,25 @@
  * along with this program.  If not, see <http://www.gnu.org/licenses/>.
  */
 
-#ifndef HTTPCLIENT_H
-#define HTTPCLIENT_H
+#pragma once
 
 #include <QObject>
-#include <QString>
+//#include <QString>
 #include <QNetworkReply>
 #include <QPointer>
 #include <QMap>
-#include <QDateTime>
-#include <QTimer>
 #include "kid3api.h"
 
 class QByteArray;
 class QNetworkAccessManager;
+class QDateTime;
+class QTimer;
 
 /**
  * Client to connect to HTTP server.
  */
 class KID3_CORE_EXPORT HttpClient : public QObject {
-Q_OBJECT
-
+  Q_OBJECT
 public:
   /** Name-value map for raw HTTP headers. */
   typedef QMap<QByteArray, QByteArray> RawHeaderMap;
@@ -59,7 +57,7 @@ public:
   /**
    * Destructor.
    */
-  virtual ~HttpClient();
+  virtual ~HttpClient() override;
 
   /**
    * Send a HTTP GET request.
@@ -203,5 +201,3 @@ private:
   /** Minimum interval between two requests to server in ms */
   static QMap<QString, int> s_minimumRequestInterval;
 };
-
-#endif
