@@ -6,7 +6,7 @@
  * \author Urs Fleisch
  * \date 13 Jul 2013
  *
- * Copyright (C) 2013  Urs Fleisch
+ * Copyright (C) 2013-2018  Urs Fleisch
  *
  * This file is part of Kid3.
  *
@@ -24,8 +24,7 @@
  * along with this program.  If not, see <http://www.gnu.org/licenses/>.
  */
 
-#ifndef ISERVERIMPORTERFACTORY_H
-#define ISERVERIMPORTERFACTORY_H
+#pragma once
 
 #include <QtPlugin>
 #include "kid3api.h"
@@ -67,5 +66,3 @@ public:
 
 Q_DECLARE_INTERFACE(IServerImporterFactory,
                     "net.sourceforge.kid3.IServerImporterFactory")
-
-#endif // ISERVERIMPORTERFACTORY_H
