@@ -6,7 +6,7 @@
  * \author Urs Fleisch
  * \date 09 Oct 2006
  *
- * Copyright (C) 2006-2013  Urs Fleisch
+ * Copyright (C) 2006-2018  Urs Fleisch
  *
  * This file is part of Kid3.
  *
@@ -46,27 +46,20 @@ ServerImporter::ServerImporter(QNetworkAccessManager* netMgr,
   setObjectName(QLatin1String("ServerImporter"));
 }
 
-/**
- * Destructor.
- */
-ServerImporter::~ServerImporter()
-{
-}
-
 /** NULL-terminated array of server strings, 0 if not used */
-const char** ServerImporter::serverList() const { return 0; }
+const char** ServerImporter::serverList() const { return nullptr; }
 
 /** default server, 0 to disable */
-const char* ServerImporter::defaultServer() const { return 0; }
+const char* ServerImporter::defaultServer() const { return nullptr; }
 
 /** default CGI path, 0 to disable */
-const char* ServerImporter::defaultCgiPath() const { return 0; }
+const char* ServerImporter::defaultCgiPath() const { return nullptr; }
 
 /** anchor to online help, 0 to disable */
-const char* ServerImporter::helpAnchor() const { return 0; }
+const char* ServerImporter::helpAnchor() const { return nullptr; }
 
 /** configuration, 0 if not used */
-ServerImporterConfig* ServerImporter::config() const { return 0; }
+ServerImporterConfig* ServerImporter::config() const { return nullptr; }
 
 /** additional tags option, false if not used */
 bool ServerImporter::additionalTags() const { return false; }
@@ -101,7 +94,7 @@ QString ServerImporter::replaceHtmlEntities(QString str)
   while ((pos = numEntityRe.indexIn(str, pos)) != -1) {
     str.replace(pos, numEntityRe.matchedLength(),
                 QChar(numEntityRe.cap(1).toInt()));
-    pos += numEntityRe.matchedLength();
+    ++pos;
   }
   return str;
 }
@@ -127,20 +120,13 @@ QString ServerImporter::removeHtml(QString str)
  * @param idStr   ID
  */
 AlbumListItem::AlbumListItem(const QString& text,
-        const QString& cat, const QString& idStr) :
-  QStandardItem(text)
+        const QString& cat, const QString& idStr)
+  : QStandardItem(text)
 {
   setData(cat, Qt::UserRole + 1);
   setData(idStr, Qt::UserRole + 2);
 }
 
-/**
- * Destructor.
- */
-AlbumListItem::~AlbumListItem()
-{
-}
-
 /**
  * Get type of item.
  * Used to distinguish items of this custom type from base class items.
