@@ -6,7 +6,7 @@
  * \author Urs Fleisch
  * \date 09 Oct 2006
  *
- * Copyright (C) 2006-2011  Urs Fleisch
+ * Copyright (C) 2006-2018  Urs Fleisch
  *
  * This file is part of Kid3.
  *
@@ -24,12 +24,11 @@
  * along with this program.  If not, see <http://www.gnu.org/licenses/>.
  */
 
-#ifndef SERVERIMPORTER_H
-#define SERVERIMPORTER_H
+#pragma once
 
-#include "importclient.h"
 #include <QString>
 #include <QStandardItem>
+#include "importclient.h"
 
 class QStandardItemModel;
 class ServerImporterConfig;
@@ -39,8 +38,7 @@ class TrackDataModel;
 /**
  * Generic baseclass to import from an external source.
  */
-class KID3_CORE_EXPORT ServerImporter : public ImportClient
-{
+class KID3_CORE_EXPORT ServerImporter : public ImportClient {
   Q_OBJECT
 
 public:
@@ -56,7 +54,7 @@ public:
   /**
    * Destructor.
    */
-  virtual ~ServerImporter();
+  virtual ~ServerImporter() override = default;
 
   /**
    * Name of import source.
@@ -203,14 +201,17 @@ public:
   /**
    * Destructor.
    */
-  virtual ~AlbumListItem();
+  virtual ~AlbumListItem() override = default;
+
+  AlbumListItem(const AlbumListItem& other) = delete;
+  AlbumListItem &operator=(const AlbumListItem& other) = delete;
 
   /**
    * Get type of item.
    * Used to distinguish items of this custom type from base class items.
    * @return AlbumListItem::Type.
    */
-  virtual int type() const;
+  virtual int type() const override;
 
   /**
    * Get category.
@@ -232,5 +233,3 @@ public:
   static void dumpAlbumList(const QStandardItemModel* albumModel);
 #endif
 };
-
-#endif
