@@ -6,7 +6,7 @@
  * \author Urs Fleisch
  * \date 19 Jun 2011
  *
- * Copyright (C) 2011  Urs Fleisch
+ * Copyright (C) 2011-2018  Urs Fleisch
  *
  * This file is part of Kid3.
  *
@@ -33,10 +33,10 @@
  *
  * @param trackDataModel track data to be filled with imported values
  */
-TextImporter::TextImporter(TrackDataModel* trackDataModel) :
-  m_headerParser(new ImportParser),
-  m_trackParser(new ImportParser),
-  m_trackDataModel(trackDataModel)
+TextImporter::TextImporter(TrackDataModel* trackDataModel)
+  : m_headerParser(new ImportParser),
+    m_trackParser(new ImportParser),
+    m_trackDataModel(trackDataModel)
 {
 }
 
@@ -45,8 +45,7 @@ TextImporter::TextImporter(TrackDataModel* trackDataModel) :
  */
 TextImporter::~TextImporter()
 {
-  delete m_headerParser;
-  delete m_trackParser;
+  // Must not be inline because of forwared declared QScopedPointer.
 }
 
 /**
@@ -87,7 +86,7 @@ bool TextImporter::updateTrackData(
   FrameCollection frames(framesHdr);
   bool start = true;
   ImportTrackDataVector trackDataVector(m_trackDataModel->getTrackData());
-  ImportTrackDataVector::iterator it = trackDataVector.begin();
+  auto it = trackDataVector.begin();
   bool atTrackDataListEnd = (it == trackDataVector.end());
   while (getNextTags(frames, start)) {
     start = false;
@@ -129,8 +128,8 @@ bool TextImporter::updateTrackData(
     QList<int> trackDuration = getTrackDurations();
     if (!trackDuration.isEmpty()) {
       it = trackDataVector.begin();
-      for (QList<int>::const_iterator tdit = trackDuration.begin();
-           tdit != trackDuration.end();
+      for (auto tdit = trackDuration.constBegin();
+           tdit != trackDuration.constEnd();
            ++tdit) {
         if (it != trackDataVector.end()) {
           if (it->isEnabled()) {
@@ -200,9 +199,7 @@ void TextImporter::importFromTags(
 {
   ImportParser parser;
   parser.setFormat(extractionFormat);
-  for (ImportTrackDataVector::iterator it = trackDataVector.begin();
-       it != trackDataVector.end();
-       ++it) {
+  for (auto it = trackDataVector.begin(); it != trackDataVector.end(); ++it) {
     if (it->isEnabled()) {
       QString text(it->formatString(sourceFormat));
       int pos = 0;
