@@ -6,7 +6,7 @@
  * \author Urs Fleisch
  * \date 23 Jul 2011
  *
- * Copyright (C) 2011-2013  Urs Fleisch
+ * Copyright (C) 2011-2018  Urs Fleisch
  *
  * This file is part of Kid3.
  *
@@ -28,27 +28,13 @@
 #include <QFileInfo>
 #include <QDir>
 #include <QCoreApplication>
+#include "trackdata.h"
 #include "saferename.h"
 #include "fileproxymodel.h"
 #include "modeliterator.h"
 #include "formatconfig.h"
 
-/**
- * Constructor.
- * @param parent parent object
- */
-DirRenamer::DirRenamer(QObject* parent) : QObject(parent),
-  m_tagVersion(Frame::TagVAll), m_aborted(false), m_actionCreate(false)
-{
-  setObjectName(QLatin1String("DirRenamer"));
-}
-
-/**
- * Destructor.
- */
-DirRenamer::~DirRenamer()
-{
-}
+namespace {
 
 /**
  * Get parent directory.
@@ -58,7 +44,7 @@ DirRenamer::~DirRenamer()
  * @return parent directory (terminated by separator),
  *         empty string if no separator in dir.
  */
-static QString parentDirectory(const QString& dir)
+QString parentDirectory(const QString& dir)
 {
   QString parent(dir);
   int slashPos = parent.lastIndexOf(QLatin1Char('/'));
@@ -70,6 +56,18 @@ static QString parentDirectory(const QString& dir)
   return parent;
 }
 
+}
+
+/**
+ * Constructor.
+ * @param parent parent object
+ */
+DirRenamer::DirRenamer(QObject* parent) : QObject(parent),
+  m_tagVersion(Frame::TagVAll), m_aborted(false), m_actionCreate(false)
+{
+  setObjectName(QLatin1String("DirRenamer"));
+}
+
 /** Only defined for generation of translation files */
 #define CREATE_DIR_FAILED_FOR_PO QT_TRANSLATE_NOOP("@default", "Create directory %1 failed\n")
 
@@ -77,14 +75,24 @@ static QString parentDirectory(const QString& dir)
  * Create a directory if it does not exist.
  *
  * @param dir      directory path
+ * @param index    model index of item to rename
  * @param errorMsg if not NULL and an error occurred, a message is appended here,
  *                 otherwise it is not touched
  *
  * @return true if directory exists or was created successfully.
  */
-bool DirRenamer::createDirectory(const QString& dir,
-                   QString* errorMsg) const
+bool DirRenamer::createDirectory(
+    const QString& dir, const QPersistentModelIndex& index,
+    QString* errorMsg) const
 {
+  if (auto model = qobject_cast<const FileProxyModel*>(index.model())) {
+    const QString parentDirName = model->filePath(index.parent());
+    const QString relativeName = QDir(parentDirName).relativeFilePath(dir);
+    if (model->mkdir(index.parent(), relativeName).isValid() &&
+        QFileInfo(dir).isDir()) {
+      return true;
+    }
+  }
   if (QFileInfo(dir).isDir() ||
     (QDir().mkdir(dir) && QFileInfo(dir).isDir())) {
     return true;
@@ -118,7 +126,7 @@ bool DirRenamer::renameDirectory(
   const QString& olddir, const QString& newdir,
   const QPersistentModelIndex& index, QString* errorMsg) const
 {
-  if (QFileInfo(newdir).exists()) {
+  if (QFileInfo::exists(newdir)) {
     if (errorMsg) {
       errorMsg->append(tr("File %1 already exists\n").arg(newdir));
     }
@@ -134,11 +142,19 @@ bool DirRenamer::renameDirectory(
     // The directory must be closed before renaming on Windows.
     TaggedFileIterator::closeFileHandles(index);
   }
+  if (auto model = const_cast<FileProxyModel*>(
+        qobject_cast<const FileProxyModel*>(index.model()))) {
+    const QString parentDirName = model->filePath(index.parent());
+    const QString relativeName = QDir(parentDirName).relativeFilePath(newdir);
+    if (model->rename(index, relativeName) && QFileInfo(newdir).isDir()) {
+      return true;
+    }
+  }
   if (Utils::safeRename(olddir, newdir) && QFileInfo(newdir).isDir()) {
     return true;
   } else {
     if (errorMsg) {
-      errorMsg->append(tr("Rename %1 to %2 failed\n").arg(olddir).arg(newdir));
+      errorMsg->append(tr("Rename %1 to %2 failed\n").arg(olddir, newdir));
     }
     return false;
   }
@@ -166,7 +182,7 @@ bool DirRenamer::renameFile(const QString& oldfn, const QString& newfn,
   if (QFileInfo(newfn).isFile()) {
     return true;
   }
-  if (QFileInfo(newfn).exists()) {
+  if (QFileInfo::exists(newfn)) {
     if (errorMsg) {
       errorMsg->append(tr("%1 already exists\n").arg(newfn));
     }
@@ -186,7 +202,7 @@ bool DirRenamer::renameFile(const QString& oldfn, const QString& newfn,
     return true;
   } else {
     if (errorMsg) {
-      errorMsg->append(tr("Rename %1 to %2 failed\n").arg(oldfn).arg(newfn));
+      errorMsg->append(tr("Rename %1 to %2 failed\n").arg(oldfn, newfn));
     }
     return false;
   }
@@ -250,9 +266,7 @@ void DirRenamer::addAction(RenameAction::Type type, const QString& src, const QS
                            const QPersistentModelIndex& index)
 {
   // do not add an action if the source or destination is already in an action
-  for (RenameActionList::const_iterator it = m_actions.begin();
-       it != m_actions.end();
-       ++it) {
+  for (auto it = m_actions.constBegin(); it != m_actions.constEnd(); ++it) {
     if ((!src.isEmpty() && (*it).m_src == src) ||
         (!dest.isEmpty() && (*it).m_dest == dest)){
       return;
@@ -285,9 +299,7 @@ bool DirRenamer::actionHasSource(const QString& src) const
   if (src.isEmpty()) {
     return false;
   }
-  for (RenameActionList::const_iterator it = m_actions.begin();
-       it != m_actions.end();
-       ++it) {
+  for (auto it = m_actions.constBegin(); it != m_actions.constEnd(); ++it) {
     if ((*it).m_src == src) {
       return true;
     }
@@ -305,9 +317,7 @@ bool DirRenamer::actionHasDestination(const QString& dest) const
   if (dest.isEmpty()) {
     return false;
   }
-  for (RenameActionList::const_iterator it = m_actions.begin();
-       it != m_actions.end();
-       ++it) {
+  for (auto it = m_actions.constBegin(); it != m_actions.constEnd(); ++it) {
     if ((*it).m_dest == dest) {
       return true;
     }
@@ -325,9 +335,7 @@ void DirRenamer::replaceIfAlreadyRenamed(QString& src) const
   bool found = true;
   for (int i = 0; found && i <  5; ++i) {
     found = false;
-    for (RenameActionList::const_iterator it = m_actions.begin();
-         it != m_actions.end();
-         ++it) {
+    for (auto it = m_actions.constBegin(); it != m_actions.constEnd(); ++it) {
       if ((*it).m_type == RenameAction::RenameDirectory &&
           (*it).m_src == src) {
         src = (*it).m_dest;
@@ -363,7 +371,7 @@ void DirRenamer::scheduleAction(TaggedFile* taggedFile)
           // starts with a separator and the search starts with the
           // second character.
           int slashPos = newPart.indexOf(QLatin1Char('/'), 1);
-          if (slashPos != -1 && slashPos != (int)newPart.length() - 1) {
+          if (slashPos != -1 && slashPos != newPart.length() - 1) {
             newPart.truncate(slashPos);
             // the new part has multiple directories
             // => create one directory
@@ -371,7 +379,8 @@ void DirRenamer::scheduleAction(TaggedFile* taggedFile)
             createDir = false;
           }
           // Create a directory for each file and move it.
-          addAction(RenameAction::CreateDirectory, currentDirname + newPart);
+          addAction(RenameAction::CreateDirectory, QString(),
+                    currentDirname + newPart, taggedFile->getIndex());
           if (!createDir) {
             addAction(RenameAction::RenameFile,
                       dirWithFiles + QLatin1Char('/') + taggedFile->getFilename(),
@@ -385,7 +394,7 @@ void DirRenamer::scheduleAction(TaggedFile* taggedFile)
         if (newDirname.startsWith(parent)) {
           QString newPart(newDirname.mid(parent.length()));
           int slashPos = newPart.indexOf(QLatin1Char('/'));
-          if (slashPos != -1 && slashPos != (int)newPart.length() - 1) {
+          if (slashPos != -1 && slashPos != newPart.length() - 1) {
             newPart.truncate(slashPos);
             // the new part has multiple directories
             // => rename current directory, then create additional
@@ -425,12 +434,10 @@ void DirRenamer::scheduleAction(TaggedFile* taggedFile)
  */
 void DirRenamer::performActions(QString* errorMsg)
 {
-  for (RenameActionList::const_iterator it = m_actions.begin();
-       it != m_actions.end();
-       ++it) {
+  for (auto it = m_actions.constBegin(); it != m_actions.constEnd(); ++it) {
     switch ((*it).m_type) {
       case RenameAction::CreateDirectory:
-        createDirectory((*it).m_dest, errorMsg);
+        createDirectory((*it).m_dest, (*it).m_index, errorMsg);
         break;
       case RenameAction::RenameDirectory:
         if (renameDirectory((*it).m_src, (*it).m_dest, (*it).m_index,
@@ -468,7 +475,7 @@ QStringList DirRenamer::describeAction(const RenameAction& action) const
   static const unsigned numTypeStr = sizeof(typeStr) / sizeof(typeStr[0]);
 
   QStringList actionStrs;
-  unsigned typeIdx = static_cast<unsigned>(action.m_type);
+  auto typeIdx = static_cast<unsigned>(action.m_type);
   if (typeIdx >= numTypeStr) {
     typeIdx = numTypeStr - 1;
   }
