@@ -6,7 +6,7 @@
  * \author Urs Fleisch
  * \date 12 Jun 2011
  *
- * Copyright (C) 2011-2014  Urs Fleisch
+ * Copyright (C) 2011-2018  Urs Fleisch
  *
  * This file is part of Kid3.
  *
@@ -25,11 +25,7 @@
  */
 
 #include "downloadclient.h"
-#if QT_VERSION >= 0x050100
 #include <QRegularExpression>
-#else
-#include <QRegExp>
-#endif
 #include "importconfig.h"
 
 /**
@@ -37,18 +33,11 @@
  *
  * @param netMgr network access manager
  */
-DownloadClient::DownloadClient(QNetworkAccessManager* netMgr) :
-  HttpClient(netMgr), m_canceled(false)
-{
-  connect(this, SIGNAL(bytesReceived(QByteArray)),
-          this, SLOT(requestFinished(QByteArray)));
-}
-
-/**
- * Destructor.
- */
-DownloadClient::~DownloadClient()
+DownloadClient::DownloadClient(QNetworkAccessManager* netMgr)
+  : HttpClient(netMgr), m_canceled(false)
 {
+  connect(this, &HttpClient::bytesReceived,
+          this, &DownloadClient::requestFinished);
 }
 
 /**
@@ -108,20 +97,12 @@ QUrl DownloadClient::getImageUrl(const QUrl& url)
   QUrl imgurl;
   QMap<QString, QString> urlMap =
       ImportConfig::instance().matchPictureUrlMap();
-  for (QMap<QString, QString>::const_iterator it = urlMap.constBegin();
-       it != urlMap.constEnd();
-       ++it) {
-#if QT_VERSION >= 0x050100
+  for (auto it = urlMap.constBegin(); it != urlMap.constEnd(); ++it) {
     QRegularExpression re(it.key());
     QRegularExpressionMatch match = re.match(
           urlStr, 0, QRegularExpression::NormalMatch,
           QRegularExpression::AnchoredMatchOption);
-    if (match.hasMatch())
-#else
-    QRegExp re(it.key());
-    if (re.exactMatch(urlStr))
-#endif
-    {
+    if (match.hasMatch()) {
       QString newUrl = urlStr;
       newUrl.replace(re, *it);
       if (newUrl.indexOf(QLatin1String("%25")) != -1) {
@@ -132,15 +113,7 @@ QUrl DownloadClient::getImageUrl(const QUrl& url)
         // URL encoded: decode
         newUrl = QUrl::fromPercentEncoding(newUrl.toUtf8());
       }
-#if QT_VERSION >= 0x050000
       imgurl.setUrl(newUrl);
-#else
-      if (!newUrl.contains(QLatin1Char('%'))) {
-        imgurl.setUrl(newUrl);
-      } else {
-        imgurl.setEncodedUrl(newUrl.toAscii());
-      }
-#endif
       break;
     }
   }
