@@ -6,7 +6,7 @@
  * \author Urs Fleisch
  * \date 12 Jun 2011
  *
- * Copyright (C) 2011  Urs Fleisch
+ * Copyright (C) 2011-2018  Urs Fleisch
  *
  * This file is part of Kid3.
  *
@@ -24,8 +24,7 @@
  * along with this program.  If not, see <http://www.gnu.org/licenses/>.
  */
 
-#ifndef DOWNLOADCLIENT_H
-#define DOWNLOADCLIENT_H
+#pragma once
 
 #include <QString>
 #include "httpclient.h"
@@ -47,7 +46,7 @@ public:
   /**
    * Destructor.
    */
-  virtual ~DownloadClient();
+  virtual ~DownloadClient() override = default;
 
   /**
    * Send a download request.
@@ -107,5 +106,3 @@ private:
   QUrl m_url;
   bool m_canceled;
 };
-
-#endif // DOWNLOADCLIENT_H
