@@ -6,7 +6,7 @@
  * \author Urs Fleisch
  * \date 22-Mar-2011
  *
- * Copyright (C) 2011-2014  Urs Fleisch
+ * Copyright (C) 2011-2018  Urs Fleisch
  *
  * This file is part of Kid3.
  *
@@ -25,11 +25,12 @@
  */
 
 #include "fileproxymodel.h"
-#include <QFileSystemModel>
 #include <QTimer>
+#include "filesystemmodel.h"
 #include "taggedfileiconprovider.h"
 #include "itaggedfilefactory.h"
 #include "tagconfig.h"
+#include "saferename.h"
 #include "config.h"
 
 /** Only defined for generation of translation files */
@@ -51,8 +52,8 @@ namespace {
 QHash<int,QByteArray> getRoleHash()
 {
   QHash<int, QByteArray> roles;
-  roles[QFileSystemModel::FileNameRole] = "fileName";
-  roles[QFileSystemModel::FilePathRole] = "filePath";
+  roles[FileSystemModel::FileNameRole] = "fileName";
+  roles[FileSystemModel::FilePathRole] = "filePath";
   roles[FileProxyModel::IconIdRole] = "iconId";
   roles[FileProxyModel::TruncatedRole] = "truncated";
   roles[FileProxyModel::IsDirRole] = "isDir";
@@ -68,22 +69,19 @@ QHash<int,QByteArray> getRoleHash()
  * @param parent parent object
  */
 FileProxyModel::FileProxyModel(QObject* parent) : QSortFilterProxyModel(parent),
-  m_iconProvider(new TaggedFileIconProvider), m_fsModel(0),
+  m_iconProvider(new TaggedFileIconProvider), m_fsModel(nullptr),
   m_loadTimer(new QTimer(this)), m_sortTimer(new QTimer(this)),
   m_numModifiedFiles(0), m_isLoading(false)
 {
   setObjectName(QLatin1String("FileProxyModel"));
-  connect(this, SIGNAL(rowsInserted(QModelIndex,int,int)),
-          this, SLOT(updateInsertedRows(QModelIndex,int,int)));
+  connect(this, &QAbstractItemModel::rowsInserted,
+          this, &FileProxyModel::updateInsertedRows);
   m_loadTimer->setSingleShot(true);
   m_loadTimer->setInterval(1000);
-  connect(m_loadTimer, SIGNAL(timeout()), this, SLOT(onDirectoryLoaded()));
+  connect(m_loadTimer, &QTimer::timeout, this, &FileProxyModel::onDirectoryLoaded);
   m_sortTimer->setSingleShot(true);
   m_sortTimer->setInterval(100);
-  connect(m_sortTimer, SIGNAL(timeout()), this, SLOT(emitSortingFinished()));
-#if QT_VERSION < 0x050000
-  setRoleNames(getRoleHash());
-#endif
+  connect(m_sortTimer, &QTimer::timeout, this, &FileProxyModel::emitSortingFinished);
 }
 
 /**
@@ -92,10 +90,8 @@ FileProxyModel::FileProxyModel(QObject* parent) : QSortFilterProxyModel(parent),
 FileProxyModel::~FileProxyModel()
 {
   clearTaggedFileStore();
-  delete m_iconProvider;
 }
 
-#if QT_VERSION >= 0x050000
 /**
  * Map role identifiers to role property names in scripting languages.
  * @return hash mapping role identifiers to names.
@@ -105,7 +101,6 @@ QHash<int,QByteArray> FileProxyModel::roleNames() const
   static QHash<int, QByteArray> roles = getRoleHash();
   return roles;
 }
-#endif
 
 /**
  * Get file information of model index.
@@ -185,6 +180,31 @@ bool FileProxyModel::rmdir(const QModelIndex& index) const
   return false;
 }
 
+/**
+ * Create a directory with @a name in the @a parent model index.
+ * @return index of created directory.
+ */
+QModelIndex FileProxyModel::mkdir(const QModelIndex& parent, const QString& name) const
+{
+  if (m_fsModel) {
+    QModelIndex sourceIndex(mapToSource(parent));
+    return mapFromSource(m_fsModel->mkdir(sourceIndex, name));
+  }
+  return QModelIndex();
+}
+
+/**
+ * Rename file or directory of @a index to @a newName.
+ * @return true if ok
+ */
+bool FileProxyModel::rename(const QModelIndex& index, const QString& newName)
+{
+  if (Utils::hasIllegalFileNameCharacters(newName))
+    return false;
+
+  return setData(index, newName);
+}
+
 /**
  * Get index for given path and column.
  * @param path path to file or directory
@@ -240,11 +260,13 @@ bool FileProxyModel::filterAcceptsRow(
     QString item(srcIndex.data().toString());
     if (item == QLatin1String(".") || item == QLatin1String(".."))
       return false;
-    if (m_extensions.isEmpty() || !m_fsModel || m_fsModel->isDir(srcIndex))
+    if (!m_fsModel)
       return true;
-    for (QStringList::const_iterator it = m_extensions.begin();
-         it != m_extensions.end();
-         ++it) {
+    if (m_fsModel->isDir(srcIndex))
+      return passesExcludeFolderFilters(m_fsModel->filePath(srcIndex));
+    if (m_extensions.isEmpty())
+      return true;
+    for (auto it = m_extensions.constBegin(); it != m_extensions.constEnd(); ++it) {
       if (item.endsWith(*it, Qt::CaseInsensitive))
         return true;
     }
@@ -252,6 +274,30 @@ bool FileProxyModel::filterAcceptsRow(
   return false;
 }
 
+/**
+ * Get item flags.
+ * @param index index of item
+ * @return default flags plus drag enabled depending on
+ * setExclusiveDraggableIndex().
+ */
+Qt::ItemFlags FileProxyModel::flags(const QModelIndex& index) const
+{
+  Qt::ItemFlags itemFlags = QSortFilterProxyModel::flags(index);
+
+  if (index.isValid()) {
+    if (!m_exclusiveDraggableIndex.isValid() ||
+        index == m_exclusiveDraggableIndex) {
+      itemFlags |= Qt::ItemIsDragEnabled;
+    } else {
+      itemFlags &= ~Qt::ItemIsDragEnabled;
+    }
+  }
+  // Prevent inplace editing (i.e. renaming) of files and directories.
+  itemFlags &= ~Qt::ItemIsEditable;
+
+  return itemFlags;
+}
+
 /**
  * Get data for a given role.
  * @param index model index
@@ -264,24 +310,24 @@ QVariant FileProxyModel::data(const QModelIndex& index, int role) const
     if (role == TaggedFileRole) {
       return retrieveTaggedFileVariant(index);
     } else if (role == Qt::DecorationRole && index.column() == 0) {
-      TaggedFile* taggedFile = m_taggedFiles.value(index, 0);
+      TaggedFile* taggedFile = m_taggedFiles.value(index, nullptr);
       if (taggedFile) {
         return m_iconProvider->iconForTaggedFile(taggedFile);
       }
     } else if (role == Qt::BackgroundRole && index.column() == 0) {
-      TaggedFile* taggedFile = m_taggedFiles.value(index, 0);
+      TaggedFile* taggedFile = m_taggedFiles.value(index, nullptr);
       if (taggedFile) {
         QColor color = m_iconProvider->backgroundForTaggedFile(taggedFile);
         if (color.isValid())
           return color;
       }
     } else if (role == IconIdRole && index.column() == 0) {
-      TaggedFile* taggedFile = m_taggedFiles.value(index, 0);
+      TaggedFile* taggedFile = m_taggedFiles.value(index, nullptr);
       return taggedFile
           ? m_iconProvider->iconIdForTaggedFile(taggedFile)
           : QByteArray("");
     } else if (role == TruncatedRole && index.column() == 0) {
-      TaggedFile* taggedFile = m_taggedFiles.value(index, 0);
+      TaggedFile* taggedFile = m_taggedFiles.value(index, nullptr);
       return taggedFile &&
           ((TagConfig::instance().markTruncations() &&
             taggedFile->getTruncationFlags(Frame::Tag_Id3v1) != 0) ||
@@ -311,46 +357,30 @@ bool FileProxyModel::setData(const QModelIndex& index, const QVariant& value,
 
 /**
  * Set source model.
- * @param sourceModel source model, must be QFileSystemModel
+ * @param sourceModel source model, must be FileSystemModel
  */
 void FileProxyModel::setSourceModel(QAbstractItemModel* sourceModel)
 {
-  QFileSystemModel* fsModel = qobject_cast<QFileSystemModel*>(sourceModel);
-  Q_ASSERT_X(fsModel != 0 , "setSourceModel",
-             "sourceModel is not QFileSystemModel");
+  auto fsModel = qobject_cast<FileSystemModel*>(sourceModel);
+  Q_ASSERT_X(fsModel != nullptr , "setSourceModel",
+             "sourceModel is not FileSystemModel");
   if (fsModel != m_fsModel) {
     if (m_fsModel) {
       m_isLoading = false;
-      disconnect(m_fsModel, SIGNAL(rootPathChanged(QString)),
-                 this, SLOT(onStartLoading()));
-#if QT_VERSION >= 0x040700
-      disconnect(m_fsModel, SIGNAL(directoryLoaded(QString)),
-                 this, SLOT(onDirectoryLoaded()));
-#else
-      disconnect(m_fsModel, SIGNAL(rowsInserted(QModelIndex,int,int)),
-                 this, SLOT(onDirectoryLoaded()));
-#endif
+      disconnect(m_fsModel, &FileSystemModel::rootPathChanged,
+                 this, &FileProxyModel::onStartLoading);
+      disconnect(m_fsModel, &FileSystemModel::directoryLoaded,
+                 this, &FileProxyModel::onDirectoryLoaded);
     }
     m_fsModel = fsModel;
     if (m_fsModel) {
-      connect(m_fsModel, SIGNAL(rootPathChanged(QString)),
-              this, SLOT(onStartLoading()));
-#if QT_VERSION >= 0x040700
-      connect(m_fsModel, SIGNAL(directoryLoaded(QString)),
-              this, SLOT(onDirectoryLoaded()));
-#else
-      // Qt < 4.7 does not have a directoryLoaded() signal, so
-      // rowsInserted() and a slow timeout for empty directories
-      // are used.
-      connect(m_fsModel, SIGNAL(rowsInserted(QModelIndex,int,int)),
-              this, SLOT(onDirectoryLoaded()));
-#endif
+      connect(m_fsModel, &FileSystemModel::rootPathChanged,
+              this, &FileProxyModel::onStartLoading);
+      connect(m_fsModel, &FileSystemModel::directoryLoaded,
+              this, &FileProxyModel::onDirectoryLoaded);
     }
   }
   QSortFilterProxyModel::setSourceModel(sourceModel);
-#if QT_VERSION < 0x050000
-  setRoleNames(getRoleHash());
-#endif
 }
 
 /**
@@ -382,6 +412,20 @@ void FileProxyModel::onStartLoading()
   m_loadTimer->start();
 }
 
+/**
+ * Check if more data is available.
+ * @param parent parent index of items to fetch
+ * @return true if more data available.
+ */
+bool FileProxyModel::canFetchMore(const QModelIndex& parent) const
+{
+  QString path = filePath(parent);
+  if (!passesIncludeFolderFilters(path) || !passesExcludeFolderFilters(path))
+    return false;
+
+  return QSortFilterProxyModel::canFetchMore(parent);
+}
+
 /**
  * Fetches any available data.
  * @param parent parent index of items to fetch
@@ -395,7 +439,7 @@ void FileProxyModel::fetchMore(const QModelIndex& parent)
 /**
  * Sort model.
  *
- * This method will directly call QFileSystemModel::sort() on the
+ * This method will directly call FileSystemModel::sort() on the
  * sourceModel() to take advantage of that specialized behavior. This
  * will change the order in the souce model.
  *
@@ -404,8 +448,8 @@ void FileProxyModel::fetchMore(const QModelIndex& parent)
  */
 void FileProxyModel::sort(int column, Qt::SortOrder order)
 {
-  QAbstractItemModel* srcModel = 0;
-  if (rowCount() > 0 && (srcModel = sourceModel()) != 0) {
+  QAbstractItemModel* srcModel = nullptr;
+  if (rowCount() > 0 && (srcModel = sourceModel()) != nullptr) {
     srcModel->sort(column, order);
   }
 }
@@ -418,7 +462,7 @@ void FileProxyModel::setNameFilters(const QStringList& filters)
 {
   QRegExp wildcardRe(QLatin1String("\\.\\w+"));
   QSet<QString> exts;
-  foreach (const QString& filter, filters) {
+  for (const QString& filter : filters) {
     int pos = 0;
     while ((pos = wildcardRe.indexIn(filter, pos)) != -1) {
       int len = wildcardRe.matchedLength();
@@ -442,6 +486,21 @@ void FileProxyModel::filterOutIndex(const QPersistentModelIndex& index)
   m_filteredOut.insert(mapToSource(index));
 }
 
+/**
+ * Reset internal data of the model.
+ * Is called from endResetModel().
+ */
+void FileProxyModel::resetInternalData()
+{
+  QSortFilterProxyModel::resetInternalData();
+  clearTaggedFileStore();
+  m_filteredOut.clear();
+  m_loadTimer->stop();
+  m_sortTimer->stop();
+  m_numModifiedFiles = 0;
+  m_isLoading = false;
+}
+
 /**
  * Stop filtering out indexes.
  */
@@ -468,6 +527,80 @@ void FileProxyModel::applyFilteringOutIndexes()
   invalidateFilter();
 }
 
+/**
+ * Set filters for included and excluded folders.
+ * @param includeFolders wildcard expressions for folders to be included
+ * @param excludeFolders wildcard expressions for folders to be excluded
+ */
+void FileProxyModel::setFolderFilters(const QStringList& includeFolders,
+                                      const QStringList& excludeFolders)
+{
+  QList<QRegExp> oldIncludeFolderFilters, oldExcludeFolderFilters;
+  m_includeFolderFilters.swap(oldIncludeFolderFilters);
+  m_excludeFolderFilters.swap(oldExcludeFolderFilters);
+  for (QString filter : includeFolders) {
+    filter.replace(QLatin1Char('\\'), QLatin1Char('/'));
+    m_includeFolderFilters.append(
+          QRegExp(filter, Qt::CaseInsensitive, QRegExp::Wildcard));
+  }
+
+  for (QString filter : excludeFolders) {
+    filter.replace(QLatin1Char('\\'), QLatin1Char('/'));
+    m_excludeFolderFilters.append(
+          QRegExp(filter, Qt::CaseInsensitive, QRegExp::Wildcard));
+  }
+
+  if (m_includeFolderFilters != oldIncludeFolderFilters ||
+      m_excludeFolderFilters != oldExcludeFolderFilters) {
+    invalidateFilter();
+  }
+}
+
+/**
+ * Check if a directory path passes the include folder filters.
+ * @param dirPath absolute path to directory
+ * @return true if path passes filters.
+ */
+bool FileProxyModel::passesIncludeFolderFilters(const QString& dirPath) const
+{
+  if (!m_includeFolderFilters.isEmpty()) {
+    bool included = false;
+    for (auto it = m_includeFolderFilters.constBegin();
+         it != m_includeFolderFilters.constEnd();
+         ++it) {
+      if (it->exactMatch(dirPath)) {
+        included = true;
+        break;
+      }
+    }
+    if (!included) {
+      return false;
+    }
+  }
+
+  return true;
+}
+
+/**
+ * Check if a directory path passes the include folder filters.
+ * @param dirPath absolute path to directory
+ * @return true if path passes filters.
+ */
+bool FileProxyModel::passesExcludeFolderFilters(const QString& dirPath) const
+{
+  if (!m_excludeFolderFilters.isEmpty()) {
+    for (auto it = m_excludeFolderFilters.constBegin();
+         it != m_excludeFolderFilters.constEnd();
+         ++it) {
+      if (it->exactMatch(dirPath)) {
+        return false;
+      }
+    }
+  }
+
+  return true;
+}
+
 /**
  * Retrieve tagged file for an index.
  * @param index model index
@@ -487,17 +620,17 @@ QVariant FileProxyModel::retrieveTaggedFileVariant(
  * @return true if index and value valid
  */
 bool FileProxyModel::storeTaggedFileVariant(const QPersistentModelIndex& index,
-                     QVariant value) {
+                     const QVariant& value) {
   if (index.isValid()) {
     if (value.isValid()) {
       if (value.canConvert<TaggedFile*>()) {
-        TaggedFile* oldItem = m_taggedFiles.value(index, 0);
+        TaggedFile* oldItem = m_taggedFiles.value(index, nullptr);
         delete oldItem;
         m_taggedFiles.insert(index, value.value<TaggedFile*>());
         return true;
       }
     } else {
-      if (TaggedFile* oldFile = m_taggedFiles.value(index, 0)) {
+      if (TaggedFile* oldFile = m_taggedFiles.value(index, nullptr)) {
         m_taggedFiles.remove(index);
         delete oldFile;
       }
@@ -538,7 +671,7 @@ void FileProxyModel::initTaggedFileData(const QModelIndex& index) {
  */
 bool FileProxyModel::getTaggedFileOfIndex(const QModelIndex& index,
                                           TaggedFile** taggedFile) {
-  if (!(index.isValid() && index.model() != 0))
+  if (!(index.isValid() && index.model() != nullptr))
     return false;
   QVariant data(index.model()->data(index, FileProxyModel::TaggedFileRole));
   if (!data.canConvert<TaggedFile*>())
@@ -556,11 +689,11 @@ bool FileProxyModel::getTaggedFileOfIndex(const QModelIndex& index,
  * TaggedFile or if has a TaggedFile which is null.
  */
 TaggedFile* FileProxyModel::getTaggedFileOfIndex(const QModelIndex& index) {
-  if (!(index.isValid() && index.model() != 0))
-    return 0;
+  if (!(index.isValid() && index.model() != nullptr))
+    return nullptr;
   QVariant data(index.model()->data(index, FileProxyModel::TaggedFileRole));
   if (!data.canConvert<TaggedFile*>())
-    return 0;
+    return nullptr;
   return data.value<TaggedFile*>();
 }
 
@@ -572,7 +705,7 @@ TaggedFile* FileProxyModel::getTaggedFileOfIndex(const QModelIndex& index) {
  * @return directory path, null if not directory
  */
 QString FileProxyModel::getPathIfIndexOfDir(const QModelIndex& index) {
-  const FileProxyModel* model =
+  const auto model =
       qobject_cast<const FileProxyModel*>(index.model());
   if (!model || !model->isDir(index))
     return QString();
@@ -596,7 +729,7 @@ TaggedFile* FileProxyModel::readWithId3V24(TaggedFile* taggedFile)
       QVariant data;
       data.setValue(tagLibFile);
       // setData() will not invalidate the model, so this should be safe.
-      QAbstractItemModel* setDataModel = const_cast<QAbstractItemModel*>(
+      auto setDataModel = const_cast<QAbstractItemModel*>(
           index.model());
       if (setDataModel) {
         setDataModel->setData(index, data, FileProxyModel::TaggedFileRole);
@@ -621,18 +754,20 @@ TaggedFile* FileProxyModel::createTaggedFile(
     TaggedFile::Feature feature,
     const QString& fileName,
     const QPersistentModelIndex& idx) {
-  TaggedFile* taggedFile = 0;
-  foreach (ITaggedFileFactory* factory, s_taggedFileFactories) {
-    foreach (const QString& key, factory->taggedFileKeys()) {
+  TaggedFile* taggedFile = nullptr;
+  const auto factories = s_taggedFileFactories;
+  for (ITaggedFileFactory* factory : factories) {
+    const auto keys = factory->taggedFileKeys();
+    for (const QString& key : keys) {
       if ((factory->taggedFileFeatures(key) & feature) != 0 &&
           (taggedFile = factory->createTaggedFile(key, fileName, idx,
                                                   feature))
-          != 0) {
+          != nullptr) {
         return taggedFile;
       }
     }
   }
-  return 0;
+  return nullptr;
 }
 
 /**
@@ -646,16 +781,18 @@ TaggedFile* FileProxyModel::createTaggedFile(
 TaggedFile* FileProxyModel::createTaggedFile(
     const QString& fileName,
     const QPersistentModelIndex& idx) {
-  TaggedFile* taggedFile = 0;
-  foreach (ITaggedFileFactory* factory, s_taggedFileFactories) {
-    foreach (const QString& key, factory->taggedFileKeys()) {
+  TaggedFile* taggedFile = nullptr;
+  const auto factories = s_taggedFileFactories;
+  for (ITaggedFileFactory* factory : factories) {
+    const auto keys = factory->taggedFileKeys();
+    for (const QString& key : keys) {
       taggedFile = factory->createTaggedFile(key, fileName, idx);
       if (taggedFile) {
         return taggedFile;
       }
     }
   }
-  return 0;
+  return nullptr;
 }
 
 /**
@@ -674,7 +811,7 @@ TaggedFile* FileProxyModel::readWithId3V23(TaggedFile* taggedFile)
       QVariant data;
       data.setValue(id3libFile);
       // setData() will not invalidate the model, so this should be safe.
-      QAbstractItemModel* setDataModel = const_cast<QAbstractItemModel*>(
+      auto setDataModel = const_cast<QAbstractItemModel*>(
           index.model());
       if (setDataModel) {
         setDataModel->setData(index, data, FileProxyModel::TaggedFileRole);
@@ -727,7 +864,7 @@ TaggedFile* FileProxyModel::readWithOggFlac(TaggedFile* taggedFile)
       QVariant data;
       data.setValue(tagLibFile);
       // setData() will not invalidate the model, so this should be safe.
-      QAbstractItemModel* setDataModel = const_cast<QAbstractItemModel*>(
+      auto setDataModel = const_cast<QAbstractItemModel*>(
           index.model());
       if (setDataModel) {
         setDataModel->setData(index, data, FileProxyModel::TaggedFileRole);
@@ -822,16 +959,17 @@ void FileProxyModel::notifyModelDataChanged(const QModelIndex& index)
 QList<QPair<QString, QString> > FileProxyModel::createNameFilters()
 {
   QStringList extensions;
-  foreach (ITaggedFileFactory* factory, taggedFileFactories()) {
-    foreach (const QString& key, factory->taggedFileKeys()) {
+  const auto factories = taggedFileFactories();
+  for (ITaggedFileFactory* factory : factories) {
+    const auto keys = factory->taggedFileKeys();
+    for (const QString& key : keys) {
       extensions.append(factory->supportedFileExtensions(key));
     }
   }
   // remove duplicates
   extensions.sort();
   QString lastExt(QLatin1String(""));
-  for (QStringList::iterator it = extensions.begin();
-       it != extensions.end();) {
+  for (auto it = extensions.begin(); it != extensions.end();) {
     if (*it == lastExt) {
       it = extensions.erase(it);
     } else {
@@ -842,8 +980,8 @@ QList<QPair<QString, QString> > FileProxyModel::createNameFilters()
 
   QString allPatterns;
   QList<QPair<QString, QString> > nameFilters;
-  for (QStringList::const_iterator it = extensions.begin();
-       it != extensions.end();
+  for (auto it = extensions.constBegin();
+       it != extensions.constEnd();
        ++it) {
     QString text = (*it).mid(1).toUpper();
     QString pattern = QLatin1Char('*') + *it;
@@ -854,6 +992,8 @@ QList<QPair<QString, QString> > FileProxyModel::createNameFilters()
     nameFilters.append(qMakePair(text, pattern));
   }
   if (!allPatterns.isEmpty()) {
+    // Add extensions for playlists.
+    allPatterns += QLatin1String(" *.m3u *.pls *.xspf");
     nameFilters.prepend(qMakePair(tr("All Supported Files"), allPatterns));
   }
   nameFilters.append(qMakePair(tr("All Files"), QString(QLatin1Char('*'))));
