@@ -6,7 +6,7 @@
  * \author Urs Fleisch
  * \date 22-Mar-2011
  *
- * Copyright (C) 2011-2014  Urs Fleisch
+ * Copyright (C) 2011-2018  Urs Fleisch
  *
  * This file is part of Kid3.
  *
@@ -24,19 +24,20 @@
  * along with this program.  If not, see <http://www.gnu.org/licenses/>.
  */
 
-#ifndef FILEPROXYMODEL_H
-#define FILEPROXYMODEL_H
+#pragma once
 
 #include <QSortFilterProxyModel>
 #include <QHash>
 #include <QSet>
 #include <QFileInfo>
 #include <QStringList>
+#include <QScopedPointer>
 #include "taggedfile.h"
 #include "kid3api.h"
 
-class QFileSystemModel;
 class QTimer;
+class QFileInfo;
+class FileSystemModel;
 class TaggedFileIconProvider;
 class ITaggedFileFactory;
 
@@ -46,7 +47,7 @@ class ITaggedFileFactory;
 class KID3_CORE_EXPORT FileProxyModel : public QSortFilterProxyModel {
   Q_OBJECT
 public:
-  /** Custom role, extending QFileSystemModel::Roles. */
+  /** Custom role, extending FileSystemModel::Roles. */
   enum Roles {
     TaggedFileRole = Qt::UserRole + 4,
     IconIdRole = Qt::UserRole + 5,
@@ -59,12 +60,20 @@ public:
    *
    * @param parent parent object
    */
-  explicit FileProxyModel(QObject* parent = 0);
+  explicit FileProxyModel(QObject* parent = nullptr);
 
   /**
    * Destructor.
    */
-  virtual ~FileProxyModel();
+  virtual ~FileProxyModel() override;
+
+  /**
+   * Get item flags.
+   * @param index index of item
+   * @return default flags plus drag enabled depending on
+   * setExclusiveDraggableIndex().
+   */
+  virtual Qt::ItemFlags flags(const QModelIndex& index) const override;
 
   /**
    * Get data for a given role.
@@ -73,7 +82,7 @@ public:
    * @return data for role
    */
   virtual QVariant data(const QModelIndex& index,
-                        int role=Qt::DisplayRole) const;
+                        int role = Qt::DisplayRole) const override;
 
   /**
    * Set data for a given role.
@@ -83,51 +92,44 @@ public:
    * @return true if successful
    */
   virtual bool setData(const QModelIndex& index, const QVariant& value,
-                       int role=Qt::EditRole);
+                       int role = Qt::EditRole) override;
 
   /**
    * Set source model.
-   * @param sourceModel source model, must be QFileSystemModel
+   * @param sourceModel source model, must be FileSystemModel
    */
-  virtual void setSourceModel(QAbstractItemModel* sourceModel);
+  virtual void setSourceModel(QAbstractItemModel* sourceModel) override;
 
   /**
    * Check if more data is available.
    * @param parent parent index of items to fetch
    * @return true if more data available.
    */
-  virtual bool canFetchMore(const QModelIndex& parent) const;
+  virtual bool canFetchMore(const QModelIndex& parent) const override;
 
   /**
    * Fetches any available data.
    * @param parent parent index of items to fetch
    */
-  virtual void fetchMore(const QModelIndex& parent);
+  virtual void fetchMore(const QModelIndex& parent) override;
 
   /**
    * Sort model.
    *
-   * This method will directly call QFileSystemModel::sort() on the
+   * This method will directly call FileSystemModel::sort() on the
    * sourceModel() to take advantage of that specialized behavior. This
    * will change the order in the souce model.
    *
    * @param column column to sort
    * @param order ascending or descending order
    */
-  virtual void sort(int column, Qt::SortOrder order = Qt::AscendingOrder);
+  virtual void sort(int column, Qt::SortOrder order = Qt::AscendingOrder) override;
 
-#if QT_VERSION >= 0x050000
   /**
    * Map role identifiers to role property names in scripting languages.
    * @return hash mapping role identifiers to names.
    */
-  virtual QHash<int, QByteArray> roleNames() const;
-#endif
-
-  /**
-   * Reset the model.
-   */
-  void resetModel();
+  virtual QHash<int, QByteArray> roleNames() const override;
 
   /**
    * Check if the model is currently loading a directory.
@@ -207,6 +209,18 @@ public:
    */
   bool rmdir(const QModelIndex& index) const;
 
+  /**
+   * Create a directory with @a name in the @a parent model index.
+   * @return index of created directory.
+   */
+  QModelIndex mkdir(const QModelIndex& parent, const QString& name) const;
+
+  /**
+   * Rename file or directory of @a index to @a newName.
+   * @return true if ok
+   */
+  bool rename(const QModelIndex& index, const QString& newName);
+
   /**
    * Get index for given path and column.
    * @param path path to file or directory
@@ -237,11 +251,21 @@ public:
    */
   bool isModified() const { return m_numModifiedFiles > 0; }
 
+  /**
+   * Set index of item which shall be the only item which can be dragged.
+   * This can be used to retain the selection while dragging a single item,
+   * e.g. a picture to be embedded.
+   * @param index index of single item which is draggable
+   */
+  void setExclusiveDraggableIndex(const QPersistentModelIndex& index) {
+    m_exclusiveDraggableIndex = index;
+  }
+
   /**
    * Get icon provider.
    * @return icon provider.
    */
-  TaggedFileIconProvider* getIconProvider() const { return m_iconProvider; }
+  TaggedFileIconProvider* getIconProvider() const { return m_iconProvider.data(); }
 
   /**
    * Access to tagged file factories.
@@ -436,7 +460,7 @@ protected:
    *
    * @return true to include row.
    */
-  virtual bool filterAcceptsRow(int srcRow, const QModelIndex& srcParent) const;
+  virtual bool filterAcceptsRow(int srcRow, const QModelIndex& srcParent) const override;
 
 private:
   /**
@@ -453,7 +477,7 @@ private:
    * @return true if index and value valid
    */
   bool storeTaggedFileVariant(const QPersistentModelIndex& index,
-                              QVariant value);
+                              const QVariant& value);
 
   /**
    * Clear store with tagged files.
@@ -482,10 +506,11 @@ private:
 
   QHash<QPersistentModelIndex, TaggedFile*> m_taggedFiles;
   QSet<QPersistentModelIndex> m_filteredOut;
+  QPersistentModelIndex m_exclusiveDraggableIndex;
   QList<QRegExp> m_includeFolderFilters;
   QList<QRegExp> m_excludeFolderFilters;
-  TaggedFileIconProvider* m_iconProvider;
-  QFileSystemModel* m_fsModel;
+  QScopedPointer<TaggedFileIconProvider> m_iconProvider;
+  FileSystemModel* m_fsModel;
   QTimer* m_loadTimer;
   QTimer* m_sortTimer;
   QStringList m_extensions;
@@ -496,5 +521,3 @@ private:
 };
 
 Q_DECLARE_METATYPE(TaggedFile*)
-
-#endif // FILEPROXYMODEL_H
