@@ -6,7 +6,7 @@
  * \author Urs Fleisch
  * \date 03-Feb-2013
  *
- * Copyright (C) 2013  Urs Fleisch
+ * Copyright (C) 2013-2018  Urs Fleisch
  *
  * This file is part of Kid3.
  *
@@ -28,38 +28,13 @@
 #include <QTimer>
 #include "fileproxymodel.h"
 
-/**
- * GreaterThan functor to sort modex indexes by string data.
- */
-class PersistentModelIndexGreaterThan {
-public:
-  /**
-   * Greater than call operator.
-   * @param lhs left hand side
-   * @param rhs right hand side
-   * @return true if string data of @a lhs is greater than string data of
-   * @a rhs.
-   */
-  inline bool operator()(const QPersistentModelIndex& lhs,
-                         const QPersistentModelIndex& rhs) const {
-    return lhs.data().toString().compare(rhs.data().toString()) > 0;
-  }
-};
-
 /**
  * Constructor.
  *
  * @param model file proxy model
  */
-FileProxyModelIterator::FileProxyModelIterator(FileProxyModel* model) :
-  QObject(model), m_model(model), m_numDone(0), m_aborted(false)
-{
-}
-
-/**
- * Destructor.
- */
-FileProxyModelIterator::~FileProxyModelIterator()
+FileProxyModelIterator::FileProxyModelIterator(FileProxyModel* model)
+  : QObject(model), m_model(model), m_numDone(0), m_aborted(false)
 {
 }
 
@@ -135,26 +110,33 @@ void FileProxyModelIterator::fetchNext()
     m_nextIdx = m_nodes.top();
     if (m_nextIdx.isValid()) {
       if (m_model->isDir(m_nextIdx) && m_model->canFetchMore(m_nextIdx)) {
-        connect(m_model, SIGNAL(sortingFinished()),
-                this, SLOT(onDirectoryLoaded()));
+        connect(m_model, &FileProxyModel::sortingFinished,
+                this, &FileProxyModelIterator::onDirectoryLoaded);
         m_model->fetchMore(m_nextIdx);
         return;
       }
       if (++count >= 10) {
         // Avoid spinning too long to keep the GUI responsive.
-        QTimer::singleShot(0, this, SLOT(fetchNext()));
+        QTimer::singleShot(0, this, &FileProxyModelIterator::fetchNext);
         return;
       }
       m_nodes.pop();
       ++m_numDone;
+      const int numRows = m_model->rowCount(m_nextIdx);
       QStack<QPersistentModelIndex> childNodes;
-      for (int row = m_model->rowCount(m_nextIdx) - 1; row >= 0; --row) {
+      childNodes.reserve(numRows);
+      for (int row = numRows - 1; row >= 0; --row) {
         childNodes.push(m_model->index(row, 0, m_nextIdx));
       }
       qStableSort(childNodes.begin(), childNodes.end(),
-                  PersistentModelIndexGreaterThan());
+                  [](const QPersistentModelIndex& lhs,
+                     const QPersistentModelIndex& rhs) {
+        return lhs.data().toString().compare(rhs.data().toString()) > 0;
+      });
       m_nodes += childNodes;
       emit nextReady(m_nextIdx);
+    } else {
+      m_nodes.pop();
     }
   }
   m_nodes.clear();
@@ -168,7 +150,7 @@ void FileProxyModelIterator::fetchNext()
  */
 void FileProxyModelIterator::onDirectoryLoaded()
 {
-  disconnect(m_model, SIGNAL(sortingFinished()),
-             this, SLOT(onDirectoryLoaded()));
+  disconnect(m_model, &FileProxyModel::sortingFinished,
+             this, &FileProxyModelIterator::onDirectoryLoaded);
   fetchNext();
 }
