@@ -6,7 +6,7 @@
  * \author Urs Fleisch
  * \date 9 Jan 2003
  *
- * Copyright (C) 2003-2009  Urs Fleisch
+ * Copyright (C) 2003-2018  Urs Fleisch
  *
  * This file is part of Kid3.
  *
@@ -24,8 +24,7 @@
  * along with this program.  If not, see <http://www.gnu.org/licenses/>.
  */
 
-#ifndef FRAMELIST_H
-#define FRAMELIST_H
+#pragma once
 
 #include <QObject>
 #include "frame.h"
@@ -54,7 +53,7 @@ public:
   /**
    * Destructor.
    */
-  virtual ~FrameList();
+  virtual ~FrameList() override = default;
 
   /**
    * Get editor for frames.
@@ -250,5 +249,3 @@ private:
   /** true while a frame is added */
   bool m_addingFrame;
 };
-
-#endif // FRAMELIST_H
