@@ -25,7 +25,7 @@
  */
 
 #include "frametablemodel.h"
-#include <QApplication>
+#include <QGuiApplication>
 #include <QBrush>
 #include <QPalette>
 #include <algorithm>
@@ -35,41 +35,6 @@
 
 namespace {
 
-/**
- * Sort comparator functor used for m_frameOfRow.
- */
-class FrameLessThan {
-public:
-  /**
-   * Constructor.
-   * @param frameTypeSeqNr sequence numbers for frame types
-   */
-  explicit FrameLessThan(const QVector<int>& frameTypeSeqNr) :
-    m_frameTypeSeqNr(frameTypeSeqNr) {
-  }
-
-  /**
-   * Call operator.
-   * @param lhs left hand side
-   * @param rhs right hand side
-   * @return true if frame of @a lhs precedes frame of @a rhs.
-   */
-  bool operator()(FrameCollection::iterator lhs, FrameCollection::iterator rhs)
-  {
-    int lhsType = lhs->getType();
-    int rhsType = rhs->getType();
-    int lhsSeqNr = m_frameTypeSeqNr.at(lhsType);
-    int rhsSeqNr = m_frameTypeSeqNr.at(rhsType);
-    return lhsSeqNr < rhsSeqNr ||
-           (lhsType == Frame::FT_Other && lhsType == rhsType &&
-            lhs->getInternalName() < rhs->getInternalName());
-  }
-
-private:
-  const QVector<int>& m_frameTypeSeqNr;
-};
-
-
 QHash<int,QByteArray> getRoleHash()
 {
   QHash<int, QByteArray> roles;
@@ -92,22 +57,12 @@ QHash<int,QByteArray> getRoleHash()
  * @param id3v1  true if model for ID3v1 frames
  * @param parent parent widget
  */
-FrameTableModel::FrameTableModel(bool id3v1, QObject* parent) :
-  QAbstractTableModel(parent), m_markedRows(0), m_changedFrames(0),
-  m_id3v1(id3v1),
-  m_guiApp(qobject_cast<QApplication*>(QCoreApplication::instance()) != 0)
+FrameTableModel::FrameTableModel(bool id3v1, QObject* parent)
+  : QAbstractTableModel(parent), m_markedRows(0), m_changedFrames(0),
+    m_id3v1(id3v1),
+    m_guiApp(qobject_cast<QGuiApplication*>(QCoreApplication::instance()) != nullptr)
 {
   setObjectName(QLatin1String("FrameTableModel"));
-#if QT_VERSION < 0x050000
-  setRoleNames(getRoleHash());
-#endif
-}
-
-/**
- * Destructor.
- */
-FrameTableModel::~FrameTableModel()
-{
 }
 
 /**
@@ -140,7 +95,7 @@ QVariant FrameTableModel::data(const QModelIndex& index, int role) const
       index.row() < 0 || index.row() >= static_cast<int>(frames().size()) ||
       index.column() < 0 || index.column() >= CI_NumColumns)
     return QVariant();
-  FrameCollection::iterator it = frameAt(index.row());
+  auto it = frameAt(index.row());
   bool isModified = false, isTruncated = false;
   if ((role == Qt::BackgroundColorRole && index.column() == CI_Enable) ||
       role == ModifiedRole) {
@@ -162,7 +117,7 @@ QVariant FrameTableModel::data(const QModelIndex& index, int role) const
           it->getValue() != Frame::differentRepresentation()) {
         QVariant fieldValue = it->getFieldValue(Frame::ID_PictureType);
         if (fieldValue.isValid()) {
-          PictureFrame::PictureType pictureType =
+          auto pictureType =
               static_cast<PictureFrame::PictureType>(fieldValue.toInt());
           if (pictureType != PictureFrame::PT_Other) {
             QString typeName = PictureFrame::getPictureTypeName(pictureType);
@@ -181,7 +136,7 @@ QVariant FrameTableModel::data(const QModelIndex& index, int role) const
   } else if (role == Qt::BackgroundColorRole) {
     if (index.column() == CI_Enable) {
       return !isModified ? Qt::NoBrush
-                         : m_guiApp ? QApplication::palette().mid()
+                         : m_guiApp ? QGuiApplication::palette().mid()
                                     : QBrush(Qt::gray);
     } else if (index.column() == CI_Value) {
       return isTruncated ? QBrush(Qt::red) : Qt::NoBrush;
@@ -209,18 +164,14 @@ QVariant FrameTableModel::data(const QModelIndex& index, int role) const
   } else if (role == FieldIdsRole) {
     QVariantList result;
     const Frame::FieldList& fields = it->getFieldList();
-    for (Frame::FieldList::const_iterator fit = fields.constBegin();
-         fit != fields.constEnd();
-         ++fit) {
+    for (auto fit = fields.constBegin(); fit != fields.constEnd(); ++fit) {
       result.append(fit->m_id);
     }
     return result;
   } else if (role == FieldValuesRole) {
     QVariantList result;
     const Frame::FieldList& fields = it->getFieldList();
-    for (Frame::FieldList::const_iterator fit = fields.constBegin();
-         fit != fields.constEnd();
-         ++fit) {
+    for (auto fit = fields.constBegin(); fit != fields.constEnd(); ++fit) {
       result.append(fit->m_value);
     }
     return result;
@@ -245,9 +196,9 @@ bool FrameTableModel::setData(const QModelIndex& index,
   if ((role == Qt::EditRole && index.column() == CI_Value) ||
       role == ValueRole) {
     QString valueStr(value.toString());
-    FrameCollection::iterator it = frameAt(index.row());
+    auto it = frameAt(index.row());
     if (valueStr != (*it).getValue()) {
-      Frame& frame = const_cast<Frame&>(*it);
+      auto& frame = const_cast<Frame&>(*it);
       if (valueStr.isNull()) valueStr = QLatin1String("");
       frame.setValueIfChanged(valueStr);
       emit dataChanged(index, index);
@@ -333,7 +284,7 @@ bool FrameTableModel::insertRows(int, int count, const QModelIndex&)
  */
 void FrameTableModel::insertFrame(const Frame& frame)
 {
-  FrameCollection::iterator it = m_frames.upper_bound(frame);
+  auto it = m_frames.upper_bound(frame);
   int row = rowOf(it);
   beginInsertRows(QModelIndex(), row, row);
   it = m_frames.insert(it, frame);
@@ -364,7 +315,6 @@ bool FrameTableModel::removeRows(int row, int count,
   return true;
 }
 
-#if QT_VERSION >= 0x050000
 /**
  * Map role identifiers to role property names in scripting languages.
  * @return hash mapping role identifiers to names.
@@ -374,7 +324,6 @@ QHash<int,QByteArray> FrameTableModel::roleNames() const
   static QHash<int, QByteArray> roles = getRoleHash();
   return roles;
 }
-#endif
 
 /**
  * Get the frame at a specific position in the collection.
@@ -393,10 +342,7 @@ FrameCollection::iterator FrameTableModel::frameAt(int row) const {
  */
 int FrameTableModel::rowOf(FrameCollection::iterator frameIt) const {
   int row = 0;
-  for (QVector<FrameCollection::iterator>::const_iterator it =
-       m_frameOfRow.constBegin();
-       it != m_frameOfRow.constEnd();
-       ++it) {
+  for (auto it = m_frameOfRow.constBegin(); it != m_frameOfRow.constEnd(); ++it) {
     if (frameIt == *it)
       break;
     ++row;
@@ -442,12 +388,10 @@ void FrameTableModel::markChangedFrames(quint64 frameMask)
   if (!FileConfig::instance().markChanges() || !changedBits)
     return;
 
-  FrameCollection::const_iterator it;
-  int row;
   const FrameCollection& frameCollection = frames();
-  for (it = frameCollection.begin(), row = 0;
-       it != frameCollection.end();
-       ++it, ++row) {
+  auto it = frameCollection.cbegin();
+  int row = 0;
+  for (; it != frameCollection.cend(); ++it, ++row) {
     if (it->isValueChanged() ||
         (static_cast<unsigned>((*it).getType()) < sizeof(changedBits) * 8 &&
          (changedBits & (1ULL << (*it).getType())) != 0)) {
@@ -465,10 +409,10 @@ void FrameTableModel::markChangedFrames(quint64 frameMask)
 const Frame* FrameTableModel::getFrameOfIndex(const QModelIndex& index) const
 {
   if (index.isValid() && index.row() < static_cast<int>(frames().size())) {
-    FrameCollection::iterator it = frameAt(index.row());
+    auto it = frameAt(index.row());
     return &(*it);
   }
-  return 0;
+  return nullptr;
 }
 
 /**
@@ -479,10 +423,7 @@ const Frame* FrameTableModel::getFrameOfIndex(const QModelIndex& index) const
 int FrameTableModel::getRowWithFrameIndex(int index) const
 {
   int row = 0;
-  for (QVector<FrameCollection::iterator>::const_iterator it =
-       m_frameOfRow.constBegin();
-       it != m_frameOfRow.constEnd();
-       ++it) {
+  for (auto it = m_frameOfRow.constBegin(); it != m_frameOfRow.constEnd(); ++it) {
     if ((*it)->getIndex() == index) {
       return row;
     }
@@ -499,10 +440,7 @@ int FrameTableModel::getRowWithFrameIndex(int index) const
 int FrameTableModel::getRowWithFrameName(const QString& name) const
 {
   int row = 0;
-  for (QVector<FrameCollection::iterator>::const_iterator it =
-       m_frameOfRow.constBegin();
-       it != m_frameOfRow.constEnd();
-       ++it) {
+  for (auto it = m_frameOfRow.constBegin(); it != m_frameOfRow.constEnd(); ++it) {
     if ((*it)->getName() == name) {
       return row;
     }
@@ -526,10 +464,7 @@ FrameFilter FrameTableModel::getEnabledFrameFilter(
   bool allDisabled = true;
   int numberRows = rowCount();
   int row = 0;
-  for (QVector<FrameCollection::iterator>::const_iterator it =
-       m_frameOfRow.constBegin();
-       it != m_frameOfRow.constEnd();
-       ++it) {
+  for (auto it = m_frameOfRow.constBegin(); it != m_frameOfRow.constEnd(); ++it) {
     if (row >= numberRows) break;
     if (!m_frameSelected.at(row)) {
       filter.enable((*it)->getType(), (*it)->getName(), false);
@@ -553,10 +488,7 @@ FrameCollection FrameTableModel::getEnabledFrames() const
   FrameCollection enabledFrames;
   const int numberRows = m_frameSelected.size();
   int row = 0;
-  for (QVector<FrameCollection::iterator>::const_iterator it =
-       m_frameOfRow.constBegin();
-       it != m_frameOfRow.constEnd();
-       ++it) {
+  for (auto it = m_frameOfRow.constBegin(); it != m_frameOfRow.constEnd(); ++it) {
     if (row >= numberRows) break;
     if (m_frameSelected.at(row)) {
       enabledFrames.insert(**it);
@@ -608,6 +540,32 @@ void FrameTableModel::transferFrames(FrameCollection& src)
     emit dataChanged(index(0, 0), index(numRowsChanged - 1, CI_NumColumns - 1));
 }
 
+/**
+ * Start filtering different values.
+ */
+void FrameTableModel::beginFilterDifferent()
+{
+  m_differentValues.clear();
+}
+
+/**
+ * End filtering different values.
+ */
+void FrameTableModel::endFilterDifferent()
+{
+}
+
+/**
+ * Get the different values which have been filtered for a frame type.
+ * @param type frame type
+ * @return different values.
+ */
+QSet<QString> FrameTableModel::getCompletionsForType(
+    Frame::ExtendedType type) const
+{
+  return m_differentValues.value(type);
+}
+
 /**
  * Set values which are different inactive.
  *
@@ -617,7 +575,7 @@ void FrameTableModel::filterDifferent(FrameCollection& others)
 {
   int oldNumFrames = m_frames.size();
 
-  m_frames.filterDifferent(others);
+  m_frames.filterDifferent(others, &m_differentValues);
   updateFrameRowMapping();
   resizeFrameSelected();
 
@@ -663,10 +621,9 @@ void FrameTableModel::deselectAllFrames()
  */
 void FrameTableModel::selectChangedFrames()
 {
-  int row;
-  QVector<FrameCollection::iterator>::const_iterator it;
-  for (row = 0, it = m_frameOfRow.constBegin();
-       row < m_frameSelected.size() && it != m_frameOfRow.constEnd();
+  int row = 0;
+  auto it = m_frameOfRow.constBegin();
+  for (; row < m_frameSelected.size() && it != m_frameOfRow.constEnd();
        ++row, ++it) {
     if ((*it)->isValueChanged()) {
       m_frameSelected[row] = true;
@@ -703,16 +660,24 @@ void FrameTableModel::updateFrameRowMapping()
 {
   const FrameCollection& frameCollection = frames();
   m_frameOfRow.resize(frameCollection.size());
-  FrameCollection::iterator frameIt;
-  QVector<FrameCollection::iterator>::iterator rowIt;
-  for (frameIt = frameCollection.begin(), rowIt = m_frameOfRow.begin();
-       frameIt != frameCollection.end();
-       ++frameIt, ++rowIt) {
+  auto frameIt = frameCollection.cbegin();
+  auto rowIt = m_frameOfRow.begin(); // clazy:exclude=detaching-member
+  for (; frameIt != frameCollection.cend(); ++frameIt, ++rowIt) {
     *rowIt = frameIt;
   }
   if (!m_frameTypeSeqNr.isEmpty()) {
-    std::stable_sort(m_frameOfRow.begin(), m_frameOfRow.end(),
-                     FrameLessThan(m_frameTypeSeqNr));
+    const QVector<int>& frameTypeSeqNr = m_frameTypeSeqNr;
+    std::stable_sort(m_frameOfRow.begin(), m_frameOfRow.end(), // clazy:exclude=detaching-member
+                     [&frameTypeSeqNr](FrameCollection::iterator lhs,
+                                       FrameCollection::iterator rhs) {
+      int lhsType = lhs->getType();
+      int rhsType = rhs->getType();
+      int lhsSeqNr = frameTypeSeqNr.at(lhsType);
+      int rhsSeqNr = frameTypeSeqNr.at(rhsType);
+      return lhsSeqNr < rhsSeqNr ||
+             (lhsType == Frame::FT_Other && lhsType == rhsType &&
+              lhs->getInternalName() < rhs->getInternalName());
+    });
   }
 }
 
@@ -736,11 +701,9 @@ void FrameTableModel::setFrameOrder(const QList<int>& frameTypes)
   m_frameTypeSeqNr[Frame::FT_UnknownFrame] = Frame::FT_UnknownFrame;
   m_frameTypeSeqNr[Frame::FT_Other] = Frame::FT_Other;
 
-  int seqNr;
-  QList<int>::const_iterator it;
-  for (it = frameTypes.constBegin(), seqNr = 0;
-       it != frameTypes.constEnd();
-       ++it, ++seqNr) {
+  int seqNr = 0;
+  auto it = frameTypes.constBegin();
+  for (; it != frameTypes.constEnd(); ++it, ++seqNr) {
     int frameType = *it;
     if (frameType < 0 || frameType > Frame::FT_LastFrame) {
       qWarning("FrameTableModel::setFrameOrder: Invalid frame type %d",
