@@ -24,8 +24,7 @@
  * along with this program.  If not, see <http://www.gnu.org/licenses/>.
  */
 
-#ifndef FRAMETABLEMODEL_H
-#define FRAMETABLEMODEL_H
+#pragma once
 
 #include <QAbstractTableModel>
 #include <QVector>
@@ -63,19 +62,19 @@ public:
    * @param id3v1  true if model for ID3v1 frames
    * @param parent parent widget
    */
-  explicit FrameTableModel(bool id3v1, QObject* parent = 0);
+  explicit FrameTableModel(bool id3v1, QObject* parent = nullptr);
 
   /**
    * Destructor.
    */
-  virtual ~FrameTableModel();
+  virtual ~FrameTableModel() override = default;
 
   /**
    * Get item flags for index.
    * @param index model index
    * @return item flags
    */
-  virtual Qt::ItemFlags flags(const QModelIndex& index) const;
+  virtual Qt::ItemFlags flags(const QModelIndex& index) const override;
 
   /**
    * Get data for a given role.
@@ -84,7 +83,7 @@ public:
    * @return data for role
    */
   virtual QVariant data(const QModelIndex& index,
-                        int role=Qt::DisplayRole) const;
+                        int role = Qt::DisplayRole) const override;
 
   /**
    * Set data for a given role.
@@ -94,7 +93,7 @@ public:
    * @return true if successful
    */
   virtual bool setData(const QModelIndex& index, const QVariant& value,
-                       int role=Qt::EditRole);
+                       int role = Qt::EditRole) override;
 
   /**
    * Get data for header section.
@@ -104,7 +103,7 @@ public:
    * @return header data for role
    */
   virtual QVariant headerData(int section, Qt::Orientation orientation,
-                              int role=Qt::DisplayRole) const;
+                              int role = Qt::DisplayRole) const override;
 
   /**
    * Set data for header section.
@@ -112,7 +111,7 @@ public:
    * @return false
    */
   virtual bool setHeaderData(int, Qt::Orientation, const QVariant&,
-                             int=Qt::EditRole) { return false; }
+                             int = Qt::EditRole) override { return false; }
 
   /**
    * Get number of rows.
@@ -120,7 +119,7 @@ public:
    * @return number of rows,
    * if parent is valid number of children (0 for table models)
    */
-  virtual int rowCount(const QModelIndex& parent=QModelIndex()) const;
+  virtual int rowCount(const QModelIndex& parent = QModelIndex()) const override;
 
   /**
    * Get number of columns.
@@ -128,7 +127,7 @@ public:
    * @return number of columns,
    * if parent is valid number of children (0 for table models)
    */
-  virtual int columnCount(const QModelIndex& parent=QModelIndex()) const;
+  virtual int columnCount(const QModelIndex& parent = QModelIndex()) const override;
 
   /**
    * Remove rows.
@@ -138,7 +137,7 @@ public:
    * @return true if successful
    */
   virtual bool removeRows(int row, int count,
-                          const QModelIndex& parent=QModelIndex());
+                          const QModelIndex& parent = QModelIndex()) override;
 
   /**
    * Insert rows.
@@ -149,15 +148,13 @@ public:
    * @return true if successful
    */
   virtual bool insertRows(int row, int count,
-                          const QModelIndex& parent=QModelIndex());
+                          const QModelIndex& parent = QModelIndex()) override;
 
-#if QT_VERSION >= 0x050000
   /**
    * Map role identifiers to role property names in scripting languages.
    * @return hash mapping role identifiers to names.
    */
-  virtual QHash<int,QByteArray> roleNames() const;
-#endif
+  virtual QHash<int,QByteArray> roleNames() const override;
 
   /**
    * Insert a frame.
@@ -244,6 +241,11 @@ public:
    */
   void transferFrames(FrameCollection& src);
 
+  /**
+   * Start filtering different values.
+   */
+  void beginFilterDifferent();
+
   /**
    * Set values which are different inactive.
    *
@@ -251,6 +253,18 @@ public:
    */
   void filterDifferent(FrameCollection& others);
 
+  /**
+   * End filtering different values.
+   */
+  void endFilterDifferent();
+
+  /**
+   * Get the different values which have been filtered for a frame type.
+   * @param type frame type
+   * @return different values.
+   */
+  QSet<QString> getCompletionsForType(Frame::ExtendedType type) const;
+
 public slots:
   /**
    * Select all frames in the table.
@@ -304,9 +318,8 @@ private:
   quint64 m_changedFrames;
   FrameCollection m_frames;
   QVector<FrameCollection::iterator> m_frameOfRow;
+  QHash<Frame::ExtendedType, QSet<QString>> m_differentValues;
   QVector<int> m_frameTypeSeqNr;
   bool m_id3v1;
   bool m_guiApp;
 };
-
-#endif // FRAMETABLEMODEL_H
