@@ -6,7 +6,7 @@
  * \author Urs Fleisch
  * \date 10 Jul 2011
  *
- * Copyright (C) 2011-2017  Urs Fleisch
+ * Copyright (C) 2011-2018  Urs Fleisch
  *
  * This file is part of Kid3.
  *
@@ -24,26 +24,24 @@
  * along with this program.  If not, see <http://www.gnu.org/licenses/>.
  */
 
-#ifndef KID3APPLICATION_H
-#define KID3APPLICATION_H
+#pragma once
 
 #include <QObject>
 #include <QPersistentModelIndex>
-#include <QUrl>
+#include <QScopedPointer>
 #include "frame.h"
 #include "trackdata.h"
-#include "filefilter.h"
 #include "tagsearcher.h"
 #include "generalconfig.h"
 #include "config.h"
 
-class QFileIconProvider;
-class QFileSystemModel;
 class QItemSelectionModel;
 class QItemSelection;
 class QModelIndex;
 class QNetworkAccessManager;
 class QDir;
+class QUrl;
+class FileSystemModel;
 class FileProxyModel;
 class FileProxyModelIterator;
 class DirProxyModel;
@@ -53,6 +51,7 @@ class FrameTableModel;
 class TaggedFileSelection;
 class ConfigStore;
 class PlaylistConfig;
+class PlaylistModel;
 class DownloadClient;
 class TaggedFile;
 class FrameList;
@@ -68,11 +67,10 @@ class Kid3ApplicationTagContext;
 class IAbortable;
 class ICorePlatformTools;
 class IUserCommandProcessor;
-#if defined HAVE_PHONON || QT_VERSION >= 0x050000
 class AudioPlayer;
-#endif
 class PixmapProvider;
 class FrameEditorObject;
+class FileFilter;
 
 /**
  * Kid3 application logic, independent of GUI.
@@ -137,12 +135,12 @@ public:
    * @param parent parent object
    */
   explicit Kid3Application(ICorePlatformTools* platformTools,
-                           QObject* parent = 0);
+                           QObject* parent = nullptr);
 
   /**
    * Destructor.
    */
-  virtual ~Kid3Application();
+  virtual ~Kid3Application() override;
 
 #ifdef HAVE_QTDBUS
   /**
@@ -156,7 +154,7 @@ public:
   * Get file system model.
   * @return file system model.
   */
-  QFileSystemModel* getFileSystemModel() { return m_fileSystemModel; }
+  FileSystemModel* getFileSystemModel() { return m_fileSystemModel; }
 
  /**
   * Get file proxy model.
@@ -292,7 +290,6 @@ public:
    */
   BatchImporter* getBatchImporter() { return m_batchImporter; }
 
-#if defined HAVE_PHONON || QT_VERSION >= 0x050000
   /**
    * Get audio player.
    * This method will create an audio player if it does not already exist.
@@ -306,9 +303,7 @@ public:
    * Delete audio player.
    */
   void deleteAudioPlayer();
-#endif
 
-#if QT_VERSION >= 0x050000
   /**
    * Get context for tag.
    * @param tagNr tag number
@@ -317,16 +312,6 @@ public:
   Q_INVOKABLE Kid3ApplicationTagContext* tag(Frame::TagNumber tagNr) const {
     return m_tagContext[tagNr];
   }
-#else
-  /**
-   * Get context for tag.
-   * @param tagNr tag number, for Qt 4 an int to be usable in QML
-   * @return tag context.
-   */
-  Q_INVOKABLE Kid3ApplicationTagContext* tag(int tagNr) const {
-    return m_tagContext[tagNr];
-  }
-#endif
 
   /**
    * Get current index in file proxy model or root index if current index is
@@ -384,6 +369,26 @@ public:
    */
   QString getDirPath() const;
 
+  /**
+   * Handle drop of URLs.
+   *
+   * @param urlList picture, tagged file and folder URLs to handle (if local)
+   * @param isInternal true if this is an internal drop
+   */
+  void dropUrls(const QList<QUrl>& urlList, bool isInternal);
+
+  /**
+   * Open directory after resetting the file system model.
+   * When finished directoryOpened() is emitted, also if false is returned.
+   *
+   * @param paths file or directory paths, if multiple paths are given, the
+   * common directory is opened and the files are selected, if empty, the
+   * currently open directory is reopened
+   *
+   * @return true if ok.
+   */
+  bool openDirectoryAfterReset(const QStringList& paths = QStringList());
+
   /**
    * Save all changed files.
    * longRunningOperationProgress() is emitted while saving files.
@@ -463,6 +468,14 @@ public:
    */
   bool writePlaylist(const PlaylistConfig& cfg);
 
+  /**
+   * Write empty playlist.
+   * @param cfg playlist configuration to use
+   * @param fileName file name for playlist
+   * @return true if ok.
+   */
+  bool writeEmptyPlaylist(const PlaylistConfig& cfg, const QString& fileName);
+
   /**
    * Write playlist using current playlist configuration.
    *
@@ -470,6 +483,40 @@ public:
    */
   Q_INVOKABLE bool writePlaylist();
 
+  /**
+   * Get items of a playlist.
+   * @param path path to playlist file
+   * @return list of absolute paths to playlist items.
+   */
+  Q_INVOKABLE QStringList getPlaylistItems(const QString& path);
+
+  /**
+   * Set items of a playlist.
+   * @param path path to playlist file
+   * @param items list of absolute paths to playlist items
+   * @return true if ok, false if not all @a items were found and added or
+   *         saving failed.
+   */
+  Q_INVOKABLE bool setPlaylistItems(const QString& path, const QStringList& items);
+
+  /**
+   * Get playlist model for a play list file.
+   * @param path path to playlist file
+   * @return playlist model.
+   */
+  PlaylistModel* playlistModel(const QString& path);
+
+  /**
+   * Check if any playlist model has unsaved modifications.
+   * @return true if there is a modified playlist model.
+   */
+  bool hasModifiedPlaylistModel() const;
+
+  /**
+   * Save all modified playlist models.
+   */
+  void saveModifiedPlaylistModels();
+
   /**
    * Perform rename actions and change application directory afterwards if it
    * was renamed.
@@ -522,7 +569,7 @@ public:
    * @param options options for numbering operation
    */
   Q_INVOKABLE void numberTracks(int nr, int total, Frame::TagVersion tagVersion,
-                                NumberTrackOptions options = 0);
+                                Kid3Application::NumberTrackOptions options = nullptr);
 
   /**
    * Set track data with tagged files of directory.
@@ -595,6 +642,8 @@ public:
    * @param tagMask tag bit (1 for tag 1, 2 for tag 2)
    * @param name    name of frame (e.g. "artist")
    * @param value   value of frame
+   *
+   * @return true if ok.
    */
   Q_INVOKABLE bool setFrame(Frame::TagVersion tagMask, const QString& name,
                             const QString& value);
@@ -800,6 +849,29 @@ public:
    */
   Q_INVOKABLE void setCoverArtImageData(const QByteArray& picture);
 
+  /**
+   * Open a file select dialog to get a file name.
+   * For script support, is only supported when a GUI is available.
+   * @param caption dialog caption
+   * @param dir working directory
+   * @param filter file type filter
+   * @param saveFile true to open a save file dialog
+   * @return selected file, empty if canceled.
+   */
+  Q_INVOKABLE QString selectFileName(
+      const QString& caption = QString(), const QString& dir = QString(),
+      const QString& filter = QString(), bool saveFile = false);
+
+  /**
+   * Open a file select dialog to get a directory name.
+   * For script support, is only supported when a GUI is available.
+   * @param caption dialog caption
+   * @param dir working directory
+   * @return selected directory, empty if canceled.
+   */
+  Q_INVOKABLE QString selectDirName(
+      const QString& caption = QString(), const QString& dir = QString());
+
   /**
    * Notify the tagged file factories about the changed configuration.
    */
@@ -840,6 +912,13 @@ public slots:
    */
   void openDropUrls(const QList<QUrl>& urlList);
 
+  /**
+   * Unload all tags.
+   * The tags of all files which are not modified or selected are freed to
+   * reclaim their memory.
+   */
+  void unloadAllTags();
+
   /**
    * Revert file modifications.
    * Acts on selected files or all files if no file is selected.
@@ -902,13 +981,6 @@ public slots:
    */
   void copyToOtherTag(Frame::TagVersion tagMask);
 
-  /**
-   * Copy tags using QAction::data().
-   * The source and destination tag numbers are taken from the first two bytes
-   * in QAction::data().toByteArray() if the sender() is a QAction.
-   */
-  void copyTagsActionData();
-
   /**
    * Copy from a tag to another tag.
    * @param srcTagNr source tag number
@@ -1043,7 +1115,7 @@ public slots:
    * Fetch entries of directory if not already fetched.
    * This works like FileList::expand(), but without expanding tree view
    * items and independent of the GUI. The processing is done in the background
-   * by QFileSystemModel, so the fetched items are not immediately available
+   * by FileSystemModel, so the fetched items are not immediately available
    * after calling this method.
    *
    * @param index index of directory item
@@ -1134,7 +1206,6 @@ public slots:
    */
   bool batchImport(const QString& profileName, Frame::TagVersion tagVersion);
 
-#if defined HAVE_PHONON || QT_VERSION >= 0x050000
   /**
    * Play audio file.
    */
@@ -1155,7 +1226,6 @@ public slots:
    * Deactivate the MPRIS D-Bus Interface if it is active.
    */
   void deactivateMprisInterface();
-#endif
 #endif
 
   /**
@@ -1375,6 +1445,14 @@ private slots:
    */
   void onFrameAdded(const Frame* frame, Frame::TagNumber tagNr = Frame::Tag_2);
 
+  /**
+   * Called by framelist when a frame is added.
+   * Same as onFrameAdded() with default argument, provided for functor-based
+   * connections.
+   * @param frame added frame, 0 if canceled
+   */
+  void onTag2FrameAdded(const Frame* frame);
+
   /**
    * If an image provider is used, update its picture and change the
    * coverArtImageId property if the picture of the selection changed.
@@ -1414,18 +1492,12 @@ private:
   void addFrame(Frame::TagNumber tagNr, const Frame* frame, bool edit = false);
 
   /**
-   * Open directory after resetting the file system model.
-   * This will create a new file system model and reset the file and directory
-   * proxy models.
-   * When finished directoryOpened() is emitted, also if false is returned.
+   * Open directory or add pictures on drop.
    *
-   * @param paths file or directory paths, if multiple paths are given, the
-   * common directory is opened and the files are selected, if empty, the
-   * currently open directory is reopened
-   *
-   * @return true if ok.
+   * @param paths paths of directories or files in directory
+   * @param isInternal true if this is an internal drop
    */
-  bool openDirectoryAfterReset(const QStringList& paths = QStringList());
+  void dropLocalFiles(const QStringList& paths, bool isInternal);
 
   /**
    * Second stage for applyFilter().
@@ -1442,11 +1514,9 @@ private:
 
   ICorePlatformTools* m_platformTools;
   /** Configuration */
-  ConfigStore* m_configStore;
+  QScopedPointer<ConfigStore> m_configStore;
   /** model of filesystem */
-  QFileIconProvider* m_defaultFileIconProvider;
-  QFileIconProvider* m_fileIconProvider;
-  QFileSystemModel* m_fileSystemModel;
+  FileSystemModel* m_fileSystemModel;
   FileProxyModel* m_fileProxyModel;
   FileProxyModelIterator* m_fileProxyModelIterator;
   DirProxyModel* m_dirProxyModel;
@@ -1457,6 +1527,7 @@ private:
   GenreModel* m_genreModel[Frame::Tag_NumValues];
   FrameTableModel* m_framesModel[Frame::Tag_NumValues];
   QItemSelectionModel* m_framesSelectionModel[Frame::Tag_NumValues];
+  QMap<QString, PlaylistModel*> m_playlistModels;
   /** Frame list */
   FrameList* m_framelist[Frame::Tag_NumValues];
   /** Tag context */
@@ -1473,12 +1544,10 @@ private:
   DirRenamer* m_dirRenamer;
   /** Batch importer */
   BatchImporter* m_batchImporter;
-#if defined HAVE_PHONON || QT_VERSION >= 0x050000
   /** Audio player */
   AudioPlayer* m_player;
 #ifdef HAVE_QTDBUS
   QString m_mprisServiceName;
-#endif
 #endif
   FileFilter* m_expressionFileFilter;
   /** Information about selected tagged files */
@@ -1512,7 +1581,7 @@ private:
   int m_filterPassed;
   int m_filterTotal;
   /* Context for batchImportNextFile() */
-  BatchImportProfile* m_namedBatchImportProfile;
+  QScopedPointer<BatchImportProfile> m_namedBatchImportProfile;
   const BatchImportProfile* m_batchImportProfile;
   Frame::TagVersion m_batchImportTagVersion;
   QList<ImportTrackDataVector> m_batchImportAlbums;
@@ -1568,9 +1637,9 @@ public:
    * @param app application
    * @param tagNr tag number
    */
-  Kid3ApplicationTagContext(Kid3Application* app, Frame::TagNumber tagNr) :
-    QObject(app), m_app(app), m_tagNr(tagNr),
-    m_tagVersion(Frame::tagVersionFromNumber(tagNr)) {
+  Kid3ApplicationTagContext(Kid3Application* app, Frame::TagNumber tagNr)
+    : QObject(app), m_app(app), m_tagNr(tagNr),
+      m_tagVersion(Frame::tagVersionFromNumber(tagNr)) {
   }
 
 public slots:
@@ -1648,5 +1717,3 @@ private:
   const Frame::TagNumber m_tagNr;
   const Frame::TagVersion m_tagVersion;
 };
-
-#endif // KID3APPLICATION_H
