@@ -6,7 +6,7 @@
  * \author Urs Fleisch
  * \date 21 Jun 2014
  *
- * Copyright (C) 2014  Urs Fleisch
+ * Copyright (C) 2014-2018  Urs Fleisch
  *
  * This file is part of Kid3.
  *
@@ -32,15 +32,8 @@
  * Constructor.
  * @param iconProvider icon provider to use
  */
-PixmapProvider::PixmapProvider(TaggedFileIconProvider* iconProvider) :
-  m_fileIconProvider(iconProvider), m_pixmapHash(0)
-{
-}
-
-/**
- * Destructor.
- */
-PixmapProvider::~PixmapProvider()
+PixmapProvider::PixmapProvider(TaggedFileIconProvider* iconProvider)
+  : m_fileIconProvider(iconProvider), m_pixmapHash(0)
 {
 }
 
