@@ -6,7 +6,7 @@
  * \author Urs Fleisch
  * \date 29-Mar-2011
  *
- * Copyright (C) 2011  Urs Fleisch
+ * Copyright (C) 2011-2018  Urs Fleisch
  *
  * This file is part of Kid3.
  *
@@ -27,16 +27,14 @@
 #include "taggedfileiconprovider.h"
 #include <QPixmap>
 #include <QPainter>
-#include <QApplication>
-#include <QStyle>
 #include "taggedfile.h"
 #include "tagconfig.h"
 
 /**
  * Constructor.
  */
-TaggedFileIconProvider::TaggedFileIconProvider() :
-  m_requestedSize(16, 16)
+TaggedFileIconProvider::TaggedFileIconProvider()
+  : m_requestedSize(16, 16)
 {
 }
 
@@ -66,12 +64,12 @@ void TaggedFileIconProvider::createIcons()
     const char* text1;
     const char* text2;
   } idTexts[] = {
-    {"null", 0, 0},
+    {"null", nullptr, nullptr},
     {"notag", "NO", "TAG" },
     {"v1v2", "V1", "V2"},
-    {"v1", "V1", 0},
-    {"v2", 0, "V2"},
-    {"v3", 0, "V3"},
+    {"v1", "V1", nullptr},
+    {"v2", nullptr, "V2"},
+    {"v3", nullptr, "V3"},
     {"v1v3", "V1", "V3"},
     {"v2v3", "V2", "V3"},
     {"v1v2v3", "V1", "23"}
@@ -82,16 +80,10 @@ void TaggedFileIconProvider::createIcons()
   QFont font(QLatin1String("helvetica"));
   font.setPixelSize(halfHeight);
   QFont smallFont(font);
-  smallFont.setStretch(
-#if QT_VERSION >= 0x050000
-        QFont::Condensed
-#else
-        QFont::SemiCondensed
-#endif
-        );
-  for (unsigned i = 0; i < sizeof(idTexts) / sizeof(idTexts[0]); ++i) {
-    const char* text1 = idTexts[i].text1;
-    const char* text2 = idTexts[i].text2;
+  smallFont.setStretch(QFont::Condensed);
+  for (const auto& it : idTexts) {
+    const char* text1 = it.text1;
+    const char* text2 = it.text2;
 
     QPixmap pixmap(m_requestedSize);
     pixmap.fill(Qt::transparent);
@@ -113,19 +105,17 @@ void TaggedFileIconProvider::createIcons()
       painter.drawText(QPoint(3, height - 1), QLatin1String(text2));
     }
 
-    m_pixmapMap.insert(idTexts[i].id, pixmap);
+    m_pixmapMap.insert(it.id, pixmap);
   }
 
-  for (QMap<QByteArray, QPixmap>::const_iterator it = m_pixmapMap.constBegin();
-       it != m_pixmapMap.constEnd();
-       ++it) {
+  for (auto it = m_pixmapMap.constBegin(); it != m_pixmapMap.constEnd(); ++it) {
     m_iconMap.insert(it.key(), QIcon(it.value()));
   }
 
-  QIcon modifiedIcon =
-      QApplication::style()->standardIcon(QStyle::SP_DriveFDIcon);
-  m_iconMap.insert("modified", modifiedIcon);
-  m_pixmapMap.insert("modified", modifiedIcon.pixmap(m_requestedSize));
+  if (!m_modifiedIcon.isNull()) {
+    m_iconMap.insert("modified", m_modifiedIcon);
+    m_pixmapMap.insert("modified", m_modifiedIcon.pixmap(m_requestedSize));
+  }
 }
 
 /**
