@@ -6,7 +6,7 @@
  * \author Urs Fleisch
  * \date 19 Jun 2014
  *
- * Copyright (C) 2014  Urs Fleisch
+ * Copyright (C) 2014-2018  Urs Fleisch
  *
  * This file is part of Kid3.
  *
@@ -50,13 +50,6 @@ TaggedFileSelection::TaggedFileSelection(
   setObjectName(QLatin1String("TaggedFileSelection"));
 }
 
-/**
- * Destructor.
- */
-TaggedFileSelection::~TaggedFileSelection()
-{
-}
-
 /**
  * Start adding tagged files to selection.
  * Has to be called before adding the first file using addTaggedFile().
@@ -64,11 +57,12 @@ TaggedFileSelection::~TaggedFileSelection()
 void TaggedFileSelection::beginAddTaggedFiles()
 {
   m_lastState = m_state;
-  m_state.m_singleFile = 0;
+  m_state.m_singleFile = nullptr;
   m_state.m_fileCount = 0;
   FOR_ALL_TAGS(tagNr) {
     m_state.m_tagSupportedCount[tagNr] = 0;
     m_state.m_hasTag[tagNr] = false;
+    m_framesModel[tagNr]->beginFilterDifferent();
   }
 }
 
@@ -81,6 +75,7 @@ void TaggedFileSelection::endAddTaggedFiles()
   FOR_ALL_TAGS(tagNr) {
     m_framesModel[tagNr]->setAllCheckStates(
           m_state.m_tagSupportedCount[tagNr] == 1);
+    m_framesModel[tagNr]->endFilterDifferent();
   }
   if (GuiConfig::instance().autoHideTags()) {
     // If a tag is supposed to be absent, make sure that there is really no
@@ -90,9 +85,7 @@ void TaggedFileSelection::endAddTaggedFiles()
           (m_state.m_tagSupportedCount[tagNr] > 0 ||
            m_state.m_fileCount == 0)) {
         const FrameCollection& frames = m_framesModel[tagNr]->frames();
-        for (FrameCollection::const_iterator it = frames.begin();
-             it != frames.end();
-             ++it) {
+        for (auto it = frames.cbegin(); it != frames.cend(); ++it) {
           if (!(*it).getValue().isEmpty()) {
             m_state.m_hasTag[tagNr] = true;
             break;
@@ -157,7 +150,7 @@ void TaggedFileSelection::addTaggedFile(TaggedFile* taggedFile)
       ++m_state.m_tagSupportedCount[tagNr];
     }
   }
-  m_state.m_singleFile = m_state.m_fileCount == 0 ? taggedFile : 0;
+  m_state.m_singleFile = m_state.m_fileCount == 0 ? taggedFile : nullptr;
   ++m_state.m_fileCount;
 
   FOR_ALL_TAGS(tagNr) {
@@ -262,9 +255,9 @@ QByteArray TaggedFileSelection::getPicture() const
 {
   QByteArray data;
   const FrameCollection& frames = m_framesModel[Frame::Tag_Picture]->frames();
-  FrameCollection::const_iterator it = frames.find(
+  auto it = frames.find(
         Frame(Frame::FT_Picture, QLatin1String(""), QLatin1String(""), -1));
-  if (it != frames.end() && !it->isInactive()) {
+  if (it != frames.cend() && !it->isInactive()) {
     PictureFrame::getData(*it, data);
   }
   return data;
