@@ -6,7 +6,7 @@
  * \author Urs Fleisch
  * \date 12 Aug 2011
  *
- * Copyright (C) 2011-2017  Urs Fleisch
+ * Copyright (C) 2011-2018  Urs Fleisch
  *
  * This file is part of Kid3.
  *
@@ -31,19 +31,12 @@
  * Constructor.
  * @param parent parent widget
  */
-TextTableModel::TextTableModel(QObject* parent) :
-  QAbstractTableModel(parent), m_hasHeaderLine(false)
+TextTableModel::TextTableModel(QObject* parent)
+  : QAbstractTableModel(parent), m_hasHeaderLine(false)
 {
   setObjectName(QLatin1String("TextTableModel"));
 }
 
-/**
- * Destructor.
- */
-TextTableModel::~TextTableModel()
-{
-}
-
 /**
  * Get item flags for index.
  * @param index model index
