@@ -6,7 +6,7 @@
  * \author Urs Fleisch
  * \date 14 Mar 2014
  *
- * Copyright (C) 2014-2017  Urs Fleisch
+ * Copyright (C) 2014-2018  Urs Fleisch
  *
  * This file is part of Kid3.
  *
@@ -25,28 +25,24 @@
  */
 
 #include "timeeventmodel.h"
-#include <QApplication>
+#include <QGuiApplication>
 #include <QTextStream>
+#include <QPalette>
+#include <QBrush>
 #include "eventtimingcode.h"
 
 /**
  * Constructor.
  * @param parent parent widget
  */
-TimeEventModel::TimeEventModel(QObject* parent) :
-  QAbstractTableModel(parent), m_type(SynchronizedLyrics), m_markedRow(-1),
-  m_guiApp(qobject_cast<QApplication*>(QCoreApplication::instance()) != 0)
+TimeEventModel::TimeEventModel(QObject* parent)
+  : QAbstractTableModel(parent), m_type(SynchronizedLyrics), m_markedRow(-1),
+    m_guiApp(qobject_cast<QGuiApplication*>(QCoreApplication::instance())
+             != nullptr)
 {
   setObjectName(QLatin1String("TimeEventModel"));
 }
 
-/**
- * Destructor.
- */
-TimeEventModel::~TimeEventModel()
-{
-}
-
 /**
  * Get item flags for index.
  * @param index model index
@@ -80,8 +76,8 @@ QVariant TimeEventModel::data(const QModelIndex& index, int role) const
       return timeEvent.data;
   } else if (role == Qt::BackgroundColorRole && index.column() == CI_Data) {
     return index.row() != m_markedRow ? Qt::NoBrush
-                                      : m_guiApp ? QApplication::palette().mid()
-                                                 : QBrush(Qt::gray);
+                                   : m_guiApp ? QGuiApplication::palette().mid()
+                                              : QBrush(Qt::gray);
   }
   return QVariant();
 }
@@ -100,7 +96,7 @@ bool TimeEventModel::setData(const QModelIndex& index,
       index.row() < 0 || index.row() >= m_timeEvents.size() ||
       index.column() < 0 || index.column() >= CI_NumColumns)
     return false;
-  TimeEvent& timeEvent = m_timeEvents[index.row()];
+  TimeEvent& timeEvent = m_timeEvents[index.row()]; // clazy:exclude=detaching-member
   if (index.column() == CI_Time) {
     timeEvent.time = value.toTime();
   } else {
@@ -223,9 +219,7 @@ void TimeEventModel::fromSyltFrame(const Frame::FieldList& fields)
 {
   QVariantList synchedData;
   bool unitIsFrames = false;
-  for (Frame::FieldList::const_iterator it = fields.constBegin();
-       it != fields.constEnd();
-       ++it) {
+  for (auto it = fields.constBegin(); it != fields.constEnd(); ++it) {
     const Frame::Field& fld = *it;
     if (fld.m_id == Frame::ID_TimestampFormat) {
       unitIsFrames = fld.m_value.toInt() == 1;
@@ -287,11 +281,9 @@ void TimeEventModel::fromSyltFrame(const Frame::FieldList& fields)
  */
 void TimeEventModel::toSyltFrame(Frame::FieldList& fields) const
 {
-  Frame::FieldList::iterator timeStampFormatIt = fields.end();
-  Frame::FieldList::iterator dataIt = fields.end();
-  for (Frame::FieldList::iterator it = fields.begin();
-       it != fields.end();
-       ++it) {
+  auto timeStampFormatIt = fields.end();
+  auto dataIt = fields.end();
+  for (auto it = fields.begin(); it != fields.end(); ++it) {
     if (it->m_id == Frame::ID_TimestampFormat) {
       timeStampFormatIt = it;
     } else if (it->m_value.type() == QVariant::List) {
@@ -301,7 +293,8 @@ void TimeEventModel::toSyltFrame(Frame::FieldList& fields) const
 
   QVariantList synchedData;
   bool hasMsTimeStamps = false;
-  foreach (const TimeEvent& timeEvent, m_timeEvents) {
+  const auto timeEvents = m_timeEvents;
+  for (const TimeEvent& timeEvent : timeEvents) {
     if (!timeEvent.time.isNull()) {
       QString str = timeEvent.data.toString();
       // Remove escaping, restore new line characters.
@@ -342,9 +335,7 @@ void TimeEventModel::fromEtcoFrame(const Frame::FieldList& fields)
 {
   QVariantList synchedData;
   bool unitIsFrames = false;
-  for (Frame::FieldList::const_iterator it = fields.constBegin();
-       it != fields.constEnd();
-       ++it) {
+  for (auto it = fields.constBegin(); it != fields.constEnd(); ++it) {
     const Frame::Field& fld = *it;
     if (fld.m_id == Frame::ID_TimestampFormat) {
       unitIsFrames = fld.m_value.toInt() == 1;
@@ -375,11 +366,9 @@ void TimeEventModel::fromEtcoFrame(const Frame::FieldList& fields)
  */
 void TimeEventModel::toEtcoFrame(Frame::FieldList& fields) const
 {
-  Frame::FieldList::iterator timeStampFormatIt = fields.end();
-  Frame::FieldList::iterator dataIt = fields.end();
-  for (Frame::FieldList::iterator it = fields.begin();
-       it != fields.end();
-       ++it) {
+  auto timeStampFormatIt = fields.end();
+  auto dataIt = fields.end();
+  for (auto it = fields.begin(); it != fields.end(); ++it) {
     if (it->m_id == Frame::ID_TimestampFormat) {
       timeStampFormatIt = it;
     } else if (it->m_value.type() == QVariant::List) {
@@ -389,7 +378,8 @@ void TimeEventModel::toEtcoFrame(Frame::FieldList& fields) const
 
   QVariantList synchedData;
   bool hasMsTimeStamps = false;
-  foreach (const TimeEvent& timeEvent, m_timeEvents) {
+  const auto timeEvents = m_timeEvents;
+  for (const TimeEvent& timeEvent : timeEvents) {
     if (!timeEvent.time.isNull()) {
       int code = timeEvent.data.toInt();
 
@@ -422,9 +412,7 @@ void TimeEventModel::toEtcoFrame(Frame::FieldList& fields) const
 void TimeEventModel::markRowForTimeStamp(const QTime& timeStamp)
 {
   int row = 0, oldRow = m_markedRow, newRow = -1;
-  for (QList<TimeEvent>::const_iterator it = m_timeEvents.constBegin();
-       it != m_timeEvents.constEnd();
-       ++it) {
+  for (auto it = m_timeEvents.constBegin(); it != m_timeEvents.constEnd(); ++it) {
     const TimeEvent& timeEvent = *it;
     QTime time = timeEvent.time.toTime();
     if (time.isValid() && time >= timeStamp) {
@@ -473,7 +461,7 @@ void TimeEventModel::clearMarkedRow()
 void TimeEventModel::fromLrcFile(QTextStream& stream)
 {
   QRegExp timeStampRe(QLatin1String(
-                        "([[<])(\\d\\d):(\\d\\d)(?:\\.(\\d{1,3}))?([\\]>])"));
+                        R"(([[<])(\d\d):(\d\d)(?:\.(\d{1,3}))?([\]>]))"));
   QList<TimeEvent> timeEvents;
   bool isFirstLine = true;
   forever {
@@ -552,7 +540,8 @@ void TimeEventModel::fromLrcFile(QTextStream& stream)
             continue;
           }
         }
-        foreach (const QTime& time, emptyEvents) {
+        const auto times = emptyEvents;
+        for (const QTime& time : times) {
           timeEvents.append(TimeEvent(time, str));
         }
         timeEvents.append(TimeEvent(timeStamp, str));
@@ -603,7 +592,8 @@ void TimeEventModel::toLrcFile(QTextStream& stream, const QString& title,
     stream << QLatin1String("[al:") << album << QLatin1String("]\r\n");
     atBegin = false;
   }
-  foreach (const TimeEvent& timeEvent, m_timeEvents) {
+  const auto timeEvents = m_timeEvents;
+  for (const TimeEvent& timeEvent : timeEvents) {
     QTime time = timeEvent.time.toTime();
     if (time.isValid()) {
       char firstChar = '\0';
@@ -662,10 +652,10 @@ QString TimeEventModel::timeStampToString(const QTime& time)
   if (min < 0)  min = 0;
   if (sec < 0)  sec = 0;
   if (msec < 0) msec = 0;
-  QString text = QString(QLatin1String("%1:%2.%3")).
-      arg(min, 2, 10, QLatin1Char('0')).
-      arg(sec, 2, 10, QLatin1Char('0')).
-      arg(msec / 10, 2, 10, QLatin1Char('0'));
+  QString text = QString(QLatin1String("%1:%2.%3"))
+      .arg(min, 2, 10, QLatin1Char('0'))
+      .arg(sec, 2, 10, QLatin1Char('0'))
+      .arg(msec / 10, 2, 10, QLatin1Char('0'));
   if (hour != 0) {
     text.prepend(QString::number(hour) + QLatin1Char(':'));
   }
