@@ -6,7 +6,7 @@
  * \author Urs Fleisch
  * \date 14 Mar 2014
  *
- * Copyright (C) 2014  Urs Fleisch
+ * Copyright (C) 2014-2018  Urs Fleisch
  *
  * This file is part of Kid3.
  *
@@ -24,15 +24,15 @@
  * along with this program.  If not, see <http://www.gnu.org/licenses/>.
  */
 
-#ifndef TIMEEVENTMODEL_H
-#define TIMEEVENTMODEL_H
+#pragma once
 
 #include <QAbstractTableModel>
-#include <QHeaderView>
 #include <QTime>
 #include "frame.h"
 #include "kid3api.h"
 
+class QTextStream;
+
 /**
  * Time event model.
  */
@@ -73,19 +73,19 @@ public:
    * Constructor.
    * @param parent parent widget
    */
-  explicit TimeEventModel(QObject* parent = 0);
+  explicit TimeEventModel(QObject* parent = nullptr);
 
   /**
    * Destructor.
    */
-  virtual ~TimeEventModel();
+  virtual ~TimeEventModel() override = default;
 
   /**
    * Get item flags for index.
    * @param index model index
    * @return item flags
    */
-  virtual Qt::ItemFlags flags(const QModelIndex& index) const;
+  virtual Qt::ItemFlags flags(const QModelIndex& index) const override;
 
   /**
    * Get data for a given role.
@@ -94,7 +94,7 @@ public:
    * @return data for role
    */
   virtual QVariant data(const QModelIndex& index,
-                        int role=Qt::DisplayRole) const;
+                        int role = Qt::DisplayRole) const override;
 
   /**
    * Set data for a given role.
@@ -104,7 +104,7 @@ public:
    * @return true if successful
    */
   virtual bool setData(const QModelIndex& index, const QVariant& value,
-                       int role=Qt::EditRole);
+                       int role = Qt::EditRole) override;
 
   /**
    * Get data for header section.
@@ -114,7 +114,7 @@ public:
    * @return header data for role
    */
   virtual QVariant headerData(int section, Qt::Orientation orientation,
-                              int role=Qt::DisplayRole) const;
+                              int role = Qt::DisplayRole) const override;
 
   /**
    * Set data for header section.
@@ -122,7 +122,7 @@ public:
    * @return false
    */
   virtual bool setHeaderData(int, Qt::Orientation, const QVariant&,
-                             int=Qt::EditRole) { return false; }
+                             int = Qt::EditRole) override { return false; }
 
   /**
    * Get number of rows.
@@ -130,7 +130,7 @@ public:
    * @return number of rows,
    * if parent is valid number of children (0 for table models)
    */
-  virtual int rowCount(const QModelIndex& parent=QModelIndex()) const;
+  virtual int rowCount(const QModelIndex& parent = QModelIndex()) const override;
 
   /**
    * Get number of columns.
@@ -138,7 +138,7 @@ public:
    * @return number of columns,
    * if parent is valid number of children (0 for table models)
    */
-  virtual int columnCount(const QModelIndex& parent=QModelIndex()) const;
+  virtual int columnCount(const QModelIndex& parent = QModelIndex()) const override;
 
   /**
    * Insert rows.
@@ -149,7 +149,7 @@ public:
    * @return true if successful
    */
   virtual bool insertRows(int row, int count,
-                          const QModelIndex& parent=QModelIndex());
+                          const QModelIndex& parent = QModelIndex()) override;
 
   /**
    * Remove rows.
@@ -159,7 +159,7 @@ public:
    * @return true if successful
    */
   virtual bool removeRows(int row, int count,
-                          const QModelIndex& parent=QModelIndex());
+                          const QModelIndex& parent = QModelIndex()) override;
 
   /**
    * Set type of data.
@@ -265,5 +265,3 @@ private:
   QList<TimeEvent> m_timeEvents;
   bool m_guiApp;
 };
-
-#endif // TIMEEVENTMODEL_H
