@@ -32,19 +32,12 @@
  * Constructor.
  * @param parent parent widget
  */
-TrackDataModel::TrackDataModel(QObject* parent) :
-  QAbstractTableModel(parent), m_maxDiff(0), m_diffCheckEnabled(false)
+TrackDataModel::TrackDataModel(QObject* parent)
+  : QAbstractTableModel(parent), m_maxDiff(0), m_diffCheckEnabled(false)
 {
   setObjectName(QLatin1String("TrackDataModel"));
 }
 
-/**
- * Destructor.
- */
-TrackDataModel::~TrackDataModel()
-{
-}
-
 /**
  * Get item flags for index.
  * @param index model index
@@ -84,7 +77,7 @@ QVariant TrackDataModel::data(const QModelIndex& index, int role) const
   if (role == Qt::DisplayRole || role == Qt::EditRole) {
     const ImportTrackData& trackData = m_trackDataVector.at(index.row());
     Frame::ExtendedType type = m_frameTypes.at(index.column());
-    int typeOrProperty = static_cast<int>(type.getType());
+    auto typeOrProperty = static_cast<int>(type.getType());
     if (typeOrProperty < FT_FirstTrackProperty) {
       QString value(trackData.getValue(type));
       if (!value.isNull())
@@ -176,7 +169,7 @@ QVariant TrackDataModel::headerData(
     return QVariant();
   if (orientation == Qt::Horizontal && section < m_frameTypes.size()) {
     Frame::ExtendedType type = m_frameTypes.at(section);
-    int typeOrProperty = static_cast<int>(type.getType());
+    auto typeOrProperty = static_cast<int>(type.getType());
     if (typeOrProperty < FT_FirstTrackProperty) {
       return typeOrProperty == Frame::FT_Track
         ? tr("Track") // shorter header for track number
@@ -334,7 +327,7 @@ void TrackDataModel::setTimeDifferenceCheck(bool enable, int maxDiff) {
 int TrackDataModel::calculateAccuracy() const
 {
   int numImportTracks = 0, numTracks = 0, numMismatches = 0, numMatches = 0;
-  for (ImportTrackDataVector::const_iterator it = m_trackDataVector.constBegin();
+  for (auto it = m_trackDataVector.constBegin();
        it != m_trackDataVector.constEnd();
        ++it) {
     const ImportTrackData& trackData = *it;
@@ -391,15 +384,15 @@ const Frame* TrackDataModel::getFrameOfIndex(const QModelIndex& index) const
       index.row() >= static_cast<int>(m_trackDataVector.size()) ||
       index.column() < 0 ||
       index.column() >= static_cast<int>(m_frameTypes.size()))
-    return 0;
+    return nullptr;
 
   const ImportTrackData& trackData = m_trackDataVector.at(index.row());
   Frame::ExtendedType type = m_frameTypes.at(index.column());
   if (static_cast<int>(type.getType()) >= FT_FirstTrackProperty)
-    return 0;
+    return nullptr;
 
-  FrameCollection::const_iterator it = trackData.findByExtendedType(type);
-  return it != trackData.end() ? &(*it) : 0;
+  auto it = trackData.findByExtendedType(type);
+  return it != trackData.cend() ? &(*it) : nullptr;
 }
 
 /**
@@ -414,21 +407,17 @@ void TrackDataModel::setTrackData(const ImportTrackDataVector& trackDataVector)
     Frame::FT_Artist, Frame::FT_Album, Frame::FT_Date, Frame::FT_Genre,
     Frame::FT_Comment
   };
-  unsigned numStandardColumns =
-    sizeof(initFrameTypes) / sizeof(initFrameTypes[0]);
 
   QList<Frame::ExtendedType> newFrameTypes;
-  for (unsigned i = 0; i < numStandardColumns; ++i) {
-    newFrameTypes.append(
-        Frame::ExtendedType(static_cast<Frame::Type>(initFrameTypes[i]), QLatin1String("")));
+  for (auto initFrameType : initFrameTypes) {
+    newFrameTypes.append( // clazy:exclude=reserve-candidates
+        Frame::ExtendedType(static_cast<Frame::Type>(initFrameType), QLatin1String("")));
   }
 
-  for (ImportTrackDataVector::const_iterator tit = trackDataVector.constBegin();
+  for (auto tit = trackDataVector.constBegin();
        tit != trackDataVector.constEnd();
        ++tit) {
-    for (FrameCollection::const_iterator fit = tit->begin();
-         fit != tit->end();
-         ++fit) {
+    for (auto fit = tit->cbegin(); fit != tit->cend(); ++fit) {
       Frame::ExtendedType type = fit->getExtendedType();
       if (type.getType() > Frame::FT_LastV1Frame &&
           !newFrameTypes.contains(type)) {
