@@ -6,7 +6,7 @@
  * \author Urs Fleisch
  * \date 15 May 2011
  *
- * Copyright (C) 2011  Urs Fleisch
+ * Copyright (C) 2011-2018  Urs Fleisch
  *
  * This file is part of Kid3.
  *
@@ -24,8 +24,7 @@
  * along with this program.  If not, see <http://www.gnu.org/licenses/>.
  */
 
-#ifndef TRACKDATAMODEL_H
-#define TRACKDATAMODEL_H
+#pragma once
 
 #include <QAbstractTableModel>
 #include <QList>
@@ -51,19 +50,19 @@ public:
    * Constructor.
    * @param parent parent widget
    */
-  explicit TrackDataModel(QObject* parent = 0);
+  explicit TrackDataModel(QObject* parent = nullptr);
 
   /**
    * Destructor.
    */
-  virtual ~TrackDataModel();
+  virtual ~TrackDataModel() override = default;
 
   /**
    * Get item flags for index.
    * @param index model index
    * @return item flags
    */
-  virtual Qt::ItemFlags flags(const QModelIndex& index) const;
+  virtual Qt::ItemFlags flags(const QModelIndex& index) const override;
 
   /**
    * Get data for a given role.
@@ -72,7 +71,7 @@ public:
    * @return data for role
    */
   virtual QVariant data(const QModelIndex& index,
-                        int role=Qt::DisplayRole) const;
+                        int role = Qt::DisplayRole) const override;
 
   /**
    * Set data for a given role.
@@ -82,7 +81,7 @@ public:
    * @return true if successful
    */
   virtual bool setData(const QModelIndex& index, const QVariant& value,
-                       int role=Qt::EditRole);
+                       int role = Qt::EditRole) override;
 
   /**
    * Get data for header section.
@@ -92,7 +91,7 @@ public:
    * @return header data for role
    */
   virtual QVariant headerData(int section, Qt::Orientation orientation,
-                              int role=Qt::DisplayRole) const;
+                              int role = Qt::DisplayRole) const override;
 
   /**
    * Set data for header section.
@@ -100,7 +99,7 @@ public:
    * @return false
    */
   virtual bool setHeaderData(int, Qt::Orientation, const QVariant&,
-                             int=Qt::EditRole) { return false; }
+                             int = Qt::EditRole) override { return false; }
 
   /**
    * Get number of rows.
@@ -108,7 +107,7 @@ public:
    * @return number of rows,
    * if parent is valid number of children (0 for table models)
    */
-  virtual int rowCount(const QModelIndex& parent=QModelIndex()) const;
+  virtual int rowCount(const QModelIndex& parent = QModelIndex()) const override;
 
   /**
    * Get number of columns.
@@ -116,7 +115,7 @@ public:
    * @return number of columns,
    * if parent is valid number of children (0 for table models)
    */
-  virtual int columnCount(const QModelIndex& parent=QModelIndex()) const;
+  virtual int columnCount(const QModelIndex& parent = QModelIndex()) const override;
 
   /**
    * Insert rows.
@@ -127,7 +126,7 @@ public:
    * @return true if successful
    */
   virtual bool insertRows(int row, int count,
-                          const QModelIndex& parent=QModelIndex());
+                          const QModelIndex& parent = QModelIndex()) override;
 
   /**
    * Remove rows.
@@ -137,7 +136,7 @@ public:
    * @return true if successful
    */
   virtual bool removeRows(int row, int count,
-                          const QModelIndex& parent=QModelIndex());
+                          const QModelIndex& parent = QModelIndex()) override;
 
   /**
    * Insert columns.
@@ -148,7 +147,7 @@ public:
    * @return true if successful
    */
   virtual bool insertColumns(int column, int count,
-                             const QModelIndex& parent=QModelIndex());
+                             const QModelIndex& parent = QModelIndex()) override;
   /**
    * Remove columns.
    * @param column columns are removed starting with this column
@@ -157,7 +156,7 @@ public:
    * @return true if successful
    */
   virtual bool removeColumns(int column, int count,
-                             const QModelIndex& parent=QModelIndex());
+                             const QModelIndex& parent = QModelIndex()) override;
 
   /**
    * Set the check state of all tracks in the table.
@@ -224,8 +223,6 @@ public:
 private:
   ImportTrackDataVector m_trackDataVector;
   QList<Frame::ExtendedType> m_frameTypes;
-  bool m_diffCheckEnabled;
   int m_maxDiff;
+  bool m_diffCheckEnabled;
 };
-
-#endif // TRACKDATAMODEL_H
