@@ -6,7 +6,7 @@
  * \author Urs Fleisch
  * \date 28 Mar 2009
  *
- * Copyright (C) 2009-2013  Urs Fleisch
+ * Copyright (C) 2009-2018  Urs Fleisch
  *
  * This file is part of Kid3.
  *
@@ -83,14 +83,12 @@ AttributeData::AttributeData(const QString& name)
   static QMap<QString, int> strNumMap;
   if (strNumMap.empty()) {
     // first time initialization
-    for (unsigned i = 0; i < sizeof(typeOfWmPriv) / sizeof(typeOfWmPriv[0]);
-         ++i) {
-      strNumMap.insert(QString::fromLatin1(typeOfWmPriv[i].str), typeOfWmPriv[i].type);
+    for (const auto& twp : typeOfWmPriv) {
+      strNumMap.insert(QString::fromLatin1(twp.str), twp.type);
     }
   }
-  QMap<QString, int>::const_iterator it =
-    strNumMap.find(name);
-  m_type = (it != strNumMap.end()) ? static_cast<Type>(*it) : Unknown;
+  auto it = strNumMap.constFind(name);
+  m_type = (it != strNumMap.constEnd()) ? static_cast<Type>(*it) : Unknown;
 }
 
 /**
@@ -120,7 +118,7 @@ bool AttributeData::toString(const QByteArray& data, QString& str)
           if (i == 4 || i == 6 || i == 8 || i == 10) {
             str += QLatin1Char('-');
           }
-          unsigned char c = (unsigned char)data[i];
+          auto c = static_cast<unsigned char>(data[i]);
           unsigned char d = c >> 4;
           str += QLatin1Char(d >= 10 ? d - 10 + 'A' : d + '0');
           d = c & 0x0f;
@@ -171,8 +169,8 @@ bool AttributeData::toByteArray(const QString& str, QByteArray& data)
         unsigned char buf[16];
         unsigned char* bufPtr = buf;
         for (int i = 0; i < 32;) {
-          unsigned char h = (unsigned char)hexStr[i++].toLatin1();
-          unsigned char l = (unsigned char)hexStr[i++].toLatin1();
+          auto h = static_cast<unsigned char>(hexStr[i++].toLatin1());
+          auto l = static_cast<unsigned char>(hexStr[i++].toLatin1());
           if (!((h >= '0' && h <= '9') || (h >= 'A' && h <= 'F')) ||
               !((l >= '0' && l <= '9') || (l >= 'A' && l <= 'F'))) {
             return false;
