@@ -33,7 +33,7 @@
 
 namespace {
 
-static const char* const fieldIdNames[] = {
+const char* const fieldIdNames[] = {
   "Unknown",
   QT_TRANSLATE_NOOP("@default", "Text Encoding"),
   QT_TRANSLATE_NOOP("@default", "Text"),
@@ -62,25 +62,25 @@ static const char* const fieldIdNames[] = {
   QT_TRANSLATE_NOOP("@default", "Price"),
   QT_TRANSLATE_NOOP("@default", "Date"),
   QT_TRANSLATE_NOOP("@default", "Seller"),
-  0
+  nullptr
 };
 
-static const char* const textEncodingNames[] = {
+const char* const textEncodingNames[] = {
   QT_TRANSLATE_NOOP("@default", "ISO-8859-1"),
   QT_TRANSLATE_NOOP("@default", "UTF16"),
   QT_TRANSLATE_NOOP("@default", "UTF16BE"),
   QT_TRANSLATE_NOOP("@default", "UTF8"),
-  0
+  nullptr
 };
 
-static const char* const timestampFormatNames[] = {
+const char* const timestampFormatNames[] = {
   QT_TRANSLATE_NOOP("@default", "Other"),
   QT_TRANSLATE_NOOP("@default", "MPEG frames as unit"),
   QT_TRANSLATE_NOOP("@default", "Milliseconds as unit"),
-  0
+  nullptr
 };
 
-static const char* const contentTypeNames[] = {
+const char* const contentTypeNames[] = {
   QT_TRANSLATE_NOOP("@default", "Other"),
   QT_TRANSLATE_NOOP("@default", "Lyrics"),
   QT_TRANSLATE_NOOP("@default", "Text transcription"),
@@ -88,7 +88,7 @@ static const char* const contentTypeNames[] = {
   QT_TRANSLATE_NOOP("@default", "Events"),
   QT_TRANSLATE_NOOP("@default", "Chord"),
   QT_TRANSLATE_NOOP("@default", "Trivia/pop up"),
-  0
+  nullptr
 };
 
 
@@ -153,9 +153,7 @@ const char* getNameFromType(Frame::Type type)
     QT_TRANSLATE_NOOP("@default", "Rating")           // FT_Rating,
                                   // FT_LastFrame = FT_Rating
   };
-  struct not_used { int array_size_check[
-      sizeof(names) / sizeof(names[0]) == Frame::FT_LastFrame + 1
-      ? 1 : -1 ]; };
+  Q_STATIC_ASSERT(sizeof(names) / sizeof(names[0]) == Frame::FT_LastFrame + 1);
   return type <= Frame::FT_LastFrame ? names[type] : "Unknown";
 }
 
@@ -321,8 +319,8 @@ QMap<QByteArray, QByteArray> getDisplayNamesOfIds()
   static QMap<QByteArray, QByteArray> idStrMap;
   if (idStrMap.isEmpty()) {
     // first time initialization
-    for (unsigned int i = 0; i < sizeof(strOfId) / sizeof(strOfId[0]); ++i) {
-      idStrMap.insert(strOfId[i].id, strOfId[i].str);
+    for (const auto& soi : strOfId) {
+      idStrMap.insert(soi.id, soi.str);
     }
   }
   return idStrMap;
@@ -346,7 +344,8 @@ Frame::ExtendedType::ExtendedType(Type type) :
  */
 QString Frame::ExtendedType::getName() const
 {
-  return m_type != FT_Other ? QString::fromLatin1(getNameFromType(m_type)) : m_name;
+  return m_type != FT_Other ? QString::fromLatin1(getNameFromType(m_type))
+                            : m_name;
 }
 
 /**
@@ -355,15 +354,17 @@ QString Frame::ExtendedType::getName() const
  */
 QString Frame::ExtendedType::getTranslatedName() const
 {
-  return m_type != FT_Other ? QCoreApplication::translate("@default", getNameFromType(m_type)) : m_name;
+  return m_type != FT_Other
+      ? QCoreApplication::translate("@default", getNameFromType(m_type))
+      : m_name;
 }
 
 
 /**
  * Constructor.
  */
-Frame::Frame() :
-  m_index(-1), m_marked(FrameNotice::None), m_valueChanged(false)
+Frame::Frame()
+  : m_index(-1), m_marked(FrameNotice::None), m_valueChanged(false)
 {
 }
 
@@ -371,9 +372,9 @@ Frame::Frame() :
  * Constructor.
  */
 Frame::Frame(Type type, const QString& value,
-             const QString& name, int index) :
-  m_extendedType(type, name), m_index(index), m_value(value),
-  m_marked(FrameNotice::None), m_valueChanged(false)
+             const QString& name, int index)
+  : m_extendedType(type, name), m_index(index), m_value(value),
+    m_marked(FrameNotice::None), m_valueChanged(false)
 {
 }
 
@@ -383,16 +384,9 @@ Frame::Frame(Type type, const QString& value,
  * @param value value
  * @param index index inside tag, -1 if unknown
  */
-Frame::Frame(const ExtendedType& type, const QString& value, int index) :
-  m_extendedType(type), m_index(index), m_value(value),
-  m_marked(FrameNotice::None), m_valueChanged(false)
-{
-}
-
-/**
- * Destructor.
- */
-Frame::~Frame()
+Frame::Frame(const ExtendedType& type, const QString& value, int index)
+  : m_extendedType(type), m_index(index), m_value(value),
+    m_marked(FrameNotice::None), m_valueChanged(false)
 {
 }
 
@@ -402,9 +396,8 @@ Frame::~Frame()
 void Frame::setValueFromFieldList()
 {
   if (!getFieldList().empty()) {
-    QString text;
-    for (Frame::FieldList::const_iterator fldIt = getFieldList().begin();
-         fldIt != getFieldList().end();
+    for (auto fldIt = getFieldList().constBegin();
+         fldIt != getFieldList().constEnd();
          ++fldIt) {
       int id = (*fldIt).m_id;
       if (id == ID_Text ||
@@ -426,10 +419,8 @@ void Frame::setValueFromFieldList()
 void Frame::setFieldListFromValue()
 {
   if (!fieldList().empty()) {
-    Frame::FieldList::iterator it = fieldList().end();
-    for (Frame::FieldList::iterator fldIt = fieldList().begin();
-         fldIt != fieldList().end();
-         ++fldIt) {
+    auto it = fieldList().end(); // clazy:exclude=detaching-member
+    for (auto fldIt = fieldList().begin(); fldIt != fieldList().end(); ++fldIt) { // clazy:exclude=detaching-member
       int id = (*fldIt).m_id;
       if (id == ID_Text ||
           id == ID_Description ||
@@ -465,9 +456,9 @@ void Frame::setFieldListFromValue()
 int Frame::numberWithoutTotal(const QString& str, bool* ok)
 {
   int slashPos = str.indexOf(QLatin1Char('/'));
-  return slashPos == -1 ?
-    str.toInt(ok) :
-    str.left(slashPos).toInt(ok);
+  return slashPos == -1
+      ? str.toInt(ok)
+      : str.leftRef(slashPos).toInt(ok);
 }
 
 /**
@@ -509,9 +500,7 @@ void Frame::setValueAsNumber(int n)
  */
 QVariant Frame::getFieldValue(FieldId id) const
 {
-  for (FieldList::const_iterator it = m_fieldList.begin();
-       it != m_fieldList.end();
-       ++it) {
+  for (auto it = m_fieldList.constBegin(); it != m_fieldList.constEnd(); ++it) {
     if ((*it).m_id == id) {
       return (*it).m_value;
     }
@@ -551,8 +540,7 @@ bool Frame::isEqual(const Frame& other) const
   if (m_fieldList.size() != otherFieldList.size())
     return false;
 
-  FieldList::const_iterator thisIt, otherIt;
-  for (thisIt = m_fieldList.constBegin(), otherIt = otherFieldList.constBegin();
+  for (auto thisIt = m_fieldList.constBegin(), otherIt = otherFieldList.constBegin();
        thisIt != m_fieldList.constEnd() && otherIt != otherFieldList.constEnd();
        ++thisIt, ++otherIt) {
     if (thisIt->m_id != otherIt->m_id || thisIt->m_value != otherIt->m_value) {
@@ -574,9 +562,7 @@ bool Frame::isEqual(const Frame& other) const
  */
 bool Frame::setField(Frame& frame, FieldId id, const QVariant& value)
 {
-  for (Frame::FieldList::iterator it = frame.fieldList().begin();
-       it != frame.fieldList().end();
-       ++it) {
+  for (auto it = frame.fieldList().begin(); it != frame.fieldList().end(); ++it) { // clazy:exclude=detaching-member
     if ((*it).m_id == id) {
       (*it).m_value = value;
       if (id == ID_Description) frame.setValue(value.toString());
@@ -614,8 +600,8 @@ QVariant Frame::getField(const Frame& frame, FieldId id)
 {
   QVariant result;
   if (!frame.getFieldList().empty()) {
-    for (Frame::FieldList::const_iterator it = frame.getFieldList().begin();
-         it != frame.getFieldList().end();
+    for (auto it = frame.getFieldList().constBegin();
+         it != frame.getFieldList().constEnd();
          ++it) {
       if ((*it).m_id == id) {
         result = (*it).m_value;
@@ -653,15 +639,15 @@ Frame::Type Frame::getTypeFromName(const QString& name)
   if (strNumMap.empty()) {
     // first time initialization
     for (int i = 0; i <= Frame::FT_LastFrame; ++i) {
-      Frame::Type type = static_cast<Frame::Type>(i);
-      strNumMap.insert(QString::fromLatin1(getNameFromType(type)).
-                       remove(QLatin1Char(' ')).toUpper(), type);
+      auto type = static_cast<Frame::Type>(i);
+      strNumMap.insert(QString::fromLatin1(getNameFromType(type))
+                       .remove(QLatin1Char(' ')).toUpper(), type);
     }
   }
   QString ucName(name.toUpper());
   ucName.remove(QLatin1Char(' '));
-  QMap<QString, int>::const_iterator it = strNumMap.find(ucName);
-  if (it != strNumMap.end()) {
+  auto it = strNumMap.constFind(ucName);
+  if (it != strNumMap.constEnd()) {
     return static_cast<Frame::Type>(*it);
   }
   return Frame::FT_Other;
@@ -709,7 +695,7 @@ QString Frame::getDisplayName(const QString& name)
     id = nameStr.toLatin1();
   }
 
-  QMap<QByteArray, QByteArray>::const_iterator it = idStrMap.constFind(id);
+  auto it = idStrMap.constFind(id);
   if (it != idStrMap.constEnd()) {
     return QCoreApplication::translate("@default", it->constData());
   }
@@ -724,7 +710,7 @@ QString Frame::getDisplayName(const QString& name)
 QMap<QString, QString> Frame::getDisplayNameMap(const QStringList& names)
 {
   QMap<QString, QString> map;
-  foreach (const QString& name, names) {
+  for (const QString& name : names) {
     map.insert(getDisplayName(name), name);
   }
   return map;
@@ -747,7 +733,8 @@ QString Frame::getNameForTranslatedFrameName(const QString& name)
                          name.toLatin1().constData()), name);
     }
     QMap<QByteArray, QByteArray> idStrMap = getDisplayNamesOfIds();
-    foreach (const QByteArray& name, idStrMap.values()) {
+    const auto names = idStrMap.values();
+    for (const QByteArray& name : names) {
       nameMap.insert(QCoreApplication::translate("@default", name),
                      QString::fromLatin1(name));
     }
@@ -765,11 +752,10 @@ QString Frame::getNameForTranslatedFrameName(const QString& name)
  */
 QString Frame::Field::getFieldIdName(FieldId type)
 {
-  struct not_used { int array_size_check[
-      sizeof(fieldIdNames) / sizeof(fieldIdNames[0]) == ID_Seller + 2
-      ? 1 : -1 ]; };
-  if (type >= 0 &&
-      type < static_cast<int>(
+  Q_STATIC_ASSERT(
+      sizeof(fieldIdNames) / sizeof(fieldIdNames[0]) == ID_Seller + 2);
+  if (static_cast<int>(type) >= 0 &&
+      static_cast<int>(type) < static_cast<int>(
         sizeof(fieldIdNames) / sizeof(fieldIdNames[0]) - 1)) {
     return QCoreApplication::translate("@default", fieldIdNames[type]);
   }
@@ -794,20 +780,20 @@ Frame::FieldId Frame::Field::getFieldId(const QString& fieldName)
   const char* const* fn;
   int id;
   // First try to find an exact English match.
-  for (fn = fieldIdNames, id = 0; *fn != 0; ++fn, ++id) {
+  for (fn = fieldIdNames, id = 0; *fn != nullptr; ++fn, ++id) {
     if (fieldName == QLatin1String(*fn)) {
       return static_cast<FieldId>(id);
     }
   }
   // Then try to find a lowercase match ignoring spaces.
   QString lcName = fieldName.toLower().remove(QLatin1Char(' '));
-  for (fn = fieldIdNames, id = 0; *fn != 0; ++fn, ++id) {
+  for (fn = fieldIdNames, id = 0; *fn != nullptr; ++fn, ++id) {
     if (lcName ==  QString::fromLatin1(*fn).toLower().remove(QLatin1Char(' '))) {
       return static_cast<FieldId>(id);
     }
   }
   // Finally try to find a translated name.
-  for (fn = fieldIdNames, id = 0; *fn != 0; ++fn, ++id) {
+  for (fn = fieldIdNames, id = 0; *fn != nullptr; ++fn, ++id) {
     if (fieldName == QCoreApplication::translate("@default", *fn)) {
       return static_cast<FieldId>(id);
     }
@@ -824,8 +810,8 @@ Frame::FieldId Frame::Field::getFieldId(const QString& fieldName)
  */
 QString Frame::Field::getTextEncodingName(TextEncoding type)
 {
-  if (type >= 0 &&
-      type < static_cast<int>(
+  if (static_cast<int>(type) >= 0 &&
+      static_cast<int>(type) < static_cast<int>(
         sizeof(textEncodingNames) / sizeof(textEncodingNames[0]) - 1)) {
     return QCoreApplication::translate("@default", textEncodingNames[type]);
   }
@@ -894,7 +880,7 @@ const char* const* Frame::Field::getContentTypeNames()
  * Get list of available tag versions with translated description.
  * @return tag version/description pairs.
  */
-QList<QPair<Frame::TagVersion, QString> > Frame::availableTagVersions()
+const QList<QPair<Frame::TagVersion, QString> > Frame::availableTagVersions()
 {
   QList<QPair<TagVersion, QString> > result;
   FOR_ALL_TAGS(tagNr) {
@@ -938,20 +924,26 @@ Frame::TagNumber Frame::tagNumberFromString(const QString& str)
 }
 
 #ifndef QT_NO_DEBUG
+
+namespace {
+
 /**
  * Get string representation of variant.
  * @param val variant value
  * @return string representation.
  */
-static QString variantToString(const QVariant& val)
+QString variantToString(const QVariant& val)
 {
   if (val.type() == QVariant::ByteArray) {
-    return QString(QLatin1String("ByteArray of %1 bytes")).arg(val.toByteArray().size());
+    return QString(QLatin1String("ByteArray of %1 bytes"))
+        .arg(val.toByteArray().size());
   } else {
     return val.toString();
   }
 }
 
+}
+
 /**
  * Dump contents of frame to debug console.
  */
@@ -962,9 +954,7 @@ void Frame::dump() const
          getNameFromType(getType()), m_index,
          m_valueChanged, qPrintable(m_marked.getDescription()));
   qDebug("  fields=");
-  for (FieldList::const_iterator it = m_fieldList.begin();
-       it != m_fieldList.end();
-       ++it) {
+  for (auto it = m_fieldList.constBegin(); it != m_fieldList.constEnd(); ++it) {
     qDebug("  Field: id=%s, value=%s",
            qPrintable(
              Field::getFieldIdName(static_cast<FieldId>((*it).m_id))),
@@ -986,17 +976,20 @@ quint64 FrameCollection::s_quickAccessFrames =
  * Set values which are different inactive.
  *
  * @param others frames to compare, will be modified
+ * @param differentValues optional storage for the different values
  */
-void FrameCollection::filterDifferent(FrameCollection& others)
+void FrameCollection::filterDifferent(
+    FrameCollection& others,
+    QHash<Frame::ExtendedType, QSet<QString>>* differentValues)
 {
   QByteArray frameData, othersData;
-  iterator it = begin();
+  auto it = begin();
   while (it != end()) {
-    Frame& frame = const_cast<Frame&>(*it);
+    auto& frame = const_cast<Frame&>(*it);
     // This frame list is not tied to a specific file, so the
     // index is not valid.
     frame.setIndex(-1);
-    iterator othersIt = others.find(frame);
+    auto othersIt = others.find(frame);
     if (othersIt == others.end()) {
       frame.setDifferent();
       ++it;
@@ -1009,6 +1002,14 @@ void FrameCollection::filterDifferent(FrameCollection& others)
              !(PictureFrame::getData(*it, frameData) &&
                PictureFrame::getData(*othersIt, othersData) &&
                frameData == othersData))) {
+          if (differentValues && it->getType() != Frame::FT_Picture &&
+              it->getType() != Frame::FT_Genre) {
+            auto& valueSet = (*differentValues)[it->getExtendedType()];
+            if (it->getValue() != Frame::differentRepresentation()) {
+              valueSet.insert(it->getValue());
+            }
+            valueSet.insert(othersIt->getValue());
+          }
           const_cast<Frame&>(*it).setDifferent();
         }
         // Mark as already handled.
@@ -1021,11 +1022,11 @@ void FrameCollection::filterDifferent(FrameCollection& others)
 
   // Insert frames which are in others but not in this (not marked as already
   // handled by index -2) as different frames.
-  for (iterator othersIt = others.begin();
+  for (auto othersIt = others.begin();
        othersIt != others.end();
        ++othersIt) {
     if (othersIt->getIndex() != -2) {
-      Frame& frame = const_cast<Frame&>(*othersIt);
+      auto& frame = const_cast<Frame&>(*othersIt);
       frame.setIndex(-1);
       frame.setDifferent();
       insert(frame);
@@ -1045,7 +1046,7 @@ void FrameCollection::addMissingStandardFrames()
        ++i, mask <<= 1) {
     if (s_quickAccessFrames & mask) {
       Frame frame(static_cast<Frame::Type>(i), QString(), QString(), -1);
-      FrameCollection::const_iterator it = find(frame);
+      auto it = find(frame);
       if (it == end()) {
         insert(frame);
       }
@@ -1063,9 +1064,7 @@ void FrameCollection::addMissingStandardFrames()
 FrameCollection FrameCollection::copyEnabledFrames(const FrameFilter& flt) const
 {
   FrameCollection frames;
-  for (const_iterator it = begin();
-       it != end();
-       ++it) {
+  for (auto it = cbegin(); it != cend(); ++it) {
     if (flt.isEnabled(it->getType(), it->getName())) {
       Frame frame = *it;
       frame.setIndex(-1);
@@ -1082,8 +1081,7 @@ FrameCollection FrameCollection::copyEnabledFrames(const FrameFilter& flt) const
  */
 void FrameCollection::removeDisabledFrames(const FrameFilter& flt)
 {
-  for (iterator it = begin();
-       it != end();) {
+  for (auto it = begin(); it != end();) {
     if (!flt.isEnabled(it->getType(), it->getName())) {
       erase(it++);
     } else {
@@ -1097,8 +1095,8 @@ void FrameCollection::removeDisabledFrames(const FrameFilter& flt)
  */
 void FrameCollection::setIndexesInvalid()
 {
-  for (iterator it = begin(); it != end(); ++it) {
-    Frame& frame = const_cast<Frame&>(*it);
+  for (auto it = begin(); it != end(); ++it) {
+    auto& frame = const_cast<Frame&>(*it);
     frame.setIndex(-1);
   }
 }
@@ -1111,13 +1109,11 @@ void FrameCollection::setIndexesInvalid()
  */
 void FrameCollection::merge(const FrameCollection& frames)
 {
-  for (const_iterator otherIt = frames.begin();
-       otherIt != frames.end();
-       ++otherIt) {
-    iterator it = find(*otherIt);
+  for (auto otherIt = frames.cbegin(); otherIt != frames.cend(); ++otherIt) {
+    auto it = find(*otherIt);
     if (it != end()) {
       QString value(otherIt->getValue());
-      Frame& frameFound = const_cast<Frame&>(*it);
+      auto& frameFound = const_cast<Frame&>(*it);
       if (frameFound.getValue().isEmpty() && !value.isEmpty()) {
         frameFound.setValueIfChanged(value);
       }
@@ -1159,14 +1155,14 @@ FrameCollection::const_iterator FrameCollection::searchByName(
     const QString& name) const
 {
   if (name.isEmpty())
-    return end();
+    return cend();
 
   const_iterator it;
   QString ucName = name.toUpper().remove(QLatin1Char('/'));
   int len = ucName.length();
-  for (it = begin(); it != end(); ++it) {
-    foreach (const QString& frameName,
-             QStringList() << it->getName() << it->getInternalName()) {
+  for (it = cbegin(); it != cend(); ++it) {
+    const QStringList names{it->getName(), it->getInternalName()};
+    for (const QString& frameName : names) {
       QString ucFrameName(frameName.toUpper().remove(QLatin1Char('/')));
       if (ucName == ucFrameName.leftRef(len)) {
         return it;
@@ -1195,26 +1191,26 @@ FrameCollection::const_iterator FrameCollection::findByName(
     const QString& name, int index) const
 {
   Frame frame(Frame::ExtendedType(name), QLatin1String(""), -1);
-  const_iterator it = find(frame);
-  if (it == end()) {
+  auto it = find(frame);
+  if (it == cend()) {
     it = searchByName(name);
-    if (it == end()) {
-      foreach (const QByteArray& id,
-               getDisplayNamesOfIds().keys(name.toLatin1())) {
+    if (it == cend()) {
+      const auto ids = getDisplayNamesOfIds().keys(name.toLatin1());
+      for (const QByteArray& id : ids) {
         if (!id.isEmpty()) {
           it = searchByName(QString::fromLatin1(id));
-          if (it != end()) {
+          if (it != cend()) {
             break;
           }
         }
       }
     }
   }
-  if (index > 0 && it != end()) {
+  if (index > 0 && it != cend()) {
     const Frame::ExtendedType extendedType = it->getExtendedType();
-    for (int i = 0; i < index && it != end(); ++i, ++it) {}
-    if (it != end() && !(it->getExtendedType() == extendedType)) {
-      it = end();
+    for (int i = 0; i < index && it != cend(); ++i, ++it) {}
+    if (it != cend() && !(it->getExtendedType() == extendedType)) {
+      it = cend();
     }
   }
   return it;
@@ -1233,8 +1229,8 @@ FrameCollection::const_iterator FrameCollection::findByExtendedType(
     const Frame::ExtendedType& type) const
 {
   Frame frame(type, QLatin1String(""), -1);
-  const_iterator it = find(frame);
-  if (it == end()) {
+  auto it = find(frame);
+  if (it == cend()) {
     it = searchByName(frame.getInternalName());
   }
   return it;
@@ -1250,7 +1246,7 @@ FrameCollection::const_iterator FrameCollection::findByExtendedType(
 FrameCollection::const_iterator FrameCollection::findByIndex(int index) const
 {
   const_iterator it;
-  for (it = begin(); it != end(); ++it) {
+  for (it = cbegin(); it != cend(); ++it) {
     if (it->getIndex() == index) {
       break;
     }
@@ -1268,8 +1264,8 @@ FrameCollection::const_iterator FrameCollection::findByIndex(int index) const
 QString FrameCollection::getValue(Frame::Type type) const
 {
   Frame frame(type, QLatin1String(""), QLatin1String(""), -1);
-  const_iterator it = find(frame);
-  return it != end() ? it->getValue() : QString();
+  auto it = find(frame);
+  return it != cend() ? it->getValue() : QString();
 }
 
 /**
@@ -1283,8 +1279,8 @@ QString FrameCollection::getValue(Frame::Type type) const
  */
 QString FrameCollection::getValue(const Frame::ExtendedType& type) const
 {
-  const_iterator it = findByExtendedType(type);
-  return it != end() ? it->getValue() : QString();
+  auto it = findByExtendedType(type);
+  return it != cend() ? it->getValue() : QString();
 }
 
 /**
@@ -1297,9 +1293,9 @@ void FrameCollection::setValue(Frame::Type type, const QString& value)
 {
   if (!value.isNull()) {
     Frame frame(type, QLatin1String(""), QLatin1String(""), -1);
-    iterator it = find(frame);
+    auto it = find(frame);
     if (it != end()) {
-      Frame& frameFound = const_cast<Frame&>(*it);
+      auto& frameFound = const_cast<Frame&>(*it);
       frameFound.setValueIfChanged(value);
     } else {
       frame.setValueIfChanged(value);
@@ -1321,12 +1317,12 @@ void FrameCollection::setValue(const Frame::ExtendedType& type,
 {
   if (!value.isNull()) {
     Frame frame(type, QLatin1String(""), -1);
-    const_iterator it = find(frame);
+    auto it = find(frame);
     if (it == end()) {
       it = searchByName(type.getInternalName());
     }
     if (it != end()) {
-      Frame& frameFound = const_cast<Frame&>(*it);
+      auto& frameFound = const_cast<Frame&>(*it);
       frameFound.setValueIfChanged(value);
     } else {
       frame.setValueIfChanged(value);
@@ -1370,12 +1366,12 @@ void FrameCollection::setIntValue(Frame::Type type, int value)
  */
 void FrameCollection::markChangedFrames(const FrameCollection& other)
 {
-  for (FrameCollection::iterator it = begin(); it != end(); ++it) {
-    const_iterator otherIt = it->getIndex() != -1
+  for (auto it = begin(); it != end(); ++it) {
+    auto otherIt = it->getIndex() != -1
         ? other.findByIndex(it->getIndex())
         : other.find(*it);
-    Frame& frame = const_cast<Frame&>(*it);
-    frame.setValueChanged(!(otherIt != other.end() && otherIt->isEqual(*it)));
+    auto& frame = const_cast<Frame&>(*it);
+    frame.setValueChanged(!(otherIt != other.cend() && otherIt->isEqual(*it)));
   }
 }
 
@@ -1386,9 +1382,7 @@ void FrameCollection::markChangedFrames(const FrameCollection& other)
 void FrameCollection::dump() const
 {
   qDebug("FrameCollection:");
-  for (const_iterator it = begin();
-       it != end();
-       ++it) {
+  for (const_iterator it = cbegin(); it != cend(); ++it) {
     (*it).dump();
   }
 }
@@ -1407,15 +1401,13 @@ void FrameCollection::dump() const
  * @return frames constructed from subframe fields.
  */
 FrameCollection FrameCollection::fromSubframes(
-    Frame::FieldList::const_iterator begin,
-    Frame::FieldList::const_iterator end)
+    Frame::FieldList::const_iterator begin, // clazy:exclude=function-args-by-ref
+    Frame::FieldList::const_iterator end) // clazy:exclude=function-args-by-ref
 {
   FrameCollection frames;
   Frame frame;
   int index = 0;
-  for (Frame::FieldList::const_iterator it = begin;
-       it != end;
-       ++it) {
+  for (auto it = begin; it != end; ++it) {
     const Frame::Field& fld = *it;
     if (fld.m_id == Frame::ID_Subframe) {
       if (frame.getType() != Frame::FT_UnknownFrame) {
@@ -1448,11 +1440,6 @@ FrameCollection FrameCollection::fromSubframes(
  */
 FrameFilter::FrameFilter() : m_enabledFrames(0) {}
 
-/**
- * Destructor.
- */
-FrameFilter::~FrameFilter() {}
-
 /**
  * Enable all frames.
  */
@@ -1486,7 +1473,7 @@ bool FrameFilter::isEnabled(Frame::Type type, const QString& name) const
   if (type <= Frame::FT_LastFrame) {
     return (m_enabledFrames & (1ULL << type)) != 0;
   } else if (!name.isEmpty()) {
-    std::set<QString>::const_iterator it = m_disabledOtherFrames.find(name);
+    auto it = m_disabledOtherFrames.find(name);
     return it == m_disabledOtherFrames.end();
   } else {
     return true;
@@ -1510,7 +1497,7 @@ void FrameFilter::enable(Frame::Type type, const QString& name, bool en)
     }
   } else if (!name.isEmpty()) {
     if (en) {
-      std::set<QString>::iterator it = m_disabledOtherFrames.find(name);
+      auto it = m_disabledOtherFrames.find(name);
       if (it != m_disabledOtherFrames.end()) {
         m_disabledOtherFrames.erase(it);
       }
@@ -1528,13 +1515,8 @@ void FrameFilter::enable(Frame::Type type, const QString& name, bool en)
  * @param str    string with format codes
  */
 FrameFormatReplacer::FrameFormatReplacer(
-  const FrameCollection& frames, const QString& str) :
-  FormatReplacer(str), m_frames(frames) {}
-
-/**
- * Destructor.
- */
-FrameFormatReplacer::~FrameFormatReplacer() {}
+  const FrameCollection& frames, const QString& str)
+  : FormatReplacer(str), m_frames(frames) {}
 
 /**
  * Replace a format code (one character %c or multiple characters %{chars}).
@@ -1573,9 +1555,9 @@ QString FrameFormatReplacer::getReplacement(const QString& code) const
       { "genre", 'g' }
     };
     const char c = code[0].toLatin1();
-    for (unsigned i = 0; i < sizeof(shortToLong) / sizeof(shortToLong[0]); ++i) {
-      if (shortToLong[i].shortCode == c) {
-        name = QString::fromLatin1(shortToLong[i].longCode);
+    for (const auto& s2l : shortToLong) {
+      if (s2l.shortCode == c) {
+        name = QString::fromLatin1(s2l.longCode);
         break;
       }
     }
@@ -1594,7 +1576,8 @@ QString FrameFormatReplacer::getReplacement(const QString& code) const
     }
     int len = lcName.length();
     if (len > 2 && lcName.at(len - 2) == QLatin1Char('.') &&
-        lcName.at(len - 1) >= QLatin1Char('0') && lcName.at(len - 1) <= QLatin1Char('9')) {
+        lcName.at(len - 1) >= QLatin1Char('0') &&
+        lcName.at(len - 1) <= QLatin1Char('9')) {
       fieldWidth = lcName.at(len - 1).toLatin1() - '0';
       lcName.truncate(len - 2);
       name.truncate(len - 2);
@@ -1605,8 +1588,12 @@ QString FrameFormatReplacer::getReplacement(const QString& code) const
       name.truncate(dotIndex);
     }
 
-    FrameCollection::const_iterator it = m_frames.findByName(name);
-    if (it != m_frames.end()) {
+    if (name == QLatin1String("disk")) {
+      name = QLatin1String("disc number");
+    }
+
+    auto it = m_frames.findByName(name);
+    if (it != m_frames.cend()) {
       if (fieldName.isEmpty()) {
         result = it->getValue().trimmed();
       } else {
@@ -1696,6 +1683,12 @@ QString FrameFormatReplacer::getToolTip(bool onlyRows)
   str += QCoreApplication::translate("@default", "Genre");
   str += QLatin1String("</td></tr>\n");
 
+  str += QLatin1String(R"(<tr><td></td><td>%{"t1"title"t2"}...</td><td>)");
+  const char* const prependAppendStr =
+      QT_TRANSLATE_NOOP("@default", "Prepend t1/append t2 if not empty");
+  str += QCoreApplication::translate("@default", prependAppendStr);
+  str += QLatin1String("</td></tr>\n");
+
   if (!onlyRows) str += QLatin1String("</table>\n");
   return str;
 }
