@@ -24,14 +24,15 @@
  * along with this program.  If not, see <http://www.gnu.org/licenses/>.
  */
 
-#ifndef FRAME_H
-#define FRAME_H
+#pragma once
 
-#include "formatreplacer.h"
 #include <QString>
 #include <QVariant>
 #include <QList>
+#include <QSet>
+#include <QHash>
 #include <set>
+#include "formatreplacer.h"
 #include "framenotice.h"
 #include "kid3api.h"
 
@@ -233,7 +234,7 @@ public:
    * Get list of available tag versions with translated description.
    * @return tag version/description pairs.
    */
-  static QList<QPair<TagVersion, QString> > availableTagVersions();
+  static const QList<QPair<TagVersion, QString> > availableTagVersions();
 
   /**
    * Get highest priority tag number which is set in a tag mask.
@@ -253,7 +254,7 @@ public:
    * @param tagMask tag mask with bits set for tags
    * @return list of tag numbers.
    */
-  static QList<TagNumber> tagNumbersFromMask(TagVersion tagMask) {
+  static const QList<TagNumber> tagNumbersFromMask(TagVersion tagMask) {
     QList<TagNumber> result;
     if (tagMask & TagV2) result << Tag_2;
     if (tagMask & TagV1) result << Tag_1;
@@ -265,7 +266,7 @@ public:
    * Get all tag numbers, ordered from highest to lowest priority.
    * @return list of tag numbers.
    */
-  static QList<TagNumber> allTagNumbers() {
+  static const QList<TagNumber> allTagNumbers() {
     return tagNumbersFromMask(TagVAll);
   }
 
@@ -478,11 +479,6 @@ public:
    */
   Frame(const ExtendedType& type, const QString& value, int index);
 
-  /**
-   * Destructor.
-   */
-  ~Frame();
-
   /**
    * Less than operator.
    * Needed for sorting in multiset.
@@ -712,7 +708,7 @@ public:
    *
    * @return number in string ignoring total after slash.
    */
-  static int numberWithoutTotal(const QString& str, bool* ok = 0);
+  static int numberWithoutTotal(const QString& str, bool* ok = nullptr);
 
   /**
    * Get representation of different frames in multiple files.
@@ -822,11 +818,6 @@ public:
    */
   FrameFilter();
 
-  /**
-   * Destructor.
-   */
-  ~FrameFilter();
-
   /**
    * Enable all frames.
    */
@@ -870,7 +861,7 @@ public:
   /**
    * Default value for quick access frames.
    */
-  static const quint64 DEFAULT_QUICK_ACCESS_FRAMES =
+  static constexpr quint64 DEFAULT_QUICK_ACCESS_FRAMES =
       (1ULL << Frame::FT_Title)   |
       (1ULL << Frame::FT_Artist)  |
       (1ULL << Frame::FT_Album)   |
@@ -879,22 +870,14 @@ public:
       (1ULL << Frame::FT_Track)   |
       (1ULL << Frame::FT_Genre);
 
-  /**
-   * Constructor.
-   */
-  FrameCollection() {}
-
-  /**
-   * Destructor.
-   */
-  ~FrameCollection() {}
-
   /**
    * Set values which are different inactive.
    *
    * @param others frames to compare, will be modified!
+   * @param differentValues optional storage for the different values
    */
-  void filterDifferent(FrameCollection& others);
+  void filterDifferent(FrameCollection& others,
+          QHash<Frame::ExtendedType, QSet<QString>>* differentValues = nullptr);
 
   /**
    * Add standard frames which are missing.
@@ -1208,7 +1191,10 @@ public:
   /**
    * Destructor.
    */
-  virtual ~FrameFormatReplacer();
+  virtual ~FrameFormatReplacer() override = default;
+
+  FrameFormatReplacer(const FrameFormatReplacer& other) = delete;
+  FrameFormatReplacer &operator=(const FrameFormatReplacer& other) = delete;
 
   /**
    * Get help text for supported format codes.
@@ -1238,10 +1224,13 @@ protected:
    * @return replacement string,
    *         QString::null if code not found.
    */
-  virtual QString getReplacement(const QString& code) const;
+  virtual QString getReplacement(const QString& code) const override;
 
 private:
   const FrameCollection& m_frames;
 };
 
-#endif // FRAME_H
+/** Hash function to use Frame::ExtendedType as a QHash key. */
+inline uint qHash(const Frame::ExtendedType& key) {
+  return qHash(key.getType()) ^ qHash(key.getInternalName());
+}
