@@ -6,7 +6,7 @@
  * \author Urs Fleisch
  * \date 19 May 2017
  *
- * Copyright (C) 2017  Urs Fleisch
+ * Copyright (C) 2017-2018  Urs Fleisch
  *
  * This file is part of Kid3.
  *
@@ -32,7 +32,7 @@
 
 namespace {
 
-typedef bool (*CheckFunction)(const QString& str);
+using CheckFunction = bool (*)(const QString&);
 
 bool beginsWithYearAndSpace(const QString& str)
 {
@@ -52,12 +52,9 @@ bool isDayMonth(const QString& str)
   if (str.length() != 4)
     return false;
 
-  int day = str.left(2).toInt();
-  int month = str.mid(2).toInt();
-  if (day < 1 || day > 31 || month < 1 || month > 12)
-    return false;
-
-  return true;
+  int day = str.leftRef(2).toInt();
+  int month = str.midRef(2).toInt();
+  return !(day < 1 || day > 31 || month < 1 || month > 12);
 }
 
 bool isHourMinute(const QString& str)
@@ -65,12 +62,9 @@ bool isHourMinute(const QString& str)
   if (str.length() != 4)
     return false;
 
-  int hour = str.left(2).toInt();
-  int minute = str.mid(2).toInt();
-  if (hour < 0 || hour > 23 || minute < 0 || minute > 59)
-    return false;
-
-  return true;
+  int hour = str.leftRef(2).toInt();
+  int minute = str.midRef(2).toInt();
+  return !(hour < 0 || hour > 23 || minute < 0 || minute > 59);
 }
 
 bool isNumeric(const QString& str)
@@ -129,7 +123,7 @@ bool isMusicalKey(const QString& str)
   const QChar lastChar = str.at(len - 1);
   if (lastChar == QLatin1Char('A') || lastChar == QLatin1Char('B')) {
     bool ok;
-    int nr = str.left(len - 1).toInt(&ok);
+    int nr = str.leftRef(len - 1).toInt(&ok);
     if (ok && nr >= 1 && nr <= 12) {
       return true;
     }
@@ -196,9 +190,7 @@ QString FrameNotice::getDescription() const
     QT_TRANSLATE_NOOP("@default", "Must be list of strings separated by '|'"),
     QT_TRANSLATE_NOOP("@default", "Has excess white space"),
   };
-  struct not_used { int array_size_check[
-      sizeof(descriptions) / sizeof(descriptions[0]) == NumWarnings
-      ? 1 : -1 ]; };
+  Q_STATIC_ASSERT(sizeof(descriptions) / sizeof(descriptions[0]) == NumWarnings);
   return m_warning < NumWarnings
       ? QCoreApplication::translate("@default", descriptions[m_warning])
       : QString();
@@ -231,7 +223,7 @@ const QRegExp& FrameNotice::isoDateTimeRexExp()
  */
 bool FrameNotice::addPictureTooLargeNotice(Frame& frame, int maxSize)
 {
-  QVariant data = frame.getField(frame, Frame::ID_Data);
+  QVariant data = Frame::getField(frame, Frame::ID_Data);
   if (!data.isNull()) {
     if (data.toByteArray().size() > maxSize) {
       frame.setMarked(FrameNotice::TooLarge);
@@ -323,27 +315,21 @@ bool FrameNotice::addId3StandardViolationNotice(FrameCollection& frames)
   static QMap<Warning, CheckFunction> checks;
   static QMap<QString, Frame::FieldId> uniques;
   if (warnings.isEmpty()) {
-    for (unsigned int i = 0;
-         i < sizeof(idWarning) / sizeof (idWarning[0]);
-         ++i) {
-      warnings[QString::fromLatin1(idWarning[i].id)] = idWarning[i].warning;
+    for (const auto& iw : idWarning) {
+      warnings[QString::fromLatin1(iw.id)] = iw.warning;
     }
-    for (unsigned int i = 0;
-         i < sizeof(warningFunc) / sizeof (warningFunc[0]);
-         ++i) {
-      checks[warningFunc[i].warning] = warningFunc[i].func;
+    for (const auto& wf : warningFunc) {
+      checks[wf.warning] = wf.func;
     }
-    for (unsigned int i = 0;
-         i < sizeof(uniqIdField) / sizeof (uniqIdField[0]);
-         ++i) {
-      uniques[QString::fromLatin1(uniqIdField[i].id)] = uniqIdField[i].field;
+    for (const auto& uif : uniqIdField) {
+      uniques[QString::fromLatin1(uif.id)] = uif.field;
     }
   }
 
   QSet<QString> uniqueIds;
   bool marked = false;
-  for (FrameCollection::iterator it = frames.begin(); it != frames.end(); ++it) {
-    Frame& frame = const_cast<Frame&>(*it);
+  for (auto it = frames.begin(); it != frames.end(); ++it) {
+    auto& frame = const_cast<Frame&>(*it);
     QString name = frame.getInternalName();
     QString id = name.left(4);
     QString uniqueId;
