@@ -6,7 +6,7 @@
  * \author Urs Fleisch
  * \date 9 Jan 2003
  *
- * Copyright (C) 2003-2007  Urs Fleisch
+ * Copyright (C) 2003-2018  Urs Fleisch
  *
  * This file is part of Kid3.
  *
@@ -24,15 +24,15 @@
  * along with this program.  If not, see <http://www.gnu.org/licenses/>.
  */
 
-#ifndef GENRES_H
-#define GENRES_H
+#pragma once
 
 #include <QtGlobal>
+#include "kid3api.h"
 
 class QString;
 
 /** Alphabetically sorted list of genres, conversion to/from genre numbers */
-class Genres {
+class KID3_CORE_EXPORT Genres {
 public:
   /**
    * Get name assigned to genre number.
@@ -81,9 +81,9 @@ public:
 
   /** Number of genres */
 #ifdef Q_OS_WIN32
-  enum { count = 148 };
+  enum { count = 192 };
 #else
-  static const int count = 148;
+  static const int count = 192;
 #endif
   /**
    * Pointer to alphabetic list of genres.
@@ -91,7 +91,7 @@ public:
    */
   static const char** s_strList;
 
- private:
+private:
   /**
    * Alphabetic list of genres, starts with unknown (empty) entry.
    *
@@ -104,5 +104,3 @@ public:
    */
   static const unsigned char s_genreNum[Genres::count + 1];
 };
-
-#endif /* GENRES_H */
