@@ -6,7 +6,7 @@
  * \author Urs Fleisch
  * \date 03 Mar 2008
  *
- * Copyright (C) 2008-2017  Urs Fleisch
+ * Copyright (C) 2008-2018  Urs Fleisch
  *
  * This file is part of Kid3.
  *
@@ -29,17 +29,15 @@
 #include <QImage>
 #include <QBuffer>
 #include <QCoreApplication>
-#if QT_VERSION >= 0x050000
 #include <QMimeDatabase>
 #include <QMimeType>
-#endif
 
 namespace {
 
 /**
  * List of picture type strings, NULL terminated.
  */
-static const char* const pictureTypeNames[] = {
+const char* const pictureTypeNames[] = {
   QT_TRANSLATE_NOOP("@default", "Other"),
   QT_TRANSLATE_NOOP("@default", "32x32 pixels PNG file icon"),
   QT_TRANSLATE_NOOP("@default", "Other file icon"),
@@ -61,13 +59,13 @@ static const char* const pictureTypeNames[] = {
   QT_TRANSLATE_NOOP("@default", "Illustration"),
   QT_TRANSLATE_NOOP("@default", "Band/artist logotype"),
   QT_TRANSLATE_NOOP("@default", "Publisher/Studio logotype"),
-  NULL
+  nullptr
 };
 
 /**
  * List of untranslated picture type strings, NULL terminated.
  */
-static const char* const pictureTypeStrings[] = {
+const char* const pictureTypeStrings[] = {
   "Other",
   "Png Icon",
   "Icon",
@@ -89,7 +87,7 @@ static const char* const pictureTypeStrings[] = {
   "Illustration",
   "Band Logotype",
   "Publisher Logotype",
-  NULL
+  nullptr
 };
 
 }
@@ -147,7 +145,7 @@ PictureFrame::PictureFrame(
  */
 PictureFrame::PictureFrame(const Frame& frame)
 {
-  *(static_cast<Frame*>(this)) = frame;
+  *(static_cast<Frame*>(this)) = frame; // clazy:exclude=unneeded-cast
   setType(FT_Picture);
 
   // Make sure all fields are available in the correct order
@@ -159,13 +157,6 @@ PictureFrame::PictureFrame(const Frame& frame)
   setFields(*this, enc, imgFormat, mimeType, pictureType, description, data);
 }
 
-/**
- * Destructor.
- */
-PictureFrame::~PictureFrame()
-{
-}
-
 /**
  * Set all properties.
  *
@@ -281,8 +272,8 @@ void PictureFrame::getFields(const Frame& frame,
                              QString& description, QByteArray& data,
                              ImageProperties* imgProps)
 {
-  for (Frame::FieldList::const_iterator it = frame.getFieldList().begin();
-       it != frame.getFieldList().end();
+  for (auto it = frame.getFieldList().constBegin();
+       it != frame.getFieldList().constEnd();
        ++it) {
     switch ((*it).m_id) {
       case ID_TextEnc:
@@ -536,7 +527,7 @@ bool PictureFrame::setDataFromFile(Frame& frame, const QString& fileName)
     QFile file(fileName);
     if (file.open(QIODevice::ReadOnly)) {
       int size = file.size();
-      char* data = new char[size];
+      auto data = new char[size];
       QDataStream stream(&file);
       stream.readRawData(data, size);
       QByteArray ba;
@@ -601,40 +592,8 @@ bool PictureFrame::writeDataToFile(const Frame& frame, const QString& fileName)
 QString PictureFrame::getMimeTypeForFile(const QString& fileName,
                                          QString* imgFormat)
 {
-#if QT_VERSION >= 0x050000
   QMimeDatabase mimeDb;
   QString mimeType = mimeDb.mimeTypeForFile(fileName).name();
-#else
-  static const struct {
-    const char* ext;
-    const char* type;
-  } extType[] = {
-  { ".jpg",  "image/jpeg" },
-  { ".jpeg", "image/jpeg" },
-  { ".png",  "image/png" },
-  { ".gif",  "image/gif" },
-  { ".ico",  "image/vnd.microsoft.icon" },
-  { ".svg",  "image/svg+xml" },
-  { ".txt",  "text/plain" },
-  { ".html", "text/html" },
-  { ".htm",  "text/html" },
-  { ".css",  "text/css" },
-  { ".pdf",  "application/pdf" },
-  { ".bin",  "application/octet-stream" },
-  { ".js",   "application/javascript" },
-  { ".json", "application/json" },
-  { ".woff", "application/font-woff" },
-  { ".ttf",  "application/font-sfnt" },
-  { ".eot",  "application/vnd.ms-fontobject" }
-  };
-  QString mimeType;
-  for (unsigned int i = 0; i < sizeof extType / sizeof extType[0]; ++i) {
-    if (fileName.endsWith(QLatin1String(extType[i].ext), Qt::CaseInsensitive)) {
-      mimeType = QString::fromLatin1(extType[i].type);
-      break;
-    }
-  }
-#endif
   if (imgFormat) {
     if (mimeType == QLatin1String("image/jpeg")) {
       *imgFormat = QLatin1String("JPG");
@@ -663,6 +622,8 @@ bool PictureFrame::setMimeTypeFromFileName(Frame& frame, const QString& fileName
   return false;
 }
 
+namespace {
+
 /**
  * Get a 32-bit number from a byte array stored in big-endian order.
  *
@@ -671,14 +632,13 @@ bool PictureFrame::setMimeTypeFromFileName(Frame& frame, const QString& fileName
  *
  * @return big endian 32-bit value.
  */
-static unsigned long getBigEndianULongFromByteArray(const QByteArray& data,
-                                                    int index)
+unsigned long getBigEndianULongFromByteArray(const QByteArray& data, int index)
 {
   return
-     ((unsigned char)data[index + 3] & 0xff)        |
-    (((unsigned char)data[index + 2] & 0xff) << 8)  |
-    (((unsigned char)data[index + 1] & 0xff) << 16) |
-    (((unsigned char)data[index + 0] & 0xff) << 24);
+     (static_cast<unsigned char>(data[index + 3]) & 0xff)        |
+    ((static_cast<unsigned char>(data[index + 2]) & 0xff) << 8)  |
+    ((static_cast<unsigned char>(data[index + 1]) & 0xff) << 16) |
+    ((static_cast<unsigned char>(data[index + 0]) & 0xff) << 24);
 }
 
 /**
@@ -688,8 +648,8 @@ static unsigned long getBigEndianULongFromByteArray(const QByteArray& data,
  * @param data  byte array
  * @param index index of first byte in data
  */
-static void renderBigEndianULongToByteArray(unsigned long value,
-                                            QByteArray& data, int index)
+void renderBigEndianULongToByteArray(unsigned long value,
+                                     QByteArray& data, int index)
 {
   data[index + 3] = value & 0xff;
   value >>= 8;
@@ -708,14 +668,16 @@ static void renderBigEndianULongToByteArray(unsigned long value,
  * @param index index of first byte in data
  * @param len   number of bytes to copy
  */
-static void renderCharsToByteArray(const char* str, QByteArray& data,
-                                   int index, int len)
+void renderCharsToByteArray(const char* str, QByteArray& data,
+                            int index, int len)
 {
   for (int i = 0; i < len; ++i) {
     data[index++] = *str++;
   }
 }
 
+}
+
 /**
  * Set picture from a base64 string.
  *
@@ -730,7 +692,7 @@ void PictureFrame::setFieldsFromBase64(Frame& frame, const QString& base64Value)
   QString description(QLatin1String(""));
   ImageProperties imgProps;
   if (frame.getInternalName() == QLatin1String("METADATA_BLOCK_PICTURE")) {
-    unsigned long baSize = static_cast<unsigned long>(ba.size());
+    auto baSize = static_cast<unsigned long>(ba.size());
     if (baSize < 32) return;
     int index = 0;
     pictureType = static_cast<PictureFrame::PictureType>(
@@ -830,8 +792,8 @@ void PictureFrame::getFieldsToBase64(const Frame& frame, QString& base64Value)
  */
 QString PictureFrame::getPictureTypeName(PictureType type)
 {
-  if (type >= 0 &&
-      type < static_cast<int>(
+  if (static_cast<int>(type) >= 0 &&
+      static_cast<int>(type) < static_cast<int>(
         sizeof(pictureTypeNames) / sizeof(pictureTypeNames[0]) - 1)) {
     return QCoreApplication::translate("@default", pictureTypeNames[type]);
   }
@@ -855,9 +817,10 @@ const char* const* PictureFrame::getPictureTypeNames()
  */
 const char* PictureFrame::getPictureTypeString(PictureType type)
 {
-  return type >= 0 && type < static_cast<int>(
+  return static_cast<int>(type) >= 0 &&
+      static_cast<int>(type) < static_cast<int>(
         sizeof(pictureTypeStrings) / sizeof(pictureTypeStrings[0]) - 1)
-      ? pictureTypeStrings[type] : 0;
+      ? pictureTypeStrings[type] : nullptr;
 }
 
 /**
