@@ -6,7 +6,7 @@
  * \author Urs Fleisch
  * \date 23 Feb 2007
  *
- * Copyright (C) 2007-2013  Urs Fleisch
+ * Copyright (C) 2007-2018  Urs Fleisch
  *
  * This file is part of Kid3.
  *
@@ -38,13 +38,8 @@
  * @param str       string with format codes
  */
 TrackDataFormatReplacer::TrackDataFormatReplacer(
-  const TrackData& trackData, const QString& str) :
-  FrameFormatReplacer(trackData, str), m_trackData(trackData) {}
-
-/**
- * Destructor.
- */
-TrackDataFormatReplacer::~TrackDataFormatReplacer() {}
+  const TrackData& trackData, const QString& str)
+  : FrameFormatReplacer(trackData, str), m_trackData(trackData) {}
 
 /**
  * Replace a format code (one character %c or multiple characters %{chars}).
@@ -91,9 +86,9 @@ QString TrackDataFormatReplacer::getReplacement(const QString& code) const
         { "marked", 'w' }
       };
       const char c = code[0].toLatin1();
-      for (unsigned i = 0; i < sizeof(shortToLong) / sizeof(shortToLong[0]); ++i) {
-        if (shortToLong[i].shortCode == c) {
-          name = QString::fromLatin1(shortToLong[i].longCode);
+      for (const auto& s2l : shortToLong) {
+        if (s2l.shortCode == c) {
+          name = QString::fromLatin1(s2l.longCode);
           break;
         }
       }
@@ -121,6 +116,13 @@ QString TrackDataFormatReplacer::getReplacement(const QString& code) const
         url.setPath(m_trackData.getAbsFilename());
         url.setScheme(QLatin1String("file"));
         result = url.toString();
+      } else if (name == QLatin1String("dirname")) {
+        const QString dirPath = m_trackData.getDirname();
+        int sepPos = dirPath.lastIndexOf(QLatin1Char('/'));
+        if (sepPos < 0) {
+          sepPos = dirPath.lastIndexOf(QDir::separator());
+        }
+        result = sepPos >= 0 ? dirPath.mid(sepPos + 1) : dirPath;
       } else if (name == QLatin1String("duration")) {
         result = TaggedFile::formatTime(m_trackData.getFileDuration());
       } else if (name == QLatin1String("seconds")) {
@@ -195,6 +197,12 @@ QString TrackDataFormatReplacer::getToolTip(bool onlyRows)
   str += QCoreApplication::translate("@default", "URL");
   str += QLatin1String("</td></tr>\n");
 
+  str += QLatin1String("<tr><td></td><td>%{dirname}</td><td>");
+  const char* const directoryNameStr =
+      QT_TRANSLATE_NOOP("@default", "Directory name");
+  str += QCoreApplication::translate("@default", directoryNameStr);
+  str += QLatin1String("</td></tr>\n");
+
   str += QLatin1String("<tr><td>%d</td><td>%{duration}</td><td>");
   const char* const lengthStr = QT_TRANSLATE_NOOP("@default", "Length");
   str += QCoreApplication::translate("@default", lengthStr);
@@ -269,8 +277,7 @@ QString TrackDataFormatReplacer::getToolTip(bool onlyRows)
 /**
  * Constructor.
  */
-TrackData::TrackData()
-{}
+TrackData::TrackData() = default;
 
 /**
  * Constructor.
@@ -280,10 +287,10 @@ TrackData::TrackData()
  * @param taggedFile tagged file providing track data
  * @param tagVersion source of frames
  */
-TrackData::TrackData(TaggedFile& taggedFile, Frame::TagVersion tagVersion) :
-  m_taggedFileIndex(taggedFile.getIndex())
+TrackData::TrackData(TaggedFile& taggedFile, Frame::TagVersion tagVersion)
+  : m_taggedFileIndex(taggedFile.getIndex())
 {
-  foreach (Frame::TagNumber tagNr, Frame::tagNumbersFromMask(tagVersion)) {
+  for (Frame::TagNumber tagNr : Frame::tagNumbersFromMask(tagVersion)) {
     if (empty()) {
       taggedFile.getAllFrames(tagNr, *this);
     } else {
@@ -334,6 +341,17 @@ QString TrackData::getFilename() const
   return taggedFile ? taggedFile->getFilename() : QString();
 }
 
+/**
+ * Get directory name.
+ *
+ * @return directory name.
+ */
+QString TrackData::getDirname() const
+{
+  TaggedFile* taggedFile = getTaggedFile();
+  return taggedFile ? taggedFile->getDirname() : QString();
+}
+
 /**
  * Get the format of tag.
  *
@@ -479,9 +497,7 @@ QSet<QString> getLowerCaseWords(const QString& str)
   if (!str.isEmpty()) {
     QString normalized = str.normalized(QString::NormalizationForm_D).toLower();
     QString simplified;
-    for (QString::const_iterator it = normalized.constBegin();
-         it != normalized.constEnd();
-         ++it) {
+    for (auto it = normalized.constBegin(); it != normalized.constEnd(); ++it) {
       if (it->isLetter()) {
         simplified += *it;
       } else if (it->isPunct() || it->isSpace() || it->isSymbol()) {
@@ -577,7 +593,7 @@ QString ImportTrackDataVector::getFrame(Frame::Type type) const
       return result;
     TaggedFile* taggedFile = trackData.getTaggedFile();
     FrameCollection frames;
-    foreach (Frame::TagNumber tagNr, Frame::allTagNumbers()) {
+    for (Frame::TagNumber tagNr : Frame::allTagNumbers()) {
       taggedFile->getAllFrames(tagNr, frames);
       result = frames.getValue(type);
       if (!result.isEmpty())
@@ -598,7 +614,7 @@ void ImportTrackDataVector::readTags(Frame::TagVersion tagVersion)
   for (iterator it = begin(); it != end(); ++it) {
     if (TaggedFile* taggedFile = it->getTaggedFile()) {
       it->clear();
-      foreach (Frame::TagNumber tagNr, Frame::tagNumbersFromMask(tagVersion)) {
+      for (Frame::TagNumber tagNr : Frame::tagNumbersFromMask(tagVersion)) {
         if (it->empty()) {
           taggedFile->getAllFrames(tagNr, *it);
         } else {
