@@ -6,7 +6,7 @@
  * \author Urs Fleisch
  * \date 10 Aug 2013
  *
- * Copyright (C) 2013  Urs Fleisch
+ * Copyright (C) 2013-2018  Urs Fleisch
  *
  * This file is part of Kid3.
  *
@@ -34,8 +34,8 @@
 /**
  * Constructor.
  */
-CorePlatformTools::CorePlatformTools() :
-  m_settings(0), m_config(0)
+CorePlatformTools::CorePlatformTools()
+  : m_settings(nullptr)
 {
 }
 
@@ -44,7 +44,7 @@ CorePlatformTools::CorePlatformTools() :
  */
 CorePlatformTools::~CorePlatformTools()
 {
-  delete m_config;
+  // Must not be inline because of forwared declared QScopedPointer.
 }
 
 /**
@@ -63,9 +63,9 @@ ISettings* CorePlatformTools::applicationSettings()
       m_settings = new QSettings(
             QFile::decodeName(configPath), QSettings::IniFormat, qApp);
     }
-    m_config = new Kid3Settings(m_settings);
+    m_config.reset(new Kid3Settings(m_settings));
   }
-  return m_config;
+  return m_config.data();
 }
 
 #ifdef Q_OS_WIN32
@@ -142,8 +142,9 @@ bool CorePlatformTools::moveToTrash(const QString& path) const
 #include <QDir>
 #include <QDateTime>
 #include <QTextStream>
-#include <stdlib.h>
-#include <stdio.h>
+#include <QUrl>
+#include <cstdlib>
+#include <cstdio>
 #include <sys/types.h>
 #include <sys/stat.h>
 #include <unistd.h>
@@ -164,9 +165,11 @@ bool moveToTrashDir(const QFileInfo& fi, const QString& trashDir)
   QString destName(fileName);
   int counter = 1;
   while (QFile::exists(filesPath + QLatin1Char('/') + destName) ||
-         QFile::exists(infoPath + QLatin1Char('/') + destName + QLatin1String(".trashinfo"))) {
+         QFile::exists(infoPath + QLatin1Char('/') + destName +
+                       QLatin1String(".trashinfo"))) {
     ++counter;
-    destName = QString(QLatin1String("%1.%2.%3")).arg(baseName).arg(counter).arg(suffix);
+    destName = QString(QLatin1String("%1.%2.%3"))
+        .arg(baseName).arg(counter).arg(suffix);
   }
   if (!(QDir(filesPath).exists() ||
         QDir().mkpath(filesPath)) ||
@@ -178,9 +181,9 @@ bool moveToTrashDir(const QFileInfo& fi, const QString& trashDir)
   if (!file.open(QIODevice::WriteOnly))
     return false;
   QTextStream stream(&file);
-  stream << QString(QLatin1String("[Trash Info]\nPath=%1\nDeletionDate=%2\n")).
-    arg(absPath).
-    arg(QDateTime::currentDateTime().toString(Qt::ISODate));
+  stream << QString(QLatin1String("[Trash Info]\nPath=%1\nDeletionDate=%2\n"))
+    .arg(QString::fromLatin1(QUrl(absPath).toEncoded()),
+         QDateTime::currentDateTime().toString(Qt::ISODate));
   file.close();
   return QDir().rename(absPath, filesPath + QLatin1Char('/') + destName);
 }
@@ -191,7 +194,7 @@ bool findMountPoint(dev_t dev, QString& mountPoint)
   if (FILE* fp = ::setmntent("/proc/mounts", "r")) {
     struct stat st;
     struct mntent* mnt;
-    while ((mnt = ::getmntent(fp)) != 0) {
+    while ((mnt = ::getmntent(fp)) != nullptr) {
       if (::stat(mnt->mnt_dir, &st) != 0) {
         continue;
       }
@@ -223,11 +226,7 @@ bool findExtVolumeTrash(const QString& volumeRoot, QString& trashDir)
   } else {
     trashDir += QString(QLatin1String("-%1")).arg(uid);
   }
-  if (QDir(trashDir).exists() ||
-      QDir().mkpath(trashDir)) {
-    return true;
-  }
-  return false;
+  return QDir(trashDir).exists() || QDir().mkpath(trashDir);
 }
 
 } // anonymous namespace
@@ -257,7 +256,8 @@ bool CorePlatformTools::moveFileToTrash(const QString& path)
   QString trashDir;
   if (pathStat.st_dev == trashStat.st_dev) {
     QByteArray xdhEnv = qgetenv("XDG_DATA_HOME");
-    topDir = !xdhEnv.isEmpty() ? QString::fromLatin1(xdhEnv) : QDir::homePath() + QLatin1String("/.local/share");
+    topDir = !xdhEnv.isEmpty() ? QString::fromLatin1(xdhEnv)
+                               : QDir::homePath() + QLatin1String("/.local/share");
     trashDir = topDir + QLatin1String("/Trash");
   } else if (!(findMountPoint(pathStat.st_dev, topDir) &&
                findExtVolumeTrash(topDir, trashDir))) {
