@@ -6,7 +6,7 @@
  * \author Urs Fleisch
  * \date 10 Aug 2013
  *
- * Copyright (C) 2013  Urs Fleisch
+ * Copyright (C) 2013-2018  Urs Fleisch
  *
  * This file is part of Kid3.
  *
@@ -24,9 +24,9 @@
  * along with this program.  If not, see <http://www.gnu.org/licenses/>.
  */
 
-#ifndef COREPLATFORMTOOLS_H
-#define COREPLATFORMTOOLS_H
+#pragma once
 
+#include <QScopedPointer>
 #include "icoreplatformtools.h"
 
 class QSettings;
@@ -44,13 +44,13 @@ public:
   /**
    * Destructor.
    */
-  virtual ~CorePlatformTools();
+  virtual ~CorePlatformTools() override;
 
   /**
    * Get application settings.
    * @return settings instance.
    */
-  virtual ISettings* applicationSettings();
+  virtual ISettings* applicationSettings() override;
 
   /**
    * Move file or directory to trash.
@@ -59,7 +59,7 @@ public:
    *
    * @return true if ok.
    */
-  virtual bool moveToTrash(const QString& path) const;
+  virtual bool moveToTrash(const QString& path) const override;
 
   /**
    * Construct a name filter string suitable for file dialogs.
@@ -68,14 +68,14 @@ public:
    * @return name filter string.
    */
   virtual QString fileDialogNameFilter(
-      const QList<QPair<QString, QString> >& nameFilters) const;
+      const QList<QPair<QString, QString> >& nameFilters) const override;
 
   /**
    * Get file pattern part of m_nameFilter.
    * @param nameFilter name filter string
    * @return file patterns, e.g. "*.mp3".
    */
-  virtual QString getNameFilterPatterns(const QString& nameFilter) const;
+  virtual QString getNameFilterPatterns(const QString& nameFilter) const override;
 
 #if !defined Q_OS_WIN32 && !defined Q_OS_MAC
   /**
@@ -90,7 +90,5 @@ public:
 
 private:
   QSettings* m_settings;
-  ISettings* m_config;
+  QScopedPointer<ISettings> m_config;
 };
-
-#endif // COREPLATFORMTOOLS_H
