@@ -6,7 +6,7 @@
  * \author Urs Fleisch
  * \date 06 Apr 2013
  *
- * Copyright (C) 2013  Urs Fleisch
+ * Copyright (C) 2013-2018  Urs Fleisch
  *
  * This file is part of Kid3.
  *
@@ -24,14 +24,14 @@
  * along with this program.  If not, see <http://www.gnu.org/licenses/>.
  */
 
-#ifndef ICOREPLATFORMTOOLS_H
-#define ICOREPLATFORMTOOLS_H
+#pragma once
 
 #include <QList>
 #include <QPair>
 #include "kid3api.h"
 
 class QString;
+class QWidget;
 class ISettings;
 
 /**
@@ -75,6 +75,48 @@ public:
    */
   virtual QString getNameFilterPatterns(const QString& nameFilter) const = 0;
 
+  /**
+   * Display dialog to select an existing file.
+   * This default implementation only displays a warning, it is only supported
+   * when having a GUI.
+   * @param parent parent widget
+   * @param caption caption
+   * @param dir directory
+   * @param filter filter
+   * @param selectedFilter the selected filter is returned here
+   * @return selected file, empty if canceled.
+   */
+  virtual QString getOpenFileName(QWidget* parent,
+      const QString& caption, const QString& dir, const QString& filter,
+      QString* selectedFilter);
+
+  /**
+   * Display dialog to select a file to save.
+   * This default implementation only displays a warning, it is only supported
+   * when having a GUI.
+   * @param parent parent widget
+   * @param caption caption
+   * @param dir directory
+   * @param filter filter
+   * @param selectedFilter the selected filter is returned here
+   * @return selected file, empty if canceled.
+   */
+  virtual QString getSaveFileName(QWidget* parent,
+      const QString& caption, const QString& dir, const QString& filter,
+      QString* selectedFilter);
+
+  /**
+   * Display dialog to select an existing directory.
+   * This default implementation only displays a warning, it is only supported
+   * when having a GUI.
+   * @param parent parent widget
+   * @param caption caption
+   * @param startDir start directory
+   * @return selected directory, empty if canceled.
+   */
+  virtual QString getExistingDirectory(QWidget* parent,
+      const QString& caption, const QString& startDir);
+
 protected:
   /**
    * Construct a name filter string suitable for file dialogs.
@@ -96,5 +138,3 @@ protected:
    */
   static QString qtNameFilterPatterns(const QString& nameFilter);
 };
-
-#endif // ICOREPLATFORMTOOLS_H
