@@ -6,7 +6,7 @@
  * \author Urs Fleisch
  * \date 26 Mar 2013
  *
- * Copyright (C) 2013  Urs Fleisch
+ * Copyright (C) 2013-2018  Urs Fleisch
  *
  * This file is part of Kid3.
  *
@@ -35,11 +35,7 @@
 
 namespace {
 
-#if QT_VERSION >= 0x050000
 const char* const QT_TRANSLATION_PREFIX = "qtbase_";
-#else
-const char* const QT_TRANSLATION_PREFIX = "qt_";
-#endif
 
 }
 
@@ -54,7 +50,7 @@ void Utils::loadTranslation(const QString& lang)
   QLocale locale;
 
   QStringList languages(
-#if QT_VERSION >= 0x040800 && !defined Q_OS_WIN32
+#ifndef Q_OS_WIN32
         locale.uiLanguages()
 #else
         locale.name()
@@ -75,11 +71,12 @@ void Utils::loadTranslation(const QString& lang)
   const QString searchDelimiters(QLatin1String("_.-"));
 
   // translation file for Qt
-  QTranslator* qtTr = new QTranslator(qApp);
-  foreach (const QString& localeName, languages) {
+  auto qtTr = new QTranslator(qApp);
+  const auto localeNames = languages;
+  for (const QString& localeName : localeNames) {
     if (
         localeName.startsWith(QLatin1String("en")) ||
-#if defined Q_OS_WIN32 || defined Q_OS_MAC
+#if defined Q_OS_WIN32 || defined Q_OS_MAC || defined Q_OS_ANDROID
         (!translationsDir.isNull() &&
          qtTr->load(QLatin1String(QT_TRANSLATION_PREFIX) + localeName,
                     translationsDir, searchDelimiters)) ||
@@ -97,8 +94,8 @@ void Utils::loadTranslation(const QString& lang)
   qApp->installTranslator(qtTr);
 
   // translation file for application strings
-  QTranslator* kid3Tr = new QTranslator(qApp);
-  foreach (const QString& localeName, languages) {
+  auto kid3Tr = new QTranslator(qApp);
+  for (const QString& localeName : localeNames) {
     if (
         localeName.startsWith(QLatin1String("en")) ||
         (!translationsDir.isNull() &&
