@@ -6,7 +6,7 @@
  * \author Urs Fleisch
  * \date 2 Jan 2013
  *
- * Copyright (C) 2013  Urs Fleisch
+ * Copyright (C) 2013-2018  Urs Fleisch
  *
  * This file is part of Kid3.
  *
@@ -34,6 +34,7 @@
 #include <QLabel>
 #include <QString>
 #include <QTableView>
+#include <QHeaderView>
 #include "batchimporter.h"
 #include "batchimportsourcedialog.h"
 #include "batchimportconfig.h"
@@ -42,6 +43,8 @@
 #include "contexthelp.h"
 #include "abstractlistedit.h"
 
+namespace {
+
 /**
  * Widget to edit a list of import sources.
  */
@@ -54,12 +57,12 @@ public:
    * @param parent parent widget
    */
   explicit BatchImportSourceListEdit(BatchImportSourcesModel* model,
-                                     QWidget* parent = 0);
+                                     QWidget* parent = nullptr);
 
   /**
    * Destructor.
    */
-  virtual ~BatchImportSourceListEdit();
+  virtual ~BatchImportSourceListEdit() override = default;
 
   /**
    * Set names of import servers.
@@ -69,18 +72,20 @@ public:
     m_serverNames = servers;
   }
 
-public slots:
+public:
   /**
    * Add a new item.
    */
-  virtual void addItem();
+  virtual void addItem() override;
 
   /**
    * Edit the selected item.
    */
-  virtual void editItem();
+  virtual void editItem() override;
 
 private:
+  Q_DISABLE_COPY(BatchImportSourceListEdit)
+
   QTableView* m_tableView;
   QStringList m_serverNames;
 };
@@ -92,23 +97,13 @@ private:
  * @param parent parent widget
  */
 BatchImportSourceListEdit::BatchImportSourceListEdit(
-    BatchImportSourcesModel* model, QWidget* parent) :
-  AbstractListEdit(m_tableView = new QTableView, model, parent)
+    BatchImportSourcesModel* model, QWidget* parent)
+  : AbstractListEdit(m_tableView = new QTableView, model, parent)
 {
   setObjectName(QLatin1String("BatchImportSourceListEdit"));
   m_tableView->setSelectionBehavior(QAbstractItemView::SelectRows);
-#if QT_VERSION >= 0x050000
-  m_tableView->horizontalHeader()->setSectionResizeMode(QHeaderView::ResizeToContents);
-#else
-  m_tableView->horizontalHeader()->setResizeMode(QHeaderView::ResizeToContents);
-#endif
-}
-
-/**
- * Destructor.
- */
-BatchImportSourceListEdit::~BatchImportSourceListEdit()
-{
+  m_tableView->horizontalHeader()->setSectionResizeMode(
+        QHeaderView::ResizeToContents);
 }
 
 /**
@@ -116,12 +111,12 @@ BatchImportSourceListEdit::~BatchImportSourceListEdit()
  */
 void BatchImportSourceListEdit::addItem()
 {
-  BatchImportSourceDialog* dialog = new BatchImportSourceDialog(this);
+  auto dialog = new BatchImportSourceDialog(this);
   dialog->setServerNames(m_serverNames);
   if (dialog->exec() == QDialog::Accepted) {
     BatchImportProfile::Source source;
     dialog->getSource(source);
-    if (BatchImportSourcesModel* model =
+    if (auto model =
         qobject_cast<BatchImportSourcesModel*>(getItemView()->model())) {
       int row = model->rowCount();
       model->insertRow(row);
@@ -137,11 +132,11 @@ void BatchImportSourceListEdit::editItem()
 {
   QModelIndex index = getItemView()->currentIndex();
   if (index.isValid()) {
-    if (BatchImportSourcesModel* model =
+    if (auto model =
         qobject_cast<BatchImportSourcesModel*>(getItemView()->model())) {
       BatchImportProfile::Source source;
       model->getBatchImportSource(index.row(), source);
-      BatchImportSourceDialog* dialog = new BatchImportSourceDialog(this);
+      auto dialog = new BatchImportSourceDialog(this);
       dialog->setServerNames(m_serverNames);
       dialog->setSource(source);
       if (dialog->exec() == QDialog::Accepted) {
@@ -152,6 +147,7 @@ void BatchImportSourceListEdit::editItem()
   }
 }
 
+}
 
 /**
  * Constructor.
@@ -167,8 +163,8 @@ BatchImportDialog::BatchImportDialog(const QList<ServerImporter*>& importers,
   setWindowTitle(tr("Automatic Import"));
   setSizeGripEnabled(true);
 
-  QVBoxLayout* vlayout = new QVBoxLayout(this);
-  QSplitter* splitter = new QSplitter(Qt::Vertical);
+  auto vlayout = new QVBoxLayout(this);
+  auto splitter = new QSplitter(Qt::Vertical);
 
   m_edit = new QTextEdit(this);
   m_edit->setReadOnly(true);
@@ -176,18 +172,17 @@ BatchImportDialog::BatchImportDialog(const QList<ServerImporter*>& importers,
   splitter->addWidget(m_edit);
 
   QWidget* profileWidget = new QWidget;
-  QVBoxLayout* profileLayout = new QVBoxLayout(profileWidget);
+  auto profileLayout = new QVBoxLayout(profileWidget);
   profileLayout->setContentsMargins(0, 0, 0, 0);
 
-  QHBoxLayout* destLayout = new QHBoxLayout;
+  auto destLayout = new QHBoxLayout;
   QLabel* destLabel = new QLabel(tr("D&estination:"));
   destLayout->addWidget(destLabel);
   m_destComboBox = new QComboBox;
   m_destComboBox->setEditable(false);
-  QList<QPair<Frame::TagVersion, QString> > tagVersions =
+  const QList<QPair<Frame::TagVersion, QString> > tagVersions =
       Frame::availableTagVersions();
-  for (QList<QPair<Frame::TagVersion, QString> >::const_iterator it =
-       tagVersions.constBegin(); it != tagVersions.constEnd(); ++it) {
+  for (auto it = tagVersions.constBegin(); it != tagVersions.constEnd(); ++it) {
     m_destComboBox->addItem(it->second, it->first);
   }
   destLabel->setBuddy(m_destComboBox);
@@ -195,49 +190,54 @@ BatchImportDialog::BatchImportDialog(const QList<ServerImporter*>& importers,
   destLayout->addStretch();
   profileLayout->addLayout(destLayout);
 
-  QHBoxLayout* nameLayout = new QHBoxLayout;
+  auto nameLayout = new QHBoxLayout;
   QLabel* profileLabel = new QLabel(tr("&Profile:"));
   nameLayout->addWidget(profileLabel);
   m_profileComboBox = new QComboBox;
   m_profileComboBox->setEditable(true);
-  connect(m_profileComboBox, SIGNAL(activated(int)),
-          this, SLOT(changeProfile(int)));
-  connect(m_profileComboBox, SIGNAL(editTextChanged(QString)),
-          this, SLOT(changeProfileName(QString)));
+  connect(m_profileComboBox, static_cast<void (QComboBox::*)(int)>(
+            &QComboBox::activated),
+          this, &BatchImportDialog::changeProfile);
+  connect(m_profileComboBox, &QComboBox::editTextChanged,
+          this, &BatchImportDialog::changeProfileName);
   profileLabel->setBuddy(m_profileComboBox);
   nameLayout->addWidget(m_profileComboBox, 1);
   QPushButton* profileAddButton = new QPushButton(tr("Add"));
-  connect(profileAddButton, SIGNAL(clicked()),
-          this, SLOT(addProfile()));
+  connect(profileAddButton, &QAbstractButton::clicked,
+          this, &BatchImportDialog::addProfile);
   nameLayout->addWidget(profileAddButton);
   QPushButton* profileRemoveButton = new QPushButton(tr("Remove"));
-  connect(profileRemoveButton, SIGNAL(clicked()),
-          this, SLOT(removeProfile()));
+  connect(profileRemoveButton, &QAbstractButton::clicked,
+          this, &BatchImportDialog::removeProfile);
   nameLayout->addWidget(profileRemoveButton);
   profileLayout->addLayout(nameLayout);
 
   QStringList servers;
-  foreach (const ServerImporter* si, m_importers) {
+  servers.reserve(m_importers.size());
+  const auto sis = m_importers;
+  for (const ServerImporter* si : sis) {
     servers.append(QString::fromLatin1(si->name()));
   }
   m_profileModel = new BatchImportSourcesModel(this);
-  BatchImportSourceListEdit* profileListEdit =
+  auto profileListEdit =
       new BatchImportSourceListEdit(m_profileModel, this);
   profileListEdit->setServerNames(servers);
   profileLayout->addWidget(profileListEdit);
   splitter->addWidget(profileWidget);
   vlayout->addWidget(splitter);
 
-  QHBoxLayout* hlayout = new QHBoxLayout;
+  auto hlayout = new QHBoxLayout;
   QPushButton* helpButton = new QPushButton(tr("&Help"), this);
   helpButton->setAutoDefault(false);
   hlayout->addWidget(helpButton);
-  connect(helpButton, SIGNAL(clicked()), this, SLOT(showHelp()));
+  connect(helpButton, &QAbstractButton::clicked,
+          this, &BatchImportDialog::showHelp);
 
   QPushButton* saveButton = new QPushButton(tr("&Save Settings"), this);
   saveButton->setAutoDefault(false);
   hlayout->addWidget(saveButton);
-  connect(saveButton, SIGNAL(clicked()), this, SLOT(saveConfig()));
+  connect(saveButton, &QAbstractButton::clicked,
+          this, &BatchImportDialog::saveConfig);
   hlayout->addStretch();
 
   m_startAbortButton = new QPushButton(this);
@@ -248,19 +248,14 @@ BatchImportDialog::BatchImportDialog(const QList<ServerImporter*>& importers,
   closeButton->setAutoDefault(false);
   hlayout->addWidget(m_startAbortButton);
   hlayout->addWidget(closeButton);
-  connect(m_startAbortButton, SIGNAL(clicked()), this, SLOT(startOrAbortImport()));
-  connect(closeButton, SIGNAL(clicked()), this, SLOT(reject()));
-  connect(this, SIGNAL(rejected()), this, SIGNAL(abort()));
+  connect(m_startAbortButton, &QAbstractButton::clicked,
+          this, &BatchImportDialog::startOrAbortImport);
+  connect(closeButton, &QAbstractButton::clicked, this, &QDialog::reject);
+  connect(this, &QDialog::rejected, this, &BatchImportDialog::abort);
 
   vlayout->addLayout(hlayout);
 }
 
-/**
- * Destructor.
- */
-BatchImportDialog::~BatchImportDialog()
-{}
-
 /**
  * Start or abort batch import.
  */
@@ -361,7 +356,7 @@ void BatchImportDialog::setProfileFromGuiControls()
     m_profileComboBox->setEditText(m_profiles.at(0).getName());
   }
   if (m_profileIdx >= 0 && m_profileIdx < m_profiles.size()) {
-    BatchImportProfile& profile = m_profiles[m_profileIdx];
+    BatchImportProfile& profile = m_profiles[m_profileIdx]; // clazy:exclude=detaching-member
     profile.setSources(sources);
   }
 }
@@ -382,10 +377,12 @@ void BatchImportDialog::setGuiControlsFromProfile()
     m_profileIdx = 0;
   m_profileModel->setBatchImportSources(m_profiles.at(m_profileIdx).getSources());
   if (m_profileComboBox->count() == m_profiles.size()) {
-    m_profileComboBox->setItemText(m_profileIdx, m_profiles.at(m_profileIdx).getName());
+    m_profileComboBox->setItemText(m_profileIdx,
+                                   m_profiles.at(m_profileIdx).getName());
   } else {
     m_profileComboBox->clear();
-    foreach (const BatchImportProfile& profile, m_profiles) {
+    const auto profiles = m_profiles;
+    for (const BatchImportProfile& profile : profiles) {
       m_profileComboBox->addItem(profile.getName());
     }
   }
@@ -402,8 +399,7 @@ void BatchImportDialog::setProfileFromConfig()
   const QStringList sources = batchImportCfg.profileSources();
 
   m_profiles.clear();
-  QStringList::const_iterator namesIt, sourcesIt;
-  for (namesIt = names.constBegin(), sourcesIt = sources.constBegin();
+  for (auto namesIt = names.constBegin(), sourcesIt = sources.constBegin();
        namesIt != names.constEnd() && sourcesIt != sources.constEnd();
        ++namesIt, ++sourcesIt) {
     BatchImportProfile profile;
@@ -446,7 +442,10 @@ void BatchImportDialog::saveConfig()
 
   QStringList names, sources;
   setProfileFromGuiControls();
-  foreach (const BatchImportProfile& profile, m_profiles) {
+  names.reserve(m_profiles.size());
+  sources.reserve(m_profiles.size());
+  const auto profiles = m_profiles;
+  for (const BatchImportProfile& profile : profiles) {
     names.append(profile.getName());
     sources.append(profile.getSourcesAsString());
   }
