@@ -24,12 +24,9 @@
  * along with this program.  If not, see <http://www.gnu.org/licenses/>.
  */
 
-#ifndef CONFIGDIALOGPAGES_H
-#define CONFIGDIALOGPAGES_H
+#pragma once
 
 #include <QObject>
-#include <QStringList>
-#include "config.h"
 #include "kid3api.h"
 
 class QCheckBox;
@@ -63,12 +60,12 @@ public:
   /**
    * Constructor.
    */
-  explicit ConfigDialogPages(IPlatformTools* platformTools, QObject* parent = 0);
+  explicit ConfigDialogPages(IPlatformTools* platformTools, QObject* parent = nullptr);
 
   /**
    * Destructor.
    */
-  virtual ~ConfigDialogPages();
+  virtual ~ConfigDialogPages() override = default;
 
   /**
    * Create page with tags settings.
@@ -116,6 +113,10 @@ public slots:
    */
   void setDefaultConfig();
 
+private slots:
+  void editFormatsFromTag();
+  void editFormatsToTag();
+
 private:
   /**
    * Set values in dialog from given configurations.
@@ -207,6 +208,8 @@ private:
   CheckableStringListModel* m_enabledMetadataPluginsModel;
   /** Model with enabled plugins */
   CheckableStringListModel* m_enabledPluginsModel;
+  /** Available formats for tag to filename */
+  QStringList m_toFilenameFormats;
+  /** Available formats for tag from filename */
+  QStringList m_fromFilenameFormats;
 };
-
-#endif
