@@ -6,7 +6,7 @@
  * \author Urs Fleisch
  * \date 16 Jan 2008
  *
- * Copyright (C) 2008-2013  Urs Fleisch
+ * Copyright (C) 2008-2018  Urs Fleisch
  *
  * This file is part of Kid3.
  *
@@ -49,11 +49,11 @@ FilterDialog::FilterDialog(QWidget* parent) : QDialog(parent),
   setWindowTitle(tr("Filter"));
   setSizeGripEnabled(true);
 
-  QVBoxLayout* vlayout = new QVBoxLayout(this);
+  auto vlayout = new QVBoxLayout(this);
   m_previewBox = new QGroupBox(tr("&Preview"));
   m_previewBox->setCheckable(true);
   m_previewBox->setChecked(false);
-  QVBoxLayout* previewLayout = new QVBoxLayout(m_previewBox);
+  auto previewLayout = new QVBoxLayout(m_previewBox);
   m_edit = new QTextEdit;
   m_edit->setReadOnly(true);
   m_edit->setTabStopWidth(20);
@@ -62,25 +62,23 @@ FilterDialog::FilterDialog(QWidget* parent) : QDialog(parent),
   vlayout->addWidget(m_previewBox);
 
   m_formatListEdit = new FormatListEdit(
-        QStringList() << tr("&Filter:")
-                      << tr("&Expression:"),
-        QStringList() << QString()
-                      << FileFilter::getFormatToolTip(),
+        {tr("&Filter:"), tr("&Expression:")},
+        {QString(), FileFilter::getFormatToolTip()},
         this);
   vlayout->addWidget(m_formatListEdit);
 
-  QHBoxLayout* hlayout = new QHBoxLayout;
+  auto hlayout = new QHBoxLayout;
   QPushButton* helpButton = new QPushButton(tr("&Help"), this);
   helpButton->setAutoDefault(false);
   hlayout->addWidget(helpButton);
-  connect(helpButton, SIGNAL(clicked()), this, SLOT(showHelp()));
+  connect(helpButton, &QAbstractButton::clicked, this, &FilterDialog::showHelp);
 
   QPushButton* saveButton = new QPushButton(tr("&Save Settings"), this);
   saveButton->setAutoDefault(false);
   hlayout->addWidget(saveButton);
-  connect(saveButton, SIGNAL(clicked()), this, SLOT(saveConfig()));
+  connect(saveButton, &QAbstractButton::clicked, this, &FilterDialog::saveConfig);
 
-  QSpacerItem* hspacer = new QSpacerItem(16, 0, QSizePolicy::Expanding,
+  auto hspacer = new QSpacerItem(16, 0, QSizePolicy::Expanding,
                                          QSizePolicy::Minimum);
   hlayout->addItem(hspacer);
 
@@ -92,19 +90,13 @@ FilterDialog::FilterDialog(QWidget* parent) : QDialog(parent),
   closeButton->setAutoDefault(false);
   hlayout->addWidget(m_applyButton);
   hlayout->addWidget(closeButton);
-  connect(m_applyButton, SIGNAL(clicked()), this, SLOT(applyOrAbortFilter()));
-  connect(closeButton, SIGNAL(clicked()), this, SLOT(reject()));
-  connect(this, SIGNAL(rejected()), &m_fileFilter, SLOT(abort()));
+  connect(m_applyButton, &QAbstractButton::clicked, this, &FilterDialog::applyOrAbortFilter);
+  connect(closeButton, &QAbstractButton::clicked, this, &QDialog::reject);
+  connect(this, &FilterDialog::rejected, &m_fileFilter, &FileFilter::abort);
 
   vlayout->addLayout(hlayout);
 }
 
-/**
- * Destructor.
- */
-FilterDialog::~FilterDialog()
-{}
-
 /**
  * Apply or abort filter.
  */
@@ -130,8 +122,7 @@ void FilterDialog::setFiltersFromConfig()
 {
   const FilterConfig& filterCfg = FilterConfig::instance();
   m_formatListEdit->setFormats(
-        QList<QStringList>() << filterCfg.filterNames()
-                             << filterCfg.filterExpressions(),
+        {filterCfg.filterNames(), filterCfg.filterExpressions()},
         filterCfg.filterIndex());
 }
 
