@@ -47,6 +47,7 @@
 #include <QMenu>
 #include <QCoreApplication>
 #include "config.h"
+#include "importconfig.h"
 #include "genres.h"
 #include "serverimporter.h"
 #include "servertrackimporter.h"
@@ -93,23 +94,18 @@ ImportDialog::ImportDialog(IPlatformTools* platformTools,
                            TrackDataModel* trackDataModel,
                            GenreModel* genreModel,
                            const QList<ServerImporter*>& importers,
-                           const QList<ServerTrackImporter*>& trackImporters) :
-  QDialog(parent), m_platformTools(platformTools),
-  m_autoStartSubDialog(-1), m_columnVisibility(0ULL),
-  m_trackDataModel(trackDataModel), m_importers(importers),
-  m_trackImporters(trackImporters)
+                           const QList<ServerTrackImporter*>& trackImporters)
+  : QDialog(parent), m_platformTools(platformTools),
+    m_autoStartSubDialog(-1), m_columnVisibility(0ULL),
+    m_trackDataModel(trackDataModel), m_importers(importers),
+    m_trackImporters(trackImporters)
 {
   setObjectName(QLatin1String("ImportDialog"));
   setModal(false);
   setWindowTitle(caption);
   setSizeGripEnabled(true);
 
-  m_serverImportDialog = 0;
-  m_textImportDialog = 0;
-  m_tagImportDialog = 0;
-  m_serverTrackImportDialog = 0;
-
-  QVBoxLayout* vlayout = new QVBoxLayout(this);
+  auto vlayout = new QVBoxLayout(this);
 
   m_trackDataTable = new QTableView(this);
   m_trackDataTable->setModel(m_trackDataModel);
@@ -117,23 +113,18 @@ ImportDialog::ImportDialog(IPlatformTools* platformTools,
   m_trackDataTable->setItemDelegateForColumn(
         m_trackDataModel->columnForFrameType(Frame::FT_Genre),
         new FrameItemDelegate(genreModel, this));
-#if QT_VERSION >= 0x050000
   m_trackDataTable->verticalHeader()->setSectionsMovable(true);
   m_trackDataTable->horizontalHeader()->setSectionsMovable(true);
-#else
-  m_trackDataTable->verticalHeader()->setMovable(true);
-  m_trackDataTable->horizontalHeader()->setMovable(true);
-#endif
   m_trackDataTable->horizontalHeader()->setContextMenuPolicy(
         Qt::CustomContextMenu);
-  connect(m_trackDataTable->verticalHeader(), SIGNAL(sectionMoved(int,int,int)),
-          this, SLOT(moveTableRow(int,int,int)));
+  connect(m_trackDataTable->verticalHeader(), &QHeaderView::sectionMoved,
+          this, &ImportDialog::moveTableRow);
   connect(m_trackDataTable->horizontalHeader(),
-          SIGNAL(customContextMenuRequested(QPoint)),
-      this, SLOT(showTableHeaderContextMenu(QPoint)));
+          &QWidget::customContextMenuRequested,
+      this, &ImportDialog::showTableHeaderContextMenu);
   vlayout->addWidget(m_trackDataTable);
 
-  QHBoxLayout* accuracyLayout = new QHBoxLayout;
+  auto accuracyLayout = new QHBoxLayout;
   QLabel* accuracyLabel = new QLabel(tr("Accuracy:"));
   accuracyLayout->addWidget(accuracyLabel);
   m_accuracyPercentLabel = new QLabel(QLatin1String("-"));
@@ -143,11 +134,12 @@ ImportDialog::ImportDialog(IPlatformTools* platformTools,
   QLabel* coverArtLabel = new QLabel(tr("Cover Art:"));
   accuracyLayout->addWidget(coverArtLabel);
   m_coverArtUrlLabel = new QLabel(QLatin1String(" -"));
-  m_coverArtUrlLabel->setSizePolicy(QSizePolicy::Ignored, QSizePolicy::Preferred);
+  m_coverArtUrlLabel->setSizePolicy(QSizePolicy::Ignored,
+                                    QSizePolicy::Preferred);
   accuracyLayout->addWidget(m_coverArtUrlLabel, 1);
   vlayout->addLayout(accuracyLayout);
 
-  QHBoxLayout* butlayout = new QHBoxLayout;
+  auto butlayout = new QHBoxLayout;
   QPushButton* fileButton = new QPushButton(tr("From F&ile/Clipboard..."));
   fileButton->setAutoDefault(false);
   butlayout->addWidget(fileButton);
@@ -159,10 +151,12 @@ ImportDialog::ImportDialog(IPlatformTools* platformTools,
   butlayout->addWidget(serverButton);
   m_serverComboBox = new QComboBox;
   m_serverComboBox->setEditable(false);
-  foreach (const ServerImporter* si, m_importers) {
+  const auto sis = m_importers;
+  for (const ServerImporter* si : sis) {
     m_serverComboBox->addItem(QCoreApplication::translate("@default", si->name()));
   }
-  foreach (const ServerTrackImporter* si, m_trackImporters) {
+  const auto stis = m_trackImporters;
+  for (const ServerTrackImporter* si : stis) {
     m_serverComboBox->addItem(QCoreApplication::translate("@default", si->name()));
   }
   butlayout->addWidget(m_serverComboBox);
@@ -170,7 +164,7 @@ ImportDialog::ImportDialog(IPlatformTools* platformTools,
     serverButton->hide();
     m_serverComboBox->hide();
   }
-  QSpacerItem* butspacer = new QSpacerItem(16, 0, QSizePolicy::Expanding,
+  auto butspacer = new QSpacerItem(16, 0, QSizePolicy::Expanding,
                                          QSizePolicy::Minimum);
   butlayout->addItem(butspacer);
   QLabel* destLabel = new QLabel;
@@ -178,32 +172,31 @@ ImportDialog::ImportDialog(IPlatformTools* platformTools,
   butlayout->addWidget(destLabel);
   m_destComboBox = new QComboBox;
   m_destComboBox->setEditable(false);
-  QList<QPair<Frame::TagVersion, QString> > tagVersions =
+  const QList<QPair<Frame::TagVersion, QString> > tagVersions =
       Frame::availableTagVersions();
-  for (QList<QPair<Frame::TagVersion, QString> >::const_iterator it =
-       tagVersions.constBegin(); it != tagVersions.constEnd(); ++it) {
+  for (auto it = tagVersions.constBegin(); it != tagVersions.constEnd(); ++it) {
     m_destComboBox->addItem(it->second, it->first);
   }
   destLabel->setBuddy(m_destComboBox);
   butlayout->addWidget(m_destComboBox);
-  QToolButton* revertButton = new QToolButton;
+  auto revertButton = new QToolButton;
   revertButton->setIcon(
         m_platformTools->iconFromTheme(QLatin1String("document-revert")));
   revertButton->setToolTip(tr("Revert"));
   revertButton->setShortcut(QKeySequence::Undo);
-  connect(revertButton, SIGNAL(clicked()),
-          this, SLOT(changeTagDestination()));
+  connect(revertButton, &QAbstractButton::clicked,
+          this, &ImportDialog::changeTagDestination);
   butlayout->addWidget(revertButton);
   vlayout->addLayout(butlayout);
 
-  QHBoxLayout* matchLayout = new QHBoxLayout;
+  auto matchLayout = new QHBoxLayout;
   m_mismatchCheckBox = new QCheckBox(
     tr("Check maximum allowable time &difference (sec):"));
   matchLayout->addWidget(m_mismatchCheckBox);
   m_maxDiffSpinBox = new QSpinBox;
   m_maxDiffSpinBox->setMaximum(9999);
   matchLayout->addWidget(m_maxDiffSpinBox);
-  QSpacerItem* matchSpacer = new QSpacerItem(16, 0, QSizePolicy::Expanding,
+  auto matchSpacer = new QSpacerItem(16, 0, QSizePolicy::Expanding,
                                              QSizePolicy::Minimum);
   matchLayout->addItem(matchSpacer);
   QLabel* matchLabel = new QLabel(tr("Match with:"));
@@ -219,19 +212,28 @@ ImportDialog::ImportDialog(IPlatformTools* platformTools,
   matchLayout->addWidget(titleButton);
   vlayout->addLayout(matchLayout);
 
-  connect(fileButton, SIGNAL(clicked()), this, SLOT(fromText()));
-  connect(tagsButton, SIGNAL(clicked()), this, SLOT(fromTags()));
-  connect(serverButton, SIGNAL(clicked()), this, SLOT(fromServer()));
-  connect(m_serverComboBox, SIGNAL(activated(int)), this, SLOT(fromServer()));
-  connect(lengthButton, SIGNAL(clicked()), this, SLOT(matchWithLength()));
-  connect(trackButton, SIGNAL(clicked()), this, SLOT(matchWithTrack()));
-  connect(titleButton, SIGNAL(clicked()), this, SLOT(matchWithTitle()));
-  connect(m_mismatchCheckBox, SIGNAL(toggled(bool)), this, SLOT(showPreview()));
-  connect(m_maxDiffSpinBox, SIGNAL(valueChanged(int)), this, SLOT(maxDiffChanged()));
-  connect(this, SIGNAL(finished(int)), this, SLOT(hideSubdialogs()));
+  connect(fileButton, &QAbstractButton::clicked,
+          this, &ImportDialog::fromText);
+  connect(tagsButton, &QAbstractButton::clicked,
+          this, &ImportDialog::fromTags);
+  connect(serverButton, &QAbstractButton::clicked,
+          this, &ImportDialog::fromServer);
+  connect(m_serverComboBox, static_cast<void (QComboBox::*)(int)>(
+            &QComboBox::activated), this, &ImportDialog::fromServer);
+  connect(lengthButton, &QAbstractButton::clicked,
+          this, &ImportDialog::matchWithLength);
+  connect(trackButton, &QAbstractButton::clicked,
+          this, &ImportDialog::matchWithTrack);
+  connect(titleButton, &QAbstractButton::clicked,
+          this, &ImportDialog::matchWithTitle);
+  connect(m_mismatchCheckBox, &QAbstractButton::toggled,
+          this, &ImportDialog::showPreview);
+  connect(m_maxDiffSpinBox, static_cast<void (QSpinBox::*)(int)>(
+            &QSpinBox::valueChanged), this, &ImportDialog::maxDiffChanged);
+  connect(this, &QDialog::finished, this, &ImportDialog::hideSubdialogs);
 
-  QHBoxLayout* hlayout = new QHBoxLayout;
-  QSpacerItem* hspacer = new QSpacerItem(16, 0, QSizePolicy::Expanding,
+  auto hlayout = new QHBoxLayout;
+  auto hspacer = new QSpacerItem(16, 0, QSizePolicy::Expanding,
                                          QSizePolicy::Minimum);
   QPushButton* helpButton = new QPushButton(tr("&Help"), this);
   helpButton->setAutoDefault(false);
@@ -246,10 +248,12 @@ ImportDialog::ImportDialog(IPlatformTools* platformTools,
   hlayout->addItem(hspacer);
   hlayout->addWidget(okButton);
   hlayout->addWidget(cancelButton);
-  connect(helpButton, SIGNAL(clicked()), this, SLOT(showHelp()));
-  connect(saveButton, SIGNAL(clicked()), this, SLOT(saveConfig()));
-  connect(okButton, SIGNAL(clicked()), this, SLOT(accept()));
-  connect(cancelButton, SIGNAL(clicked()), this, SLOT(reject()));
+  connect(helpButton, &QAbstractButton::clicked,
+          this, &ImportDialog::showHelp);
+  connect(saveButton, &QAbstractButton::clicked,
+          this, &ImportDialog::saveConfig);
+  connect(okButton, &QAbstractButton::clicked, this, &QDialog::accept);
+  connect(cancelButton, &QAbstractButton::clicked, this, &QDialog::reject);
   vlayout->addLayout(hlayout);
 }
 
@@ -258,10 +262,7 @@ ImportDialog::ImportDialog(IPlatformTools* platformTools,
  */
 ImportDialog::~ImportDialog()
 {
-  delete m_textImportDialog;
-  delete m_tagImportDialog;
-  delete m_serverImportDialog;
-  delete m_serverTrackImportDialog;
+  // Must not be inline because of forwared declared QScopedPointer.
 }
 
 /**
@@ -279,10 +280,10 @@ void ImportDialog::fromServer()
 void ImportDialog::fromText()
 {
   if (!m_textImportDialog) {
-    m_textImportDialog = new TextImportDialog(
-          m_platformTools, this, m_trackDataModel);
-    connect(m_textImportDialog, SIGNAL(trackDataUpdated()),
-            this, SLOT(showPreview()));
+    m_textImportDialog.reset(new TextImportDialog(
+          m_platformTools, this, m_trackDataModel));
+    connect(m_textImportDialog.data(), &TextImportDialog::trackDataUpdated,
+            this, &ImportDialog::showPreview);
   }
   m_textImportDialog->clear();
   m_textImportDialog->show();
@@ -294,9 +295,9 @@ void ImportDialog::fromText()
 void ImportDialog::fromTags()
 {
   if (!m_tagImportDialog) {
-    m_tagImportDialog = new TagImportDialog(this, m_trackDataModel);
-    connect(m_tagImportDialog, SIGNAL(trackDataUpdated()),
-            this, SLOT(showPreview()));
+    m_tagImportDialog.reset(new TagImportDialog(this, m_trackDataModel));
+    connect(m_tagImportDialog.data(), &TagImportDialog::trackDataUpdated,
+            this, &ImportDialog::showPreview);
   }
   m_tagImportDialog->clear();
   m_tagImportDialog->show();
@@ -328,11 +329,11 @@ void ImportDialog::displayServerImportDialog(int importerIdx)
 void ImportDialog::displayServerImportDialog(ServerImporter* source)
 {
   if (!m_serverImportDialog) {
-    m_serverImportDialog = new ServerImportDialog(this);
-    connect(m_serverImportDialog, SIGNAL(trackDataUpdated()),
-            this, SLOT(showPreview()));
-    connect(m_serverImportDialog, SIGNAL(accepted()),
-            this, SLOT(onServerImportDialogClosed()));
+    m_serverImportDialog.reset(new ServerImportDialog(this));
+    connect(m_serverImportDialog.data(), &ServerImportDialog::trackDataUpdated,
+            this, &ImportDialog::showPreview);
+    connect(m_serverImportDialog.data(), &QDialog::accepted,
+            this, &ImportDialog::onServerImportDialogClosed);
   }
   m_serverImportDialog->setImportSource(source);
   m_serverImportDialog->setArtistAlbum(
@@ -349,9 +350,9 @@ void ImportDialog::displayServerImportDialog(ServerImporter* source)
 void ImportDialog::displayServerTrackImportDialog(ServerTrackImporter* source)
 {
   if (!m_serverTrackImportDialog) {
-    m_serverTrackImportDialog = new ServerTrackImportDialog(this, m_trackDataModel);
-    connect(m_serverTrackImportDialog, SIGNAL(trackDataUpdated()),
-            this, SLOT(showPreview()));
+    m_serverTrackImportDialog.reset(new ServerTrackImportDialog(this, m_trackDataModel));
+    connect(m_serverTrackImportDialog.data(), &ServerTrackImportDialog::trackDataUpdated,
+            this, &ImportDialog::showPreview);
   }
   m_serverTrackImportDialog->setImportSource(source);
   m_serverTrackImportDialog->initTable();
@@ -412,7 +413,8 @@ void ImportDialog::clear()
   m_maxDiffSpinBox->setValue(importCfg.maxTimeDifference());
   m_columnVisibility = importCfg.importVisibleColumns();
 
-  foreach (int frameType, checkableFrameTypes()) {
+  const auto frameTypes = checkableFrameTypes();
+  for (int frameType : frameTypes) {
     if (frameType < 64) {
       int column = m_trackDataModel->columnForFrameType(frameType);
       if (column != -1) {
@@ -445,9 +447,11 @@ void ImportDialog::showPreview()
 
   int accuracy = m_trackDataModel->calculateAccuracy();
   m_accuracyPercentLabel->setText(accuracy >= 0 && accuracy <= 100
-                                  ? QString::number(accuracy) + QLatin1Char('%') : QLatin1String("-"));
+                                  ? QString::number(accuracy) + QLatin1Char('%')
+                                  : QLatin1String("-"));
   QUrl coverArtUrl = m_trackDataModel->getTrackData().getCoverArtUrl();
-  m_coverArtUrlLabel->setText(coverArtUrl.isEmpty() ? QLatin1String("-") : coverArtUrl.toString());
+  m_coverArtUrlLabel->setText(coverArtUrl.isEmpty() ? QLatin1String("-")
+                                                    : coverArtUrl.toString());
 }
 
 /**
@@ -531,15 +535,16 @@ void ImportDialog::maxDiffChanged() {
  * @param fromIndex index of position moved to
  */
 void ImportDialog::moveTableRow(int, int fromIndex, int toIndex) {
-  QHeaderView* vHeader = qobject_cast<QHeaderView*>(sender());
+  auto vHeader = qobject_cast<QHeaderView*>(sender());
   if (vHeader) {
     // revert movement, but avoid recursion
-    disconnect(vHeader, SIGNAL(sectionMoved(int,int,int)), 0, 0);
+    disconnect(vHeader, &QHeaderView::sectionsMoved, nullptr, nullptr);
     vHeader->moveSection(toIndex, fromIndex);
-    connect(vHeader, SIGNAL(sectionMoved(int,int,int)), this, SLOT(moveTableRow(int,int,int)));
+    connect(vHeader, &QHeaderView::sectionMoved,
+            this, &ImportDialog::moveTableRow);
   }
   ImportTrackDataVector trackDataVector(m_trackDataModel->getTrackData());
-  int numTracks = static_cast<int>(trackDataVector.size());
+  auto numTracks = static_cast<int>(trackDataVector.size());
   if (fromIndex < numTracks && toIndex < numTracks) {
     // swap elements but keep file durations and names
     ImportTrackData fromData(trackDataVector[fromIndex]);
@@ -604,17 +609,18 @@ void ImportDialog::showTableHeaderContextMenu(const QPoint& pos)
 {
   if (QWidget* widget = qobject_cast<QWidget*>(sender())) {
     QMenu menu(widget);
-    foreach (int frameType, checkableFrameTypes()) {
+    const auto frameTypes = checkableFrameTypes();
+    for (int frameType : frameTypes) {
       int column = m_trackDataModel->columnForFrameType(frameType);
       if (column != -1) {
-        QAction* action = new QAction(&menu);
+        auto action = new QAction(&menu);
         action->setText(
               m_trackDataModel->headerData(column, Qt::Horizontal).toString());
         action->setData(frameType);
         action->setCheckable(true);
         action->setChecked((m_columnVisibility & (1ULL << frameType)) != 0ULL);
-        connect(action, SIGNAL(triggered(bool)),
-                this, SLOT(toggleTableColumnVisibility(bool)));
+        connect(action, &QAction::triggered,
+                this, &ImportDialog::toggleTableColumnVisibility);
         menu.addAction(action);
       }
     }
@@ -630,7 +636,7 @@ void ImportDialog::showTableHeaderContextMenu(const QPoint& pos)
  */
 void ImportDialog::toggleTableColumnVisibility(bool visible)
 {
-  if (QAction* action = qobject_cast<QAction*>(sender())) {
+  if (auto action = qobject_cast<QAction*>(sender())) {
     bool ok;
     int frameType = action->data().toInt(&ok);
     if (ok && frameType < 64) {
