@@ -6,7 +6,7 @@
  * \author Urs Fleisch
  * \date 17 Sep 2003
  *
- * Copyright (C) 2003-2012  Urs Fleisch
+ * Copyright (C) 2003-2018  Urs Fleisch
  *
  * This file is part of Kid3.
  *
@@ -24,12 +24,11 @@
  * along with this program.  If not, see <http://www.gnu.org/licenses/>.
  */
 
-#ifndef IMPORTDIALOG_H
-#define IMPORTDIALOG_H
+#pragma once
 
 #include <QDialog>
-#include "config.h"
-#include "importconfig.h"
+#include <QScopedPointer>
+#include "frame.h"
 
 class IPlatformTools;
 class QString;
@@ -41,6 +40,7 @@ class QSpinBox;
 class QTableView;
 class QLabel;
 class TrackDataModel;
+class GenreModel;
 class ServerTrackImportDialog;
 class ServerImporter;
 class ServerImportDialog;
@@ -55,8 +55,7 @@ class ServerTrackImporter;
  * Import dialog.
  */
 class ImportDialog : public QDialog {
-Q_OBJECT
-
+  Q_OBJECT
 public:
   /**
    * Constructor.
@@ -64,6 +63,7 @@ public:
    * @param platformTools platform tools
    * @param parent        parent widget
    * @param caption       dialog title
+   * @param genreModel    genre model
    * @param trackDataModel track data to be filled with imported values,
    *                      is passed with durations of files set
    * @param importers     server importers
@@ -72,13 +72,14 @@ public:
   ImportDialog(IPlatformTools* platformTools,
                QWidget* parent, QString& caption,
                TrackDataModel* trackDataModel,
+               GenreModel* genreModel,
                const QList<ServerImporter*>& importers,
                const QList<ServerTrackImporter*>& trackImporters);
 
   /**
    * Destructor.
    */
-  ~ImportDialog();
+  virtual ~ImportDialog() override;
 
   /**
    * Shows the dialog as a modeless dialog.
@@ -97,7 +98,7 @@ public:
    *
    * @return TagV1, TagV2 or TagV2V1 for ID3v1, ID3v2 or both.
    */
-  TrackData::TagVersion getDestination() const;
+  Frame::TagVersion getDestination() const;
 
 private slots:
   /**
@@ -243,13 +244,11 @@ private:
   /** track importers for differen servers */
   QList<ServerTrackImporter*> m_trackImporters;
   /** Server track import dialog */
-  ServerTrackImportDialog* m_serverTrackImportDialog;
+  QScopedPointer<ServerTrackImportDialog> m_serverTrackImportDialog;
   /** Server import dialog */
-  ServerImportDialog* m_serverImportDialog;
+  QScopedPointer<ServerImportDialog> m_serverImportDialog;
   /** Text import dialog */
-  TextImportDialog* m_textImportDialog;
+  QScopedPointer<TextImportDialog> m_textImportDialog;
   /** Tag import dialog */
-  TagImportDialog* m_tagImportDialog;
+  QScopedPointer<TagImportDialog> m_tagImportDialog;
 };
-
-#endif
