@@ -6,7 +6,7 @@
  * \author Urs Fleisch
  * \date 25 May 2006
  *
- * Copyright (C) 2006-2013  Urs Fleisch
+ * Copyright (C) 2006-2018  Urs Fleisch
  *
  * This file is part of Kid3.
  *
@@ -42,16 +42,16 @@
  *
  * @param parent parent widget
  */
-NumberTracksDialog::NumberTracksDialog(QWidget* parent) :
-  QDialog(parent)
+NumberTracksDialog::NumberTracksDialog(QWidget* parent)
+  : QDialog(parent)
 {
   setObjectName(QLatin1String("NumberTracksDialog"));
   setModal(true);
   setWindowTitle(tr("Number Tracks"));
 
   const NumberTracksConfig& cfg = NumberTracksConfig::instance();
-  QVBoxLayout* vlayout = new QVBoxLayout(this);
-  QHBoxLayout* trackLayout = new QHBoxLayout;
+  auto vlayout = new QVBoxLayout(this);
+  auto trackLayout = new QHBoxLayout;
   m_numberTracksCheckBox = new QCheckBox(tr("Start &number:"), this);
   m_numberTracksCheckBox->setChecked(cfg.isTrackNumberingEnabled());
   m_trackSpinBox = new QSpinBox(this);
@@ -60,17 +60,16 @@ NumberTracksDialog::NumberTracksDialog(QWidget* parent) :
   trackLayout->addWidget(m_numberTracksCheckBox);
   trackLayout->addWidget(m_trackSpinBox);
 
-  QSpacerItem* trackSpacer = new QSpacerItem(16, 0, QSizePolicy::Expanding,
+  auto trackSpacer = new QSpacerItem(16, 0, QSizePolicy::Expanding,
                                              QSizePolicy::Minimum);
   trackLayout->addItem(trackSpacer);
 
   QLabel* destLabel = new QLabel(tr("&Destination:"), this);
   m_destComboBox = new QComboBox(this);
   m_destComboBox->setEditable(false);
-  QList<QPair<Frame::TagVersion, QString> > tagVersions =
+  const QList<QPair<Frame::TagVersion, QString> > tagVersions =
       Frame::availableTagVersions();
-  for (QList<QPair<Frame::TagVersion, QString> >::const_iterator it =
-       tagVersions.constBegin(); it != tagVersions.constEnd(); ++it) {
+  for (auto it = tagVersions.constBegin(); it != tagVersions.constEnd(); ++it) {
     m_destComboBox->addItem(it->second, it->first);
   }
   m_destComboBox->setCurrentIndex(
@@ -86,7 +85,7 @@ NumberTracksDialog::NumberTracksDialog(QWidget* parent) :
   m_resetCounterCheckBox->setChecked(cfg.isDirectoryCounterResetEnabled());
   vlayout->addWidget(m_resetCounterCheckBox);
 
-  QHBoxLayout* totalLayout = new QHBoxLayout;
+  auto totalLayout = new QHBoxLayout;
   m_totalNumTracksCheckBox = new QCheckBox(tr("&Total number of tracks:"),
                                            this);
   m_totalNumTrackSpinBox = new QSpinBox(this);
@@ -95,23 +94,23 @@ NumberTracksDialog::NumberTracksDialog(QWidget* parent) :
     totalLayout->addWidget(m_totalNumTracksCheckBox);
     totalLayout->addWidget(m_totalNumTrackSpinBox);
   }
-  QSpacerItem* totalSpacer = new QSpacerItem(16, 0, QSizePolicy::Expanding,
+  auto totalSpacer = new QSpacerItem(16, 0, QSizePolicy::Expanding,
                                              QSizePolicy::Minimum);
   totalLayout->addItem(totalSpacer);
   vlayout->addLayout(totalLayout);
 
-  QHBoxLayout* hlayout = new QHBoxLayout;
+  auto hlayout = new QHBoxLayout;
   QPushButton* helpButton = new QPushButton(tr("&Help"), this);
   helpButton->setAutoDefault(false);
   hlayout->addWidget(helpButton);
-  connect(helpButton, SIGNAL(clicked()), this, SLOT(showHelp()));
+  connect(helpButton, &QAbstractButton::clicked, this, &NumberTracksDialog::showHelp);
 
   QPushButton* saveButton = new QPushButton(tr("&Save Settings"), this);
   saveButton->setAutoDefault(false);
   hlayout->addWidget(saveButton);
-  connect(saveButton, SIGNAL(clicked()), this, SLOT(saveConfig()));
+  connect(saveButton, &QAbstractButton::clicked, this, &NumberTracksDialog::saveConfig);
 
-  QSpacerItem* hspacer = new QSpacerItem(16, 0, QSizePolicy::Expanding,
+  auto hspacer = new QSpacerItem(16, 0, QSizePolicy::Expanding,
                                          QSizePolicy::Minimum);
   hlayout->addItem(hspacer);
 
@@ -119,22 +118,16 @@ NumberTracksDialog::NumberTracksDialog(QWidget* parent) :
   okButton->setAutoDefault(false);
   okButton->setDefault(true);
   hlayout->addWidget(okButton);
-  connect(okButton, SIGNAL(clicked()), this, SLOT(accept()));
+  connect(okButton, &QAbstractButton::clicked, this, &QDialog::accept);
 
   QPushButton* cancelButton = new QPushButton(tr("&Cancel"), this);
   cancelButton->setAutoDefault(false);
   hlayout->addWidget(cancelButton);
-  connect(cancelButton, SIGNAL(clicked()), this, SLOT(reject()));
+  connect(cancelButton, &QAbstractButton::clicked, this, &QDialog::reject);
 
   vlayout->addLayout(hlayout);
 }
 
-/**
- * Destructor.
- */
-NumberTracksDialog::~NumberTracksDialog()
-{}
-
 /**
  * Get start number.
  */
