@@ -6,7 +6,7 @@
  * \author Urs Fleisch
  * \date 21 Mar 2004
  *
- * Copyright (C) 2004-2013  Urs Fleisch
+ * Copyright (C) 2004-2018  Urs Fleisch
  *
  * This file is part of Kid3.
  *
@@ -41,6 +41,7 @@
 #include "contexthelp.h"
 #include "rendirconfig.h"
 #include "dirrenamer.h"
+#include "stringlisteditdialog.h"
 
 /**
  * Constructor.
@@ -48,39 +49,33 @@
  * @param parent parent widget
  * @param dirRenamer directory renamer
  */
-RenDirDialog::RenDirDialog(QWidget* parent, DirRenamer* dirRenamer) :
-  QWizard(parent), m_taggedFile(0), m_dirRenamer(dirRenamer)
+RenDirDialog::RenDirDialog(QWidget* parent, DirRenamer* dirRenamer)
+  : QWizard(parent), m_taggedFile(nullptr), m_dirRenamer(dirRenamer)
 {
   setObjectName(QLatin1String("RenDirDialog"));
   setModal(true);
   setWindowTitle(tr("Rename Directory"));
   setSizeGripEnabled(true);
 
-  QWizardPage* mainPage = new QWizardPage;
+  auto mainPage = new QWizardPage;
 
-  QVBoxLayout* mainLayout = new QVBoxLayout(mainPage);
+  auto mainLayout = new QVBoxLayout(mainPage);
   setupMainPage(mainPage, mainLayout);
   mainPage->setTitle(tr("Format"));
   addPage(mainPage);
 
-  QWizardPage* previewPage = new QWizardPage;
+  auto previewPage = new QWizardPage;
   setupPreviewPage(previewPage);
   previewPage->setTitle(tr("Preview"));
   addPage(previewPage);
 
   setOptions(HaveHelpButton | HaveCustomButton1);
   setButtonText(CustomButton1, tr("&Save Settings"));
-  connect(this, SIGNAL(helpRequested()), this, SLOT(showHelp()));
-  connect(this, SIGNAL(customButtonClicked(int)), this, SLOT(saveConfig()));
-  connect(this, SIGNAL(currentIdChanged(int)), this, SLOT(pageChanged()));
+  connect(this, &QWizard::helpRequested, this, &RenDirDialog::showHelp);
+  connect(this, &QWizard::customButtonClicked, this, &RenDirDialog::saveConfig);
+  connect(this, &QWizard::currentIdChanged, this, &RenDirDialog::pageChanged);
 }
 
-/**
- * Destructor.
- */
-RenDirDialog::~RenDirDialog()
-{}
-
 /**
  * Set up the main wizard page.
  *
@@ -93,32 +88,45 @@ void RenDirDialog::setupMainPage(QWidget* page, QVBoxLayout* vlayout)
     return;
   }
 
-  QFormLayout* actionLayout = new QFormLayout;
+  auto actionLayout = new QFormLayout;
   actionLayout->setFieldGrowthPolicy(QFormLayout::AllNonFixedFieldsGrow);
   m_actionComboBox = new QComboBox(page);
   m_tagversionComboBox = new QComboBox(page);
   m_actionComboBox->insertItem(ActionRename, tr("Rename Directory"));
   m_actionComboBox->insertItem(ActionCreate, tr("Create Directory"));
   actionLayout->addRow(tr("&Action:"), m_actionComboBox);
-  connect(m_actionComboBox, SIGNAL(activated(int)), this, SLOT(slotUpdateNewDirname()));
-  m_tagversionComboBox->addItem(tr("From Tag 2 and Tag 1"), Frame::TagV2V1);
-  m_tagversionComboBox->addItem(tr("From Tag 1"), Frame::TagV1);
-  m_tagversionComboBox->addItem(tr("From Tag 2"), Frame::TagV2);
+  connect(m_actionComboBox, static_cast<void (QComboBox::*)(int)>(
+            &QComboBox::activated), this, &RenDirDialog::slotUpdateNewDirname);
+  const QList<QPair<Frame::TagVersion, QString> > tagVersions =
+      Frame::availableTagVersions();
+  for (auto it = tagVersions.constBegin(); it != tagVersions.constEnd(); ++it) {
+    m_tagversionComboBox->addItem(it->second, it->first);
+  }
   actionLayout->addRow(tr("&Source:"), m_tagversionComboBox);
-  connect(m_tagversionComboBox, SIGNAL(activated(int)), this, SLOT(slotUpdateNewDirname()));
+  connect(m_tagversionComboBox, static_cast<void (QComboBox::*)(int)>(
+            &QComboBox::activated), this, &RenDirDialog::slotUpdateNewDirname);
 
+  auto formatLayout = new QHBoxLayout;
   m_formatComboBox = new QComboBox(page);
-  m_formatComboBox->addItems(RenDirConfig::getDefaultDirFormatList());
   m_formatComboBox->setEditable(true);
   const RenDirConfig& renDirCfg = RenDirConfig::instance();
-  m_formatComboBox->setItemText(renDirCfg.dirFormatIndex(),
-                                renDirCfg.dirFormat());
-  m_formatComboBox->setCurrentIndex(renDirCfg.dirFormatIndex());
-  actionLayout->addRow(tr("&Format:"), m_formatComboBox);
+  m_formats = renDirCfg.dirFormats();
+  m_format = renDirCfg.dirFormat();
+  setFormats();
+  formatLayout->addWidget(m_formatComboBox, 1);
+  auto editFormatsButton = new QPushButton(tr("&Edit..."));
+  connect(editFormatsButton, &QPushButton::clicked,
+          this, &RenDirDialog::editFormats);
+  formatLayout->addWidget(editFormatsButton);
+  auto formatLabel = new QLabel(tr("&Format:"));
+  formatLabel->setBuddy(m_formatComboBox);
+  actionLayout->addRow(formatLabel, formatLayout);
   m_tagversionComboBox->setCurrentIndex(
         m_tagversionComboBox->findData(renDirCfg.renDirSource()));
-  connect(m_formatComboBox, SIGNAL(activated(int)), this, SLOT(slotUpdateNewDirname()));
-  connect(m_formatComboBox, SIGNAL(editTextChanged(QString)), this, SLOT(slotUpdateNewDirname()));
+  connect(m_formatComboBox, static_cast<void (QComboBox::*)(int)>(
+            &QComboBox::activated), this, &RenDirDialog::slotUpdateNewDirname);
+  connect(m_formatComboBox, &QComboBox::editTextChanged,
+          this, &RenDirDialog::slotUpdateNewDirname);
 
   m_currentDirLabel = new QLabel(page);
   m_newDirLabel = new QLabel(page);
@@ -135,7 +143,7 @@ void RenDirDialog::setupMainPage(QWidget* page, QVBoxLayout* vlayout)
  */
 void RenDirDialog::setupPreviewPage(QWidget* page)
 {
-  QVBoxLayout* vlayout = new QVBoxLayout(page);
+  auto vlayout = new QVBoxLayout(page);
   m_edit = new QTextEdit(page);
   m_edit->setReadOnly(true);
   m_edit->setAcceptRichText(false);
@@ -184,9 +192,11 @@ QString RenDirDialog::getNewDirname() const
  * Set configuration from dialog in directory renamer.
  */
 void RenDirDialog::setDirRenamerConfiguration() {
-  m_dirRenamer->setTagVersion(TrackData::tagVersionCast(m_tagversionComboBox->itemData(m_tagversionComboBox->currentIndex()).toInt()));
+  m_dirRenamer->setTagVersion(Frame::tagVersionCast(
+    m_tagversionComboBox->itemData(m_tagversionComboBox->currentIndex()).toInt()));
   m_dirRenamer->setAction(m_actionComboBox->currentIndex() == ActionCreate);
-  m_dirRenamer->setFormat(m_formatComboBox->currentText());
+  m_format = m_formatComboBox->currentText();
+  m_dirRenamer->setFormat(m_format);
 }
 
 /**
@@ -197,7 +207,8 @@ void RenDirDialog::slotUpdateNewDirname()
   if (m_taggedFile) {
     setDirRenamerConfiguration();
     QString currentDirname;
-    QString newDirname(m_dirRenamer->generateNewDirname(m_taggedFile, &currentDirname));
+    QString newDirname(m_dirRenamer->generateNewDirname(m_taggedFile,
+                                                        &currentDirname));
     m_currentDirLabel->setText(currentDirname);
     setNewDirname(newDirname);
   }
@@ -209,9 +220,11 @@ void RenDirDialog::slotUpdateNewDirname()
 void RenDirDialog::saveConfig()
 {
   RenDirConfig& renDirCfg = RenDirConfig::instance();
-  renDirCfg.setDirFormatIndex(m_formatComboBox->currentIndex());
-  renDirCfg.setDirFormat(m_formatComboBox->currentText());
-  renDirCfg.setRenDirSource(TrackData::tagVersionCast(
+  m_format = m_formatComboBox->currentText();
+  setFormats();
+  renDirCfg.setDirFormats(m_formats);
+  renDirCfg.setDirFormat(m_format);
+  renDirCfg.setRenDirSource(Frame::tagVersionCast(
     m_tagversionComboBox->itemData(m_tagversionComboBox->currentIndex()).toInt()));
 }
 
@@ -281,6 +294,38 @@ void RenDirDialog::pageChanged()
   }
 }
 
+/**
+ * Open dialog to edit formats.
+ */
+void RenDirDialog::editFormats()
+{
+  setFormats();
+  StringListEditDialog dialog(m_formats, tr("Directory Name from Tag"), this);
+  if (dialog.exec() == QDialog::Accepted) {
+    m_formats = dialog.stringList();
+    setFormats();
+  }
+}
+
+/**
+ * Set items of format combo box from configuration.
+ */
+void RenDirDialog::setFormats()
+{
+  int idx = m_formats.indexOf(m_format);
+  if (idx == -1) {
+    m_formats.append(m_format);
+    idx = m_formats.size() - 1;
+  }
+  m_formatComboBox->blockSignals(true);
+  if (!m_formats.isEmpty()) {
+    m_formatComboBox->clear();
+    m_formatComboBox->addItems(m_formats);
+  }
+  m_formatComboBox->setCurrentIndex(idx);
+  m_formatComboBox->blockSignals(false);
+}
+
 /**
  * Called when the wizard is canceled.
  */
