@@ -6,7 +6,7 @@
  * \author Urs Fleisch
  * \date 09 Oct 2006
  *
- * Copyright (C) 2006-2011  Urs Fleisch
+ * Copyright (C) 2006-2018  Urs Fleisch
  *
  * This file is part of Kid3.
  *
@@ -24,13 +24,10 @@
  * along with this program.  If not, see <http://www.gnu.org/licenses/>.
  */
 
-#ifndef SERVERIMPORTDIALOG_H
-#define SERVERIMPORTDIALOG_H
+#pragma once
 
-#include "config.h"
 #include <QDialog>
 #include <QString>
-#include <QStandardItem>
 
 class QLineEdit;
 class QLabel;
@@ -39,6 +36,7 @@ class QPushButton;
 class QCheckBox;
 class QStatusBar;
 class QListView;
+class QStandardItem;
 class QStandardItemModel;
 class ServerImporter;
 class ServerImporterConfig;
@@ -47,10 +45,8 @@ class ImportTrackDataVector;
 /**
  * Generic dialog to import from an external source.
  */
-class ServerImportDialog : public QDialog
-{
-Q_OBJECT
-
+class ServerImportDialog : public QDialog {
+  Q_OBJECT
 public:
   /**
    * Constructor.
@@ -62,7 +58,7 @@ public:
   /**
    * Destructor.
    */
-  virtual ~ServerImportDialog();
+  virtual ~ServerImportDialog() override = default;
 
   /**
    * Set importer to be used.
@@ -232,5 +228,3 @@ private:
   QStatusBar* m_statusBar;
   ServerImporter* m_source;
 };
-
-#endif
