@@ -6,7 +6,7 @@
  * \author Urs Fleisch
  * \date 13 Sep 2005
  *
- * Copyright (C) 2005-2012  Urs Fleisch
+ * Copyright (C) 2005-2018  Urs Fleisch
  *
  * This file is part of Kid3.
  *
@@ -24,8 +24,7 @@
  * along with this program.  If not, see <http://www.gnu.org/licenses/>.
  */
 
-#ifndef SERVERTRACKIMPORTDIALOG_H
-#define SERVERTRACKIMPORTDIALOG_H
+#pragma once
 
 #include <QDialog>
 #include <QString>
@@ -65,7 +64,7 @@ public:
   /**
    * Destructor.
    */
-  virtual ~ServerTrackImportDialog();
+  virtual ~ServerTrackImportDialog() override;
 
   /**
    * Set importer to be used.
@@ -104,18 +103,18 @@ public slots:
   /**
    * Shows the dialog as a modal dialog.
    */
-  int exec();
+  virtual int exec() override;
 
 protected slots:
   /**
    * Hides the dialog and sets the result to QDialog::Accepted.
    */
-  virtual void accept();
+  virtual void accept() override;
 
   /**
    * Hides the dialog and sets the result to QDialog::Rejected.
    */
-  virtual void reject();
+  virtual void reject() override;
 
 private slots:
   /**
@@ -190,5 +189,3 @@ private:
   TrackDataModel* m_trackDataModel;
   QVector<ImportTrackDataVector> m_trackResults;
 };
-
-#endif // SERVERTRACKIMPORTDIALOG_H
