@@ -6,7 +6,7 @@
  * \author Urs Fleisch
  * \date 9 Jan 2003
  *
- * Copyright (C) 2003-2017  Urs Fleisch
+ * Copyright (C) 2003-2018  Urs Fleisch
  *
  * This file is part of Kid3.
  *
@@ -56,6 +56,7 @@
 #include "downloadclient.h"
 #include "downloaddialog.h"
 #include "playlistdialog.h"
+#include "playlisteditdialog.h"
 #include "editframefieldsdialog.h"
 #include "progresswidget.h"
 #include "fileproxymodel.h"
@@ -66,10 +67,13 @@
 #include "pictureframe.h"
 #include "fileconfig.h"
 #include "playlistconfig.h"
+#include "playlistmodel.h"
+#include "importconfig.h"
 #include "exportconfig.h"
 #include "guiconfig.h"
 #include "tagconfig.h"
 #include "filterconfig.h"
+#include "isettings.h"
 #include "contexthelp.h"
 #include "frame.h"
 #include "textexporter.h"
@@ -78,12 +82,8 @@
 #include "dirrenamer.h"
 #include "iplatformtools.h"
 #include "saferename.h"
-#if defined HAVE_PHONON || QT_VERSION >= 0x050000
 #include "audioplayer.h"
-#endif
-#if defined HAVE_PHONON || QT_VERSION >= 0x050000
 #include "playtoolbar.h"
-#endif
 
 /**
  * Constructor.
@@ -94,65 +94,59 @@
  */
 BaseMainWindowImpl::BaseMainWindowImpl(QMainWindow* mainWin,
                                        IPlatformTools* platformTools,
-                                       Kid3Application* app) :
-  m_platformTools(platformTools), m_w(mainWin), m_self(0),
-  m_app(app),
-  m_importDialog(0), m_batchImportDialog(0), m_browseCoverArtDialog(0),
-  m_exportDialog(0), m_findReplaceDialog(0), m_renDirDialog(0),
-  m_numberTracksDialog(0), m_filterDialog(0),
-  m_downloadDialog(new DownloadDialog(m_w, tr("Download"))),
-  m_playlistDialog(0), m_progressWidget(0),
-  m_progressBar(0), m_progressAbortButton(0), m_editFrameDialog(0),
-#if defined HAVE_PHONON || QT_VERSION >= 0x050000
-  m_playToolBar(0),
-#endif
-  m_editFrameTaggedFile(0), m_editFrameTagNr(Frame::Tag_2),
-  m_progressTerminationHandler(0),
-  m_progressDisconnected(false),
-  m_findReplaceActive(false), m_expandNotificationNeeded(false)
+                                       Kid3Application* app)
+  : m_platformTools(platformTools), m_w(mainWin), m_self(nullptr),
+    m_form(nullptr), m_app(app),
+    m_exportDialog(nullptr), m_findReplaceDialog(nullptr),
+    m_downloadDialog(new DownloadDialog(m_w, tr("Download"))),
+    m_progressWidget(nullptr),
+    m_progressBar(nullptr), m_progressAbortButton(nullptr),
+    m_editFrameDialog(nullptr), m_editFrameTaggedFile(nullptr),
+    m_editFrameTagNr(Frame::Tag_2),
+    m_progressTerminationHandler(nullptr),  m_progressDisconnected(false),
+    m_findReplaceActive(false), m_expandNotificationNeeded(false)
 {
   m_downloadDialog->close();
   ContextHelp::init(m_platformTools);
 
   DownloadClient* downloadClient = m_app->getDownloadClient();
-  connect(downloadClient, SIGNAL(progress(QString,int,int)),
-          m_downloadDialog, SLOT(updateProgressStatus(QString,int,int)));
-  connect(downloadClient, SIGNAL(downloadStarted(QString)),
-          m_downloadDialog, SLOT(showStartOfDownload(QString)));
-  connect(downloadClient, SIGNAL(aborted()),
-          m_downloadDialog, SLOT(reset()));
-  connect(m_downloadDialog, SIGNAL(canceled()),
-          downloadClient, SLOT(cancelDownload()));
+  connect(downloadClient, &HttpClient::progress,
+          m_downloadDialog, &DownloadDialog::updateProgressStatus);
+  connect(downloadClient, &DownloadClient::downloadStarted,
+          m_downloadDialog, &DownloadDialog::showStartOfDownload);
+  connect(downloadClient, &DownloadClient::aborted,
+          m_downloadDialog, &QProgressDialog::reset);
+  connect(m_downloadDialog, &QProgressDialog::canceled,
+          downloadClient, &DownloadClient::cancelDownload);
   connect(downloadClient,
-    SIGNAL(downloadFinished(QByteArray,QString,QString)),
+    &DownloadClient::downloadFinished,
     m_app,
-    SLOT(imageDownloaded(QByteArray,QString,QString)));
+    &Kid3Application::imageDownloaded);
 
-  connect(m_app, SIGNAL(fileSelectionUpdateRequested()),
-          this, SLOT(updateCurrentSelection()));
-  connect(m_app, SIGNAL(selectedFilesUpdated()),
-          this, SLOT(updateGuiControls()));
-  connect(m_app, SIGNAL(selectedFilesChanged(QItemSelection,QItemSelection)),
-          this, SLOT(applySelectionChange(QItemSelection,QItemSelection)));
-  connect(m_app, SIGNAL(frameModified(TaggedFile*,Frame::TagNumber)),
-          this, SLOT(updateAfterFrameModification(TaggedFile*,Frame::TagNumber)));
-  connect(m_app, SIGNAL(confirmedOpenDirectoryRequested(QStringList)),
-          this, SLOT(confirmedOpenDirectory(QStringList)));
-  connect(m_app, SIGNAL(toggleExpandedRequested(QModelIndex)),
-          this, SLOT(toggleExpanded(QModelIndex)));
-  connect(m_app, SIGNAL(expandFileListRequested()),
-          this, SLOT(expandFileList()));
-  connect(m_app, SIGNAL(directoryOpened()),
-          this, SLOT(onDirectoryOpened()));
-  connect(m_app, SIGNAL(modifiedChanged(bool)),
-          this, SLOT(updateWindowCaption()));
-  connect(m_app, SIGNAL(filteredChanged(bool)),
-          this, SLOT(updateWindowCaption()));
-  connect(m_app, SIGNAL(longRunningOperationProgress(QString,int,int,bool*)),
-          this, SLOT(showOperationProgress(QString,int,int,bool*)));
-#if defined HAVE_PHONON || QT_VERSION >= 0x050000
-  connect(m_app, SIGNAL(aboutToPlayAudio()), this, SLOT(showPlayToolBar()));
-#endif
+  connect(m_app, &Kid3Application::fileSelectionUpdateRequested,
+          this, &BaseMainWindowImpl::updateCurrentSelection);
+  connect(m_app, &Kid3Application::selectedFilesUpdated,
+          this, &BaseMainWindowImpl::updateGuiControls);
+  connect(m_app, &Kid3Application::selectedFilesChanged,
+          this, &BaseMainWindowImpl::applySelectionChange);
+  connect(m_app, &Kid3Application::frameModified,
+          this, &BaseMainWindowImpl::updateAfterFrameModification);
+  connect(m_app, &Kid3Application::confirmedOpenDirectoryRequested,
+          this, &BaseMainWindowImpl::confirmedOpenDirectory);
+  connect(m_app, &Kid3Application::toggleExpandedRequested,
+          this, &BaseMainWindowImpl::toggleExpanded);
+  connect(m_app, &Kid3Application::expandFileListRequested,
+          this, &BaseMainWindowImpl::expandFileList);
+  connect(m_app, &Kid3Application::directoryOpened,
+          this, &BaseMainWindowImpl::onDirectoryOpened);
+  connect(m_app, &Kid3Application::modifiedChanged,
+          this, &BaseMainWindowImpl::updateWindowCaption);
+  connect(m_app, &Kid3Application::filteredChanged,
+          this, &BaseMainWindowImpl::updateWindowCaption);
+  connect(m_app, &Kid3Application::longRunningOperationProgress,
+          this, &BaseMainWindowImpl::showOperationProgress);
+  connect(m_app, &Kid3Application::aboutToPlayAudio,
+          this, &BaseMainWindowImpl::showPlayToolBar);
 }
 
 /**
@@ -160,16 +154,7 @@ BaseMainWindowImpl::BaseMainWindowImpl(QMainWindow* mainWin,
  */
 BaseMainWindowImpl::~BaseMainWindowImpl()
 {
-  delete m_importDialog;
-  delete m_batchImportDialog;
-  delete m_renDirDialog;
-  delete m_numberTracksDialog;
-  delete m_filterDialog;
-  delete m_browseCoverArtDialog;
-  delete m_playlistDialog;
-#if defined HAVE_PHONON || QT_VERSION >= 0x050000
-  delete m_playToolBar;
-#endif
+  qDeleteAll(m_playlistEditDialogs);
 }
 
 /**
@@ -272,12 +257,12 @@ void BaseMainWindowImpl::showOperationProgress(const QString& name,
     if (m_progressBar) {
       m_w->statusBar()->removeWidget(m_progressBar);
       delete m_progressBar;
-      m_progressBar = 0;
+      m_progressBar = nullptr;
     }
     if (m_progressAbortButton) {
       m_w->statusBar()->removeWidget(m_progressAbortButton);
       delete m_progressAbortButton;
-      m_progressAbortButton = 0;
+      m_progressAbortButton = nullptr;
     }
     slotStatusMsg(tr("Ready."));
   } else if (done < total || (done == 0 && total == 0)) {
@@ -311,21 +296,21 @@ void BaseMainWindowImpl::saveDirectory(bool updateGui)
   // files from being saved.
   if (m_playToolBar) {
     m_playToolBar->close();
-    delete m_playToolBar;
-    m_playToolBar = 0;
+    m_playToolBar.reset();
   }
   m_app->deleteAudioPlayer();
 #endif
 
-  QStringList errorFiles = m_app->saveDirectory();
+  const QStringList errorFiles = m_app->saveDirectory();
 
   if (!errorFiles.empty()) {
     QStringList errorMsgs, notWritableFiles;
-    foreach (const QString& filePath, errorFiles) {
+    errorMsgs.reserve(errorFiles.size());
+    for (const QString& filePath : errorFiles) {
       QFileInfo fileInfo(filePath);
       if (!fileInfo.isWritable()) {
         errorMsgs.append(tr("%1 is not writable").arg(fileInfo.fileName()));
-        notWritableFiles.append(filePath);
+        notWritableFiles.append(filePath); // clazy:exclude=reserve-candidates
       } else {
         errorMsgs.append(fileInfo.fileName());
       }
@@ -342,15 +327,16 @@ void BaseMainWindowImpl::saveDirectory(bool updateGui)
         errorMsgs,
         tr("File Error"));
       if (rc == QMessageBox::Yes) {
-        FileProxyModel* model =
+        auto model =
             qobject_cast<FileProxyModel*>(m_form->getFileList()->model());
         TaggedFile* taggedFile;
-        foreach (const QString& filePath, notWritableFiles) {
+        const auto filePaths = notWritableFiles;
+        for (const QString& filePath : filePaths) {
           QFile::setPermissions(filePath,
               QFile::permissions(filePath) | QFile::WriteUser);
           if (model &&
               (taggedFile = FileProxyModel::getTaggedFileOfIndex(
-                 model->index(filePath))) != 0) {
+                 model->index(filePath))) != nullptr) {
             taggedFile->undoRevertChangedFilename();
           }
         }
@@ -375,7 +361,7 @@ void BaseMainWindowImpl::saveDirectory(bool updateGui)
  */
 bool BaseMainWindowImpl::saveModified(bool doNotRevert)
 {
-  bool completed=true;
+  bool completed = true;
 
   if(m_app->isModified() && !m_app->getDirName().isEmpty())
   {
@@ -388,7 +374,7 @@ bool BaseMainWindowImpl::saveModified(bool doNotRevert)
     {
     case QMessageBox::Yes:
       saveDirectory();
-      completed=true;
+      completed = true;
       break;
 
     case QMessageBox::No:
@@ -397,15 +383,15 @@ bool BaseMainWindowImpl::saveModified(bool doNotRevert)
           m_app->getFileSelectionModel()->clearSelection();
         m_app->revertFileModifications();
       }
-      completed=true;
+      completed = true;
       break;
 
     case QMessageBox::Cancel:
-      completed=false;
+      completed = false;
       break;
 
     default:
-      completed=false;
+      completed = false;
       break;
     }
   }
@@ -413,6 +399,28 @@ bool BaseMainWindowImpl::saveModified(bool doNotRevert)
   return completed;
 }
 
+/**
+ * If a playlist was modified, save after asking user.
+ * @return false if user canceled.
+ */
+bool BaseMainWindowImpl::saveModifiedPlaylists()
+{
+  if (m_app->hasModifiedPlaylistModel()) {
+    int answer = m_platformTools->warningYesNoCancel(
+        m_w,
+        tr("A playlist has been modified.\n"
+           "Do you want to save it?"),
+        tr("Warning"));
+    if (answer == QMessageBox::Yes) {
+      m_app->saveModifiedPlaylistModels();
+    }
+    if (answer != QMessageBox::Yes && answer != QMessageBox::No) {
+      return false;
+    }
+  }
+  return true;
+}
+
 /**
  * Free allocated resources.
  * Our destructor may not be called, so cleanup is done here.
@@ -435,7 +443,7 @@ void BaseMainWindowImpl::cleanup()
 bool BaseMainWindowImpl::queryBeforeClosing()
 {
   updateCurrentSelection();
-  if (saveModified(true)) {
+  if (saveModified(true) && saveModifiedPlaylists()) {
     saveOptions();
     cleanup();
     return true;
@@ -471,11 +479,22 @@ void BaseMainWindowImpl::slotFileOpenDirectory()
     QString dir = m_platformTools->getExistingDirectory(m_w, QString(),
                                                         m_app->getDirName());
     if (!dir.isEmpty()) {
-      m_app->openDirectory(QStringList() << dir);
+      m_app->openDirectory({dir});
     }
   }
 }
 
+/**
+ * Reload the current directory.
+ */
+void BaseMainWindowImpl::slotFileReload()
+{
+  updateCurrentSelection();
+  if(saveModified()) {
+    m_app->openDirectoryAfterReset();
+  }
+}
+
 /**
  * Open recent directory.
  *
@@ -484,7 +503,7 @@ void BaseMainWindowImpl::slotFileOpenDirectory()
 void BaseMainWindowImpl::openRecentDirectory(const QString& dir)
 {
   updateCurrentSelection();
-  confirmedOpenDirectory(QStringList() << dir);
+  confirmedOpenDirectory({dir});
 }
 
 /**
@@ -525,13 +544,19 @@ void BaseMainWindowImpl::slotStatusMsg(const QString& text)
 void BaseMainWindowImpl::slotPlaylistDialog()
 {
   if (!m_playlistDialog) {
-    m_playlistDialog = new PlaylistDialog(m_w);
+    m_playlistDialog.reset(new PlaylistDialog(m_w));
   }
   m_playlistDialog->readConfig();
   if (m_playlistDialog->exec() == QDialog::Accepted) {
     PlaylistConfig cfg;
     m_playlistDialog->getCurrentConfig(cfg);
-    writePlaylist(cfg);
+    QString newEmptyPlaylistFileName =
+        m_playlistDialog->getFileNameForNewEmptyPlaylist();
+    if (newEmptyPlaylistFileName.isEmpty()) {
+      writePlaylist(cfg);
+    } else {
+      m_app->writeEmptyPlaylist(cfg, newEmptyPlaylistFileName);
+    }
   }
 }
 
@@ -564,6 +589,55 @@ bool BaseMainWindowImpl::slotCreatePlaylist()
   return writePlaylist(PlaylistConfig::instance());
 }
 
+/**
+ * Open dialog to edit playlist.
+ * @param playlistPath path to playlist file
+ */
+void BaseMainWindowImpl::showPlaylistEditDialog(const QString& playlistPath)
+{
+  PlaylistEditDialog* dialog = m_playlistEditDialogs.value(playlistPath);
+  if (!dialog) {
+    PlaylistModel* model = m_app->playlistModel(playlistPath);
+    dialog = new PlaylistEditDialog(model,
+                                    m_form->getFileList()->selectionModel(),
+                                    m_w);
+    connect(dialog, &QDialog::finished,
+            this, &BaseMainWindowImpl::onPlaylistEditDialogFinished);
+    m_playlistEditDialogs.insert(playlistPath, dialog);
+
+    // The playlist windows are placed above the directory list.
+    // If multiple playlist windows are open, they are displaced by the height
+    // of the title bar.
+    QWidget* dirList = m_form->getDirList();
+    int titleBarHeight = dialog->style()->pixelMetric(QStyle::PM_TitleBarHeight);
+    int yOffset = titleBarHeight * m_playlistEditDialogs.size();
+    QRect geometry(dirList->mapToGlobal(QPoint(0, 0)), dirList->size());
+    geometry.setTop(geometry.top() + yOffset);
+    dialog->setGeometry(geometry);
+
+    QStringList filesNotFound = model->filesNotFound();
+    if (!filesNotFound.isEmpty()) {
+      m_platformTools->warningDialog(
+            m_w, tr("Files not found"), filesNotFound.join(QLatin1Char('\n')),
+            tr("Error"));
+    }
+  }
+
+  dialog->showNormal();
+  dialog->raise();
+}
+
+/**
+ * Called when a playlist edit dialog is closed.
+ */
+void BaseMainWindowImpl::onPlaylistEditDialogFinished()
+{
+  if (auto dialog = qobject_cast<PlaylistEditDialog*>(sender())) {
+    m_playlistEditDialogs.remove(m_playlistEditDialogs.key(dialog));
+    dialog->deleteLater();
+  }
+}
+
 /**
  * Update track data and create import dialog.
  */
@@ -572,14 +646,14 @@ void BaseMainWindowImpl::setupImportDialog()
   m_app->filesToTrackDataModel(ImportConfig::instance().importDest());
   if (!m_importDialog) {
     QString caption(tr("Import"));
-    m_importDialog =
+    m_importDialog.reset(
       new ImportDialog(m_platformTools, m_w, caption,
                        m_app->getTrackDataModel(),
                        m_app->genreModel(Frame::Tag_2),
                        m_app->getServerImporters(),
-                       m_app->getServerTrackImporters());
-    connect(m_importDialog, SIGNAL(accepted()),
-            this, SLOT(applyImportedTrackData()));
+                       m_app->getServerTrackImporters()));
+    connect(m_importDialog.data(), &QDialog::accepted,
+            this, &BaseMainWindowImpl::applyImportedTrackData);
   }
   m_importDialog->clear();
 }
@@ -597,7 +671,7 @@ void BaseMainWindowImpl::applyImportedTrackData()
  */
 void BaseMainWindowImpl::slotImport()
 {
-  if (QAction* action = qobject_cast<QAction*>(sender())) {
+  if (auto action = qobject_cast<QAction*>(sender())) {
     setupImportDialog();
     if (m_importDialog) {
       m_importDialog->showWithSubDialog(action->data().toInt());
@@ -611,18 +685,18 @@ void BaseMainWindowImpl::slotImport()
 void BaseMainWindowImpl::slotBatchImport()
 {
   if (!m_batchImportDialog) {
-    m_batchImportDialog = new BatchImportDialog(m_app->getServerImporters(),
-                                                m_w);
-    connect(m_batchImportDialog,
-            SIGNAL(start(BatchImportProfile,Frame::TagVersion)),
-            m_app,
-            SLOT(batchImport(BatchImportProfile,Frame::TagVersion)));
-    connect(m_app->getBatchImporter(), SIGNAL(reportImportEvent(int,QString)),
-            m_batchImportDialog, SLOT(showImportEvent(int,QString)));
-    connect(m_batchImportDialog, SIGNAL(abort()),
-            m_app->getBatchImporter(), SLOT(abort()));
-    connect(m_app->getBatchImporter(), SIGNAL(finished()),
-            this, SLOT(updateGuiControls()));
+    m_batchImportDialog.reset(new BatchImportDialog(m_app->getServerImporters(),
+                                                m_w));
+    connect(m_batchImportDialog.data(), &BatchImportDialog::start,
+            m_app, static_cast<void (Kid3Application::*)(
+              const BatchImportProfile&, Frame::TagVersion)>(
+              &Kid3Application::batchImport));
+    connect(m_app->getBatchImporter(), &BatchImporter::reportImportEvent,
+            m_batchImportDialog.data(), &BatchImportDialog::showImportEvent);
+    connect(m_batchImportDialog.data(), &BatchImportDialog::abort,
+            m_app->getBatchImporter(), &BatchImporter::abort);
+    connect(m_app->getBatchImporter(), &BatchImporter::finished,
+            this, &BaseMainWindowImpl::updateGuiControls);
   }
   m_app->getBatchImporter()->clearAborted();
   m_batchImportDialog->readConfig();
@@ -635,14 +709,14 @@ void BaseMainWindowImpl::slotBatchImport()
 void BaseMainWindowImpl::slotBrowseCoverArt()
 {
   if (!m_browseCoverArtDialog) {
-    m_browseCoverArtDialog = new BrowseCoverArtDialog(m_app, m_w);
+    m_browseCoverArtDialog.reset(new BrowseCoverArtDialog(m_app, m_w));
   }
   FrameCollection frames2;
   QModelIndex index = m_form->getFileList()->currentIndex();
   if (TaggedFile* taggedFile = FileProxyModel::getTaggedFileOfIndex(index)) {
     taggedFile->readTags(false);
     frames2.clear();
-    foreach (Frame::TagNumber tagNr, Frame::allTagNumbers()) {
+    for (Frame::TagNumber tagNr : Frame::allTagNumbers()) {
       if (frames2.empty()) {
         taggedFile->getAllFrames(tagNr, frames2);
       } else {
@@ -673,7 +747,7 @@ void BaseMainWindowImpl::slotExport()
   m_exportDialog->showPreview();
   m_exportDialog->exec();
   delete m_exportDialog;
-  m_exportDialog = 0;
+  m_exportDialog = nullptr;
 }
 
 /**
@@ -723,18 +797,18 @@ void BaseMainWindowImpl::findReplace(bool findOnly)
   TagSearcher* tagSearcher = m_app->getTagSearcher();
   if (!m_findReplaceDialog) {
     m_findReplaceDialog = new FindReplaceDialog(m_w);
-    connect(m_findReplaceDialog, SIGNAL(findRequested(TagSearcher::Parameters)),
-            m_app, SLOT(findText(TagSearcher::Parameters)));
+    connect(m_findReplaceDialog, &FindReplaceDialog::findRequested,
+            m_app, &Kid3Application::findText);
     connect(m_findReplaceDialog,
-            SIGNAL(replaceRequested(TagSearcher::Parameters)),
-            m_app, SLOT(replaceText(TagSearcher::Parameters)));
+            &FindReplaceDialog::replaceRequested,
+            m_app, &Kid3Application::replaceText);
     connect(m_findReplaceDialog,
-            SIGNAL(replaceAllRequested(TagSearcher::Parameters)),
-            m_app, SLOT(replaceAll(TagSearcher::Parameters)));
-    connect(m_findReplaceDialog, SIGNAL(finished(int)),
-            this, SLOT(deactivateFindReplace()));
-    connect(tagSearcher, SIGNAL(progress(QString)),
-            m_findReplaceDialog, SLOT(showProgress(QString)));
+            &FindReplaceDialog::replaceAllRequested,
+            m_app, &Kid3Application::replaceAll);
+    connect(m_findReplaceDialog, &QDialog::finished,
+            this, &BaseMainWindowImpl::deactivateFindReplace);
+    connect(tagSearcher, &TagSearcher::progress,
+            m_findReplaceDialog, &FindReplaceDialog::showProgress);
   }
   m_findReplaceDialog->init(findOnly);
   m_findReplaceDialog->show();
@@ -743,10 +817,10 @@ void BaseMainWindowImpl::findReplace(bool findOnly)
     if (selItems.size() == 1) {
       tagSearcher->setStartIndex(selItems.first());
     }
-    connect(tagSearcher, SIGNAL(textFound()),
-            this, SLOT(showFoundText()));
-    connect(tagSearcher, SIGNAL(textReplaced()),
-            this, SLOT(updateReplacedText()));
+    connect(tagSearcher, &TagSearcher::textFound,
+            this, &BaseMainWindowImpl::showFoundText);
+    connect(tagSearcher, &TagSearcher::textReplaced,
+            this, &BaseMainWindowImpl::updateReplacedText);
     m_findReplaceActive = true;
   }
 }
@@ -759,10 +833,10 @@ void BaseMainWindowImpl::deactivateFindReplace()
   if (m_findReplaceActive) {
     TagSearcher* tagSearcher = m_app->getTagSearcher();
     tagSearcher->abort();
-    disconnect(tagSearcher, SIGNAL(textFound()),
-               this, SLOT(showFoundText()));
-    disconnect(tagSearcher, SIGNAL(textReplaced()),
-               this, SLOT(updateReplacedText()));
+    disconnect(tagSearcher, &TagSearcher::textFound,
+               this, &BaseMainWindowImpl::showFoundText);
+    disconnect(tagSearcher, &TagSearcher::textReplaced,
+               this, &BaseMainWindowImpl::updateReplacedText);
     m_findReplaceActive = false;
   }
 }
@@ -806,17 +880,17 @@ void BaseMainWindowImpl::slotRenameDirectory()
 {
   if (saveModified()) {
     if (!m_renDirDialog) {
-      m_renDirDialog = new RenDirDialog(m_w, m_app->getDirRenamer());
-      connect(m_renDirDialog, SIGNAL(actionSchedulingRequested()),
-              m_app, SLOT(scheduleRenameActions()));
-      connect(m_app->getDirRenamer(), SIGNAL(actionScheduled(QStringList)),
-              m_renDirDialog, SLOT(displayActionPreview(QStringList)));
+      m_renDirDialog.reset(new RenDirDialog(m_w, m_app->getDirRenamer()));
+      connect(m_renDirDialog.data(), &RenDirDialog::actionSchedulingRequested,
+              m_app, &Kid3Application::scheduleRenameActions);
+      connect(m_app->getDirRenamer(), &DirRenamer::actionScheduled,
+              m_renDirDialog.data(), &RenDirDialog::displayActionPreview);
     }
     if (TaggedFile* taggedFile =
       TaggedFileOfDirectoryIterator::first(m_app->currentOrRootIndex())) {
       m_renDirDialog->startDialog(taggedFile);
     } else {
-      m_renDirDialog->startDialog(0, m_app->getDirName());
+      m_renDirDialog->startDialog(nullptr, m_app->getDirName());
     }
     if (m_renDirDialog->exec() == QDialog::Accepted) {
       QString errorMsg(m_app->performRenameActions());
@@ -843,7 +917,7 @@ void BaseMainWindowImpl::slotRenameDirectory()
 void BaseMainWindowImpl::slotNumberTracks()
 {
   if (!m_numberTracksDialog) {
-    m_numberTracksDialog = new NumberTracksDialog(m_w);
+    m_numberTracksDialog.reset(new NumberTracksDialog(m_w));
   }
   m_numberTracksDialog->setTotalNumberOfTracks(
     m_app->getTotalNumberOfTracksInDir(),
@@ -872,13 +946,14 @@ void BaseMainWindowImpl::slotFilter()
 {
   if (saveModified()) {
     if (!m_filterDialog) {
-      m_filterDialog = new FilterDialog(m_w);
-      connect(m_filterDialog, SIGNAL(apply(FileFilter&)),
-              m_app, SLOT(applyFilter(FileFilter&)));
-      connect(m_app, SIGNAL(fileFiltered(int,QString,int,int)),
-              m_filterDialog, SLOT(showFilterEvent(int,QString)));
-      connect(m_app, SIGNAL(fileFiltered(int,QString,int,int)),
-              this, SLOT(filterProgress(int,QString,int,int)));
+      m_filterDialog.reset(new FilterDialog(m_w));
+      connect(m_filterDialog.data(), &FilterDialog::apply,
+              m_app, static_cast<void (Kid3Application::*)(FileFilter&)>(
+                &Kid3Application::applyFilter));
+      connect(m_app, &Kid3Application::fileFiltered,
+              m_filterDialog.data(), &FilterDialog::showFilterEvent);
+      connect(m_app, &Kid3Application::fileFiltered,
+              this, &BaseMainWindowImpl::filterProgress);
     }
     FilterConfig::instance().setFilenameFormat(
           FileConfig::instance().toFilenameFormat());
@@ -923,7 +998,6 @@ void BaseMainWindowImpl::terminateFilter()
   }
 }
 
-#if defined HAVE_PHONON || QT_VERSION >= 0x050000
 /**
  * Play audio file.
  */
@@ -938,24 +1012,23 @@ void BaseMainWindowImpl::slotPlayAudio()
 void BaseMainWindowImpl::showPlayToolBar()
 {
   if (!m_playToolBar) {
-    m_playToolBar = new PlayToolBar(m_app->getAudioPlayer(), m_w);
+    m_playToolBar.reset(new PlayToolBar(m_app->getAudioPlayer(), m_w));
     m_playToolBar->setAllowedAreas(Qt::TopToolBarArea | Qt::BottomToolBarArea);
-    m_w->addToolBar(Qt::BottomToolBarArea, m_playToolBar);
-    connect(m_playToolBar, SIGNAL(errorMessage(QString)),
-            this, SLOT(slotStatusMsg(QString)));
+    m_w->addToolBar(Qt::BottomToolBarArea, m_playToolBar.data());
+    connect(m_playToolBar.data(), &PlayToolBar::errorMessage,
+            this, &BaseMainWindowImpl::slotStatusMsg);
 #ifdef HAVE_QTDBUS
-    connect(m_playToolBar, SIGNAL(closed()),
-            m_app, SLOT(deactivateMprisInterface()));
+    connect(m_playToolBar.data(), &PlayToolBar::closed,
+            m_app, &Kid3Application::deactivateMprisInterface);
 #endif
 #ifdef Q_OS_WIN32
     // Phonon on Windows cannot play if the file is open.
-    connect(m_playToolBar, SIGNAL(aboutToPlay(QString)),
-            m_app, SLOT(closeFileHandle(QString)));
+    connect(m_playToolBar.data(), &PlayToolBar::aboutToPlay,
+            m_app, &Kid3Application::closeFileHandle);
 #endif
   }
   m_playToolBar->show();
 }
-#endif
 
 /**
  * Set window title with information from directory, filter and modification
@@ -1090,7 +1163,7 @@ void BaseMainWindowImpl::selectFrame(Frame* frame, const TaggedFile* taggedFile)
       *frame = Frame(type, QLatin1String(""), name, -1);
     }
   }
-  emit frameSelected(m_editFrameTagNr, ok ? frame : 0);
+  emit frameSelected(m_editFrameTagNr, ok ? frame : nullptr);
 }
 
 /**
@@ -1134,7 +1207,7 @@ void BaseMainWindowImpl::editFrameOfTaggedFile(const Frame* frame,
                                                TaggedFile* taggedFile)
 {
   if (!frame || !taggedFile) {
-    emit frameEdited(m_editFrameTagNr, 0);
+    emit frameEdited(m_editFrameTagNr, nullptr);
     return;
   }
 
@@ -1155,8 +1228,8 @@ void BaseMainWindowImpl::editFrameOfTaggedFile(const Frame* frame,
   }
   if (!m_editFrameDialog) {
     m_editFrameDialog = new EditFrameFieldsDialog(m_platformTools, m_app, m_w);
-    connect(m_editFrameDialog, SIGNAL(finished(int)),
-            this, SLOT(onEditFrameDialogFinished(int)));
+    connect(m_editFrameDialog, &QDialog::finished,
+            this, &BaseMainWindowImpl::onEditFrameDialogFinished);
   }
   m_editFrameDialog->setWindowTitle(name);
   m_editFrameDialog->setFrame(m_editFrame, m_editFrameTaggedFile,
@@ -1170,7 +1243,7 @@ void BaseMainWindowImpl::editFrameOfTaggedFile(const Frame* frame,
  */
 void BaseMainWindowImpl::onEditFrameDialogFinished(int result)
 {
-  if (EditFrameFieldsDialog* dialog =
+  if (auto dialog =
       qobject_cast<EditFrameFieldsDialog*>(sender())) {
     if (result == QDialog::Accepted) {
       const Frame::FieldList& fields = dialog->getUpdatedFieldList();
@@ -1181,12 +1254,13 @@ void BaseMainWindowImpl::onEditFrameDialogFinished(int result)
         m_editFrame.setValueFromFieldList();
       }
       if (m_editFrameTaggedFile->setFrame(m_editFrameTagNr, m_editFrame)) {
-        m_editFrameTaggedFile->markTagChanged(m_editFrameTagNr, m_editFrame.getType());
+        m_editFrameTaggedFile->markTagChanged(m_editFrameTagNr,
+                                              m_editFrame.getType());
       }
     }
   }
   emit frameEdited(m_editFrameTagNr,
-                   result == QDialog::Accepted ? &m_editFrame : 0);
+                   result == QDialog::Accepted ? &m_editFrame : nullptr);
 }
 
 /**
@@ -1195,15 +1269,18 @@ void BaseMainWindowImpl::onEditFrameDialogFinished(int result)
 void BaseMainWindowImpl::renameFile()
 {
   QItemSelectionModel* selectModel = m_app->getFileSelectionModel();
-  FileProxyModel* model =
+  auto model =
       qobject_cast<FileProxyModel*>(m_form->getFileList()->model());
   if (!selectModel || !model)
     return;
 
   QList<QPersistentModelIndex> selItems;
-  foreach (const QModelIndex& index, selectModel->selectedRows())
+  const auto indexes = selectModel->selectedRows();
+  selItems.reserve(indexes.size());
+  for (const QModelIndex& index : indexes)
     selItems.append(index);
-  foreach (const QPersistentModelIndex& index, selItems) {
+  const auto selectedIndexes = selItems;
+  for (const QPersistentModelIndex& index : selectedIndexes) {
     TaggedFile* taggedFile = FileProxyModel::getTaggedFileOfIndex(index);
     QString absFilename, dirName, fileName;
     if (taggedFile) {
@@ -1238,7 +1315,14 @@ void BaseMainWindowImpl::renameFile()
         TaggedFileIterator::closeFileHandles(index);
       }
       QString newPath = dirName + QLatin1Char('/') + newFileName;
-      if (!Utils::safeRename(absFilename, newPath)) {
+      if (model->rename(index, newFileName)) {
+        if (taggedFile) {
+          taggedFile->updateCurrentFilename();
+          if (selItems.size() == 1) {
+            m_form->setFilename(newFileName);
+          }
+        }
+      } else {
 #ifdef Q_OS_WIN32
         if (QMessageBox::warning(
               0, tr("File Error"),
@@ -1250,9 +1334,9 @@ void BaseMainWindowImpl::renameFile()
         }
 #else
         QMessageBox::warning(
-          0, tr("File Error"),
+          nullptr, tr("File Error"),
           tr("Error while renaming:\n") +
-          tr("Rename %1 to %2 failed\n").arg(fileName).arg(newFileName),
+          tr("Rename %1 to %2 failed\n").arg(fileName, newFileName),
           QMessageBox::Ok, Qt::NoButton);
 #endif
       }
@@ -1261,7 +1345,8 @@ void BaseMainWindowImpl::renameFile()
 }
 
 /** Only defined for generation of translation files */
-#define WANT_TO_DELETE_FOR_PO QT_TRANSLATE_NOOP("@default", "Do you really want to move these %1 items to the trash?")
+#define WANT_TO_DELETE_FOR_PO \
+  QT_TRANSLATE_NOOP("@default", "Do you really want to move these %1 items to the trash?")
 
 /**
  * Delete the selected file(s).
@@ -1269,17 +1354,20 @@ void BaseMainWindowImpl::renameFile()
 void BaseMainWindowImpl::deleteFile()
 {
   QItemSelectionModel* selectModel = m_app->getFileSelectionModel();
-  FileProxyModel* model =
+  auto model =
       qobject_cast<FileProxyModel*>(m_form->getFileList()->model());
   if (!selectModel || !model)
     return;
 
   QStringList files;
   QList<QPersistentModelIndex> selItems;
-  foreach (const QModelIndex& index, selectModel->selectedRows())
+  const auto indexes = selectModel->selectedRows();
+  selItems.reserve(indexes.size());
+  for (const QModelIndex& index : indexes)
     selItems.append(index);
-  foreach (const QPersistentModelIndex& index, selItems) {
-    files.append(model->filePath(index));
+  const auto selectedIndexes = selItems;
+  for (const QPersistentModelIndex& index : selectedIndexes) {
+    files.append(model->filePath(index)); // clazy:exclude=reserve-candidates
   }
 
   const int numFiles = files.size();
@@ -1287,19 +1375,23 @@ void BaseMainWindowImpl::deleteFile()
     if (m_platformTools->warningContinueCancelList(
           m_w,
           numFiles > 1
-          ? tr("Do you really want to move these %1 items to the trash?").
-            arg(numFiles)
+          ? tr("Do you really want to move these %1 items to the trash?")
+            .arg(numFiles)
           : tr("Do you really want to move this item to the trash?"),
           files,
           tr("Move to Trash"))) {
       bool rmdirError = false;
       files.clear();
-      foreach (const QPersistentModelIndex& index, selItems) {
+      for (const QPersistentModelIndex& index : selectedIndexes) {
         QString absFilename(model->filePath(index));
+        if (!QFileInfo(absFilename).isWritable()) {
+          QFile::setPermissions(absFilename,
+              QFile::permissions(absFilename) | QFile::WriteUser);
+        }
         if (model->isDir(index)) {
           if (!m_platformTools->moveToTrash(absFilename)) {
             rmdirError = true;
-            files.append(absFilename);
+            files.append(absFilename); // clazy:exclude=reserve-candidates
           }
         } else {
           if (TaggedFile* taggedFile =
@@ -1309,7 +1401,7 @@ void BaseMainWindowImpl::deleteFile()
             taggedFile->closeFileHandle();
           }
           if (!m_platformTools->moveToTrash(absFilename)) {
-            files.append(absFilename);
+            files.append(absFilename); // clazy:exclude=reserve-candidates
           }
         }
       }
@@ -1341,8 +1433,8 @@ void BaseMainWindowImpl::expandFileList()
 {
   m_expandNotificationNeeded = sender() == m_app;
   connect(m_app->getFileProxyModelIterator(),
-          SIGNAL(nextReady(QPersistentModelIndex)),
-          this, SLOT(expandNextDirectory(QPersistentModelIndex)));
+          &FileProxyModelIterator::nextReady,
+          this, &BaseMainWindowImpl::expandNextDirectory);
   // If this slot is invoked from the file list menu action and the
   // shift key is pressed, only expand the current subtree.
   QObject* emitter = sender();
@@ -1384,8 +1476,8 @@ void BaseMainWindowImpl::terminateExpandFileList()
 {
   m_app->getFileProxyModelIterator()->abort();
   disconnect(m_app->getFileProxyModelIterator(),
-             SIGNAL(nextReady(QPersistentModelIndex)),
-             this, SLOT(expandNextDirectory(QPersistentModelIndex)));
+             &FileProxyModelIterator::nextReady,
+             this, &BaseMainWindowImpl::expandNextDirectory);
   if (m_expandNotificationNeeded) {
     m_expandNotificationNeeded = false;
     m_app->notifyExpandFileListFinished();
@@ -1402,9 +1494,9 @@ void BaseMainWindowImpl::terminateExpandFileList()
  * @param disconnectModel true to disconnect the file list models while the
  * progress widget is shown
  */
-void BaseMainWindowImpl::startProgressMonitoring(const QString& title,
-                                                 void (BaseMainWindowImpl::*terminationHandler)(),
-                                                 bool disconnectModel)
+void BaseMainWindowImpl::startProgressMonitoring(
+    const QString& title, void (BaseMainWindowImpl::*terminationHandler)(),
+    bool disconnectModel)
 {
   if (!m_progressTitle.isEmpty() && m_progressTitle != title) {
     stopProgressMonitoring();
@@ -1433,7 +1525,7 @@ void BaseMainWindowImpl::stopProgressMonitoring()
     (this->*m_progressTerminationHandler)();
   }
   m_progressTitle.clear();
-  m_progressTerminationHandler = 0;
+  m_progressTerminationHandler = nullptr;
 }
 
 /**
@@ -1499,7 +1591,7 @@ BaseMainWindow::BaseMainWindow(QMainWindow* mainWin,
  */
 BaseMainWindow::~BaseMainWindow()
 {
-  delete m_impl;
+  // Must not be inline because of forwared declared QScopedPointer.
 }
 
 /**
@@ -1511,7 +1603,6 @@ void BaseMainWindow::init()
   m_impl->init();
 }
 
-#if defined HAVE_PHONON || QT_VERSION >= 0x050000
 /**
  * Play audio file.
  */
@@ -1519,7 +1610,6 @@ void BaseMainWindow::slotPlayAudio()
 {
   m_impl->slotPlayAudio();
 }
-#endif
 
 /**
  * Change status message.
