@@ -6,7 +6,7 @@
  * \author Urs Fleisch
  * \date 9 Jan 2003
  *
- * Copyright (C) 2003-2017  Urs Fleisch
+ * Copyright (C) 2003-2018  Urs Fleisch
  *
  * This file is part of Kid3.
  *
@@ -24,14 +24,13 @@
  * along with this program.  If not, see <http://www.gnu.org/licenses/>.
  */
 
-#ifndef BASEMAINWINDOW_H
-#define BASEMAINWINDOW_H
+#pragma once
 
 #include <QMainWindow>
 #include <QDateTime>
-#include "config.h"
+#include <QScopedPointer>
 #include "iframeeditor.h"
-#include "trackdata.h"
+#include "frame.h"
 #include "kid3api.h"
 
 class QProgressBar;
@@ -53,11 +52,10 @@ class FilterDialog;
 class FileFilter;
 class DownloadDialog;
 class PlaylistDialog;
+class PlaylistEditDialog;
 class PlaylistConfig;
 class EditFrameFieldsDialog;
-#if defined HAVE_PHONON || QT_VERSION >= 0x050000
 class PlayToolBar;
-#endif
 class DirContents;
 class FileProxyModel;
 class DirProxyModel;
@@ -88,7 +86,7 @@ public:
   /**
    * Destructor.
    */
-  virtual ~BaseMainWindowImpl();
+  virtual ~BaseMainWindowImpl() override;
 
   /**
    * Create dialog to edit a frame and update the fields
@@ -99,7 +97,7 @@ public:
    * @param frame frame to edit
    * @param taggedFile tagged file where frame has to be set
    */
-  virtual void editFrameOfTaggedFile(const Frame* frame, TaggedFile* taggedFile);
+  virtual void editFrameOfTaggedFile(const Frame* frame, TaggedFile* taggedFile) override;
 
   /**
    * Let user select a frame type.
@@ -109,26 +107,26 @@ public:
    * @param frame is filled with the selected frame
    * @param taggedFile tagged file for which frame has to be selected
    */
-  virtual void selectFrame(Frame* frame, const TaggedFile* taggedFile);
+  virtual void selectFrame(Frame* frame, const TaggedFile* taggedFile) override;
 
   /**
    * Return object which emits frameSelected(), frameEdited() signals.
    *
    * @return object which emits signals.
    */
-  virtual QObject* qobject();
+  virtual QObject* qobject() override;
 
   /**
    * Get the tag number of the edited frame.
    * @return tag number.
    */
-  virtual Frame::TagNumber tagNumber() const;
+  virtual Frame::TagNumber tagNumber() const override;
 
   /**
    * Set the tag number of the edited frame.
    * @param tagNr tag number
    */
-  virtual void setTagNumber(Frame::TagNumber tagNr);
+  virtual void setTagNumber(Frame::TagNumber tagNr) override;
 
   /**
    * Set back pointer for implementation class.
@@ -209,6 +207,11 @@ public slots:
    */
   void slotFileOpenDirectory();
 
+  /**
+   * Reload the current directory.
+   */
+  void slotFileReload();
+
   /**
    * Save modified files.
    */
@@ -238,6 +241,12 @@ public slots:
    */
   bool slotCreatePlaylist();
 
+  /**
+   * Open dialog to edit playlist.
+   * @param playlistPath path to playlist file
+   */
+  void showPlaylistEditDialog(const QString& playlistPath);
+
   /**
    * Import.
    */
@@ -294,12 +303,10 @@ public slots:
    */
   void slotFilter();
 
-#if defined HAVE_PHONON || QT_VERSION >= 0x050000
   /**
    * Play audio file.
    */
   void slotPlayAudio();
-#endif
 
   /**
    * Update files of current selection.
@@ -363,12 +370,10 @@ private slots:
   void updateAfterFrameModification(TaggedFile* taggedFile,
                                     Frame::TagNumber tagNr);
 
-#if defined HAVE_PHONON || QT_VERSION >= 0x050000
   /**
    * Show play tool bar.
    */
   void showPlayToolBar();
-#endif
 
   /**
    * Expand item if it is a directory.
@@ -392,11 +397,16 @@ private slots:
   void applyImportedTrackData();
 
   /**
-   * Called when the edit fram dialog is finished.
+   * Called when the edit frame dialog is finished.
    * @param result dialog result
    */
   void onEditFrameDialogFinished(int result);
 
+  /**
+   * Called when a playlist edit dialog is closed.
+   */
+  void onPlaylistEditDialogFinished();
+
   /**
    * Toggle expanded state of directory in the file list.
    * @param index index of directory
@@ -462,6 +472,12 @@ private:
    */
   bool saveModified(bool doNotRevert = false);
 
+  /**
+   * If a playlist was modified, save after asking user.
+   * @return false if user canceled.
+   */
+  bool saveModifiedPlaylists();
+
   /**
    * Update track data and create import dialog.
    */
@@ -501,7 +517,9 @@ private:
    * @param disconnectModel true to disconnect the file list models while the
    * progress widget is shown
    */
-  void startProgressMonitoring(const QString& title, void (BaseMainWindowImpl::*terminationHandler)(), bool disconnectModel);
+  void startProgressMonitoring(const QString& title,
+                               void (BaseMainWindowImpl::*terminationHandler)(),
+                               bool disconnectModel);
 
   /**
    * Stop monitoring the progress started with startProgressMonitoring().
@@ -531,35 +549,35 @@ private:
   /** Application logic */
   Kid3Application* m_app;
   /** Import dialog */
-  ImportDialog* m_importDialog;
+  QScopedPointer<ImportDialog> m_importDialog;
   /** Batch import dialog */
-  BatchImportDialog* m_batchImportDialog;
+  QScopedPointer<BatchImportDialog> m_batchImportDialog;
   /** Browse cover art dialog */
-  BrowseCoverArtDialog* m_browseCoverArtDialog;
+  QScopedPointer<BrowseCoverArtDialog> m_browseCoverArtDialog;
   /** Export dialog */
   ExportDialog* m_exportDialog;
   /** Find and replace dialog */
   FindReplaceDialog* m_findReplaceDialog;
   /** Rename directory dialog */
-  RenDirDialog* m_renDirDialog;
+  QScopedPointer<RenDirDialog> m_renDirDialog;
   /** Number tracks dialog */
-  NumberTracksDialog* m_numberTracksDialog;
+  QScopedPointer<NumberTracksDialog> m_numberTracksDialog;
   /** Filter dialog */
-  FilterDialog* m_filterDialog;
+  QScopedPointer<FilterDialog> m_filterDialog;
   /** Download dialog */
   DownloadDialog* m_downloadDialog;
   /** Playlist dialog */
-  PlaylistDialog* m_playlistDialog;
+  QScopedPointer<PlaylistDialog> m_playlistDialog;
+  /** Playlist edit dialogs */
+  QMap<QString, PlaylistEditDialog*> m_playlistEditDialogs;
   /** Progress dialog */
   ProgressWidget* m_progressWidget;
   QProgressBar* m_progressBar;
   QToolButton* m_progressAbortButton;
   /** Edit frame dialog */
   EditFrameFieldsDialog* m_editFrameDialog;
-#if defined HAVE_PHONON || QT_VERSION >= 0x050000
   /** Play toolbar */
-  PlayToolBar* m_playToolBar;
-#endif
+  QScopedPointer<PlayToolBar> m_playToolBar;
   Frame m_editFrame;
   TaggedFile* m_editFrameTaggedFile;
   Frame::TagNumber m_editFrameTagNr;
@@ -641,12 +659,10 @@ public:
    */
   virtual void setWindowCaption(const QString& caption, bool modified) = 0;
 
-#if defined HAVE_PHONON || QT_VERSION >= 0x050000
   /**
    * Play audio file.
    */
   void slotPlayAudio();
-#endif
 
   /**
    * Update files of current selection.
@@ -664,7 +680,7 @@ public:
    * Access to implementation object.
    * @return implementation object.
    */
-  BaseMainWindowImpl* impl() { return m_impl; }
+  BaseMainWindowImpl* impl() { return m_impl.data(); }
 
 protected:
   /**
@@ -718,7 +734,5 @@ protected:
   Kid3Form* form();
 
 private:
-  BaseMainWindowImpl* m_impl;
+  QScopedPointer<BaseMainWindowImpl> m_impl;
 };
-
-#endif /* BASEMAINWINDOW_H */
