@@ -6,7 +6,7 @@
  * \author Urs Fleisch
  * \date 9 Jan 2003
  *
- * Copyright (C) 2003-2014  Urs Fleisch
+ * Copyright (C) 2003-2018  Urs Fleisch
  *
  * This file is part of Kid3.
  *
@@ -32,17 +32,166 @@
 #include <QMenu>
 #include <QHeaderView>
 #include <QDesktopServices>
+#include <QMouseEvent>
+#include <QDialog>
+#include <QLayout>
+#include <QPushButton>
+#include <QTextCursor>
+#include <QTextEdit>
+#include <QMessageBox>
+#include <QCoreApplication>
 #include "fileproxymodel.h"
 #include "modeliterator.h"
 #include "taggedfile.h"
 #include "basemainwindow.h"
 #include "useractionsconfig.h"
 #include "guiconfig.h"
+#include "playlistconfig.h"
 #include "externalprocess.h"
 #include "commandformatreplacer.h"
 
 namespace {
 
+/**
+ * Dialog to show output from external process.
+ */
+class OutputViewer : public QDialog, public ExternalProcess::IOutputViewer {
+public:
+  /**
+   * Constructor.
+   *
+   * @param parent parent widget
+   */
+  explicit OutputViewer(QWidget* parent);
+
+  /**
+   * Destructor.
+   */
+  virtual ~OutputViewer() override;
+
+  /**
+   * Set caption.
+   * @param title caption
+   */
+  virtual void setCaption(const QString& title) override;
+
+  /**
+   * Append text.
+   */
+  virtual void append(const QString& text) override;
+
+  /**
+   * Scroll text to bottom.
+   */
+  virtual void scrollToBottom() override;
+
+private:
+  QTextEdit* m_textEdit;
+};
+
+/**
+ * Constructor.
+ *
+ * @param parent parent widget
+ */
+OutputViewer::OutputViewer(QWidget* parent) : QDialog(parent)
+{
+  setObjectName(QLatin1String("OutputViewer"));
+  setModal(false);
+  auto vlayout = new QVBoxLayout(this);
+  m_textEdit = new QTextEdit(this);
+  m_textEdit->setReadOnly(true);
+  m_textEdit->setLineWrapMode(QTextEdit::NoWrap);
+  m_textEdit->setStyleSheet(QLatin1String("font-family: \"Courier\";"));
+  vlayout->addWidget(m_textEdit);
+  auto buttonLayout = new QHBoxLayout;
+  QPushButton* clearButton = new QPushButton(
+        QCoreApplication::translate("FileList", "C&lear"), this);
+  auto hspacer = new QSpacerItem(16, 0, QSizePolicy::Expanding,
+                                         QSizePolicy::Minimum);
+  QPushButton* closeButton = new QPushButton(
+        QCoreApplication::translate("FileList", "&Close"), this);
+  buttonLayout->addWidget(clearButton);
+  buttonLayout->addItem(hspacer);
+  buttonLayout->addWidget(closeButton);
+  connect(clearButton, &QAbstractButton::clicked, m_textEdit, &QTextEdit::clear);
+  connect(closeButton, &QAbstractButton::clicked, this, &QDialog::accept);
+  vlayout->addLayout(buttonLayout);
+  resize(600, 424);
+}
+
+/**
+ * Destructor.
+ */
+OutputViewer::~OutputViewer()
+{
+  // not inline or default to silence weak-vtables warning
+}
+
+/**
+ * Set caption.
+ * @param title caption
+ */
+void OutputViewer::setCaption(const QString& title)
+{
+  setWindowTitle(title);
+  show();
+  raise();
+}
+
+/**
+ * Append text.
+ */
+void OutputViewer::append(const QString& text)
+{
+  if (text.isEmpty())
+    return;
+
+  QString txt(text);
+  txt.replace(QLatin1String("\r\n"), QLatin1String("\n"));
+  int startPos = 0;
+  int txtLen = txt.length();
+  while (startPos < txtLen) {
+    QChar ch;
+    int len;
+    int crLfPos = txt.indexOf(QRegExp(QLatin1String("[\\r\\n]")), startPos);
+    if (crLfPos >= startPos) {
+      ch = txt.at(crLfPos);
+      len = crLfPos - startPos;
+    } else {
+      ch = QChar();
+      len = -1;
+    }
+    QString line(txt.mid(startPos, len));
+    if (!m_textEdit->textCursor().atBlockEnd()) {
+      QTextCursor cursor = m_textEdit->textCursor();
+      cursor.movePosition(QTextCursor::Right, QTextCursor::KeepAnchor,
+                          line.length());
+      m_textEdit->setTextCursor(cursor);
+    }
+    m_textEdit->insertPlainText(line);
+    if (ch == QLatin1Char('\r')) {
+      m_textEdit->moveCursor(QTextCursor::StartOfLine);
+    } else if (ch == QLatin1Char('\n')) {
+      m_textEdit->moveCursor(QTextCursor::EndOfLine);
+      m_textEdit->insertPlainText(ch);
+    }
+    if (len == -1) {
+      break;
+    }
+    startPos = crLfPos + 1;
+  }
+}
+
+/**
+ * Scroll text to bottom.
+ */
+void OutputViewer::scrollToBottom()
+{
+  m_textEdit->moveCursor(QTextCursor::End);
+}
+
+
 /**
  * Create a name for an action.
  * @param text user action text
@@ -51,9 +200,7 @@ namespace {
 QString nameForAction(const QString& text)
 {
   QString name;
-  for (QString::const_iterator cit = text.constBegin();
-       cit != text.constEnd();
-       ++cit) {
+  for (auto cit = text.constBegin(); cit != text.constEnd(); ++cit) {
     if (cit->toLatin1() == '\0') {
       continue;
     }
@@ -77,19 +224,17 @@ QString nameForAction(const QString& text)
  * @param parent parent widget
  * @param mainWin main window
  */
-FileList::FileList(QWidget* parent, BaseMainWindowImpl* mainWin) :
-  ConfigurableTreeView(parent), m_process(0), m_mainWin(mainWin),
-  m_renameAction(0), m_deleteAction(0)
+FileList::FileList(QWidget* parent, BaseMainWindowImpl* mainWin)
+  : ConfigurableTreeView(parent), m_mainWin(mainWin),
+    m_renameAction(nullptr), m_deleteAction(nullptr)
 {
   setObjectName(QLatin1String("FileList"));
   setSelectionMode(ExtendedSelection);
   setContextMenuPolicy(Qt::CustomContextMenu);
-  connect(this, SIGNAL(customContextMenuRequested(QPoint)),
-      this, SLOT(customContextMenu(QPoint)));
-#if defined HAVE_PHONON || QT_VERSION >= 0x050000
-  connect(this, SIGNAL(doubleClicked(QModelIndex)),
-          this, SLOT(playIfTaggedFile(QModelIndex)));
-#endif
+  connect(this, &QWidget::customContextMenuRequested,
+      this, &FileList::customContextMenu);
+  connect(this, &QAbstractItemView::doubleClicked,
+          this, &FileList::onDoubleClicked);
 }
 
 /**
@@ -97,7 +242,7 @@ FileList::FileList(QWidget* parent, BaseMainWindowImpl* mainWin) :
  */
 FileList::~FileList()
 {
-  delete m_process;
+  // Must not be inline because of forwared declared QScopedPointer.
 }
 
 /**
@@ -110,6 +255,58 @@ QSize FileList::sizeHint() const
                QTreeView::sizeHint().height());
 }
 
+/**
+ * Enable dragging if the item is pressed at the left icon side.
+ * @param event mouse event
+ */
+void FileList::mousePressEvent(QMouseEvent* event)
+{
+  QPoint pos = event->pos();
+  if (pos.x() < 80) {
+    QModelIndex idx = indexAt(pos);
+    if (const auto fsModel =
+        qobject_cast<const FileProxyModel*>(idx.model())) {
+      if (!FileProxyModel::getTaggedFileOfIndex(idx)) {
+        // The file possibly dragged is not a tagged file, e.g. an image file.
+        // Make it the only draggable file in order to keep the selection of
+        // tagged files while still being able to drag an image file on them.
+        const_cast<FileProxyModel*>(fsModel)->setExclusiveDraggableIndex(idx);
+        setSelectionMode(MultiSelection);
+      } else {
+        const_cast<FileProxyModel*>(fsModel)->setExclusiveDraggableIndex(
+              QPersistentModelIndex());
+        setSelectionMode(ExtendedSelection);
+      }
+    }
+    setDragEnabled(true);
+  } else {
+    setDragEnabled(false);
+    setSelectionMode(ExtendedSelection);
+  }
+  ConfigurableTreeView::mousePressEvent(event);
+}
+
+/**
+ * Called when a drag operation is started.
+ * Reimplemented to close all tagged files before being dropped to another
+ * application, which would not be able to open them on Windows.
+ * @param supportedActions drop actions
+ */
+void FileList::startDrag(Qt::DropActions supportedActions)
+{
+  const auto indexes = selectedIndexes();
+  for (const QModelIndex& index : indexes) {
+    const QAbstractItemModel* mdl = index.model();
+    if (index.column() == 0 &&
+        mdl && (mdl->flags(index) & Qt::ItemIsDragEnabled)) {
+      if (TaggedFile* tf = FileProxyModel::getTaggedFileOfIndex(index)) {
+        tf->closeFileHandle();
+      }
+    }
+  }
+  ConfigurableTreeView::startDrag(supportedActions);
+}
+
 /**
  * Init the user actions for the context menu.
  */
@@ -120,17 +317,14 @@ void FileList::initUserActions()
   int id = 0;
   const QList<UserActionsConfig::MenuCommand> commands =
       UserActionsConfig::instance().contextMenuCommands();
-  for (QList<UserActionsConfig::MenuCommand>::const_iterator
-         it = commands.constBegin();
-       it != commands.constEnd();
-       ++it) {
+  for (auto it = commands.constBegin(); it != commands.constEnd(); ++it) {
     const QString text((*it).getName());
     const QString name = nameForAction(text);
     if (!name.isEmpty() && it->getCommand() != QLatin1String("@beginmenu")) {
       QAction* action = oldUserActions.take(name);
       if (!action) {
         action = new QAction(text, this);
-        connect(action, SIGNAL(triggered()), this, SLOT(executeAction()));
+        connect(action, &QAction::triggered, this, &FileList::executeSenderAction);
         emit userActionAdded(name, action);
       }
       action->setData(id);
@@ -138,9 +332,7 @@ void FileList::initUserActions()
     }
     ++id;
   }
-  for (QMap<QString, QAction*>::const_iterator it = oldUserActions.constBegin();
-       it != oldUserActions.constEnd();
-       ++it) {
+  for (auto it = oldUserActions.constBegin(); it != oldUserActions.constEnd(); ++it) {
     emit userActionRemoved(it.key(), it.value());
   }
 }
@@ -154,28 +346,53 @@ void FileList::initUserActions()
 void FileList::contextMenu(const QModelIndex& index, const QPoint& pos)
 {
   if (index.isValid()) {
+    QString path;
+    bool isPlaylist = false;
+    if (const auto model =
+            qobject_cast<const FileProxyModel*>(index.model())) {
+      path = model->filePath(index);
+      PlaylistConfig::formatFromFileExtension(path, &isPlaylist);
+    }
     QMenu menu(this);
+#if QT_VERSION >= 0x050600
+    menu.addAction(tr("&Expand all"), m_mainWin,
+                   &BaseMainWindowImpl::expandFileList);
+    menu.addAction(tr("&Collapse all"), this, &QTreeView::collapseAll);
+#else
     menu.addAction(tr("&Expand all"), m_mainWin, SLOT(expandFileList()));
     menu.addAction(tr("&Collapse all"), this, SLOT(collapseAll()));
+#endif
     if (m_renameAction) {
       menu.addAction(m_renameAction);
     }
     if (m_deleteAction) {
       menu.addAction(m_deleteAction);
     }
-#if defined HAVE_PHONON || QT_VERSION >= 0x050000
+#if QT_VERSION >= 0x050600
+    menu.addAction(tr("&Play"), m_mainWin, &BaseMainWindowImpl::slotPlayAudio);
+#else
     menu.addAction(tr("&Play"), m_mainWin, SLOT(slotPlayAudio()));
 #endif
+    if (isPlaylist) {
+      QAction* editPlaylistAction = new QAction(tr("E&dit"), &menu);
+      editPlaylistAction->setData(path);
+      connect(editPlaylistAction, &QAction::triggered,
+              this, &FileList::editPlaylist);
+      menu.addAction(editPlaylistAction);
+    }
+#if QT_VERSION >= 0x050600
+    menu.addAction(tr("&Open"), this, &FileList::openFile);
+    menu.addAction(tr("Open Containing &Folder"),
+                   this, &FileList::openContainingFolder);
+#else
     menu.addAction(tr("&Open"), this, SLOT(openFile()));
     menu.addAction(tr("Open Containing &Folder"),
                    this, SLOT(openContainingFolder()));
+#endif
     QMenu* userMenu = &menu;
     QList<UserActionsConfig::MenuCommand> commands =
         UserActionsConfig::instance().contextMenuCommands();
-    for (QList<UserActionsConfig::MenuCommand>::const_iterator
-           it = commands.constBegin();
-         it != commands.constEnd();
-         ++it) {
+    for (auto it = commands.constBegin(); it != commands.constEnd(); ++it) {
       const QString text((*it).getName());
       const QString name = nameForAction(text);
       if (!text.isEmpty()) {
@@ -187,7 +404,7 @@ void FileList::contextMenu(const QModelIndex& index, const QPoint& pos)
       } else if (it->getCommand() == QLatin1String("@separator")) {
         userMenu->addSeparator();
       } else if (it->getCommand() == QLatin1String("@endmenu")) {
-        if (QMenu* parentMenu = qobject_cast<QMenu*>(userMenu->parent())) {
+        if (auto parentMenu = qobject_cast<QMenu*>(userMenu->parent())) {
           userMenu = parentMenu;
         }
       }
@@ -222,10 +439,10 @@ void FileList::contextMenu(const QModelIndex& index, const QPoint& pos)
 QStringList FileList::formatStringList(const QStringList& format)
 {
   QStringList files;
-  TaggedFile* firstSelectedFile = 0;
-  QModelIndexList selItems(selectionModel()
+  TaggedFile* firstSelectedFile = nullptr;
+  const QModelIndexList selItems(selectionModel()
        ? selectionModel()->selectedRows() : QModelIndexList());
-  foreach (const QModelIndex& index, selItems) {
+  for (const QModelIndex& index : selItems) {
     if (TaggedFile* taggedFile = FileProxyModel::getTaggedFileOfIndex(index)) {
       if (!firstSelectedFile) {
         firstSelectedFile = taggedFile;
@@ -245,9 +462,7 @@ QStringList FileList::formatStringList(const QStringList& format)
 
   FrameCollection frames;
   QStringList fmt;
-  for (QStringList::const_iterator it = format.begin();
-       it != format.end();
-       ++it) {
+  for (auto it = format.constBegin(); it != format.constEnd(); ++it) {
     if ((*it).indexOf(QLatin1Char('%')) == -1) {
       fmt.push_back(*it);
     } else {
@@ -258,9 +473,7 @@ QStringList FileList::formatStringList(const QStringList& format)
         // list of URLs or URL
         QUrl url;
         url.setScheme(QLatin1String("file"));
-        for (QStringList::const_iterator fit = files.begin();
-             fit != files.end();
-             ++fit) {
+        for (auto fit = files.constBegin(); fit != files.constEnd(); ++fit) {
           url.setPath(*fit);
           fmt.push_back(url.toString());
         }
@@ -268,7 +481,7 @@ QStringList FileList::formatStringList(const QStringList& format)
         if (firstSelectedFile) {
           // use merged tags to format string
           frames.clear();
-          foreach (Frame::TagNumber tagNr, Frame::allTagNumbers()) {
+          for (Frame::TagNumber tagNr : Frame::allTagNumbers()) {
             if (frames.empty()) {
               firstSelectedFile->getAllFrames(tagNr, frames);
             } else {
@@ -296,9 +509,11 @@ QStringList FileList::formatStringList(const QStringList& format)
  */
 void FileList::executeContextCommand(int id)
 {
-  if (id < static_cast<int>(UserActionsConfig::instance().contextMenuCommands().size())) {
+  if (id < static_cast<int>(
+        UserActionsConfig::instance().contextMenuCommands().size())) {
     QStringList args;
-    const UserActionsConfig::MenuCommand& menuCmd = UserActionsConfig::instance().contextMenuCommands().at(id);
+    const UserActionsConfig::MenuCommand& menuCmd =
+        UserActionsConfig::instance().contextMenuCommands().at(id);
     QString cmd = menuCmd.getCommand();
 
     int len = cmd.length();
@@ -334,10 +549,26 @@ void FileList::executeContextCommand(int id)
     args = formatStringList(args);
 
     if (!m_process) {
-      m_process = new ExternalProcess(m_mainWin->app(), this);
+      m_process.reset(new ExternalProcess(m_mainWin->app(), this));
+    }
+    if (menuCmd.outputShown() && !m_process->outputViewer()) {
+      m_process->setOutputViewer(new OutputViewer(this));
+    }
+    if (menuCmd.mustBeConfirmed() && !args.isEmpty()) {
+      if (QMessageBox::question(
+            this, menuCmd.getName(),
+            tr("Execute ") + args.join(QLatin1String(" ")) + QLatin1Char('?'),
+            QMessageBox::Ok, QMessageBox::Cancel) != QMessageBox::Ok) {
+        return;
+      }
+    }
+    if (!m_process->launchCommand(menuCmd.getName(), args,
+                                  menuCmd.outputShown())) {
+      QMessageBox::warning(
+        this, menuCmd.getName(),
+        tr("Could not execute ") + args.join(QLatin1String(" ")),
+        QMessageBox::Ok, Qt::NoButton);
     }
-    m_process->launchCommand(menuCmd.getName(), args, menuCmd.mustBeConfirmed(),
-                             menuCmd.outputShown());
   }
 }
 
@@ -363,10 +594,7 @@ void FileList::executeAction(QAction* action)
     id = 0;
     QList<UserActionsConfig::MenuCommand> commands =
         UserActionsConfig::instance().contextMenuCommands();
-    for (QList<UserActionsConfig::MenuCommand>::const_iterator
-           it = commands.constBegin();
-         it != commands.constEnd();
-         ++it) {
+    for (auto it = commands.constBegin(); it != commands.constEnd(); ++it) {
       if (name == (*it).getName()) {
         executeContextCommand(id);
         break;
@@ -376,6 +604,16 @@ void FileList::executeAction(QAction* action)
   }
 }
 
+/**
+ * Execute context menu action which sent signal.
+ * Same as executeAction() with default arguments, provided for functor-based
+ * connections.
+ */
+void FileList::executeSenderAction()
+{
+  executeAction(nullptr);
+}
+
 /**
  * Display a custom context menu with operations for selected files.
  *
@@ -386,20 +624,37 @@ void FileList::customContextMenu(const QPoint& pos)
   contextMenu(currentIndex(), mapToGlobal(pos));
 }
 
-#if defined HAVE_PHONON || QT_VERSION >= 0x050000
 /**
- * Play item if it is a tagged file.
+ * Handle double click to file.
  *
  * @param index model index of item
  */
-void FileList::playIfTaggedFile(const QModelIndex& index)
+void FileList::onDoubleClicked(const QModelIndex& index)
 {
-  if (GuiConfig::instance().playOnDoubleClick() &&
-      FileProxyModel::getTaggedFileOfIndex(index)) {
-    m_mainWin->slotPlayAudio();
+  if (FileProxyModel::getTaggedFileOfIndex(index)) {
+    if (GuiConfig::instance().playOnDoubleClick()) {
+      m_mainWin->slotPlayAudio();
+    }
+  } else if (const auto model =
+             qobject_cast<const FileProxyModel*>(index.model())) {
+    QString path = model->filePath(index);
+    bool isPlaylist = false;
+    PlaylistConfig::formatFromFileExtension(path, &isPlaylist);
+    if (isPlaylist) {
+      m_mainWin->showPlaylistEditDialog(path);
+    }
+  }
+}
+
+/**
+ * Called when "Edit" action is called from context menu.
+ */
+void FileList::editPlaylist()
+{
+  if (auto action = qobject_cast<QAction*>(sender())) {
+    m_mainWin->showPlaylistEditDialog(action->data().toString());
   }
 }
-#endif
 
 /**
  * Set rename action.
@@ -437,9 +692,10 @@ void FileList::setDeleteAction(QAction* action)
 void FileList::openFile()
 {
   if (QItemSelectionModel* selModel = selectionModel()) {
-    if (const FileProxyModel* fsModel =
+    if (const auto fsModel =
         qobject_cast<const FileProxyModel*>(selModel->model())) {
-      foreach (const QModelIndex& index, selModel->selectedRows()) {
+      const auto indexes = selModel->selectedRows();
+      for (const QModelIndex& index : indexes) {
         QDesktopServices::openUrl(
               QUrl::fromLocalFile(fsModel->filePath(index)));
       }
@@ -458,7 +714,7 @@ void FileList::openContainingFolder()
       const FileProxyModel* fsModel;
       QModelIndex index = indexes.first().parent();
       if (index.isValid() &&
-          (fsModel = qobject_cast<const FileProxyModel*>(index.model())) != 0 &&
+          (fsModel = qobject_cast<const FileProxyModel*>(index.model())) != nullptr &&
           fsModel->isDir(index)) {
         QDesktopServices::openUrl(
               QUrl::fromLocalFile(fsModel->filePath(index)));
