@@ -6,7 +6,7 @@
  * \author Urs Fleisch
  * \date 9 Jan 2003
  *
- * Copyright (C) 2003-2014  Urs Fleisch
+ * Copyright (C) 2003-2018  Urs Fleisch
  *
  * This file is part of Kid3.
  *
@@ -24,13 +24,12 @@
  * along with this program.  If not, see <http://www.gnu.org/licenses/>.
  */
 
-#ifndef FILELIST_H
-#define FILELIST_H
+#pragma once
 
 #include <QList>
 #include <QMap>
+#include <QScopedPointer>
 #include "configurabletreeview.h"
-#include "config.h"
 #include "kid3api.h"
 
 class BaseMainWindowImpl;
@@ -40,8 +39,7 @@ class ExternalProcess;
  * List of files to operate on.
  */
 class KID3_GUI_EXPORT FileList : public ConfigurableTreeView {
-Q_OBJECT
-
+  Q_OBJECT
 public:
   /**
    * Constructor.
@@ -53,13 +51,13 @@ public:
   /**
    * Destructor.
    */
-  virtual ~FileList();
+  virtual ~FileList() override;
 
   /**
    * Returns the recommended size for the widget.
    * @return recommended size.
    */
-  virtual QSize sizeHint() const;
+  virtual QSize sizeHint() const override;
 
   /**
    * Set rename action.
@@ -73,6 +71,21 @@ public:
    */
   void setDeleteAction(QAction* action);
 
+protected:
+  /**
+   * Enable dragging if the item is pressed at the left icon side.
+   * @param event mouse event
+   */
+  virtual void mousePressEvent(QMouseEvent* event) override;
+
+  /**
+   * Called when a drag operation is started.
+   * Reimplemented to close all tagged files before being dropped to another
+   * application, which would not be able to open them on Windows.
+   * @param supportedActions drop actions
+   */
+  virtual void startDrag(Qt::DropActions supportedActions) override;
+
 public slots:
   /**
    * Init the user actions for the context menu.
@@ -115,7 +128,14 @@ private slots:
    *
    * @param action action of selected menu, 0 to use sender() action
    */
-  void executeAction(QAction* action = 0);
+  void executeAction(QAction* action = nullptr);
+
+  /**
+   * Execute context menu action which sent signal.
+   * Same as executeAction() with default arguments, provided for functor-based
+   * connections.
+   */
+  void executeSenderAction();
 
   /**
    * Display a custom context menu with operations for selected files.
@@ -124,20 +144,23 @@ private slots:
    */
   void customContextMenu(const QPoint& pos);
 
-#if defined HAVE_PHONON || QT_VERSION >= 0x050000
   /**
-   * Play item if it is a tagged file.
+   * Handle double click to file.
    *
    * @param index model index of item
    */
-  void playIfTaggedFile(const QModelIndex& index);
-#endif
+  void onDoubleClicked(const QModelIndex& index);
 
   /**
    * Open with standard application.
    */
   void openFile();
 
+  /**
+   * Called when "Edit" action is called from context menu.
+   */
+  void editPlaylist();
+
   /**
    * Open containing folder.
    */
@@ -170,11 +193,9 @@ private:
   QStringList formatStringList(const QStringList& format);
 
   /** Process for context menu commands */
-  ExternalProcess* m_process;
+  QScopedPointer<ExternalProcess> m_process;
   BaseMainWindowImpl* m_mainWin;
   QAction* m_renameAction;
   QAction* m_deleteAction;
   QMap<QString, QAction*> m_userActions;
 };
-
-#endif // FILELIST_H
