@@ -6,7 +6,7 @@
  * \author Urs Fleisch
  * \date 8 Apr 2003
  *
- * Copyright (C) 2003-2017  Urs Fleisch
+ * Copyright (C) 2003-2018  Urs Fleisch
  *
  * This file is part of Kid3.
  *
@@ -45,9 +45,12 @@
 #include <QScrollArea>
 #include <QUrl>
 #include <QApplication>
-#include <QFileSystemModel>
 #include <QMimeData>
 #include <QMenu>
+#include <QFileIconProvider>
+#include <QStyle>
+#include <QHeaderView>
+#include "filesystemmodel.h"
 #include "frametable.h"
 #include "frametablemodel.h"
 #include "trackdata.h"
@@ -62,19 +65,22 @@
 #include "formatconfig.h"
 #include "dirproxymodel.h"
 #include "fileproxymodel.h"
+#include "filesystemmodel.h"
 #include "taggedfileiconprovider.h"
 #include "kid3application.h"
-#if defined Q_OS_MAC && QT_VERSION >= 0x050200
+#ifdef Q_OS_MAC
 #include <CoreFoundation/CFURL.h>
 #endif
 
 /** Collapse pixmap, will be allocated in constructor */
-QPixmap* Kid3Form::s_collapsePixmap = 0;
+QPixmap* Kid3Form::s_collapsePixmap = nullptr;
 /** Expand pixmap, will be allocated in constructor */
-QPixmap* Kid3Form::s_expandPixmap = 0;
+QPixmap* Kid3Form::s_expandPixmap = nullptr;
+
+namespace {
 
 /** picture for collapse pixmap */
-static const char* const collapse_xpm[] = {
+const char* const collapse_xpm[] = {
   "7 7 3 1",
   " \tc None",
   ".\tc #FFFFFF",
@@ -89,7 +95,7 @@ static const char* const collapse_xpm[] = {
 };
 
 /** picture for expand pixmap */
-static const char* const expand_xpm[] = {
+const char* const expand_xpm[] = {
   "7 7 3 1",
   " \tc None",
   ".\tc #FFFFFF",
@@ -107,16 +113,15 @@ static const char* const expand_xpm[] = {
 /**
  * Event filter for double click on picture label.
  */
-class PictureDblClickHandler : public QObject
-{
+class PictureDblClickHandler : public QObject {
 public:
   /**
    * Constructor.
    * @param app application
    */
-  explicit PictureDblClickHandler(Kid3Application* app) :
-    QObject(app), m_app(app) {}
-  virtual ~PictureDblClickHandler() {}
+  explicit PictureDblClickHandler(Kid3Application* app)
+    : QObject(app), m_app(app) {}
+  virtual ~PictureDblClickHandler() override = default;
 
 protected:
   /**
@@ -127,9 +132,11 @@ protected:
    *
    * @return true if event is filtered.
    */
-  virtual bool eventFilter(QObject* obj, QEvent* event);
+  virtual bool eventFilter(QObject* obj, QEvent* event) override;
 
 private:
+  Q_DISABLE_COPY(PictureDblClickHandler)
+
   Kid3Application* m_app;
 };
 
@@ -153,6 +160,92 @@ bool PictureDblClickHandler::eventFilter(QObject* obj, QEvent* event)
 }
 
 
+/**
+ * File decoration provider for FileSystemModel delegating to QFileIconProvider.
+ */
+class WidgetFileDecorationProvider : public AbstractFileDecorationProvider {
+public:
+  virtual QVariant headerDecoration() const override {
+    // From QFileSystemModel:
+    // ### TODO oh man this is ugly and doesn't even work all the way!
+    // it is still 2 pixels off
+    QImage pixmap(16, 1, QImage::Format_Mono);
+    pixmap.fill(0);
+    pixmap.setAlphaChannel(pixmap.createAlphaMask());
+    return pixmap;
+  }
+
+  virtual QVariant computerDecoration() const override {
+    return m_provider.icon(QFileIconProvider::Computer);
+  }
+
+  virtual QVariant folderDecoration() const override {
+    return m_provider.icon(QFileIconProvider::Folder);
+  }
+
+  virtual QVariant fileDecoration() const override {
+    return m_provider.icon(QFileIconProvider::File);
+  }
+
+  virtual QVariant decoration(const QFileInfo& info) const override {
+    return m_provider.icon(info);
+  }
+
+  virtual QString type(const QFileInfo& info) const override {
+    return m_provider.type(info);
+  }
+
+private:
+  QFileIconProvider m_provider;
+};
+
+
+/**
+ * Get the items from a combo box.
+ *
+ * @param comboBox combo box
+ *
+ * @return item texts from combo box.
+ */
+QStringList getItemsFromComboBox(const QComboBox* comboBox)
+{
+  QStringList lst;
+  const int numItems = comboBox->count();
+  lst.reserve(numItems);
+  for (int i = 0; i < numItems; ++i) {
+    lst += comboBox->itemText(i);
+  }
+  return lst;
+}
+
+/**
+ * Set items in combo box and add current item if not already existing.
+ * @param items combo box item
+ * @param currentItem current item
+ * @param comboBox combo box to set
+ */
+void setItemsInComboBox(const QStringList& items, const QString& currentItem,
+                        QComboBox* comboBox)
+{
+  QStringList allItems = items;
+  int idx = allItems.indexOf(currentItem);
+  if (idx == -1) {
+    allItems.append(currentItem);
+    idx = allItems.size() - 1;
+  }
+  // Block signals on combo box while setting contents to avoid
+  // editTextChanged() signals causing configuration changes.
+  comboBox->blockSignals(true);
+  if (!allItems.isEmpty()) {
+    comboBox->clear();
+    comboBox->addItems(allItems);
+  }
+  comboBox->setCurrentIndex(idx);
+  comboBox->blockSignals(false);
+}
+
+}
+
 /**
  * Constructs an Id3Form as a child of 'parent', with the
  * name 'name' and widget flags set to 'f'.
@@ -161,7 +254,8 @@ bool PictureDblClickHandler::eventFilter(QObject* obj, QEvent* event)
  */
 Kid3Form::Kid3Form(Kid3Application* app, BaseMainWindowImpl* mainWin,
                    QWidget* parent)
-  : QSplitter(parent), m_pictureLabel(0), m_app(app), m_mainWin(mainWin)
+  : QSplitter(parent), m_pictureLabel(nullptr), m_app(app), m_mainWin(mainWin),
+    m_iconProvider(new WidgetFileDecorationProvider)
 {
   setObjectName(QLatin1String("Kid3Form"));
 
@@ -173,10 +267,10 @@ Kid3Form::Kid3Form(Kid3Application* app, BaseMainWindowImpl* mainWin,
   }
 
   if (!s_collapsePixmap) {
-    s_collapsePixmap = new QPixmap((const char**)collapse_xpm);
+    s_collapsePixmap = new QPixmap(const_cast<const char**>(collapse_xpm));
   }
   if (!s_expandPixmap) {
-    s_expandPixmap = new QPixmap((const char**)expand_xpm);
+    s_expandPixmap = new QPixmap(const_cast<const char**>(expand_xpm));
   }
 
   setAcceptDrops(true);
@@ -187,9 +281,15 @@ Kid3Form::Kid3Form(Kid3Application* app, BaseMainWindowImpl* mainWin,
   m_leftSideWidget->addWidget(m_vSplitter);
   m_fileListBox = new FileList(m_vSplitter, m_mainWin);
   FileProxyModel* fileProxyModel = m_app->getFileProxyModel();
+  if (FileSystemModel* fsModel =
+          qobject_cast<FileSystemModel*>(fileProxyModel->sourceModel())) {
+    fsModel->setDecorationProvider(m_iconProvider.data());
+  }
+  TaggedFileIconProvider* tagIconProvider = fileProxyModel->getIconProvider();
+  tagIconProvider->setModifiedIcon(
+        QApplication::style()->standardIcon(QStyle::SP_DriveFDIcon));
   int iconHeight = (((fontMetrics().height() - 1) / 16) + 1) * 16;
-  fileProxyModel->getIconProvider()->setRequestedSize(
-        QSize(iconHeight, iconHeight));
+  tagIconProvider->setRequestedSize(QSize(iconHeight, iconHeight));
   m_fileListBox->setModel(fileProxyModel);
   m_fileListBox->setSelectionModel(m_app->getFileSelectionModel());
   m_dirListBox = new ConfigurableTreeView(m_vSplitter);
@@ -198,21 +298,21 @@ Kid3Form::Kid3Form(Kid3Application* app, BaseMainWindowImpl* mainWin,
   m_dirListBox->setRootIsDecorated(false);
   m_dirListBox->setModel(m_app->getDirProxyModel());
   m_dirListBox->setSelectionModel(m_app->getDirSelectionModel());
-  connect(m_dirListBox, SIGNAL(activated(QModelIndex)), this,
-      SLOT(dirSelected(QModelIndex)));
+  connect(m_dirListBox, &QAbstractItemView::activated, this,
+      &Kid3Form::dirSelected);
 
-  connect(m_app, SIGNAL(fileRootIndexChanged(QModelIndex)),
-          this, SLOT(setFileRootIndex(QModelIndex)));
-  connect(m_app, SIGNAL(dirRootIndexChanged(QModelIndex)),
-          this, SLOT(setDirRootIndex(QModelIndex)));
-  connect(m_app, SIGNAL(directoryOpened()),
-          this, SLOT(onFirstDirectoryOpened()));
+  connect(m_app, &Kid3Application::fileRootIndexChanged,
+          this, &Kid3Form::setFileRootIndex);
+  connect(m_app, &Kid3Application::dirRootIndexChanged,
+          this, &Kid3Form::setDirRootIndex);
+  connect(m_app, &Kid3Application::directoryOpened,
+          this, &Kid3Form::onFirstDirectoryOpened);
 
   m_rightHalfVBox = new QWidget;
-  QScrollArea* scrollView = new QScrollArea(this);
+  auto scrollView = new QScrollArea(this);
   scrollView->setWidget(m_rightHalfVBox);
   scrollView->setWidgetResizable(true);
-  QVBoxLayout* rightHalfLayout = new QVBoxLayout(m_rightHalfVBox);
+  auto rightHalfLayout = new QVBoxLayout(m_rightHalfVBox);
   rightHalfLayout->setSpacing(0);
 
   m_fileButton = new QToolButton(m_rightHalfVBox);
@@ -221,9 +321,9 @@ Kid3Form::Kid3Form(Kid3Application* app, BaseMainWindowImpl* mainWin,
 #ifdef Q_OS_MAC
   m_fileButton->setStyleSheet(QLatin1String("border: 0;"));
 #endif
-  connect(m_fileButton, SIGNAL(clicked()), this, SLOT(showHideFile()));
+  connect(m_fileButton, &QAbstractButton::clicked, this, &Kid3Form::showHideFile);
   m_fileLabel = new QLabel(tr("F&ile"), m_rightHalfVBox);
-  QHBoxLayout* fileButtonLayout = new QHBoxLayout;
+  auto fileButtonLayout = new QHBoxLayout;
   fileButtonLayout->addWidget(m_fileButton);
   fileButtonLayout->addWidget(m_fileLabel);
   rightHalfLayout->addLayout(fileButtonLayout);
@@ -231,14 +331,14 @@ Kid3Form::Kid3Form(Kid3Application* app, BaseMainWindowImpl* mainWin,
   m_fileWidget = new QWidget(m_rightHalfVBox);
   m_fileWidget->setSizePolicy(QSizePolicy::Expanding, QSizePolicy::Fixed);
   rightHalfLayout->addWidget(m_fileWidget);
-  QGridLayout* fileLayout = new QGridLayout(m_fileWidget);
+  auto fileLayout = new QGridLayout(m_fileWidget);
 
   m_nameLabel = new QLabel(tr("Name:"), m_fileWidget);
   fileLayout->addWidget(m_nameLabel, 0, 0);
 
   m_nameLineEdit = new QLineEdit(m_fileWidget);
-  connect(m_nameLineEdit, SIGNAL(textEdited(QString)), this,
-      SLOT(nameLineEditChanged(QString)));
+  connect(m_nameLineEdit, &QLineEdit::textEdited, this,
+      &Kid3Form::nameLineEditChanged);
   fileLayout->addWidget(m_nameLineEdit, 0, 1, 1, 4);
   m_fileLabel->setBuddy(m_nameLineEdit);
 
@@ -248,18 +348,21 @@ Kid3Form::Kid3Form(Kid3Application* app, BaseMainWindowImpl* mainWin,
 
   m_formatComboBox = new QComboBox(m_fileWidget);
   m_formatComboBox->setEditable(true);
-  m_formatComboBox->setSizeAdjustPolicy(QComboBox::AdjustToMinimumContentsLengthWithIcon);
+  m_formatComboBox->setSizeAdjustPolicy(
+        QComboBox::AdjustToMinimumContentsLengthWithIcon);
   m_formatComboBox->setSizePolicy(QSizePolicy::Expanding, QSizePolicy::Fixed);
   m_formatComboBox->setToolTip(TrackDataFormatReplacer::getToolTip());
-  connect(m_formatComboBox, SIGNAL(editTextChanged(QString)),
-          this, SLOT(onFormatEditTextChanged(QString)));
+  connect(m_formatComboBox, &QComboBox::editTextChanged,
+          this, &Kid3Form::onFormatEditTextChanged);
   m_formatFromFilenameComboBox = new QComboBox(m_fileWidget);
   m_formatFromFilenameComboBox->setEditable(true);
-  m_formatFromFilenameComboBox->setSizeAdjustPolicy(QComboBox::AdjustToMinimumContentsLengthWithIcon);
-  m_formatFromFilenameComboBox->setSizePolicy(QSizePolicy::Expanding, QSizePolicy::Fixed);
+  m_formatFromFilenameComboBox->setSizeAdjustPolicy(
+        QComboBox::AdjustToMinimumContentsLengthWithIcon);
+  m_formatFromFilenameComboBox->setSizePolicy(
+        QSizePolicy::Expanding, QSizePolicy::Fixed);
   m_formatFromFilenameComboBox->setToolTip(FrameFormatReplacer::getToolTip());
-  connect(m_formatFromFilenameComboBox, SIGNAL(editTextChanged(QString)),
-          this, SLOT(onFormatFromFilenameEditTextChanged(QString)));
+  connect(m_formatFromFilenameComboBox, &QComboBox::editTextChanged,
+          this, &Kid3Form::onFormatFromFilenameEditTextChanged);
 
   fileLayout->addWidget(m_formatComboBox, 1, 1);
 
@@ -279,13 +382,13 @@ Kid3Form::Kid3Form(Kid3Application* app, BaseMainWindowImpl* mainWin,
       m_fnButton[tagNr] = new QPushButton(tr("Tag %1").arg(tagStr),
                                           m_fileWidget);
       m_fnButton[tagNr]->setToolTip(tr("Filename from Tag %1").arg(tagStr));
-      connect(m_fnButton[tagNr], SIGNAL(clicked()),
-              m_app->tag(tagNr), SLOT(getFilenameFromTags()));
+      connect(m_fnButton[tagNr], &QAbstractButton::clicked,
+              m_app->tag(tagNr), &Kid3ApplicationTagContext::getFilenameFromTags);
       fileLayout->addWidget(m_fnButton[tagNr], 1, column++);
       setTabOrder(tabWidget, m_fnButton[tagNr]);
       tabWidget = m_fnButton[tagNr];
     } else {
-      m_fnButton[tagNr] = 0;
+      m_fnButton[tagNr] = nullptr;
     }
   }
 
@@ -304,13 +407,13 @@ Kid3Form::Kid3Form(Kid3Application* app, BaseMainWindowImpl* mainWin,
       m_toTagButton[tagNr] =
         new QPushButton(tr("Tag %1").arg(tagStr), m_fileWidget);
       m_toTagButton[tagNr]->setToolTip(tr("Tag %1 from Filename").arg(tagStr));
-      connect(m_toTagButton[tagNr], SIGNAL(clicked()),
-              m_app->tag(tagNr), SLOT(getTagsFromFilename()));
+      connect(m_toTagButton[tagNr], &QAbstractButton::clicked,
+              m_app->tag(tagNr), &Kid3ApplicationTagContext::getTagsFromFilename);
       fileLayout->addWidget(m_toTagButton[tagNr], 2, column++);
       setTabOrder(tabWidget, m_toTagButton[tagNr]);
       tabWidget = m_toTagButton[tagNr];
     } else {
-      m_toTagButton[tagNr] = 0;
+      m_toTagButton[tagNr] = nullptr;
     }
   }
 
@@ -321,9 +424,11 @@ Kid3Form::Kid3Form(Kid3Application* app, BaseMainWindowImpl* mainWin,
 #ifdef Q_OS_MAC
     m_tagButton[tagNr]->setStyleSheet(QLatin1String("border: 0;"));
 #endif
-    connect(m_tagButton[tagNr], SIGNAL(clicked()), tag(tagNr), SLOT(showHideTag()));
-    m_tagLabel[tagNr] = new QLabel(tr("Tag &%1").arg(Frame::tagNumberToString(tagNr)), m_rightHalfVBox);
-    QHBoxLayout* tagButtonLayout = new QHBoxLayout;
+    connect(m_tagButton[tagNr], &QAbstractButton::clicked,
+            tag(tagNr), &Kid3FormTagContext::showHideTag);
+    m_tagLabel[tagNr] = new QLabel(
+          tr("Tag &%1").arg(Frame::tagNumberToString(tagNr)), m_rightHalfVBox);
+    auto tagButtonLayout = new QHBoxLayout;
     tagButtonLayout->addWidget(m_tagButton[tagNr]);
     tagButtonLayout->addWidget(m_tagLabel[tagNr]);
     rightHalfLayout->addLayout(tagButtonLayout);
@@ -334,48 +439,49 @@ Kid3Form::Kid3Form(Kid3Application* app, BaseMainWindowImpl* mainWin,
     }
     rightHalfLayout->addWidget(m_tagWidget[tagNr], 100);
 
-    QHBoxLayout* idHBoxLayout = new QHBoxLayout(m_tagWidget[tagNr]);
-    m_frameTable[tagNr] = new FrameTable(m_app->frameModel(tagNr), m_app->genreModel(tagNr),
-                                     m_tagWidget[tagNr]);
+    auto idHBoxLayout = new QHBoxLayout(m_tagWidget[tagNr]);
+    m_frameTable[tagNr] = new FrameTable(
+          m_app->frameModel(tagNr), m_app->genreModel(tagNr), m_tagWidget[tagNr]);
     m_frameTable[tagNr]->setSelectionModel(m_app->getFramesSelectionModel(tagNr));
     idHBoxLayout->addWidget(m_frameTable[tagNr], tagNr == Frame::Tag_Id3v1 ? 100 : 0);
     m_tagLabel[tagNr]->setBuddy(m_frameTable[tagNr]);
 
-    QVBoxLayout* buttonsVBoxLayout = new QVBoxLayout;
+    auto buttonsVBoxLayout = new QVBoxLayout;
     idHBoxLayout->addLayout(buttonsVBoxLayout);
 
     if (tagNr <= Frame::Tag_2) {
-      Frame::TagNumber otherTagNr = tagNr == Frame::Tag_1 ? Frame::Tag_2 :
-            tagNr == Frame::Tag_2 ? Frame::Tag_1 : Frame::Tag_NumValues;
+      Frame::TagNumber otherTagNr = tagNr == Frame::Tag_1
+          ? Frame::Tag_2
+          : tagNr == Frame::Tag_2 ? Frame::Tag_1 : Frame::Tag_NumValues;
       m_id3PushButton[tagNr] =
         new QPushButton(tr("From Tag %1")
                         .arg(Frame::tagNumberToString(otherTagNr)),
                         m_tagWidget[tagNr]);
-      connect(m_id3PushButton[tagNr], SIGNAL(clicked()),
-              m_app->tag(tagNr), SLOT(copyToOtherTag()));
+      connect(m_id3PushButton[tagNr], &QAbstractButton::clicked,
+              m_app->tag(tagNr), &Kid3ApplicationTagContext::copyToOtherTag);
       buttonsVBoxLayout->addWidget(m_id3PushButton[tagNr]);
       setTabOrder(tabWidget, m_id3PushButton[tagNr]);
 
       QPushButton* copyPushButton = new QPushButton(tr("Copy"),
                                                     m_tagWidget[tagNr]);
-      connect(copyPushButton, SIGNAL(clicked()),
-              m_app->tag(tagNr), SLOT(copyTags()));
+      connect(copyPushButton, &QAbstractButton::clicked,
+              m_app->tag(tagNr), &Kid3ApplicationTagContext::copyTags);
       buttonsVBoxLayout->addWidget(copyPushButton);
       setTabOrder(m_id3PushButton[tagNr], copyPushButton);
 
       QPushButton* pastePushButton =
         new QPushButton(tr("Paste"), m_tagWidget[tagNr]);
-      connect(pastePushButton, SIGNAL(clicked()),
-              m_app->tag(tagNr), SLOT(pasteTags()));
+      connect(pastePushButton, &QAbstractButton::clicked,
+              m_app->tag(tagNr), &Kid3ApplicationTagContext::pasteTags);
       buttonsVBoxLayout->addWidget(pastePushButton);
       setTabOrder(copyPushButton, pastePushButton);
       tabWidget = pastePushButton;
     } else {
       m_id3PushButton[tagNr] = new QPushButton(tr("From"));
-      QMenu* menu = new QMenu(this);
+      auto menu = new QMenu(this);
       QAction* action = menu->addAction(tr("Filename"));
-      connect(action, SIGNAL(triggered()),
-              m_app->tag(tagNr), SLOT(getTagsFromFilename()));
+      connect(action, &QAction::triggered,
+              m_app->tag(tagNr), &Kid3ApplicationTagContext::getTagsFromFilename);
       FOR_ALL_TAGS(fromTagNr) {
         if (fromTagNr != tagNr) {
           action = menu->addAction(
@@ -384,13 +490,13 @@ Kid3Form::Kid3Form(Kid3Application* app, BaseMainWindowImpl* mainWin,
           ba.append(static_cast<char>(fromTagNr));
           ba.append(static_cast<char>(tagNr));
           action->setData(ba);
-          connect(action, SIGNAL(triggered()),
-                  m_app, SLOT(copyTagsActionData()));
+          connect(action, &QAction::triggered,
+                  this, &Kid3Form::copyTagsActionData);
         }
       }
       action = menu->addAction(tr("Paste"));
-      connect(action, SIGNAL(triggered()),
-              m_app->tag(tagNr), SLOT(pasteTags()));
+      connect(action, &QAction::triggered,
+              m_app->tag(tagNr), &Kid3ApplicationTagContext::pasteTags);
       m_id3PushButton[tagNr]->setMenu(menu);
       buttonsVBoxLayout->addWidget(m_id3PushButton[tagNr]);
       setTabOrder(tabWidget, m_id3PushButton[tagNr]);
@@ -398,8 +504,8 @@ Kid3Form::Kid3Form(Kid3Application* app, BaseMainWindowImpl* mainWin,
       QPushButton* toButton = new QPushButton(tr("To"));
       menu = new QMenu(this);
       action = menu->addAction(tr("Filename"));
-      connect(action, SIGNAL(triggered()),
-              m_app->tag(tagNr), SLOT(getFilenameFromTags()));
+      connect(action, &QAction::triggered,
+              m_app->tag(tagNr), &Kid3ApplicationTagContext::getFilenameFromTags);
       FOR_ALL_TAGS(fromTagNr) {
         if (fromTagNr != tagNr) {
           action = menu->addAction(
@@ -408,13 +514,13 @@ Kid3Form::Kid3Form(Kid3Application* app, BaseMainWindowImpl* mainWin,
           ba.append(static_cast<char>(tagNr));
           ba.append(static_cast<char>(fromTagNr));
           action->setData(ba);
-          connect(action, SIGNAL(triggered()),
-                  m_app, SLOT(copyTagsActionData()));
+          connect(action, &QAction::triggered,
+                  this, &Kid3Form::copyTagsActionData);
         }
       }
       action = menu->addAction(tr("Copy"));
-      connect(action, SIGNAL(triggered()),
-              m_app->tag(tagNr), SLOT(copyTags()));
+      connect(action, &QAction::triggered,
+              m_app->tag(tagNr), &Kid3ApplicationTagContext::copyTags);
       toButton->setMenu(menu);
       buttonsVBoxLayout->addWidget(toButton);
       setTabOrder(m_id3PushButton[tagNr], toButton);
@@ -423,7 +529,8 @@ Kid3Form::Kid3Form(Kid3Application* app, BaseMainWindowImpl* mainWin,
 
     QPushButton* removePushButton =
       new QPushButton(tr("Remove"), m_tagWidget[tagNr]);
-    connect(removePushButton, SIGNAL(clicked()), m_app->tag(tagNr), SLOT(removeTags()));
+    connect(removePushButton, &QAbstractButton::clicked,
+            m_app->tag(tagNr), &Kid3ApplicationTagContext::removeTags);
     buttonsVBoxLayout->addWidget(removePushButton);
     setTabOrder(tabWidget, removePushButton);
     tabWidget = removePushButton;
@@ -436,17 +543,20 @@ Kid3Form::Kid3Form(Kid3Application* app, BaseMainWindowImpl* mainWin,
 
       QPushButton* editFramesPushButton =
         new QPushButton(tr("Edit..."), m_tagWidget[tagNr]);
-      connect(editFramesPushButton, SIGNAL(clicked()), m_app->tag(tagNr), SLOT(editFrame()));
+      connect(editFramesPushButton, &QAbstractButton::clicked,
+              m_app->tag(tagNr), &Kid3ApplicationTagContext::editFrame);
       buttonsVBoxLayout->addWidget(editFramesPushButton);
       setTabOrder(tabWidget, editFramesPushButton);
       QPushButton* framesAddPushButton =
         new QPushButton(tr("Add..."), m_tagWidget[tagNr]);
-      connect(framesAddPushButton, SIGNAL(clicked()), m_app->tag(tagNr), SLOT(addFrame()));
+      connect(framesAddPushButton, &QAbstractButton::clicked,
+              m_app->tag(tagNr), &Kid3ApplicationTagContext::addFrame);
       buttonsVBoxLayout->addWidget(framesAddPushButton);
       setTabOrder(editFramesPushButton, framesAddPushButton);
       QPushButton* deleteFramesPushButton =
         new QPushButton(tr("Delete"), m_tagWidget[tagNr]);
-      connect(deleteFramesPushButton, SIGNAL(clicked()), m_app->tag(tagNr), SLOT(deleteFrame()));
+      connect(deleteFramesPushButton, &QAbstractButton::clicked,
+              m_app->tag(tagNr), &Kid3ApplicationTagContext::deleteFrame);
       buttonsVBoxLayout->addWidget(deleteFramesPushButton);
       setTabOrder(framesAddPushButton, deleteFramesPushButton);
       tabWidget = deleteFramesPushButton;
@@ -527,7 +637,7 @@ void Kid3Form::dropEvent(QDropEvent* ev)
   } else if (ev->mimeData()->hasFormat(QLatin1String("text/uri-list"))) {
     QList<QUrl> urls = ev->mimeData()->urls();
     ev->acceptProposedAction();
-    m_app->openDropUrls(urls);
+    m_app->dropUrls(urls, ev->source() != nullptr);
   } else {
     ev->ignore();
   }
@@ -550,7 +660,8 @@ void Kid3Form::markChangedFilename(bool en)
 {
   if (en) {
     QPalette changedPalette(m_nameLabel->palette());
-    changedPalette.setBrush(QPalette::Active, QPalette::Window, changedPalette.mid());
+    changedPalette.setBrush(QPalette::Active, QPalette::Window,
+                            changedPalette.mid());
     m_nameLabel->setPalette(changedPalette);
   } else {
     m_nameLabel->setPalette(QPalette());
@@ -586,12 +697,12 @@ void Kid3Form::formatLineEdit(QLineEdit* le, const QString& txt,
  */
 void Kid3Form::dirSelected(const QModelIndex& index)
 {
-  QString dirPath = index.data(QFileSystemModel::FilePathRole).toString();
+  QString dirPath = index.data(FileSystemModel::FilePathRole).toString();
   if (!dirPath.isEmpty()) {
     m_app->setDirUpIndex(
         dirPath.endsWith(QLatin1String("..")) ? index.parent() : QModelIndex());
     m_mainWin->updateCurrentSelection();
-    m_mainWin->confirmedOpenDirectory(QStringList() << dirPath);
+    m_mainWin->confirmedOpenDirectory({dirPath});
   }
 }
 
@@ -608,8 +719,9 @@ void Kid3Form::enableControls(Frame::TagNumber tagNr, bool enable)
   if (m_toTagButton[tagNr]) {
     m_toTagButton[tagNr]->setEnabled(enable);
   }
-  Frame::TagNumber otherTagNr = tagNr == Frame::Tag_1 ? Frame::Tag_2 :
-        tagNr == Frame::Tag_2 ? Frame::Tag_1 : Frame::Tag_NumValues;
+  Frame::TagNumber otherTagNr = tagNr == Frame::Tag_1
+      ? Frame::Tag_2
+      : tagNr == Frame::Tag_2 ? Frame::Tag_1 : Frame::Tag_NumValues;
   if (otherTagNr < Frame::Tag_NumValues) {
     m_id3PushButton[otherTagNr]->setEnabled(enable);
   }
@@ -718,15 +830,37 @@ void Kid3Form::onFormatFromFilenameEditTextChanged(const QString& text)
 void Kid3Form::onFirstDirectoryOpened()
 {
   // Only call this once.
-  disconnect(m_app, SIGNAL(directoryOpened()),
-             this, SLOT(onFirstDirectoryOpened()));
+  disconnect(m_app, &Kid3Application::directoryOpened,
+             this, &Kid3Form::onFirstDirectoryOpened);
   const GuiConfig& guiCfg = GuiConfig::instance();
   m_app->getFileProxyModel()->sort(guiCfg.fileListSortColumn(),
                                    guiCfg.fileListSortOrder());
-  foreach (int column, guiCfg.fileListVisibleColumns()) {
+  int firstFileSectionSize = 0;
+  const QHeaderView* fileHeader = m_fileListBox->header();
+  const auto columns = guiCfg.fileListVisibleColumns();
+  for (int column : columns) {
     m_fileListBox->resizeColumnToContents(column);
+    if (firstFileSectionSize <= 0 && fileHeader) {
+      firstFileSectionSize = fileHeader->sectionSize(column);
+    }
   }
   m_fileListBox->scrollTo(m_fileListBox->currentIndex());
+
+  int firstDirSectionSize = 0;
+  QHeaderView* dirHeader = m_dirListBox->header();
+  const auto dirColumns = guiCfg.dirListVisibleColumns();
+  for (int column : dirColumns) {
+    m_dirListBox->resizeColumnToContents(column);
+    if (firstDirSectionSize <= 0 && dirHeader) {
+      firstDirSectionSize = dirHeader->sectionSize(column);
+      if (firstDirSectionSize < firstFileSectionSize) {
+        // The directory column often only contains "." and "..", which results
+        // in a small size. Make it at least as wide as the corresponding
+        // file list column.
+        dirHeader->resizeSection(column, firstFileSectionSize);
+      }
+    }
+  }
 }
 
 /**
@@ -779,22 +913,6 @@ void Kid3Form::setFocusDirList()
   m_dirListBox->setFocus();
 }
 
-/**
- * Get the items from a combo box.
- *
- * @param comboBox combo box
- *
- * @return item texts from combo box.
- */
-static QStringList getItemsFromComboBox(const QComboBox* comboBox)
-{
-  QStringList lst;
-  for (int i = 0; i < comboBox->count(); ++i) {
-    lst += comboBox->itemText(i);
-  }
-  return lst;
-}
-
 /**
  * Save the local settings to the configuration.
  */
@@ -804,10 +922,8 @@ void Kid3Form::saveConfig()
   FileConfig& fileCfg = FileConfig::instance();
   guiCfg.setSplitterSizes(sizes());
   guiCfg.setVSplitterSizes(m_vSplitter->sizes());
-  fileCfg.setToFilenameFormatIndex(m_formatComboBox->currentIndex());
   fileCfg.setToFilenameFormat(m_formatComboBox->currentText());
   fileCfg.setToFilenameFormats(getItemsFromComboBox(m_formatComboBox));
-  fileCfg.setFromFilenameFormatIndex(m_formatFromFilenameComboBox->currentIndex());
   fileCfg.setFromFilenameFormat(m_formatFromFilenameComboBox->currentText());
   fileCfg.setFromFilenameFormats(getItemsFromComboBox(m_formatFromFilenameComboBox));
   if (!guiCfg.autoHideTags()) {
@@ -838,36 +954,20 @@ void Kid3Form::readConfig()
   if (!guiCfg.splitterSizes().isEmpty()) {
     setSizes(guiCfg.splitterSizes());
   } else {
-    setSizes(QList<int>() << 307 << 601);
+    setSizes({307, 601});
   }
   if (!guiCfg.vSplitterSizes().isEmpty()) {
     m_vSplitter->setSizes(guiCfg.vSplitterSizes());
   } else {
-    m_vSplitter->setSizes(QList<int>() << 451 << 109);
+    m_vSplitter->setSizes({451, 109});
   }
 
-  // Block signals on combo boxes while setting contents to avoid
-  // editTextChanged() signals causing configuration changes.
-  m_formatComboBox->blockSignals(true);
-  m_formatFromFilenameComboBox->blockSignals(true);
-  if (!fileCfg.toFilenameFormats().isEmpty()) {
-    m_formatComboBox->clear();
-    m_formatComboBox->addItems(fileCfg.toFilenameFormats());
-  }
-  if (!fileCfg.fromFilenameFormats().isEmpty()) {
-    m_formatFromFilenameComboBox->clear();
-    m_formatFromFilenameComboBox->addItems(fileCfg.fromFilenameFormats());
-  }
-  m_formatComboBox->setItemText(fileCfg.toFilenameFormatIndex(),
-                                fileCfg.toFilenameFormat());
-  m_formatComboBox->setCurrentIndex(fileCfg.toFilenameFormatIndex());
-  m_formatFromFilenameComboBox->setItemText(
-    fileCfg.fromFilenameFormatIndex(),
-    fileCfg.fromFilenameFormat());
-  m_formatFromFilenameComboBox->setCurrentIndex(
-    fileCfg.fromFilenameFormatIndex());
-  m_formatComboBox->blockSignals(false);
-  m_formatFromFilenameComboBox->blockSignals(false);
+  setToFilenameFormats();
+  setFromFilenameFormats();
+  connect(&fileCfg, &FileConfig::toFilenameFormatsChanged,
+          this, &Kid3Form::setToFilenameFormats, Qt::UniqueConnection);
+  connect(&fileCfg, &FileConfig::fromFilenameFormatsChanged,
+          this, &Kid3Form::setFromFilenameFormats, Qt::UniqueConnection);
 
   if (!guiCfg.autoHideTags()) {
     hideFile(guiCfg.hideFile());
@@ -884,6 +984,26 @@ void Kid3Form::readConfig()
   m_dirListBox->setVisibleColumns(guiCfg.dirListVisibleColumns());
 }
 
+/**
+ * Set items of "Format <arrow up>" combo box from file configuration.
+ */
+void Kid3Form::setToFilenameFormats()
+{
+  const FileConfig& fileCfg = FileConfig::instance();
+  setItemsInComboBox(fileCfg.toFilenameFormats(), fileCfg.toFilenameFormat(),
+                     m_formatComboBox);
+}
+
+/**
+ * Set items of "Format <arrow down>" combo box from file configuration.
+ */
+void Kid3Form::setFromFilenameFormats()
+{
+  const FileConfig& fileCfg = FileConfig::instance();
+  setItemsInComboBox(fileCfg.fromFilenameFormats(), fileCfg.fromFilenameFormat(),
+                     m_formatFromFilenameComboBox);
+}
+
 /**
  * Set preview picture data.
  * @param data picture data, empty if no picture is available
@@ -959,6 +1079,28 @@ bool Kid3Form::previousFile(bool select, bool onlyTaggedFiles)
   return ok;
 }
 
+/**
+ * Select the next tagged file as the current file.
+ * Same as nextFile() with default arguments, provided for functor-based
+ * connections.
+ * @return true if a next file exists.
+ */
+bool Kid3Form::selectNextTaggedFile()
+{
+  return nextFile(true, true);
+}
+
+/**
+ * Select the previous tagged file as the current file.
+ * Same as previousFile() with default arguments, provided for functor-based
+ * connections.
+ * @return true if a previous file exists.
+ */
+bool Kid3Form::selectPreviousTaggedFile()
+{
+  return previousFile(true, true);
+}
+
 /**
  * Get frame table which is currently in editing state.
  * The returned frame table can be used to restore the editing state after
@@ -974,7 +1116,7 @@ FrameTable* Kid3Form::getEditingFrameTable() const
       }
     }
   }
-  return 0;
+  return nullptr;
 }
 
 /**
@@ -1023,3 +1165,23 @@ void Kid3Form::removeLeftSideWidget(QWidget* widget)
 {
   m_leftSideWidget->removeWidget(widget);
 }
+
+/**
+ * Copy tags using QAction::data().
+ * The source and destination tag numbers are taken from the first two bytes
+ * in QAction::data().toByteArray() if the sender() is a QAction.
+ */
+void Kid3Form::copyTagsActionData()
+{
+  if (auto action = qobject_cast<QAction*>(sender())) {
+    QByteArray ba = action->data().toByteArray();
+    if (ba.size() == 2) {
+      Frame::TagNumber srcTagNr = Frame::tagNumberCast(ba.at(0));
+      Frame::TagNumber dstTagNr = Frame::tagNumberCast(ba.at(1));
+      if (srcTagNr != Frame::Tag_NumValues &&
+          dstTagNr != Frame::Tag_NumValues) {
+        m_app->copyTag(srcTagNr, dstTagNr);
+      }
+    }
+  }
+}
