@@ -6,7 +6,7 @@
  * \author Urs Fleisch
  * \date 8 Apr 2003
  *
- * Copyright (C) 2003-2017  Urs Fleisch
+ * Copyright (C) 2003-2018  Urs Fleisch
  *
  * This file is part of Kid3.
  *
@@ -24,13 +24,11 @@
  * along with this program.  If not, see <http://www.gnu.org/licenses/>.
  */
 
-#ifndef KID3FORM_H
-#define KID3FORM_H
+#pragma once
 
 #include <QSplitter>
 #include <QLineEdit>
-#include "taggedfile.h"
-#include "config.h"
+#include "frame.h"
 
 class QLabel;
 class QCheckBox;
@@ -51,11 +49,12 @@ class ConfigurableTreeView;
 class PictureLabel;
 class BaseMainWindowImpl;
 class Kid3FormTagContext;
+class AbstractFileDecorationProvider;
 
 /**
  * Main widget.
  */
-class Kid3Form : public QSplitter {
+class KID3_GUI_EXPORT Kid3Form : public QSplitter {
   Q_OBJECT
 public:
   /**
@@ -66,12 +65,12 @@ public:
    * @param parent parent widget
    */
   Kid3Form(Kid3Application* app, BaseMainWindowImpl* mainWin,
-           QWidget* parent = 0);
+           QWidget* parent = nullptr);
 
   /**
    * Destructor.
    */
-  virtual ~Kid3Form();
+  virtual ~Kid3Form() override;
 
   /**
    * Get context for tag.
@@ -289,6 +288,22 @@ public slots:
    */
   bool previousFile(bool select = true, bool onlyTaggedFiles = true);
 
+  /**
+   * Select the next tagged file as the current file.
+   * Same as nextFile() with default arguments, provided for functor-based
+   * connections.
+   * @return true if a next file exists.
+   */
+  bool selectNextTaggedFile();
+
+  /**
+   * Select the previous tagged file as the current file.
+   * Same as previousFile() with default arguments, provided for functor-based
+   * connections.
+   * @return true if a previous file exists.
+   */
+  bool selectPreviousTaggedFile();
+
   /**
    * Set the root index of the file list.
    *
@@ -309,28 +324,28 @@ protected:
    *
    * @param ev drag event.
    */
-  virtual void dragEnterEvent(QDragEnterEvent* ev);
+  virtual void dragEnterEvent(QDragEnterEvent* ev) override;
 
   /**
    * Handle event when mouse is moved while dragging.
    *
    * @param ev drag event.
    */
-  virtual void dragMoveEvent(QDragMoveEvent* ev);
+  virtual void dragMoveEvent(QDragMoveEvent* ev) override;
 
   /**
    * Handle event when mouse leaves widget while dragging.
    *
    * @param ev drag event.
    */
-  virtual void dragLeaveEvent(QDragLeaveEvent* ev);
+  virtual void dragLeaveEvent(QDragLeaveEvent* ev) override;
 
   /**
    * Handle drop event.
    *
    * @param ev drop event.
    */
-  virtual void dropEvent(QDropEvent* ev);
+  virtual void dropEvent(QDropEvent* ev) override;
 
 private slots:
   /**
@@ -357,6 +372,23 @@ private slots:
    */
   void onFirstDirectoryOpened();
 
+  /**
+   * Copy tags using QAction::data().
+   * The source and destination tag numbers are taken from the first two bytes
+   * in QAction::data().toByteArray() if the sender() is a QAction.
+   */
+  void copyTagsActionData();
+
+  /**
+   * Set items of "Format <arrow up>" combo box from file configuration.
+   */
+  void setToFilenameFormats();
+
+  /**
+   * Set items of "Format <arrow down>" combo box from file configuration.
+   */
+  void setFromFilenameFormats();
+
 private:
   /**
    * Format string within line edit.
@@ -399,6 +431,7 @@ private:
   PictureLabel* m_pictureLabel;
   Kid3Application* m_app;
   BaseMainWindowImpl* m_mainWin;
+  QScopedPointer<AbstractFileDecorationProvider> m_iconProvider;
 
   /** Collapse pixmap, will be allocated in constructor */
   static QPixmap* s_collapsePixmap;
@@ -436,5 +469,3 @@ private:
   Kid3Form* const m_form;
   const Frame::TagNumber m_tagNr;
 };
-
-#endif // KID3FORM_H
