@@ -42,17 +42,13 @@
  * @param parent parent widget
  */
 FrameTable::FrameTable(FrameTableModel* model, GenreModel* genreModel,
-                       QWidget* parent) :
-  QTableView(parent), m_currentEditor(0)
+                       QWidget* parent)
+  : QTableView(parent), m_currentEditor(nullptr)
 {
   setObjectName(QLatin1String("FrameTable"));
   setModel(model);
   setSelectionMode(SingleSelection);
-#if QT_VERSION >= 0x050000
   horizontalHeader()->setSectionResizeMode(FrameTableModel::CI_Value, QHeaderView::Stretch);
-#else
-  horizontalHeader()->setResizeMode(FrameTableModel::CI_Value, QHeaderView::Stretch);
-#endif
   // Set a small height instead of hiding the header, so that the column
   // widths can still be resized by the user.
   horizontalHeader()->setFixedHeight(2);
@@ -74,44 +70,36 @@ FrameTable::FrameTable(FrameTableModel* model, GenreModel* genreModel,
     QStyle::SE_ViewItemCheckIndicator, &option, this).width();
   setColumnWidth(FrameTableModel::CI_Enable, width);
 
-#if QT_VERSION >= 0x050000
   horizontalHeader()->setSectionResizeMode(FrameTableModel::CI_Value, QHeaderView::Stretch);
-#else
-  horizontalHeader()->setResizeMode(FrameTableModel::CI_Value, QHeaderView::Stretch);
-#endif
   setItemDelegate(new FrameItemDelegate(genreModel, this));
   setEditTriggers(AllEditTriggers);
   viewport()->installEventFilter(this); // keep track of editors
   setContextMenuPolicy(Qt::CustomContextMenu);
-  connect(this, SIGNAL(customContextMenuRequested(QPoint)),
-      this, SLOT(customContextMenu(QPoint)));
+  connect(this, &QWidget::customContextMenuRequested,
+      this, &FrameTable::customContextMenu);
 }
 
-/**
- * Destructor.
- */
-FrameTable::~FrameTable() {}
-
 /**
  * Filters events if this object has been installed as an event filter
  * for the watched object.
  * This method is reimplemented to keep track of the current open editor.
  * It has to be installed on the viewport of the table.
+ * @param watched watched object
  * @param event event
  * @return true to filter event out.
  */
-bool FrameTable::eventFilter(QObject*, QEvent* event)
+bool FrameTable::eventFilter(QObject* watched, QEvent* event)
 {
   if (event) {
     QEvent::Type type = event->type();
     if (type == QEvent::ChildAdded) {
-      QObject* obj = ((QChildEvent*)event)->child();
+      QObject* obj = static_cast<QChildEvent*>(event)->child();
       if (obj && obj->isWidgetType()) {
-        m_currentEditor = (QWidget*)obj;
+        m_currentEditor = static_cast<QWidget*>(obj);
       }
     } else if (type == QEvent::ChildRemoved) {
-      if (m_currentEditor == ((QChildEvent*)event)->child()) {
-        m_currentEditor = 0;
+      if (m_currentEditor == static_cast<QChildEvent*>(event)->child()) {
+        m_currentEditor = nullptr;
       }
     } else if (type == QEvent::WindowDeactivate) {
       // this is done to avoid losing focus when the window is deactivated
@@ -122,7 +110,7 @@ bool FrameTable::eventFilter(QObject*, QEvent* event)
       }
     }
   }
-  return false;
+  return QTableView::eventFilter(watched, event);
 }
 
 /**
@@ -149,7 +137,7 @@ bool FrameTable::acceptEdit()
  */
 const QWidget* FrameTable::getCurrentEditor() const
 {
-  return state() == EditingState ? m_currentEditor : 0;
+  return state() == EditingState ? m_currentEditor : nullptr;
 }
 
 /**
@@ -161,14 +149,14 @@ const QWidget* FrameTable::getCurrentEditor() const
  */
 void FrameTable::contextMenu(int row, int col, const QPoint& pos)
 {
-  const FrameTableModel* ftModel =
+  const auto ftModel =
     qobject_cast<const FrameTableModel*>(model());
   if (ftModel && col == 0 && row >= 0) {
     QMenu menu(this);
     QAction* action = menu.addAction(tr("&Select all"));
-    connect(action, SIGNAL(triggered()), ftModel, SLOT(selectAllFrames()));
+    connect(action, &QAction::triggered, ftModel, &FrameTableModel::selectAllFrames);
     action = menu.addAction(tr("&Deselect all"));
-    connect(action, SIGNAL(triggered()), ftModel, SLOT(deselectAllFrames()));
+    connect(action, &QAction::triggered, ftModel, &FrameTableModel::deselectAllFrames);
     menu.setMouseTracking(true);
     menu.exec(pos);
   }
@@ -195,14 +183,14 @@ void FrameTable::customContextMenu(const QPoint& pos)
  */
 void FrameTable::setValueSelection(int row, int start, int length)
 {
-  if (const FrameTableModel* ftModel =
+  if (const auto ftModel =
       qobject_cast<const FrameTableModel*>(model())) {
     QModelIndex idx = ftModel->index(row, FrameTableModel::CI_Value);
     if (idx.isValid()) {
       scrollTo(idx);
       setCurrentIndex(idx);
       edit(idx);
-      if (QLineEdit* le = qobject_cast<QLineEdit*>(indexWidget(idx))) {
+      if (auto le = qobject_cast<QLineEdit*>(indexWidget(idx))) {
         le->setSelection(start, length);
       }
     }
