@@ -6,7 +6,7 @@
  * \author Urs Fleisch
  * \date 24-Aug-2010
  *
- * Copyright (C) 2010-2013  Urs Fleisch
+ * Copyright (C) 2010-2018  Urs Fleisch
  *
  * This file is part of Kid3.
  *
@@ -26,8 +26,6 @@
 
 #include "playtoolbar.h"
 
-#if defined HAVE_PHONON || QT_VERSION >= 0x050000
-
 #include <QAction>
 #include <QLCDNumber>
 #include <QHBoxLayout>
@@ -36,17 +34,15 @@
 #include <QStyle>
 #include <QLabel>
 #include <QSplitter>
-#ifdef HAVE_PHONON
-#include <phonon/mediaobject.h>
-#include <phonon/seekslider.h>
-#include <phonon/volumeslider.h>
-#else
 #include <QMediaPlaylist>
 #include <QSlider>
-#endif
 #include "audioplayer.h"
 
-static const QString zeroTime(QLatin1String(" 0:00"));
+namespace {
+
+const QString zeroTime(QLatin1String(" 0:00"));
+
+}
 
 /**
  * Constructor.
@@ -54,8 +50,8 @@ static const QString zeroTime(QLatin1String(" 0:00"));
  * @param player audio player
  * @param parent parent widget
  */
-PlayToolBar::PlayToolBar(AudioPlayer* player, QWidget* parent) :
-  QToolBar(parent), m_player(player)
+PlayToolBar::PlayToolBar(AudioPlayer* player, QWidget* parent)
+  : QToolBar(parent), m_player(player)
 {
   setObjectName(QLatin1String("Kid3Player"));
   setWindowTitle(tr("Play"));
@@ -73,19 +69,9 @@ PlayToolBar::PlayToolBar(AudioPlayer* player, QWidget* parent) :
   QAction* closeAction = new QAction(
     style()->standardIcon(QStyle::SP_TitleBarCloseButton), tr("Close"), this);
 
-  QSplitter* splitter = new QSplitter(this);
+  auto splitter = new QSplitter(this);
   m_titleLabel = new QLabel(splitter);
 
-#ifdef HAVE_PHONON
-  Phonon::MediaObject* mediaObject = m_player->mediaObject();
-  Phonon::SeekSlider* seekSlider = new Phonon::SeekSlider(splitter);
-  seekSlider->setMediaObject(mediaObject);
-  seekSlider->setSizePolicy(QSizePolicy::Fixed, QSizePolicy::Fixed);
-  seekSlider->setIconVisible(false);
-  Phonon::VolumeSlider* volumeSlider = new Phonon::VolumeSlider(this);
-  volumeSlider->setAudioOutput(m_player->audioOutput());
-  volumeSlider->setSizePolicy(QSizePolicy::Fixed, QSizePolicy::Fixed);
-#else
   QMediaPlayer* mediaPlayer = m_player->mediaPlayer();
   m_seekSlider = new QSlider(Qt::Horizontal, splitter);
   m_seekSlider->setSizePolicy(QSizePolicy::Fixed, QSizePolicy::Fixed);
@@ -95,8 +81,8 @@ PlayToolBar::PlayToolBar(AudioPlayer* player, QWidget* parent) :
   if (maximum > 0) {
     m_seekSlider->setMaximum(maximum);
   }
-  connect(m_seekSlider, SIGNAL(actionTriggered(int)),
-          this, SLOT(seekAction(int)));
+  connect(m_seekSlider, &QAbstractSlider::actionTriggered,
+          this, &PlayToolBar::seekAction);
   m_muteAction = new QAction(
         style()->standardIcon(QStyle::SP_MediaVolume), tr("Mute"), this);
   m_volumeSlider = new QSlider(Qt::Horizontal, this);
@@ -105,9 +91,8 @@ PlayToolBar::PlayToolBar(AudioPlayer* player, QWidget* parent) :
   int volume = mediaPlayer->volume();
   m_volumeSlider->setValue(volume);
   setVolumeToolTip(volume);
-  connect(m_volumeSlider, SIGNAL(actionTriggered(int)),
-          this, SLOT(volumeAction(int)));
-#endif
+  connect(m_volumeSlider, &QAbstractSlider::actionTriggered,
+          this, &PlayToolBar::volumeAction);
 
   m_timeLcd = new QLCDNumber(this);
   m_timeLcd->setSegmentStyle(QLCDNumber::Flat);
@@ -119,42 +104,34 @@ PlayToolBar::PlayToolBar(AudioPlayer* player, QWidget* parent) :
   addAction(m_previousAction);
   addAction(m_nextAction);
   addWidget(splitter);
-#ifdef HAVE_PHONON
-  addWidget(volumeSlider);
-#else
   addAction(m_muteAction);
   addWidget(m_volumeSlider);
-#endif
   addWidget(m_timeLcd);
   addAction(closeAction);
 
-#ifdef HAVE_PHONON
-  connect(mediaObject, SIGNAL(stateChanged(Phonon::State,Phonon::State)),
-          this, SLOT(stateChanged(Phonon::State)));
-#else
-  connect(mediaPlayer, SIGNAL(stateChanged(QMediaPlayer::State)),
-          this, SLOT(stateChanged(QMediaPlayer::State)));
-  connect(mediaPlayer, SIGNAL(error(QMediaPlayer::Error)),
-          this, SLOT(error(QMediaPlayer::Error)));
-  connect(mediaPlayer, SIGNAL(durationChanged(qint64)),
-          this, SLOT(durationChanged(qint64)));
-  connect(mediaPlayer, SIGNAL(volumeChanged(int)),
-          this, SLOT(setVolumeToolTip(int)));
-  connect(m_muteAction, SIGNAL(triggered()), this, SLOT(toggleMute()));
-#endif
-  connect(m_player, SIGNAL(positionChanged(qint64)), this, SLOT(tick(qint64)));
-  connect(m_player, SIGNAL(trackChanged(QString,bool,bool)),
-          this, SLOT(trackChanged(QString,bool,bool)));
-  connect(m_player, SIGNAL(aboutToPlay(QString)),
-          this, SIGNAL(aboutToPlay(QString)));
-  connect(m_playOrPauseAction, SIGNAL(triggered()),
-          m_player, SLOT(playOrPause()));
-  connect(m_stopAction, SIGNAL(triggered()), m_player, SLOT(stop()));
-  connect(m_previousAction, SIGNAL(triggered()), m_player, SLOT(previous()));
-  connect(m_nextAction, SIGNAL(triggered()), m_player, SLOT(next()));
-  connect(closeAction, SIGNAL(triggered()), this, SLOT(close()));
+  connect(mediaPlayer, &QMediaPlayer::stateChanged,
+          this, &PlayToolBar::stateChanged);
+  connect(mediaPlayer, static_cast<void (QMediaPlayer::*)(QMediaPlayer::Error)>(
+            &QMediaPlayer::error),
+          this, &PlayToolBar::error);
+  connect(mediaPlayer, &QMediaPlayer::durationChanged,
+          this, &PlayToolBar::durationChanged);
+  connect(mediaPlayer, &QMediaPlayer::volumeChanged,
+          this, &PlayToolBar::setVolumeToolTip);
+  connect(m_muteAction, &QAction::triggered, this, &PlayToolBar::toggleMute);
+  connect(m_player, &AudioPlayer::positionChanged, this, &PlayToolBar::tick);
+  connect(m_player, &AudioPlayer::trackChanged,
+          this, &PlayToolBar::trackChanged);
+  connect(m_player, &AudioPlayer::aboutToPlay,
+          this, &PlayToolBar::aboutToPlay);
+  connect(m_playOrPauseAction, &QAction::triggered,
+          m_player, &AudioPlayer::playOrPause);
+  connect(m_stopAction, &QAction::triggered, m_player, &AudioPlayer::stop);
+  connect(m_previousAction, &QAction::triggered, m_player, &AudioPlayer::previous);
+  connect(m_nextAction, &QAction::triggered, m_player, &AudioPlayer::next);
+  connect(closeAction, &QAction::triggered, this, &QWidget::close);
 
-#if defined Q_OS_MAC && QT_VERSION >= 0x050000
+#ifdef Q_OS_MAC
   setStyleSheet(QLatin1String("QToolButton { border: 0; }"));
 #endif
 }
@@ -191,49 +168,11 @@ void PlayToolBar::tick(qint64 msec)
   }
   m_timeLcd->display(QString(QLatin1String("%1:%2")).arg(minutes, 2, 10, QLatin1Char(' '))
                      .arg(seconds, 2, 10, QLatin1Char('0')));
-#ifndef HAVE_PHONON
   if (!m_seekSlider->isSliderDown()) {
     m_seekSlider->setValue(msec / 1000);
   }
-#endif
 }
 
-#ifdef HAVE_PHONON
-/**
- * Update button states when the Phonon state changed.
- *
- * @param newState new Phonon state
- */
-void PlayToolBar::stateChanged(Phonon::State newState)
-{
-  switch (newState) {
-    case Phonon::ErrorState:
-      m_playOrPauseAction->setEnabled(false);
-      m_stopAction->setEnabled(false);
-      emit errorMessage(m_player->mediaObject()->errorString());
-      break;
-    case Phonon::PlayingState:
-      m_playOrPauseAction->setEnabled(true);
-      m_playOrPauseAction->setIcon(m_pauseIcon);
-      m_stopAction->setEnabled(true);
-      break;
-    case Phonon::PausedState:
-      m_playOrPauseAction->setEnabled(true);
-      m_playOrPauseAction->setIcon(m_playIcon);
-      m_stopAction->setEnabled(true);
-      break;
-    case Phonon::StoppedState:
-      m_playOrPauseAction->setEnabled(true);
-      m_playOrPauseAction->setIcon(m_playIcon);
-      m_stopAction->setEnabled(false);
-      m_timeLcd->display(zeroTime);
-      break;
-    default:
-      m_playOrPauseAction->setEnabled(false);
-      break;
-  }
-}
-#else
 /**
  * Update button states when the Phonon state changed.
  *
@@ -329,7 +268,6 @@ void PlayToolBar::toggleMute()
   m_muteAction->setIcon(style()->standardIcon(muted
       ? QStyle::SP_MediaVolumeMuted : QStyle::SP_MediaVolume));
 }
-#endif
 
 /**
  * Update display and button state when the current track is changed.
@@ -341,14 +279,6 @@ void PlayToolBar::toggleMute()
 void  PlayToolBar::trackChanged(const QString& filePath,
                                 bool hasPrevious, bool hasNext)
 {
-#ifdef HAVE_PHONON
-  m_timeLcd->display(zeroTime);
-  QFileInfo fi(filePath);
-  m_titleLabel->setText(fi.fileName());
-
-  m_previousAction->setEnabled(hasPrevious);
-  m_nextAction->setEnabled(hasNext);
-#else
   QFileInfo fi(filePath);
   m_titleLabel->setText(fi.fileName());
 
@@ -360,7 +290,4 @@ void  PlayToolBar::trackChanged(const QString& filePath,
   if (maximum > 0) {
     m_seekSlider->setMaximum(maximum);
   }
-#endif
 }
-
-#endif // HAVE_PHONON
