@@ -6,7 +6,7 @@
  * \author Urs Fleisch
  * \date 18 Sep 2015
  *
- * Copyright (C) 2015  Urs Fleisch
+ * Copyright (C) 2015-2018  Urs Fleisch
  *
  * This file is part of Kid3.
  *
@@ -49,44 +49,37 @@ SubframesEditor::SubframesEditor(IPlatformTools* platformTools,
                                  Kid3Application* app,
                                  const TaggedFile* taggedFile,
                                  Frame::TagNumber tagNr,
-                                 QWidget* parent) :
-  QWidget(parent), m_platformTools(platformTools), m_app(app),
-  m_taggedFile(taggedFile), m_tagNr(tagNr),
-  m_editFrameDialog(0), m_editFrameRow(-1)
+                                 QWidget* parent)
+  : QWidget(parent), m_platformTools(platformTools), m_app(app),
+    m_taggedFile(taggedFile), m_tagNr(tagNr),
+    m_editFrameDialog(nullptr), m_editFrameRow(-1)
 {
   setObjectName(QLatin1String("SubframesEditor"));
-  QHBoxLayout* layout = new QHBoxLayout(this);
+  auto layout = new QHBoxLayout(this);
   m_frameTableModel = new FrameTableModel(false, this);
   m_frameTable = new FrameTable(m_frameTableModel, new GenreModel(false, this),
                                 this);
   layout->addWidget(m_frameTable);
-  QVBoxLayout* buttonLayout = new QVBoxLayout;
+  auto buttonLayout = new QVBoxLayout;
   m_editButton = new QPushButton(tr("Edit..."));
   m_editButton->setDefault(false);
   m_editButton->setAutoDefault(false);
-  connect(m_editButton, SIGNAL(clicked()), this, SLOT(onEditClicked()));
+  connect(m_editButton, &QAbstractButton::clicked, this, &SubframesEditor::onEditClicked);
   buttonLayout->addWidget(m_editButton);
   m_addButton = new QPushButton(tr("Add..."));
   m_addButton->setDefault(false);
   m_addButton->setAutoDefault(false);
-  connect(m_addButton, SIGNAL(clicked()), this, SLOT(onAddClicked()));
+  connect(m_addButton, &QAbstractButton::clicked, this, &SubframesEditor::onAddClicked);
   buttonLayout->addWidget(m_addButton);
   m_deleteButton = new QPushButton(tr("Delete"));
   m_deleteButton->setDefault(false);
   m_deleteButton->setAutoDefault(false);
-  connect(m_deleteButton, SIGNAL(clicked()), this, SLOT(onDeleteClicked()));
+  connect(m_deleteButton, &QAbstractButton::clicked, this, &SubframesEditor::onDeleteClicked);
   buttonLayout->addWidget(m_deleteButton);
   buttonLayout->addStretch();
   layout->addLayout(buttonLayout);
 }
 
-/**
- * Destructor.
- */
-SubframesEditor::~SubframesEditor()
-{
-}
-
 /**
  * Set subframes.
  * @param frames subframes, will be cleared
@@ -103,10 +96,8 @@ void SubframesEditor::setFrames(FrameCollection& frames)
 void SubframesEditor::getFrames(FrameCollection& frames) const
 {
   frames = m_frameTableModel->frames();
-  for (FrameCollection::iterator it = frames.begin();
-       it != frames.end();
-       ++it) {
-    Frame& frame = const_cast<Frame&>(*it);
+  for (auto it = frames.begin(); it != frames.end(); ++it) {
+    auto& frame = const_cast<Frame&>(*it);
     if (frame.isValueChanged()) {
       frame.setFieldListFromValue();
     }
@@ -184,8 +175,8 @@ void SubframesEditor::editFrame(const Frame& frame, int row)
   }
   if (!m_editFrameDialog) {
     m_editFrameDialog = new EditFrameFieldsDialog(m_platformTools, m_app, this);
-    connect(m_editFrameDialog, SIGNAL(finished(int)),
-            this, SLOT(onEditFrameDialogFinished(int)));
+    connect(m_editFrameDialog, &QDialog::finished,
+            this, &SubframesEditor::onEditFrameDialogFinished);
   }
   m_editFrameDialog->setWindowTitle(name);
   m_editFrameDialog->setFrame(m_editFrame, m_taggedFile, m_tagNr);
@@ -198,7 +189,7 @@ void SubframesEditor::editFrame(const Frame& frame, int row)
  */
 void SubframesEditor::onEditFrameDialogFinished(int result)
 {
-  if (EditFrameFieldsDialog* dialog =
+  if (auto dialog =
       qobject_cast<EditFrameFieldsDialog*>(sender())) {
     if (result == QDialog::Accepted) {
       const Frame::FieldList& fields = dialog->getUpdatedFieldList();
