@@ -24,8 +24,7 @@
  * along with this program.  If not, see <http://www.gnu.org/licenses/>.
  */
 
-#ifndef TABLEMODELEDIT_H
-#define TABLEMODELEDIT_H
+#pragma once
 
 #include "abstractlistedit.h"
 
@@ -43,25 +42,23 @@ public:
    * @param model item model
    * @param parent parent widget
    */
-  explicit TableModelEdit(QAbstractItemModel* model, QWidget* parent = 0);
+  explicit TableModelEdit(QAbstractItemModel* model, QWidget* parent = nullptr);
 
   /**
    * Destructor.
    */
-  virtual ~TableModelEdit();
+  virtual ~TableModelEdit() override = default;
 
   /**
    * Add a new item.
    */
-  virtual void addItem();
+  virtual void addItem() override;
 
   /**
    * Edit the selected item.
    */
-  virtual void editItem();
+  virtual void editItem() override;
 
 private:
   QTableView* m_tableView;
 };
-
-#endif // TABLEMODELEDIT_H
