@@ -6,7 +6,7 @@
  * \author Urs Fleisch
  * \date 15 Mar 2014
  *
- * Copyright (C) 2014  Urs Fleisch
+ * Copyright (C) 2014-2018  Urs Fleisch
  *
  * This file is part of Kid3.
  *
@@ -41,6 +41,7 @@
 #include <QApplication>
 #include <QClipboard>
 #include <QMimeData>
+#include <QHeaderView>
 #include "config.h"
 #include "fileconfig.h"
 #include "timeeventmodel.h"
@@ -55,16 +56,19 @@
 class TimeEventTableView : public QTableView {
 public:
   /** Constructor. */
-  TimeEventTableView(QWidget* parent = 0) : QTableView(parent) {}
+  TimeEventTableView(QWidget* parent = nullptr) : QTableView(parent) {}
   /** Destructor. */
-  virtual ~TimeEventTableView() {}
+  virtual ~TimeEventTableView() override = default;
 
 protected:
   /**
    * Handle key events, delete cell contents if Delete key is pressed.
    * @param event key event
    */
-  virtual void keyPressEvent(QKeyEvent* event);
+  virtual void keyPressEvent(QKeyEvent* event) override;
+
+private:
+  Q_DISABLE_COPY(TimeEventTableView)
 };
 
 void TimeEventTableView::keyPressEvent(QKeyEvent* event)
@@ -95,18 +99,18 @@ TimeEventEditor::TimeEventEditor(IPlatformTools* platformTools,
                                  Kid3Application* app,
                                  QWidget* parent, const Frame::Field& field,
                                  const TaggedFile* taggedFile,
-                                 Frame::TagNumber tagNr) :
-  QWidget(parent),
-  m_platformTools(platformTools), m_app(app), m_eventCodeDelegate(0),
-  m_model(0), m_taggedFile(taggedFile), m_tagNr(tagNr),
-  m_byteArray(field.m_value.toByteArray()), m_fileIsPlayed(false)
+                                 Frame::TagNumber tagNr)
+  : QWidget(parent),
+    m_platformTools(platformTools), m_app(app), m_eventCodeDelegate(nullptr),
+    m_model(nullptr), m_taggedFile(taggedFile), m_tagNr(tagNr),
+    m_byteArray(field.m_value.toByteArray()), m_fileIsPlayed(false)
 {
   setObjectName(QLatin1String("TimeEventEditor"));
-  QVBoxLayout* vlayout = new QVBoxLayout(this);
+  auto vlayout = new QVBoxLayout(this);
   m_label = new QLabel(this);
   vlayout->addWidget(m_label);
   vlayout->setContentsMargins(0, 0, 0, 0);
-  QHBoxLayout* buttonLayout = new QHBoxLayout;
+  auto buttonLayout = new QHBoxLayout;
   QPushButton* addButton = new QPushButton(tr("&Add"), this);
   addButton->setAutoDefault(false);
   QPushButton* deleteButton = new QPushButton(tr("&Delete"), this);
@@ -127,37 +131,30 @@ TimeEventEditor::TimeEventEditor(IPlatformTools* platformTools,
   buttonLayout->addWidget(exportButton);
   buttonLayout->addWidget(helpButton);
   buttonLayout->addStretch();
-  connect(addButton, SIGNAL(clicked()), this, SLOT(addItem()));
-  connect(deleteButton, SIGNAL(clicked()), this, SLOT(deleteRows()));
-  connect(clipButton, SIGNAL(clicked()), this, SLOT(clipData()));
-  connect(importButton, SIGNAL(clicked()), this, SLOT(importData()));
-  connect(exportButton, SIGNAL(clicked()), this, SLOT(exportData()));
-  connect(helpButton, SIGNAL(clicked()), this, SLOT(showHelp()));
+  connect(addButton, &QAbstractButton::clicked, this, &TimeEventEditor::addItem);
+  connect(deleteButton, &QAbstractButton::clicked, this, &TimeEventEditor::deleteRows);
+  connect(clipButton, &QAbstractButton::clicked, this, &TimeEventEditor::clipData);
+  connect(importButton, &QAbstractButton::clicked, this, &TimeEventEditor::importData);
+  connect(exportButton, &QAbstractButton::clicked, this, &TimeEventEditor::exportData);
+  connect(helpButton, &QAbstractButton::clicked, this, &TimeEventEditor::showHelp);
   vlayout->addLayout(buttonLayout);
   m_tableView = new TimeEventTableView;
   m_tableView->verticalHeader()->hide();
   m_tableView->horizontalHeader()->setStretchLastSection(true);
   m_tableView->setItemDelegateForColumn(0, new TimeStampDelegate(this));
   m_tableView->setContextMenuPolicy(Qt::CustomContextMenu);
-  connect(m_tableView, SIGNAL(customContextMenuRequested(QPoint)),
-      this, SLOT(customContextMenu(QPoint)));
+  connect(m_tableView, &QWidget::customContextMenuRequested,
+      this, &TimeEventEditor::customContextMenu);
   vlayout->addWidget(m_tableView);
 }
 
-/**
- * Destructor.
- */
-TimeEventEditor::~TimeEventEditor()
-{
-}
-
 /**
  * Connect to player when editor is shown.
  * @param event event
  */
 void TimeEventEditor::showEvent(QShowEvent* event)
 {
-  QTimer::singleShot(0, this, SLOT(preparePlayer()));
+  QTimer::singleShot(0, this, &TimeEventEditor::preparePlayer);
   QWidget::showEvent(event);
 }
 
@@ -167,11 +164,9 @@ void TimeEventEditor::showEvent(QShowEvent* event)
  */
 void TimeEventEditor::hideEvent(QHideEvent* event)
 {
-#if defined HAVE_PHONON || QT_VERSION >= 0x050000
   AudioPlayer* player = m_app->getAudioPlayer();
-  disconnect(player, 0, this, 0);
+  disconnect(player, nullptr, this, nullptr);
   m_fileIsPlayed = false;
-#endif
   QWidget::hideEvent(event);
 }
 
@@ -190,7 +185,7 @@ void TimeEventEditor::setModel(TimeEventModel* model)
     m_tableView->setItemDelegateForColumn(1, m_eventCodeDelegate);
   } else {
     m_label->setText(tr("Lyrics"));
-    m_tableView->setItemDelegateForColumn(1, 0);
+    m_tableView->setItemDelegateForColumn(1, nullptr);
   }
   m_tableView->setModel(m_model);
 }
@@ -200,19 +195,17 @@ void TimeEventEditor::setModel(TimeEventModel* model)
  */
 void TimeEventEditor::preparePlayer()
 {
-#if defined HAVE_PHONON || QT_VERSION >= 0x050000
   m_app->showAudioPlayer();
   AudioPlayer* player = m_app->getAudioPlayer();
   QString filePath = m_taggedFile->getAbsFilename();
   if (player->getFileName() != filePath) {
-    player->setFiles(QStringList() << filePath, -1);
+    player->setFiles({filePath}, -1);
   }
   m_fileIsPlayed = true;
-  connect(player, SIGNAL(trackChanged(QString,bool,bool)),
-          this, SLOT(onTrackChanged(QString)), Qt::UniqueConnection);
-  connect(player, SIGNAL(positionChanged(qint64)),
-          this, SLOT(onPositionChanged(qint64)), Qt::UniqueConnection);
-#endif
+  connect(player, &AudioPlayer::trackChanged,
+          this, &TimeEventEditor::onTrackChanged, Qt::UniqueConnection);
+  connect(player, &AudioPlayer::positionChanged,
+          this, &TimeEventEditor::onPositionChanged, Qt::UniqueConnection);
 }
 
 /**
@@ -221,23 +214,21 @@ void TimeEventEditor::preparePlayer()
 void TimeEventEditor::addItem()
 {
   QTime timeStamp;
-#if defined HAVE_PHONON || QT_VERSION >= 0x050000
   preparePlayer();
   AudioPlayer* player = m_app->getAudioPlayer();
   timeStamp = QTime(0, 0).addMSecs(player->getCurrentPosition());
-#endif
   if (m_model) {
     // If the current row is empty, set the time stamp there, else insert a new
     // row sorted by time stamps or use the first empty row.
     QModelIndex index = m_tableView->currentIndex();
     if (!(index.isValid() &&
-          (index = index.sibling(index.row(), TimeEventModel::CI_Time)).
-          data().isNull())) {
+          (index = index.sibling(index.row(), TimeEventModel::CI_Time))
+          .data().isNull())) {
       int row = 0;
       bool insertRow = true;
       while (row < m_model->rowCount()) {
-        QTime time = m_model->index(row, TimeEventModel::CI_Time).
-            data().toTime();
+        QTime time = m_model->index(row, TimeEventModel::CI_Time)
+            .data().toTime();
         if (time.isNull()) {
           insertRow = false;
           break;
@@ -278,7 +269,7 @@ void TimeEventEditor::importData()
     return;
 
   QString loadFileName = m_platformTools->getOpenFileName(this, QString(),
-        m_taggedFile->getDirname(), getLrcNameFilter(), 0);
+        m_taggedFile->getDirname(), getLrcNameFilter(), nullptr);
   if (!loadFileName.isEmpty()) {
     QFile file(loadFileName);
     if (file.open(QIODevice::ReadOnly)) {
@@ -304,7 +295,7 @@ void TimeEventEditor::exportData()
   }
   suggestedFileName += QLatin1String(".lrc");
   QString saveFileName = m_platformTools->getSaveFileName(
-        this, QString(), suggestedFileName, getLrcNameFilter(), 0);
+        this, QString(), suggestedFileName, getLrcNameFilter(), nullptr);
   if (!saveFileName.isEmpty()) {
     QFile file(saveFileName);
     if (file.open(QIODevice::WriteOnly)) {
@@ -338,12 +329,12 @@ QString TimeEventEditor::getLrcNameFilter() const
 {
   const char* const lyricsStr = QT_TRANSLATE_NOOP("@default", "Lyrics");
   const char* const allFilesStr = QT_TRANSLATE_NOOP("@default", "All Files");
-  return m_platformTools->fileDialogNameFilter(
-        QList<QPair<QString, QString> >()
-        << qMakePair(QCoreApplication::translate("@default", lyricsStr),
-                     QString(QLatin1String("*.lrc")))
-        << qMakePair(QCoreApplication::translate("@default", allFilesStr),
-                     QString(QLatin1Char('*'))));
+  return m_platformTools->fileDialogNameFilter({
+        qMakePair(QCoreApplication::translate("@default", lyricsStr),
+                  QString(QLatin1String("*.lrc"))),
+        qMakePair(QCoreApplication::translate("@default", allFilesStr),
+                  QString(QLatin1Char('*')))
+  });
 }
 
 /**
@@ -368,7 +359,8 @@ void TimeEventEditor::deleteRows()
 
   QMap<int, int> rows;
   if (QItemSelectionModel* selModel = m_tableView->selectionModel()) {
-    foreach (const QModelIndex& index, selModel->selectedIndexes()) {
+    const auto indexes = selModel->selectedIndexes();
+    for (const QModelIndex& index : indexes) {
       rows.insert(index.row(), 0);
     }
   }
@@ -393,7 +385,8 @@ void TimeEventEditor::clearCells()
                      ? QVariant::Int : QVariant::String);
   QVariant emptyTime(QVariant::Time);
   if (QItemSelectionModel* selModel = m_tableView->selectionModel()) {
-    foreach (const QModelIndex& index, selModel->selectedIndexes()) {
+    const auto indexes = selModel->selectedIndexes();
+    for (const QModelIndex& index : indexes) {
       m_model->setData(index, index.column() == TimeEventModel::CI_Time
                        ? emptyTime : emptyData);
     }
@@ -410,7 +403,8 @@ void TimeEventEditor::addOffset()
 
   int offset = QInputDialog::getInt(this, tr("Offset"), tr("Milliseconds"));
   if (QItemSelectionModel* selModel = m_tableView->selectionModel()) {
-    foreach (const QModelIndex& index, selModel->selectedIndexes()) {
+    const auto indexes = selModel->selectedIndexes();
+    for (const QModelIndex& index : indexes) {
       if (index.column() == TimeEventModel::CI_Time) {
         m_model->setData(index, index.data().toTime().addMSecs(offset));
       }
@@ -423,7 +417,6 @@ void TimeEventEditor::addOffset()
  */
 void TimeEventEditor::seekPosition()
 {
-#if defined HAVE_PHONON || QT_VERSION >= 0x050000
   QModelIndex index = m_tableView->currentIndex();
   if (index.isValid() && m_fileIsPlayed) {
     QTime timeStamp =
@@ -433,7 +426,6 @@ void TimeEventEditor::seekPosition()
       player->setCurrentPosition(QTime(0, 0).msecsTo(timeStamp));
     }
   }
-#endif
 }
 
 /**
@@ -445,17 +437,17 @@ void TimeEventEditor::customContextMenu(const QPoint& pos)
 {
   QMenu menu(this);
   QAction* action = menu.addAction(tr("&Insert row"));
-  connect(action, SIGNAL(triggered()), this, SLOT(insertRow()));
+  connect(action, &QAction::triggered, this, &TimeEventEditor::insertRow);
   QModelIndex index = m_tableView->indexAt(pos);
   if (index.isValid()) {
     action = menu.addAction(tr("&Delete rows"));
-    connect(action, SIGNAL(triggered()), this, SLOT(deleteRows()));
+    connect(action, &QAction::triggered, this, &TimeEventEditor::deleteRows);
     action = menu.addAction(tr("C&lear"));
-    connect(action, SIGNAL(triggered()), this, SLOT(clearCells()));
+    connect(action, &QAction::triggered, this, &TimeEventEditor::clearCells);
     action = menu.addAction(tr("&Add offset..."));
-    connect(action, SIGNAL(triggered()), this, SLOT(addOffset()));
+    connect(action, &QAction::triggered, this, &TimeEventEditor::addOffset);
     action = menu.addAction(tr("&Seek to position"));
-    connect(action, SIGNAL(triggered()), this, SLOT(seekPosition()));
+    connect(action, &QAction::triggered, this, &TimeEventEditor::seekPosition);
   }
   menu.setMouseTracking(true);
   menu.exec(m_tableView->mapToGlobal(pos));
