@@ -6,7 +6,7 @@
  * \author Urs Fleisch
  * \date 13 Dec 2009
  *
- * Copyright (C) 2009-2013  Urs Fleisch
+ * Copyright (C) 2009-2018  Urs Fleisch
  *
  * This file is part of Kid3.
  *
@@ -43,18 +43,13 @@ AmazonImporter::AmazonImporter(
   setObjectName(QLatin1String("AmazonImporter"));
 }
 
-/**
- * Destructor.
- */
-AmazonImporter::~AmazonImporter()
-{
-}
-
 /**
  * Name of import source.
  * @return name.
  */
-const char* AmazonImporter::name() const { return QT_TRANSLATE_NOOP("@default", "Amazon"); }
+const char* AmazonImporter::name() const {
+  return QT_TRANSLATE_NOOP("@default", "Amazon");
+}
 
 /** NULL-terminated array of server strings, 0 if not used */
 const char** AmazonImporter::serverList() const
@@ -63,7 +58,7 @@ const char** AmazonImporter::serverList() const
     // Parsing only works with English text
     "www.amazon.com",
     "www.amazon.co.uk",
-    0                  // end of StrList
+    nullptr            // end of StrList
   };
   return servers;
 }
@@ -302,9 +297,9 @@ void AmazonImporter::parseAlbumResults(const QByteArray& albumStr)
   }
   if (start >= 0) {
     QRegExp durationRe(QLatin1String("(\\d+):(\\d+)"));
-    QRegExp nrTitleRe(QLatin1String("\\s*\\d+\\.\\s+(.*\\S)"));
+    QRegExp nrTitleRe(QLatin1String(R"(\s*\d+\.\s+(.*\S))"));
     FrameCollection frames(framesHdr);
-    ImportTrackDataVector::iterator it = trackDataVector.begin();
+    auto it = trackDataVector.begin();
     bool atTrackDataListEnd = (it == trackDataVector.end());
     int trackNr = 1;
     while (start >= 0) {
@@ -398,8 +393,8 @@ void AmazonImporter::parseAlbumResults(const QByteArray& albumStr)
                                              runtimeStart);
                 if (runtimeEnd > runtimeStart &&
                     durationRe.indexIn(
-                      str.mid(runtimeStart + 1, runtimeEnd - runtimeStart - 1).
-                      remove(QLatin1Char('\n')).remove(QLatin1Char('\r')))
+                      str.mid(runtimeStart + 1, runtimeEnd - runtimeStart - 1)
+                      .remove(QLatin1Char('\n')).remove(QLatin1Char('\r')))
                     >= 0) {
                   duration = durationRe.cap(1).toInt() * 60 +
                       durationRe.cap(2).toInt();
@@ -464,9 +459,7 @@ void AmazonImporter::parseAlbumResults(const QByteArray& albumStr)
     }
   } else if (!framesHdr.empty()) {
     // if there are no track data, fill frame header data
-    for (ImportTrackDataVector::iterator it = trackDataVector.begin();
-         it != trackDataVector.end();
-         ++it) {
+    for (auto it = trackDataVector.begin(); it != trackDataVector.end(); ++it) {
       if (it->isEnabled()) {
         (*it).setFrameCollection(framesHdr);
       }
