@@ -6,7 +6,7 @@
  * \author Urs Fleisch
  * \date 13 Oct 2006
  *
- * Copyright (C) 2006-2014  Urs Fleisch
+ * Copyright (C) 2006-2018  Urs Fleisch
  *
  * This file is part of Kid3.
  *
@@ -34,7 +34,7 @@
 
 namespace {
 
-const char discogsServer[] = "www.discogs.com:80";
+const char discogsServer[] = "www.discogs.com";
 
 /**
  * Remove trailing stars and numbers like (2) from a string.
@@ -49,12 +49,12 @@ QString fixUpArtist(QString str)
   str.replace(QLatin1String("* / "), QLatin1String(" / "));
   str.replace(QLatin1String("*,"), QLatin1String(","));
   str.remove(QRegExp(QLatin1String("\\*$")));
-  str.remove(QRegExp(QLatin1String("[*\\s]*\\(\\d+\\)\\(tracks:[^)]+\\)")));
+  str.remove(QRegExp(QLatin1String(R"([*\s]*\(\d+\)\(tracks:[^)]+\))")));
   str.replace(QRegExp(
     QLatin1String("[*\\s]*\\((?:\\d+|tracks:[^)]+)\\)(\\s*/\\s*,|\\s*&amp;|"
                   "\\s*And|\\s*and)")),
     QLatin1String("\\1"));
-  str.remove(QRegExp(QLatin1String("[*\\s]*\\((?:\\d+|tracks:[^)]+)\\)$")));
+  str.remove(QRegExp(QLatin1String(R"([*\s]*\((?:\d+|tracks:[^)]+)\)$)")));
   return ServerImporter::removeHtml(str);
 }
 
@@ -97,23 +97,19 @@ bool parseCredits(const QString& str, FrameCollection& frames)
 {
   bool result = false;
   QStringList lines = str.split(QLatin1Char('\n'));
-  for (QStringList::const_iterator it = lines.begin();
-       it != lines.end();
-       ++it) {
+  for (auto it = lines.constBegin(); it != lines.constEnd(); ++it) {
     int nameStart = (*it).indexOf(QLatin1String(" - "));
     if (nameStart != -1) {
-      QStringList names = (*it).mid(nameStart + 3).split(QLatin1String(", "));
+      const QStringList names = (*it).mid(nameStart + 3).split(QLatin1String(", "));
       QString name;
-      foreach (const QString& namesPart, names) {
+      for (const QString& namesPart : names) {
         if (!name.isEmpty()) {
           name += QLatin1String(", ");
         }
         name += fixUpArtist(namesPart);
       }
       QStringList credits = (*it).left(nameStart).split(QLatin1String(", "));
-      for (QStringList::const_iterator cit = credits.begin();
-           cit != credits.end();
-           ++cit) {
+      for (auto cit = credits.constBegin(); cit != credits.constEnd(); ++cit) {
         static const struct {
           const char* credit;
           Frame::Type type;
@@ -129,11 +125,9 @@ bool parseCredits(const QString& str, FrameCollection& frames)
           { "Songwriter", Frame::FT_Composer }
         };
         bool found = false;
-        for (unsigned i = 0;
-             i < sizeof(creditToType) / sizeof(creditToType[0]);
-             ++i) {
-          if (*cit == QString::fromLatin1(creditToType[i].credit)) {
-            frames.setValue(creditToType[i].type, name);
+        for (const auto& c2t : creditToType) {
+          if (*cit == QString::fromLatin1(c2t.credit)) {
+            frames.setValue(c2t.type, name);
             found = true;
             break;
           }
@@ -155,13 +149,11 @@ bool parseCredits(const QString& str, FrameCollection& frames)
             { "Co-producer", "Producer" },
             { "Executive Producer", "Producer" }
           };
-          for (unsigned i = 0;
-               i < sizeof(creditToArrangement) / sizeof(creditToArrangement[0]);
-               ++i) {
+          for (const auto& c2a : creditToArrangement) {
             if ((*cit).startsWith(
-                  QString::fromLatin1(creditToArrangement[i].credit))) {
+                  QString::fromLatin1(c2a.credit))) {
               addInvolvedPeople(frames, Frame::FT_Arranger,
-                QString::fromLatin1(creditToArrangement[i].arrangement), name);
+                QString::fromLatin1(c2a.arrangement), name);
               found = true;
               break;
             }
@@ -179,10 +171,8 @@ bool parseCredits(const QString& str, FrameCollection& frames)
             "Clarinet", "Horn", "Cornet", "Flute", "Oboe", "Saxophone",
             "Trumpet", "Tuba", "Trombone"
           };
-          for (unsigned i = 0;
-               i < sizeof(instruments) / sizeof(instruments[0]);
-               ++i) {
-            if ((*cit).contains(QString::fromLatin1(instruments[i]))) {
+          for (auto instrument : instruments) {
+            if ((*cit).contains(QString::fromLatin1(instrument))) {
               addInvolvedPeople(frames, Frame::FT_Performer, *cit, name);
               found = true;
               break;
@@ -207,8 +197,8 @@ bool parseCredits(const QString& str, FrameCollection& frames)
  * @param trackDataModel track data to be filled with imported values
  */
 DiscogsImporter::DiscogsImporter(QNetworkAccessManager* netMgr,
-                                 TrackDataModel* trackDataModel) :
-  ServerImporter(netMgr, trackDataModel)
+                                 TrackDataModel* trackDataModel)
+  : ServerImporter(netMgr, trackDataModel)
 {
   setObjectName(QLatin1String("DiscogsImporter"));
   m_discogsHeaders["User-Agent"] =
@@ -217,13 +207,6 @@ DiscogsImporter::DiscogsImporter(QNetworkAccessManager* netMgr,
       "Safari/6533.18.5";
 }
 
-/**
- * Destructor.
- */
-DiscogsImporter::~DiscogsImporter()
-{
-}
-
 /**
  * Name of import source.
  * @return name.
@@ -346,10 +329,10 @@ void DiscogsImporter::parseAlbumResults(const QByteArray& albumStr)
     // in the Style field.
     QStringList genreList;
     static const char* const fields[] = { "Style:", "Genre:" };
-    for (unsigned i = 0; i < sizeof(fields) / sizeof(fields[0]); ++i) {
-      start = str.indexOf(QString::fromLatin1(fields[i]) + QLatin1Char('<'));
+    for (auto field : fields) {
+      start = str.indexOf(QString::fromLatin1(field) + QLatin1Char('<'));
       if (start >= 0) {
-        start += qstrlen(fields[i]); // skip field
+        start += qstrlen(field); // skip field
         end = str.indexOf(QLatin1String("</div>"), start + 1);
         if (end > start) {
           QString genreStr = str.mid(start, end - start);
@@ -367,9 +350,7 @@ void DiscogsImporter::parseAlbumResults(const QByteArray& albumStr)
       }
     }
     int genreNum = 255;
-    for (QStringList::const_iterator it = genreList.begin();
-         it != genreList.end();
-         ++it) {
+    for (auto it = genreList.constBegin(); it != genreList.constEnd(); ++it) {
       genreNum = Genres::getNumber(*it);
       if (genreNum != 255) {
         break;
@@ -469,6 +450,7 @@ void DiscogsImporter::parseAlbumResults(const QByteArray& albumStr)
     /*
      * cover art can be found in image source
      */
+    // Using a raw string literal in the next line would disturb doxygen.
     start = str.indexOf(QLatin1String("<meta property=\"og:image\" content=\""));
     if (start >= 0) {
       start += 35;
@@ -517,7 +499,7 @@ void DiscogsImporter::parseAlbumResults(const QByteArray& albumStr)
 
       FrameCollection frames(framesHdr);
       QRegExp posRe(QLatin1String(
-        "<td [^>]*class=\"tracklist_track_pos\">(\\d+)</td>"));
+        R"(<td [^>]*class="tracklist_track_pos">(\d+)</td>)"));
       QRegExp artistsRe(QLatin1String(
         "class=\"tracklist_content_multi_artist_dash\">&ndash;</span>"
         "<a href=\"/artist/[^>]+>([^<]+)</a>"));
@@ -529,8 +511,8 @@ void DiscogsImporter::parseAlbumResults(const QByteArray& albumStr)
         "<td [^>]*class=\"tracklist_track_duration\"[^>]*>(?:<meta[^>]*>)?"
         "(?:<span>)?(\\d+):(\\d+)</"));
       QRegExp indexRe(QLatin1String("<td class=\"track_index\">([^<]+)$"));
-      QRegExp rowEndRe(QLatin1String("</td>[\\s\\r\\n]*</tr>"));
-      ImportTrackDataVector::iterator it = trackDataVector.begin();
+      QRegExp rowEndRe(QLatin1String(R"(</td>[\s\r\n]*</tr>)"));
+      auto it = trackDataVector.begin();
       bool atTrackDataListEnd = (it == trackDataVector.end());
       int trackNr = 1;
       start = 0;
@@ -680,7 +662,7 @@ void DiscogsImporter::sendFindQuery(
   sendRequest(QString::fromLatin1(discogsServer),
               QString(QLatin1String("/search/?q=")) +
               encodeUrlQuery(artist + QLatin1Char(' ') + album) +
-              QLatin1String("&type=release&layout=sm"),
+              QLatin1String("&type=release&layout=sm"), QLatin1String("https"),
               m_discogsHeaders);
 }
 
@@ -701,5 +683,5 @@ void DiscogsImporter::sendTrackListQuery(
    */
   sendRequest(QString::fromLatin1(discogsServer), QLatin1Char('/') +
               QString::fromLatin1(QUrl::toPercentEncoding(cat)) +
-              QLatin1Char('/') + id, m_discogsHeaders);
+              QLatin1Char('/') + id, QLatin1String("https"), m_discogsHeaders);
 }
