@@ -6,7 +6,7 @@
  * \author Urs Fleisch
  * \date 18 Jan 2004
  *
- * Copyright (C) 2004-2013  Urs Fleisch
+ * Copyright (C) 2004-2018  Urs Fleisch
  *
  * This file is part of Kid3.
  *
@@ -31,7 +31,11 @@
 #include "config.h"
 #include "genres.h"
 
-static const char gnudbServer[] = "www.gnudb.org:80";
+namespace {
+
+const char gnudbServer[] = "www.gnudb.org:80";
+
+}
 
 /**
  * Constructor.
@@ -40,19 +44,12 @@ static const char gnudbServer[] = "www.gnudb.org:80";
  * @param trackDataModel track data to be filled with imported values
  */
 FreedbImporter::FreedbImporter(QNetworkAccessManager* netMgr,
-                               TrackDataModel *trackDataModel) :
-  ServerImporter(netMgr, trackDataModel)
+                               TrackDataModel *trackDataModel)
+  : ServerImporter(netMgr, trackDataModel)
 {
   setObjectName(QLatin1String("FreedbImporter"));
 }
 
-/**
- * Destructor.
- */
-FreedbImporter::~FreedbImporter()
-{
-}
-
 /**
  * Name of import source.
  * @return name.
@@ -76,7 +73,7 @@ const char** FreedbImporter::serverList() const
     "ru.freedb.org:80",
     "uk.freedb.org:80",
     "us.freedb.org:80",
-    0                  // end of StrList
+    nullptr      // end of StrList
   };
   return servers;
 }
@@ -114,15 +111,15 @@ Tracks: 12, total time: 49:07, year: 2002, genre: Metal<br>
     QByteArray charset(searchStr.mid(charSetPos, 5));
     isUtf8 = charset == "utf-8" || charset == "UTF-8";
   }
-  QString str = isUtf8 ? QString::fromUtf8(searchStr) :
-                         QString::fromLatin1(searchStr);
-  QRegExp titleRe(QLatin1String("<a href=\"[^\"]+/cd/[^\"]+\"><b>([^<]+)</b></a>"));
+  QString str = isUtf8 ? QString::fromUtf8(searchStr)
+                       : QString::fromLatin1(searchStr);
+  QRegExp titleRe(QLatin1String(R"(<a href="[^"]+/cd/[^"]+"><b>([^<]+)</b></a>)"));
   QRegExp catIdRe(QLatin1String("Discid: ([a-z]+)[\\s/]+([0-9a-f]+)"));
   QStringList lines = str.split(QRegExp(QLatin1String("[\\r\\n]+")));
   QString title;
   bool inEntries = false;
   m_albumListModel->clear();
-  for (QStringList::const_iterator it = lines.begin(); it != lines.end(); ++it) {
+  for (auto it = lines.constBegin(); it != lines.constEnd(); ++it) {
     if (inEntries) {
       if (titleRe.indexIn(*it) != -1) {
         title = titleRe.cap(1);
@@ -139,13 +136,15 @@ Tracks: 12, total time: 49:07, year: 2002, genre: Metal<br>
   }
 }
 
+namespace {
+
 /**
  * Parse the track durations from freedb.org.
  *
  * @param text          text buffer containing data from freedb.org
  * @param trackDuration list for results
  */
-static void parseFreedbTrackDurations(
+void parseFreedbTrackDurations(
   const QString& text,
   QList<int>& trackDuration)
 {
@@ -171,7 +170,7 @@ static void parseFreedbTrackDurations(
   if (discLenPos != -1) {
     int len = discLenRe.matchedLength();
     discLenPos += 12;
-    int discLen = text.mid(discLenPos, len - 12).toInt();
+    int discLen = text.midRef(discLenPos, len - 12).toInt();
     int trackOffsetPos = text.indexOf(QLatin1String("Track frame offsets"), 0);
     if (trackOffsetPos != -1) {
       QRegExp re(QLatin1String("#\\s*\\d+"));
@@ -180,7 +179,7 @@ static void parseFreedbTrackDurations(
              trackOffsetPos < discLenPos) {
         len = re.matchedLength();
         trackOffsetPos += 1;
-        int trackOffset = text.mid(trackOffsetPos, len - 1).toInt();
+        int trackOffset = text.midRef(trackOffsetPos, len - 1).toInt();
         if (lastOffset != -1) {
           int duration = (trackOffset - lastOffset) / 75;
           trackDuration.append(duration);
@@ -201,24 +200,25 @@ static void parseFreedbTrackDurations(
  * @param text text buffer containing data from freedb.org
  * @param frames tags to put result
  */
-static void parseFreedbAlbumData(const QString& text,
-                                 FrameCollection& frames)
+void parseFreedbAlbumData(const QString& text, FrameCollection& frames)
 {
-  QRegExp fdre(QLatin1String("DTITLE=\\s*(\\S[^\\r\\n]*\\S)\\s*/\\s*(\\S[^\\r\\n]*\\S)[\\r\\n]"));
+  QRegExp fdre(QLatin1String(R"(DTITLE=\s*(\S[^\r\n]*\S)\s*/\s*(\S[^\r\n]*\S)[\r\n])"));
   if (fdre.indexIn(text) != -1) {
     frames.setArtist(fdre.cap(1));
     frames.setAlbum(fdre.cap(2));
   }
-  fdre.setPattern(QLatin1String("EXTD=[^\\r\\n]*YEAR:\\s*(\\d+)\\D"));
+  fdre.setPattern(QLatin1String(R"(EXTD=[^\r\n]*YEAR:\s*(\d+)\D)"));
   if (fdre.indexIn(text) != -1) {
     frames.setYear(fdre.cap(1).toInt());
   }
-  fdre.setPattern(QLatin1String("EXTD=[^\\r\\n]*ID3G:\\s*(\\d+)\\D"));
+  fdre.setPattern(QLatin1String(R"(EXTD=[^\r\n]*ID3G:\s*(\d+)\D)"));
   if (fdre.indexIn(text) != -1) {
     frames.setGenre(QString::fromLatin1(Genres::getName(fdre.cap(1).toInt())));
   }
 }
 
+}
+
 /**
  * Parse result of album request and populate m_trackDataModel with results.
  *
@@ -235,14 +235,14 @@ void FreedbImporter::parseAlbumResults(const QByteArray& albumStr)
   ImportTrackDataVector trackDataVector(m_trackDataModel->getTrackData());
   trackDataVector.setCoverArtUrl(QUrl());
   FrameCollection frames(framesHdr);
-  ImportTrackDataVector::iterator it = trackDataVector.begin();
-  QList<int>::const_iterator tdit = trackDuration.begin();
+  auto it = trackDataVector.begin();
+  auto tdit = trackDuration.constBegin();
   bool atTrackDataListEnd = (it == trackDataVector.end());
   int pos = 0;
   int oldpos = pos;
   int tracknr = 0;
   for (;;) {
-    QRegExp fdre(QString(QLatin1String("TTITLE%1=([^\\r\\n]+)[\\r\\n]")).arg(tracknr));
+    QRegExp fdre(QString(QLatin1String(R"(TTITLE%1=([^\r\n]+)[\r\n])")).arg(tracknr));
     QString title;
     int idx;
     while ((idx = fdre.indexIn(text, pos)) != -1) {
@@ -255,7 +255,7 @@ void FreedbImporter::parseAlbumResults(const QByteArray& albumStr)
     } else {
       break;
     }
-    int duration = (tdit != trackDuration.end()) ?
+    int duration = (tdit != trackDuration.constEnd()) ?
       *tdit++ : 0;
     if (atTrackDataListEnd) {
       ImportTrackData trackData;
