@@ -6,7 +6,7 @@
  * \author Urs Fleisch
  * \date 26 Apr 2007
  *
- * Copyright (C) 2007-2013  Urs Fleisch
+ * Copyright (C) 2007-2018  Urs Fleisch
  *
  * This file is part of Kid3.
  *
@@ -29,7 +29,11 @@
 #include "freedbconfig.h"
 #include "config.h"
 
-static const char trackTypeServer[] = "tracktype.org:80";
+namespace {
+
+const char trackTypeServer[] = "tracktype.org:80";
+
+}
 
 /**
  * Constructor.
@@ -38,19 +42,12 @@ static const char trackTypeServer[] = "tracktype.org:80";
  * @param trackDataModel track data to be filled with imported values
  */
 TrackTypeImporter::TrackTypeImporter(QNetworkAccessManager* netMgr,
-                                     TrackDataModel *trackDataModel) :
-  FreedbImporter(netMgr, trackDataModel)
+                                     TrackDataModel *trackDataModel)
+  : FreedbImporter(netMgr, trackDataModel)
 {
   setObjectName(QLatin1String("TrackTypeImporter"));
 }
 
-/**
- * Destructor.
- */
-TrackTypeImporter::~TrackTypeImporter()
-{
-}
-
 /**
  * Name of import source.
  * @return name.
@@ -64,7 +61,7 @@ const char** TrackTypeImporter::serverList() const
 {
   static const char* servers[] = {
     "tracktype.org:80",
-    0                  // end of StrList
+    nullptr            // end of StrList
   };
   return servers;
 }
@@ -99,7 +96,7 @@ theoretically, but never seen
   QStringList lines = str.split(QRegExp(QLatin1String("[\\r\\n]+")));
   bool inEntries = false;
   m_albumListModel->clear();
-  for (QStringList::const_iterator it = lines.begin(); it != lines.end(); ++it) {
+  for (auto it = lines.constBegin(); it != lines.constEnd(); ++it) {
     if (*it == QLatin1String(".")) {
       break;
     }
