@@ -43,9 +43,11 @@
 
 /** MPEG4IP version as 16-bit hex number with major and minor version. */
 #if defined MP4V2_PROJECT_version_major && defined MP4V2_PROJECT_version_minor
-#define MPEG4IP_MAJOR_MINOR_VERSION ((MP4V2_PROJECT_version_major << 8) | MP4V2_PROJECT_version_minor)
+#define MPEG4IP_MAJOR_MINOR_VERSION ((MP4V2_PROJECT_version_major << 8) | \
+  MP4V2_PROJECT_version_minor)
 #elif defined MPEG4IP_MAJOR_VERSION && defined MPEG4IP_MINOR_VERSION
-#define MPEG4IP_MAJOR_MINOR_VERSION ((MPEG4IP_MAJOR_VERSION << 8) | MPEG4IP_MINOR_VERSION)
+#define MPEG4IP_MAJOR_MINOR_VERSION ((MPEG4IP_MAJOR_VERSION << 8) | \
+  MPEG4IP_MINOR_VERSION)
 #else
 #define MPEG4IP_MAJOR_MINOR_VERSION 0x0009
 #endif
@@ -61,25 +63,10 @@
 #define MP4TagsSetGenreID MP4TagsSetGEID
 #endif
 
-/**
- * Constructor.
- *
- * @param idx index in file proxy model
- */
-M4aFile::M4aFile(const QPersistentModelIndex& idx) :
-  TaggedFile(idx), m_fileRead(false)
-{
-}
-
-/**
- * Destructor.
- */
-M4aFile::~M4aFile()
-{
-}
+namespace {
 
 /** Mapping between frame types and field names. */
-static const struct {
+const struct {
   const char* name;
   Frame::Type type;
 } nameTypes[] = {
@@ -188,23 +175,24 @@ freeFormNameTypes[] = {
  *
  * @return field name, QString::null if not defined.
  */
-static QString getNameForType(Frame::Type type)
+QString getNameForType(Frame::Type type)
 {
   static QMap<Frame::Type, QString> typeNameMap;
   if (typeNameMap.empty()) {
     // first time initialization
-    for (unsigned i = 0; i < sizeof(nameTypes) / sizeof(nameTypes[0]); ++i) {
-      if (nameTypes[i].type != Frame::FT_Other) {
-        typeNameMap.insert(nameTypes[i].type, QString::fromLatin1(nameTypes[i].name));
+    for (const auto& nameType : nameTypes) {
+      if (nameType.type != Frame::FT_Other) {
+        typeNameMap.insert(nameType.type, QString::fromLatin1(nameType.name));
       }
     }
-    for (unsigned i = 0; i < sizeof(freeFormNameTypes) / sizeof(freeFormNameTypes[0]); ++i) {
-      typeNameMap.insert(freeFormNameTypes[i].type, QString::fromLatin1(freeFormNameTypes[i].name));
+    for (const auto& freeFormNameType : freeFormNameTypes) {
+      typeNameMap.insert(freeFormNameType.type,
+                         QString::fromLatin1(freeFormNameType.name));
     }
   }
   if (type != Frame::FT_Other) {
-    QMap<Frame::Type, QString>::const_iterator it = typeNameMap.find(type);
-    if (it != typeNameMap.end()) {
+    auto it = typeNameMap.constFind(type);
+    if (it != typeNameMap.constEnd()) {
       return *it;
     }
   }
@@ -220,19 +208,18 @@ static QString getNameForType(Frame::Type type)
  *
  * @return type, FT_Unknown or FT_Other if not predefined field.
  */
-static Frame::Type getTypeForName(const QString& name,
-                                  bool onlyPredefined = false)
+Frame::Type getTypeForName(const QString& name, bool onlyPredefined = false)
 {
   if (name.length() == 4) {
     static QMap<QString, Frame::Type> nameTypeMap;
     if (nameTypeMap.empty()) {
       // first time initialization
-      for (unsigned i = 0; i < sizeof(nameTypes) / sizeof(nameTypes[0]); ++i) {
-        nameTypeMap.insert(QString::fromLatin1(nameTypes[i].name), nameTypes[i].type);
+      for (const auto& nameType : nameTypes) {
+        nameTypeMap.insert(QString::fromLatin1(nameType.name), nameType.type);
       }
     }
-    QMap<QString, Frame::Type>::const_iterator it = nameTypeMap.find(name);
-    if (it != nameTypeMap.end()) {
+    auto it = nameTypeMap.constFind(name);
+    if (it != nameTypeMap.constEnd()) {
       return *it;
     }
   }
@@ -240,12 +227,13 @@ static Frame::Type getTypeForName(const QString& name,
     static QMap<QString, Frame::Type> freeFormNameTypeMap;
     if (freeFormNameTypeMap.empty()) {
       // first time initialization
-      for (unsigned i = 0; i < sizeof(freeFormNameTypes) / sizeof(freeFormNameTypes[0]); ++i) {
-        freeFormNameTypeMap.insert(QString::fromLatin1(freeFormNameTypes[i].name), freeFormNameTypes[i].type);
+      for (const auto& freeFormNameType : freeFormNameTypes) {
+        freeFormNameTypeMap.insert(QString::fromLatin1(freeFormNameType.name),
+                                   freeFormNameType.type);
       }
     }
-    QMap<QString, Frame::Type>::const_iterator it = freeFormNameTypeMap.find(name);
-    if (it != freeFormNameTypeMap.end()) {
+    auto it = freeFormNameTypeMap.constFind(name);
+    if (it != freeFormNameTypeMap.constEnd()) {
       return *it;
     }
     return Frame::FT_Other;
@@ -264,7 +252,7 @@ static Frame::Type getTypeForName(const QString& name,
  *
  * @return true if a free form field.
  */
-static bool isFreeFormMetadata(MP4FileHandle hFile, const char* name)
+bool isFreeFormMetadata(MP4FileHandle hFile, const char* name)
 {
   bool result = false;
   if (getTypeForName(name, true) == Frame::FT_UnknownFrame) {
@@ -289,8 +277,8 @@ static bool isFreeFormMetadata(MP4FileHandle hFile, const char* name)
  *
  * @return byte array with string representation.
  */
-static QByteArray getValueByteArray(const char* name,
-                                    const uint8_t* value, uint32_t size)
+QByteArray getValueByteArray(const char* name,
+                             const uint8_t* value, uint32_t size)
 {
   QByteArray str;
   if (name[0] == '\251') {
@@ -363,10 +351,15 @@ static QByteArray getValueByteArray(const char* name,
     }
   } else if (std::strcmp(name, "plID") == 0) {
     if (size >= 8) {
-      qulonglong val = (qulonglong)value[7] + ((qulonglong)value[6] << 8) +
-        ((qulonglong)value[5] << 16) + ((qulonglong)value[4] << 24) +
-        ((qulonglong)value[3] << 32) + ((qulonglong)value[2] << 40) +
-        ((qulonglong)value[1] << 48) + ((qulonglong)value[0] << 56);
+      qulonglong val =
+          static_cast<qulonglong>(value[7]) +
+          (static_cast<qulonglong>(value[6]) << 8) +
+          (static_cast<qulonglong>(value[5]) << 16) +
+          (static_cast<qulonglong>(value[4]) << 24) +
+          (static_cast<qulonglong>(value[3]) << 32) +
+          (static_cast<qulonglong>(value[2]) << 40) +
+          (static_cast<qulonglong>(value[1]) << 48) +
+          (static_cast<qulonglong>(value[0]) << 56);
       if (val > 0) {
         str.setNum(val);
       }
@@ -378,6 +371,18 @@ static QByteArray getValueByteArray(const char* name,
   return str;
 }
 
+}
+
+/**
+ * Constructor.
+ *
+ * @param idx index in file proxy model
+ */
+M4aFile::M4aFile(const QPersistentModelIndex& idx)
+  : TaggedFile(idx), m_fileRead(false)
+{
+}
+
 /**
  * Get key of tagged file format.
  * @return "Mp4v2Metadata".
@@ -414,7 +419,7 @@ void M4aFile::readTags(bool force)
     if (list) {
       for (uint32_t i = 0; i < list->size; ++i) {
         MP4ItmfItem& item = list->elements[i];
-        const char* key = 0;
+        const char* key = nullptr;
         if (memcmp(item.code, "----", 4) == 0) {
           // free form tagfield
           if (item.name) {
@@ -425,8 +430,11 @@ void M4aFile::readTags(bool force)
         }
         if (key) {
           QByteArray ba;
-          if (item.dataList.size > 0 && item.dataList.elements[0].value && item.dataList.elements[0].valueSize > 0) {
-            ba = getValueByteArray(key, item.dataList.elements[0].value, item.dataList.elements[0].valueSize);
+          if (item.dataList.size > 0 &&
+              item.dataList.elements[0].value &&
+              item.dataList.elements[0].valueSize > 0) {
+            ba = getValueByteArray(key, item.dataList.elements[0].value,
+                item.dataList.elements[0].valueSize);
           }
           m_metadata[QString::fromLatin1(key)] = ba;
         }
@@ -575,14 +583,13 @@ bool M4aFile::writeTags(bool force, bool* renamed, bool preserve)
       MP4MetadataDelete(handle);
 #endif
 
-      for (MetadataMap::const_iterator it = m_metadata.begin();
-           it != m_metadata.end();
-           ++it) {
+      for (auto it = m_metadata.constBegin(); it != m_metadata.constEnd(); ++it) {
         const QByteArray& value = *it;
         if (!value.isEmpty()) {
           const QString& name = it.key();
           const QByteArray& str = value;
 #if MPEG4IP_MAJOR_MINOR_VERSION >= 0x0109
+          // clazy:excludeall=qlatin1string-non-ascii
           if (name == QLatin1String("\251nam")) {
             MP4TagsSetName(tags, str);
           } else if (name == QLatin1String("\251ART")) {
@@ -629,7 +636,7 @@ bool M4aFile::writeTags(bool force, bool* renamed, bool preserve)
             MP4TagsSetCompilation(tags, &cpl);
           } else if (name == QLatin1String("covr")) {
             MP4TagArtwork artwork;
-            artwork.data = (void *)value.data();
+            artwork.data = const_cast<char*>(value.data());
             artwork.size = value.size();
             artwork.type = MP4_ART_UNDEFINED;
             MP4TagsAddArtwork(tags, &artwork);
@@ -859,7 +866,7 @@ bool M4aFile::writeTags(bool force, bool* renamed, bool preserve)
   }
 
   if (isFilenameChanged()) {
-    if (!renameFile(currentFilename(), getFilename())) {
+    if (!renameFile()) {
       return false;
     }
     markFilenameUnchanged();
@@ -903,8 +910,7 @@ void M4aFile::deleteFrames(Frame::TagNumber tagNr, const FrameFilter& flt)
     markTagChanged(Frame::Tag_2, Frame::FT_UnknownFrame);
   } else {
     bool changed = false;
-    for (MetadataMap::iterator it = m_metadata.begin();
-         it != m_metadata.end();) {
+    for (auto it = m_metadata.begin(); it != m_metadata.end();) { // clazy:exclude=detaching-member
       QString name(it.key());
       Frame::Type type = getTypeForName(name);
       if (flt.isEnabled(type, name)) {
@@ -931,8 +937,8 @@ void M4aFile::deleteFrames(Frame::TagNumber tagNr, const FrameFilter& flt)
 QString M4aFile::getTextField(const QString& name) const
 {
   if (m_fileRead) {
-    MetadataMap::const_iterator it = m_metadata.find(name);
-    if (it != m_metadata.end()) {
+    auto it = m_metadata.constFind(name);
+    if (it != m_metadata.constEnd()) {
       return QString::fromUtf8((*it).data(), (*it).size());
     }
     return QLatin1String("");
@@ -954,7 +960,7 @@ void M4aFile::setTextField(const QString& name, const QString& value,
 {
   if (m_fileRead && !value.isNull()) {
     QByteArray str = value.toUtf8();
-    MetadataMap::iterator it = m_metadata.find(name);
+    auto it = m_metadata.find(name); // clazy:exclude=detaching-member
     if (it != m_metadata.end()) {
       if (QString::fromUtf8((*it).data(), (*it).size()) != value) {
         *it = str;
@@ -1056,8 +1062,7 @@ QString M4aFile::getTagFormat(Frame::TagNumber tagNr) const
  */
 bool M4aFile::getFrame(Frame::TagNumber tagNr, Frame::Type type, Frame& frame) const
 {
-  QString name = getNameForType(type);
- if (type < Frame::FT_FirstFrame || type > Frame::FT_LastV1Frame ||
+  if (type < Frame::FT_FirstFrame || type > Frame::FT_LastV1Frame ||
       tagNr > 1)
     return false;
 
@@ -1087,7 +1092,7 @@ bool M4aFile::setFrame(Frame::TagNumber tagNr, const Frame& frame)
 {
   if (tagNr == Frame::Tag_2) {
     QString name(frame.getInternalName());
-    MetadataMap::iterator it = m_metadata.find(name);
+    auto it = m_metadata.find(name); // clazy:exclude=detaching-member
     if (it != m_metadata.end()) {
       if (frame.getType() != Frame::FT_Picture) {
         QByteArray str = frame.getValue().toUtf8();
@@ -1198,7 +1203,7 @@ bool M4aFile::deleteFrame(Frame::TagNumber tagNr, const Frame& frame)
 {
   if (tagNr == Frame::Tag_2) {
     QString name(frame.getInternalName());
-    MetadataMap::iterator it = m_metadata.find(name);
+    auto it = m_metadata.find(name); // clazy:exclude=detaching-member
     if (it != m_metadata.end()) {
       m_metadata.erase(it);
       markTagChanged(Frame::Tag_2, frame.getType());
@@ -1222,9 +1227,7 @@ void M4aFile::getAllFrames(Frame::TagNumber tagNr, FrameCollection& frames)
     frames.clear();
     QString name;
     QString value;
-    for (MetadataMap::const_iterator it = m_metadata.begin();
-         it != m_metadata.end();
-         ++it) {
+    for (auto it = m_metadata.constBegin(); it != m_metadata.constEnd(); ++it) {
       name = it.key();
       Frame::Type type = getTypeForName(name);
       if (type != Frame::FT_Picture) {
@@ -1293,8 +1296,8 @@ QStringList M4aFile::getFrameIds(Frame::TagNumber tagNr) const
   };
 
   QStringList lst;
-  for (unsigned i = 0; i < sizeof(types) / sizeof(types[0]); ++i) {
-    lst.append(Frame::ExtendedType(types[i], QLatin1String("")).
+  for (auto type : types) {
+    lst.append(Frame::ExtendedType(type, QLatin1String("")). // clazy:exclude=reserve-candidates
                getName());
   }
 #if MPEG4IP_MAJOR_MINOR_VERSION >= 0x0106
