@@ -6,7 +6,7 @@
  * \author Urs Fleisch
  * \date 25 Oct 2007
  *
- * Copyright (C) 2007-2011  Urs Fleisch
+ * Copyright (C) 2007-2018  Urs Fleisch
  *
  * This file is part of Kid3.
  *
@@ -24,8 +24,7 @@
  * along with this program.  If not, see <http://www.gnu.org/licenses/>.
  */
 
-#ifndef M4AFILE_H
-#define M4AFILE_H
+#pragma once
 
 #include "taggedfile.h"
 #include <QMap>
@@ -43,20 +42,20 @@ public:
   /**
    * Destructor.
    */
-  virtual ~M4aFile();
+  virtual ~M4aFile() override = default;
 
   /**
    * Get key of tagged file format.
    * @return "Mp4v2Metadata".
    */
-  virtual QString taggedFileKey() const;
+  virtual QString taggedFileKey() const override;
 
   /**
    * Read tags from file.
    *
    * @param force true to force reading even if tags were already read.
    */
-  virtual void readTags(bool force);
+  virtual void readTags(bool force) override;
 
   /**
    * Write tags to file and rename it if necessary.
@@ -69,14 +68,14 @@ public:
    *
    * @return true if ok, false if the file could not be written or renamed.
    */
-  virtual bool writeTags(bool force, bool* renamed, bool preserve);
+  virtual bool writeTags(bool force, bool* renamed, bool preserve) override;
 
   /**
    * Free resources allocated when calling readTags().
    *
    * @param force true to force clearing even if the tags are modified
    */
-  virtual void clearTags(bool force);
+  virtual void clearTags(bool force) override;
 
   /**
    * Remove frames.
@@ -84,7 +83,7 @@ public:
    * @param tagNr tag number
    * @param flt filter specifying which frames to remove
    */
-  virtual void deleteFrames(Frame::TagNumber tagNr, const FrameFilter& flt);
+  virtual void deleteFrames(Frame::TagNumber tagNr, const FrameFilter& flt) override;
 
   /**
    * Check if tag information has already been read.
@@ -93,7 +92,7 @@ public:
    *         false if the tags have not been read yet, in which case
    *         hasTag() does not return meaningful information.
    */
-  virtual bool isTagInformationRead() const;
+  virtual bool isTagInformationRead() const override;
 
   /**
    * Check if file has a tag.
@@ -102,14 +101,14 @@ public:
    * @return true if a V2 tag is available.
    * @see isTagInformationRead()
    */
-  virtual bool hasTag(Frame::TagNumber tagNr) const;
+  virtual bool hasTag(Frame::TagNumber tagNr) const override;
 
   /**
    * Get technical detail information.
    *
    * @param info the detail information is returned here
    */
-  virtual void getDetailInfo(DetailInfo& info) const;
+  virtual void getDetailInfo(DetailInfo& info) const override;
 
   /**
    * Get duration of file.
@@ -117,14 +116,14 @@ public:
    * @return duration in seconds,
    *         0 if unknown.
    */
-  virtual unsigned getDuration() const;
+  virtual unsigned getDuration() const override;
 
   /**
    * Get file extension including the dot.
    *
    * @return file extension ".m4a".
    */
-  virtual QString getFileExtension() const;
+  virtual QString getFileExtension() const override;
 
   /**
    * Get the format of tag.
@@ -132,7 +131,7 @@ public:
    * @param tagNr tag number
    * @return "Vorbis".
    */
-  virtual QString getTagFormat(Frame::TagNumber tagNr) const;
+  virtual QString getTagFormat(Frame::TagNumber tagNr) const override;
 
   /**
    * Get a specific frame from the tags.
@@ -143,7 +142,7 @@ public:
    *
    * @return true if ok.
    */
-  virtual bool getFrame(Frame::TagNumber tagNr, Frame::Type type, Frame& frame) const;
+  virtual bool getFrame(Frame::TagNumber tagNr, Frame::Type type, Frame& frame) const override;
 
   /**
    * Set a frame in the tags.
@@ -153,7 +152,7 @@ public:
    *
    * @return true if ok.
    */
-  virtual bool setFrame(Frame::TagNumber tagNr, const Frame& frame);
+  virtual bool setFrame(Frame::TagNumber tagNr, const Frame& frame) override;
 
   /**
    * Add a frame in the tags.
@@ -163,7 +162,7 @@ public:
    *
    * @return true if ok.
    */
-  virtual bool addFrame(Frame::TagNumber tagNr, Frame& frame);
+  virtual bool addFrame(Frame::TagNumber tagNr, Frame& frame) override;
 
   /**
    * Delete a frame from the tags.
@@ -173,7 +172,7 @@ public:
    *
    * @return true if ok.
    */
-  virtual bool deleteFrame(Frame::TagNumber tagNr, const Frame& frame);
+  virtual bool deleteFrame(Frame::TagNumber tagNr, const Frame& frame) override;
 
   /**
    * Get all frames in tag.
@@ -181,14 +180,14 @@ public:
    * @param tagNr tag number
    * @param frames frame collection to set.
    */
-  virtual void getAllFrames(Frame::TagNumber tagNr, FrameCollection& frames);
+  virtual void getAllFrames(Frame::TagNumber tagNr, FrameCollection& frames) override;
 
   /**
    * Get a list of frame IDs which can be added.
    * @param tagNr tag number
    * @return list with frame IDs.
    */
-  virtual QStringList getFrameIds(Frame::TagNumber tagNr) const;
+  virtual QStringList getFrameIds(Frame::TagNumber tagNr) const override;
 
 private:
   M4aFile(const M4aFile&);
@@ -250,5 +249,3 @@ private:
   /** Metadata. */
   MetadataMap m_metadata;
 };
-
-#endif // M4AFILE_H
