@@ -6,7 +6,7 @@
  * \author Urs Fleisch
  * \date 27 Jul 2013
  *
- * Copyright (C) 2013  Urs Fleisch
+ * Copyright (C) 2013-2018  Urs Fleisch
  *
  * This file is part of Kid3.
  *
@@ -24,8 +24,7 @@
  * along with this program.  If not, see <http://www.gnu.org/licenses/>.
  */
 
-#ifndef MP4V2METADATAPLUGIN_H
-#define MP4V2METADATAPLUGIN_H
+#pragma once
 
 #include <QObject>
 #include "itaggedfilefactory.h"
@@ -33,50 +32,48 @@
 /**
  * Mp4v2 metadata plugin.
  */
-class KID3_PLUGIN_EXPORT Mp4v2MetadataPlugin :
-    public QObject, public ITaggedFileFactory {
+class KID3_PLUGIN_EXPORT Mp4v2MetadataPlugin
+    : public QObject, public ITaggedFileFactory {
   Q_OBJECT
-#if QT_VERSION >= 0x050000
   Q_PLUGIN_METADATA(IID "net.sourceforge.kid3.ITaggedFileFactory")
-#endif
   Q_INTERFACES(ITaggedFileFactory)
 public:
   /*!
    * Constructor.
    * @param parent parent object
    */
-  explicit Mp4v2MetadataPlugin(QObject* parent = 0);
+  explicit Mp4v2MetadataPlugin(QObject* parent = nullptr);
 
   /**
    * Destructor.
    */
-  virtual ~Mp4v2MetadataPlugin();
+  virtual ~Mp4v2MetadataPlugin() override = default;
 
   /**
    * Get name of factory, the same as the QObject::objectName() of the plugin.
    * @return factory name.
    */
-  virtual QString name() const;
+  virtual QString name() const override;
 
   /**
    * Get keys of available tagged file formats.
    * @return list of keys.
    */
-  virtual QStringList taggedFileKeys() const;
+  virtual QStringList taggedFileKeys() const override;
 
   /**
    * Get features supported.
    * @param key tagged file key
    * @return bit mask with Features flags set.
    */
-  virtual int taggedFileFeatures(const QString& key) const;
+  virtual int taggedFileFeatures(const QString& key) const override;
 
   /**
    * Initialize tagged file factory.
    *
    * @param key tagged file key
    */
-  virtual void initialize(const QString& key);
+  virtual void initialize(const QString& key) override;
 
   /**
    * Create a tagged file.
@@ -93,7 +90,7 @@ public:
       const QString& key,
       const QString& fileName,
       const QPersistentModelIndex& idx,
-      int features = 0);
+      int features = 0) override;
 
   /**
    * Get a list with all extensions (e.g. ".mp3") supported by TaggedFile subclass.
@@ -102,7 +99,7 @@ public:
    *
    * @return list of file extensions.
    */
-  virtual QStringList supportedFileExtensions(const QString& key) const;
+  virtual QStringList supportedFileExtensions(const QString& key) const override;
 
   /**
    * Notify about configuration change.
@@ -110,7 +107,5 @@ public:
    *
    * @param key tagged file key
    */
-  virtual void notifyConfigurationChange(const QString& key);
+  virtual void notifyConfigurationChange(const QString& key) override;
 };
-
-#endif // MP4V2METADATAPLUGIN_H
