@@ -36,25 +36,7 @@
 #include <cmath>
 #include <QByteArray>
 
-/**
- * Constructor.
- *
- * @param idx index in file proxy model
- */
-FlacFile::FlacFile(const QPersistentModelIndex& idx) :
-  OggFile(idx), m_chain(0)
-{
-}
-
-/**
- * Destructor.
- */
-FlacFile::~FlacFile()
-{
-  if (m_chain) {
-    delete m_chain;
-  }
-}
+namespace {
 
 #ifdef HAVE_FLAC_PICTURE
 /**
@@ -63,7 +45,7 @@ FlacFile::~FlacFile()
  * @param frame frame to set
  * @param pic   picture block to get
  */
-static void getPicture(Frame& frame, const FLAC::Metadata::Picture* pic)
+void getPicture(Frame& frame, const FLAC::Metadata::Picture* pic)
 {
   QByteArray ba(reinterpret_cast<const char*>(pic->get_data()),
     pic->get_data_length());
@@ -89,7 +71,7 @@ static void getPicture(Frame& frame, const FLAC::Metadata::Picture* pic)
  *
  * @return true if ok.
  */
-static bool setPicture(const Frame& frame, FLAC::Metadata::Picture* pic)
+bool setPicture(const Frame& frame, FLAC::Metadata::Picture* pic)
 {
   Frame::TextEncoding enc;
   PictureFrame::PictureType pictureType = PictureFrame::PT_CoverFront;
@@ -111,7 +93,7 @@ static bool setPicture(const Frame& frame, FLAC::Metadata::Picture* pic)
   pic->set_description(
     reinterpret_cast<const FLAC__byte*>(
       static_cast<const char*>(description.toUtf8())));
-  const FLAC__byte* data = reinterpret_cast<const FLAC__byte*>(ba.data());
+  const auto data = reinterpret_cast<const FLAC__byte*>(ba.data());
   int dataLength = ba.size();
   if (!data || dataLength <= 0) {
     // Avoid assertion crash in FLAC__metadata_object_picture_set_data().
@@ -128,6 +110,25 @@ static bool setPicture(const Frame& frame, FLAC::Metadata::Picture* pic)
 }
 #endif // HAVE_FLAC_PICTURE
 
+}
+
+/**
+ * Constructor.
+ *
+ * @param idx index in file proxy model
+ */
+FlacFile::FlacFile(const QPersistentModelIndex& idx) : OggFile(idx)
+{
+}
+
+/**
+ * Destructor.
+ */
+FlacFile::~FlacFile()
+{
+  // Must not be inline because of forwared declared QScopedPointer.
+}
+
 /**
  * Get key of tagged file format.
  * @return "FlacMetadata".
@@ -150,9 +151,9 @@ void FlacFile::readTags(bool force)
     markTagUnchanged(Frame::Tag_2);
     m_fileRead = true;
     QByteArray fnIn = QFile::encodeName(currentFilePath());
-    readFileInfo(m_fileInfo, 0); // just to start invalid
+    readFileInfo(m_fileInfo, nullptr); // just to start invalid
     if (!m_chain) {
-      m_chain = new FLAC::Metadata::Chain;
+      m_chain.reset(new FLAC::Metadata::Chain);
     }
     if (m_chain && m_chain->is_valid()) {
       if (m_chain->read(fnIn)) {
@@ -167,7 +168,7 @@ void FlacFile::readTags(bool force)
           if (mdt == FLAC__METADATA_TYPE_STREAMINFO) {
             FLAC::Metadata::Prototype* proto = mdit.get_block();
             if (proto) {
-              FLAC::Metadata::StreamInfo* si =
+              auto si =
                 dynamic_cast<FLAC::Metadata::StreamInfo*>(proto);
               readFileInfo(m_fileInfo, si);
               delete proto;
@@ -175,7 +176,7 @@ void FlacFile::readTags(bool force)
           } else if (mdt == FLAC__METADATA_TYPE_VORBIS_COMMENT) {
             FLAC::Metadata::Prototype* proto = mdit.get_block();
             if (proto) {
-              FLAC::Metadata::VorbisComment* vc =
+              auto vc =
                 dynamic_cast<FLAC::Metadata::VorbisComment*>(proto);
               if (vc && vc->is_valid()) {
                 unsigned numComments = vc->get_num_comments();
@@ -185,12 +186,12 @@ void FlacFile::readTags(bool force)
                   if (entry.is_valid()) {
                     QString name =
                       QString::fromUtf8(entry.get_field_name(),
-                                        entry.get_field_name_length()).
-                      trimmed().toUpper();
+                                        entry.get_field_name_length())
+                        .trimmed().toUpper();
                     QString value =
                       QString::fromUtf8(entry.get_field_value(),
-                                        entry.get_field_value_length()).
-                      trimmed();
+                                        entry.get_field_value_length())
+                        .trimmed();
                     if (!value.isEmpty()) {
                       m_comments.push_back(
                         CommentField(name, value));
@@ -205,7 +206,7 @@ void FlacFile::readTags(bool force)
           else if (mdt == FLAC__METADATA_TYPE_PICTURE) {
             FLAC::Metadata::Prototype* proto = mdit.get_block();
             if (proto) {
-              FLAC::Metadata::Picture* pic =
+              auto pic =
                 dynamic_cast<FLAC::Metadata::Picture*>(proto);
               if (pic) {
                 Frame frame(Frame::FT_Picture, QLatin1String(""), QLatin1String(""), pictureNr++);
@@ -255,7 +256,7 @@ bool FlacFile::writeTags(bool force, bool* renamed, bool preserve)
 #ifdef HAVE_FLAC_PICTURE
     bool pictureSet = false;
     bool pictureRemoved = false;
-    PictureList::iterator pictureIt = m_pictures.begin();
+    auto pictureIt = m_pictures.begin(); // clazy:exclude=detaching-member
 #endif
 
     FLAC::Metadata::Chain::Status status = m_chain->status();
@@ -265,8 +266,7 @@ bool FlacFile::writeTags(bool force, bool* renamed, bool preserve)
       // empty file with flac extension. m_chain->status() will set the status
       // to FLAC__METADATA_CHAIN_STATUS_OK (!?), so we have to delete the
       // chain to avoid a crash with the next call to writeTags().
-      delete m_chain;
-      m_chain = 0;
+      m_chain.reset();
       return false;
     }
 
@@ -281,7 +281,7 @@ bool FlacFile::writeTags(bool force, bool* renamed, bool preserve)
         } else {
           FLAC::Metadata::Prototype* proto = mdit.get_block();
           if (proto) {
-            FLAC::Metadata::VorbisComment* vc =
+            auto vc =
               dynamic_cast<FLAC::Metadata::VorbisComment*>(proto);
             if (vc && vc->is_valid()) {
               setVorbisComment(vc);
@@ -296,7 +296,7 @@ bool FlacFile::writeTags(bool force, bool* renamed, bool preserve)
         if (pictureIt != m_pictures.end()) {
           FLAC::Metadata::Prototype* proto = mdit.get_block();
           if (proto) {
-            FLAC::Metadata::Picture* pic =
+            auto pic =
               dynamic_cast<FLAC::Metadata::Picture*>(proto);
             if (pic) {
               if (setPicture(*pictureIt++, pic)) {
@@ -314,7 +314,7 @@ bool FlacFile::writeTags(bool force, bool* renamed, bool preserve)
         }
       } else if (mdt == FLAC__METADATA_TYPE_PADDING) {
         if (pictureIt != m_pictures.end()) {
-          FLAC::Metadata::Picture* pic = new FLAC::Metadata::Picture;
+          auto pic = new FLAC::Metadata::Picture;
           if (setPicture(*pictureIt, pic) && mdit.set_block(pic)) {
             ++pictureIt;
             pictureSet = true;
@@ -328,7 +328,7 @@ bool FlacFile::writeTags(bool force, bool* renamed, bool preserve)
 #endif
       if (!mdit.next()) {
         if (!commentsSet) {
-          FLAC::Metadata::VorbisComment* vc = new FLAC::Metadata::VorbisComment;
+          auto vc = new FLAC::Metadata::VorbisComment;
           if (vc->is_valid()) {
             setVorbisComment(vc);
             if (mdit.insert_block_after(vc)) {
@@ -341,7 +341,7 @@ bool FlacFile::writeTags(bool force, bool* renamed, bool preserve)
         }
 #ifdef HAVE_FLAC_PICTURE
         while (pictureIt != m_pictures.end()) {
-          FLAC::Metadata::Picture* pic = new FLAC::Metadata::Picture;
+          auto pic = new FLAC::Metadata::Picture;
           if (setPicture(*pictureIt, pic) && mdit.insert_block_after(pic)) {
             pictureSet = true;
           } else {
@@ -369,7 +369,7 @@ bool FlacFile::writeTags(bool force, bool* renamed, bool preserve)
     }
   }
   if (isFilenameChanged()) {
-    if (!renameFile(currentFilename(), getFilename())) {
+    if (!renameFile()) {
       return false;
     }
     markFilenameUnchanged();
@@ -392,8 +392,7 @@ void FlacFile::clearTags(bool force)
 
   bool priorIsTagInformationRead = isTagInformationRead();
   if (m_chain) {
-    delete m_chain;
-    m_chain = 0;
+    m_chain.reset();
   }
 #ifdef HAVE_FLAC_PICTURE
   m_pictures.clear();
@@ -431,7 +430,7 @@ bool FlacFile::setFrame(Frame::TagNumber tagNr, const Frame& frame)
     if (frame.getType() == Frame::FT_Picture) {
       int index = frame.getIndex();
       if (index != -1 && index < static_cast<int>(m_pictures.size())) {
-        PictureList::iterator it = m_pictures.begin() + index;
+        auto it = m_pictures.begin() + index;
         if (it != m_pictures.end()) {
           Frame newFrame(frame);
           PictureFrame::setDescription(newFrame, frame.getValue());
@@ -463,8 +462,9 @@ bool FlacFile::addFrame(Frame::TagNumber tagNr, Frame& frame)
     if (frame.getType() == Frame::FT_Picture) {
       if (frame.getFieldList().empty()) {
         PictureFrame::setFields(
-          frame, Frame::TE_ISO8859_1, QLatin1String("JPG"), QLatin1String("image/jpeg"),
-          PictureFrame::PT_CoverFront, QLatin1String(""), QByteArray());
+              frame, Frame::TE_ISO8859_1, QLatin1String("JPG"),
+              QLatin1String("image/jpeg"), PictureFrame::PT_CoverFront,
+              QLatin1String(""), QByteArray());
       }
       PictureFrame::setDescription(frame, frame.getValue());
       frame.setIndex(m_pictures.size());
@@ -528,9 +528,7 @@ void FlacFile::getAllFrames(Frame::TagNumber tagNr, FrameCollection& frames)
   OggFile::getAllFrames(tagNr, frames);
   if (tagNr == Frame::Tag_2) {
     int i = 0;
-    for (PictureList::iterator it = m_pictures.begin();
-         it != m_pictures.end();
-         ++it) {
+    for (auto it = m_pictures.begin(); it != m_pictures.end(); ++it) { // clazy:exclude=detaching-member
       (*it).setIndex(i++);
       frames.insert(*it);
     }
@@ -559,7 +557,7 @@ void FlacFile::setVorbisComment(FLAC::Metadata::VorbisComment* vc)
   }
 #endif
   // then our comments are appended
-  CommentList::iterator it = m_comments.begin();
+  auto it = m_comments.begin(); // clazy:exclude=detaching-member
   while (it != m_comments.end()) {
     QString name((*it).getName());
     QString value((*it).getValue());
