@@ -29,14 +29,15 @@
 #include <QFile>
 #include <QDir>
 #include <QByteArray>
-#include <stdio.h>
-#include <math.h>
+#include <cstdio>
+#include <cmath>
 #ifdef HAVE_VORBIS
 #include <vorbis/vorbisfile.h>
 #include "vcedit.h"
 #endif
 #include "pictureframe.h"
 #include "tagconfig.h"
+#include "fileproxymodel.h"
 
 namespace {
 
@@ -59,7 +60,7 @@ size_t oggread(void* ptr, size_t size, size_t nmemb, void* stream)
   if (!stream || !size)
     return 0;
 
-  QIODevice* iodev = reinterpret_cast<QIODevice*>(stream);
+  auto iodev = reinterpret_cast<QIODevice*>(stream);
   qint64 len = iodev->read(reinterpret_cast<char*>(ptr), size * nmemb);
   return len / size;
 }
@@ -77,7 +78,7 @@ size_t oggwrite(const void* ptr, size_t size, size_t nmemb, void* stream)
   if (!stream || !size)
     return 0;
 
-  QIODevice* iodev = reinterpret_cast<QIODevice*>(stream);
+  auto iodev = reinterpret_cast<QIODevice*>(stream);
   qint64 len = iodev->write(reinterpret_cast<const char*>(ptr), size * nmemb);
   return len / size;
 }
@@ -91,7 +92,7 @@ size_t oggwrite(const void* ptr, size_t size, size_t nmemb, void* stream)
  */
 int oggseek(void* stream, ogg_int64_t offset, int whence)
 {
-  QIODevice* iodev = reinterpret_cast<QIODevice*>(stream);
+  auto iodev = reinterpret_cast<QIODevice*>(stream);
   if (!iodev || iodev->isSequential())
     return -1;
 
@@ -114,7 +115,7 @@ int oggseek(void* stream, ogg_int64_t offset, int whence)
  */
 int oggclose(void* stream)
 {
-  if (QIODevice* iodev = reinterpret_cast<QIODevice*>(stream)) {
+  if (auto iodev = reinterpret_cast<QIODevice*>(stream)) {
     iodev->close();
     return 0;
   }
@@ -128,7 +129,7 @@ int oggclose(void* stream)
  */
 long oggtell(void* stream)
 {
-  if (QIODevice* iodev = reinterpret_cast<QIODevice*>(stream)) {
+  if (auto iodev = reinterpret_cast<QIODevice*>(stream)) {
     return iodev->pos();
   }
   return -1;
@@ -141,15 +142,8 @@ long oggtell(void* stream)
  *
  * @param idx index in file proxy model
  */
-OggFile::OggFile(const QPersistentModelIndex& idx) :
-  TaggedFile(idx), m_fileRead(false)
-{
-}
-
-/**
- * Destructor.
- */
-OggFile::~OggFile()
+OggFile::OggFile(const QPersistentModelIndex& idx)
+  : TaggedFile(idx), m_fileRead(false)
 {
 }
 
@@ -248,13 +242,16 @@ bool OggFile::writeTags(bool force, bool* renamed, bool preserve)
   if (m_fileRead && (force || isTagChanged(Frame::Tag_2))) {
     bool writeOk = false;
     // we have to rename the original file and delete it afterwards
-    QString filename = currentFilename();
-    QString tempFilename(filename + QLatin1String("_KID3"));
-    if (!renameFile(filename, tempFilename)) {
+    const QString filename = currentFilename();
+    const QString newFilename = getFilename();
+    const QString tempFilename(filename + QLatin1String("_KID3"));
+    setFilename(tempFilename); // getFilename() will now return tempFilename
+    if (!renameFile()) {
+      setFilename(newFilename);
       return false;
     }
     QString fnIn = dirname + QDir::separator() + tempFilename;
-    QString fnOut = dirname + QDir::separator() + getFilename();
+    QString fnOut = dirname + QDir::separator() + newFilename;
     QFile fpIn(fnIn);
     if (fpIn.open(QIODevice::ReadOnly)) {
 
@@ -273,15 +270,15 @@ bool OggFile::writeTags(bool force, bool* renamed, bool preserve)
             if (vc) {
               ::vorbis_comment_clear(vc);
               ::vorbis_comment_init(vc);
-              CommentList::iterator it = m_comments.begin();
+              auto it = m_comments.begin(); // clazy:exclude=detaching-member
               while (it != m_comments.end()) {
                 QString name((*it).getName());
                 QString value((*it).getValue());
                 if (!value.isEmpty()) {
                   ::vorbis_comment_add_tag(
                     vc,
-                    const_cast<char*>(name.toLatin1().data()),
-                    const_cast<char*>((const char*)value.toUtf8().data()));
+                    name.toLatin1().data(),
+                    value.toUtf8().data());
                   ++it;
                 } else {
                   it = m_comments.erase(it);
@@ -303,21 +300,30 @@ bool OggFile::writeTags(bool force, bool* renamed, bool preserve)
         setFileTimeStamps(fnOut, actime, modtime);
       }
     }
+    const FileProxyModel* model = getFileProxyModel();
     if (!writeOk) {
       // restore old file
-      QDir(dirname).remove(getFilename());
-      renameFile(tempFilename, currentFilename());
+      if (!(model && model->remove(model->index(fnOut)))) {
+        QDir(dirname).remove(newFilename);
+      }
+      markFilenameUnchanged(); // currentFilename() will now return tempFilename
+      setFilename(newFilename); // getFilename() will now return newFilename
+      renameFile();
+      markFilenameUnchanged(); // currentFilename() will now return newFilename
       return false;
     }
     markTagUnchanged(Frame::Tag_2);
-    QDir(dirname).remove(tempFilename);
+    if (!(model && model->remove(model->index(fnIn)))) {
+      QDir(dirname).remove(tempFilename);
+    }
+    setFilename(newFilename);
     if (isFilenameChanged()) {
       markFilenameUnchanged();
       *renamed = true;
     }
   } else if (isFilenameChanged()) {
     // tags not changed, but file name
-    if (!renameFile(currentFilename(), getFilename())) {
+    if (!renameFile()) {
       return false;
     }
     markFilenameUnchanged();
@@ -348,6 +354,8 @@ bool OggFile::writeTags(bool, bool*, bool) { return false; }
 void OggFile::clearTags(bool) {}
 #endif // HAVE_VORBIS
 
+namespace {
+
 /**
  * Get name of frame from type.
  *
@@ -355,7 +363,7 @@ void OggFile::clearTags(bool) {}
  *
  * @return name.
  */
-static const char* getVorbisNameFromType(Frame::Type type)
+const char* getVorbisNameFromType(Frame::Type type)
 {
   static const char* const names[] = {
     "TITLE",           // FT_Title,
@@ -409,9 +417,7 @@ static const char* getVorbisNameFromType(Frame::Type type)
     "RATING"           // FT_Rating,
                        // FT_LastFrame = FT_Rating
   };
-  struct not_used { int array_size_check[
-      sizeof(names) / sizeof(names[0]) == Frame::FT_LastFrame + 1
-      ? 1 : -1 ]; };
+  Q_STATIC_ASSERT(sizeof(names) / sizeof(names[0]) == Frame::FT_LastFrame + 1);
   if (type == Frame::FT_Picture &&
       TagConfig::instance().pictureNameIndex() == TagConfig::VP_COVERART) {
     return "COVERART";
@@ -426,22 +432,21 @@ static const char* getVorbisNameFromType(Frame::Type type)
  *
  * @return frame type.
  */
-static Frame::Type getTypeFromVorbisName(QString name)
+Frame::Type getTypeFromVorbisName(QString name)
 {
   static QMap<QString, int> strNumMap;
   if (strNumMap.empty()) {
     // first time initialization
     for (int i = 0; i <= Frame::FT_LastFrame; ++i) {
-      Frame::Type type = static_cast<Frame::Type>(i);
+      auto type = static_cast<Frame::Type>(i);
       strNumMap.insert(QString::fromLatin1(getVorbisNameFromType(type)), type);
     }
     strNumMap.insert(QLatin1String("DESCRIPTION"), Frame::FT_Comment);
     strNumMap.insert(QLatin1String("COVERART"), Frame::FT_Picture);
     strNumMap.insert(QLatin1String("METADATA_BLOCK_PICTURE"), Frame::FT_Picture);
   }
-  QMap<QString, int>::const_iterator it =
-    strNumMap.find(name.remove(QLatin1Char('=')).toUpper());
-  if (it != strNumMap.end()) {
+  auto it = strNumMap.constFind(name.remove(QLatin1Char('=')).toUpper());
+  if (it != strNumMap.constEnd()) {
     return static_cast<Frame::Type>(*it);
   }
   return Frame::FT_Other;
@@ -454,7 +459,7 @@ static Frame::Type getTypeFromVorbisName(QString name)
  *
  * @return Vorbis key.
  */
-static QString getVorbisName(const Frame& frame)
+QString getVorbisName(const Frame& frame)
 {
   Frame::Type type = frame.getType();
   if (type <= Frame::FT_LastFrame) {
@@ -464,6 +469,8 @@ static QString getVorbisName(const Frame& frame)
   }
 }
 
+}
+
 /**
  * Remove frames.
  *
@@ -480,8 +487,7 @@ void OggFile::deleteFrames(Frame::TagNumber tagNr, const FrameFilter& flt)
     markTagChanged(Frame::Tag_2, Frame::FT_UnknownFrame);
   } else {
     bool changed = false;
-    for (OggFile::CommentList::iterator it = m_comments.begin();
-         it != m_comments.end();) {
+    for (auto it = m_comments.begin(); it != m_comments.end();) { // clazy:exclude=detaching-member
       QString name((*it).getName());
       if (flt.isEnabled(getTypeFromVorbisName(name), name)) {
         it = m_comments.erase(it);
@@ -787,9 +793,7 @@ void OggFile::getAllFrames(Frame::TagNumber tagNr, FrameCollection& frames)
     frames.clear();
     QString name;
     int i = 0;
-    for (OggFile::CommentList::const_iterator it = m_comments.begin();
-         it != m_comments.end();
-         ++it) {
+    for (auto it = m_comments.constBegin(); it != m_comments.constEnd(); ++it) {
       name = (*it).getName();
       Frame::Type type = getTypeFromVorbisName(name);
       if (type == Frame::FT_Picture) {
@@ -846,12 +850,14 @@ QStringList OggFile::getFrameIds(Frame::TagNumber tagNr) const
   };
 
   QStringList lst;
+  lst.reserve(Frame::FT_LastFrame - Frame::FT_FirstFrame + 1 +
+              sizeof(fieldNames) / sizeof(fieldNames[0]));
   for (int k = Frame::FT_FirstFrame; k <= Frame::FT_LastFrame; ++k) {
-    lst.append(Frame::ExtendedType(static_cast<Frame::Type>(k), QLatin1String("")).
-               getName());
+    lst.append(Frame::ExtendedType(static_cast<Frame::Type>(k),
+                                   QLatin1String("")).getName());
   }
-  for (unsigned i = 0; i < sizeof(fieldNames) / sizeof(fieldNames[0]); ++i) {
-    lst.append(QString::fromLatin1(fieldNames[i]));
+  for (auto fieldName : fieldNames) {
+    lst.append(QString::fromLatin1(fieldName));
   }
   return lst;
 }
@@ -872,7 +878,7 @@ bool OggFile::readFileInfo(FileInfo& info, const QString& fn) const
   QFile fp(fn);
   if (fp.open(QIODevice::ReadOnly)) {
     OggVorbis_File vf;
-    if (::ov_open_callbacks(&fp, &vf, 0, 0, ovcb) == 0) {
+    if (::ov_open_callbacks(&fp, &vf, nullptr, 0, ovcb) == 0) {
       vorbis_info* vi = ::ov_info(&vf, -1);
       if (vi) {
         info.valid = true;
