@@ -6,7 +6,7 @@
  * \author Urs Fleisch
  * \date 27 Jul 2013
  *
- * Copyright (C) 2013  Urs Fleisch
+ * Copyright (C) 2013-2018  Urs Fleisch
  *
  * This file is part of Kid3.
  *
@@ -27,11 +27,11 @@
 #include "taglibmetadataplugin.h"
 #include "taglibfile.h"
 
-#if QT_VERSION < 0x050000
-Q_EXPORT_PLUGIN2(TaglibMetadataPlugin, TaglibMetadataPlugin)
-#endif
+namespace {
 
-static const QLatin1String TAGGEDFILE_KEY("TaglibMetadata");
+const QLatin1String TAGGEDFILE_KEY("TaglibMetadata");
+
+}
 
 /*!
  * Constructor.
@@ -42,13 +42,6 @@ TaglibMetadataPlugin::TaglibMetadataPlugin(QObject* parent) : QObject(parent)
   setObjectName(QLatin1String("TaglibMetadata"));
 }
 
-/**
- * Destructor.
- */
-TaglibMetadataPlugin::~TaglibMetadataPlugin()
-{
-}
-
 /**
  * Get name of factory, the same as the QObject::objectName() of the plugin.
  * @return factory name.
@@ -64,7 +57,7 @@ QString TaglibMetadataPlugin::name() const
  */
 QStringList TaglibMetadataPlugin::taggedFileKeys() const
 {
-  return QStringList() << TAGGEDFILE_KEY;
+  return {TAGGEDFILE_KEY};
 }
 
 /**
@@ -76,15 +69,9 @@ int TaglibMetadataPlugin::taggedFileFeatures(const QString& key) const
 {
   if (key == TAGGEDFILE_KEY) {
     return TaggedFile::TF_ID3v11 | TaggedFile::TF_ID3v22 |
-#if TAGLIB_VERSION >= 0x010500
         TaggedFile::TF_OggFlac |
-#endif
-#if TAGLIB_VERSION >= 0x010700
         TaggedFile::TF_OggPictures |
-#endif
-#if TAGLIB_VERSION >= 0x010800
         TaggedFile::TF_ID3v23 |
-#endif
         TaggedFile::TF_ID3v24;
   }
   return 0;
@@ -119,49 +106,36 @@ TaggedFile* TaglibMetadataPlugin::createTaggedFile(
     const QPersistentModelIndex& idx,
     int features)
 {
-#if TAGLIB_VERSION >= 0x010800
   Q_UNUSED(features)
-#endif
   if (key == TAGGEDFILE_KEY) {
     QString ext = fileName.right(4).toLower();
     QString ext2 = ext.right(3);
-    if (((ext == QLatin1String(".mp3") || ext == QLatin1String(".mp2") || ext == QLatin1String(".aac"))
-#if TAGLIB_VERSION < 0x010800
-         && (TagConfig::instance().id3v2Version() == TagConfig::ID3v2_4_0 ||
-             (features & TaggedFile::TF_ID3v24) != 0)
-#endif
-          )
-        || ext == QLatin1String(".mpc") || ext == QLatin1String(".oga") || ext == QLatin1String(".ogg") || ext == QLatin1String("flac")
+    if (   ext == QLatin1String(".mp3") || ext == QLatin1String(".mp2")
+        || ext == QLatin1String(".aac")
+        || ext == QLatin1String(".mpc") || ext == QLatin1String(".oga")
+        || ext == QLatin1String(".ogg") || ext == QLatin1String("flac")
         || ext == QLatin1String(".spx") || ext == QLatin1String(".tta")
-#if TAGLIB_VERSION >= 0x010600
 #ifdef TAGLIB_WITH_MP4
-        || ext == QLatin1String(".m4a") || ext == QLatin1String(".m4b") || ext == QLatin1String(".m4p") || ext == QLatin1String(".mp4")
+        || ext == QLatin1String(".m4a") || ext == QLatin1String(".m4b")
+        || ext == QLatin1String(".m4p") || ext == QLatin1String(".mp4")
         || ext == QLatin1String(".m4v") || ext == QLatin1String("mp4v")
 #endif
 #ifdef TAGLIB_WITH_ASF
-        || ext == QLatin1String(".wma") || ext ==  QLatin1String(".asf")
+        || ext == QLatin1String(".wma") || ext == QLatin1String(".asf")
 #endif
-        || ext == QLatin1String(".aif") || ext ==  QLatin1String("aiff") || ext ==  QLatin1String(".wav")
-#endif
-#if TAGLIB_VERSION >= 0x010700
-        || ext == QLatin1String(".ape")
-#endif
-#if TAGLIB_VERSION >= 0x010800
-        || ext == QLatin1String(".mod") || ext == QLatin1String(".s3m") || ext2 == QLatin1String(".it")
+        || ext == QLatin1String(".aif") || ext == QLatin1String("aiff")
+        || ext == QLatin1String(".wav") || ext == QLatin1String(".ape")
+        || ext == QLatin1String(".mod") || ext == QLatin1String(".s3m")
+        || ext2 == QLatin1String(".it")
 #ifdef HAVE_TAGLIB_XM_SUPPORT
         || ext2 == QLatin1String(".xm")
 #endif
-#endif
-#if TAGLIB_VERSION >= 0x010900
         || ext == QLatin1String("opus")
-#endif
-#if TAGLIB_VERSION >= 0x010901
         || ext == QLatin1String(".dsf")
-#endif
         || ext2 == QLatin1String(".wv"))
       return new TagLibFile(idx);
   }
-  return 0;
+  return nullptr;
 }
 
 /**
@@ -175,34 +149,27 @@ QStringList
 TaglibMetadataPlugin::supportedFileExtensions(const QString& key) const
 {
   if (key == TAGGEDFILE_KEY) {
-    return QStringList() << QLatin1String(".flac") << QLatin1String(".mp3") << QLatin1String(".mpc") << QLatin1String(".oga") << QLatin1String(".ogg") <<
-      QLatin1String(".spx") << QLatin1String(".tta") << QLatin1String(".aac") << QLatin1String(".mp2") <<
-#if TAGLIB_VERSION >= 0x010600
+    return {
+      QLatin1String(".flac"), QLatin1String(".mp3"), QLatin1String(".mpc"),
+      QLatin1String(".oga"), QLatin1String(".ogg"), QLatin1String(".spx"),
+      QLatin1String(".tta"), QLatin1String(".aac"), QLatin1String(".mp2"),
 #ifdef TAGLIB_WITH_MP4
-      QLatin1String(".m4a") << QLatin1String(".m4b") << QLatin1String(".m4p") << QLatin1String(".mp4") <<
-      QLatin1String(".m4v") << QLatin1String(".mp4v") <<
+      QLatin1String(".m4a"), QLatin1String(".m4b"), QLatin1String(".m4p"),
+      QLatin1String(".mp4"), QLatin1String(".m4v"), QLatin1String(".mp4v"),
 #endif
 #ifdef TAGLIB_WITH_ASF
-      QLatin1String(".wma") << QLatin1String(".asf") <<
+      QLatin1String(".wma"), QLatin1String(".asf"),
 #endif
-      QLatin1String(".aif") << QLatin1String(".aiff") << QLatin1String(".wav") <<
-#endif
-#if TAGLIB_VERSION >= 0x010700
-      QLatin1String(".ape") <<
-#endif
-#if TAGLIB_VERSION >= 0x010800
-      QLatin1String(".mod") << QLatin1String(".s3m") << QLatin1String(".it") <<
+      QLatin1String(".aif"), QLatin1String(".aiff"), QLatin1String(".wav"),
+      QLatin1String(".ape"),
+      QLatin1String(".mod"), QLatin1String(".s3m"), QLatin1String(".it"),
 #ifdef HAVE_TAGLIB_XM_SUPPORT
-      QLatin1String(".xm") <<
+      QLatin1String(".xm"),
 #endif
-#endif
-#if TAGLIB_VERSION >= 0x010900
-      QLatin1String(".opus") <<
-#endif
-#if TAGLIB_VERSION >= 0x010901
-      QLatin1String(".dsf") <<
-#endif
-      QLatin1String(".wv");
+      QLatin1String(".opus"),
+      QLatin1String(".dsf"),
+      QLatin1String(".wv")
+    };
   }
   return QStringList();
 }
